@@ -15,14 +15,14 @@
 ***************************************************************************
 """
 
-__author__ = 'Médéric Ribreux'
-__date__ = 'March 2016'
-__copyright__ = '(C) 2016, Médéric Ribreux'
+__author__ = "Médéric Ribreux"
+__date__ = "March 2016"
+__copyright__ = "(C) 2016, Médéric Ribreux"
 
 
 def processCommand(alg, parameters, context, feedback):
     # v.in.geonames needs to use WGS84 projection
-    alg.commands.append('g.proj -c epsg=4326')
+    alg.commands.append("g.proj -c epsg=4326")
 
     # Launch the algorithm
     alg.processCommand(parameters, context, feedback)
