@@ -15,26 +15,26 @@
 ***************************************************************************
 """
 
-__author__ = 'Médéric Ribreux'
-__date__ = 'February 2016'
-__copyright__ = '(C) 2016, Médéric Ribreux'
+__author__ = "Médéric Ribreux"
+__date__ = "February 2016"
+__copyright__ = "(C) 2016, Médéric Ribreux"
 
 
 def processInputs(alg, parameters, context, feedback):
-    if 'input' in alg.exportedLayers:
+    if "input" in alg.exportedLayers:
         return
 
     # We need to use v.in.ogr instead of v.external
-    alg.loadVectorLayerFromParameter('input', parameters, context, feedback, False)
+    alg.loadVectorLayerFromParameter("input", parameters, context, feedback, False)
     alg.processInputs(parameters, context, feedback)
 
 
 def processOutputs(alg, parameters, context, feedback):
-    fileName = alg.parameterAsOutputLayer(parameters, 'output', context)
-    grassName = '{}{}'.format('output', alg.uniqueSuffix)
-    dataType = 'auto'
+    fileName = alg.parameterAsOutputLayer(parameters, "output", context)
+    grassName = "{}{}".format("output", alg.uniqueSuffix)
+    dataType = "auto"
     # if we export a graph, output type will be a line
-    if alg.parameterAsBoolean(parameters, '-l', context):
-        dataType = 'line'
+    if alg.parameterAsBoolean(parameters, "-l", context):
+        dataType = "line"
 
     alg.exportVectorLayer(grassName, fileName, dataType=dataType)
