@@ -15,30 +15,32 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'August 2012'
-__copyright__ = '(C) 2012, Victor Olaya'
+__author__ = "Victor Olaya"
+__date__ = "August 2012"
+__copyright__ = "(C) 2012, Victor Olaya"
 
 import sys
 from qgis.PyQt.QtCore import QCoreApplication
-from qgis.core import (Qgis,
-                       QgsApplication,
-                       QgsFeatureSink,
-                       QgsProcessingFeedback,
-                       QgsProcessingUtils,
-                       QgsMessageLog,
-                       QgsProcessingException,
-                       QgsProcessingFeatureSourceDefinition,
-                       QgsProcessingFeatureSource,
-                       QgsProcessingParameters,
-                       QgsProject,
-                       QgsFeatureRequest,
-                       QgsFeature,
-                       QgsExpression,
-                       QgsWkbTypes,
-                       QgsGeometry,
-                       QgsVectorLayerUtils,
-                       QgsVectorLayer)
+from qgis.core import (
+    Qgis,
+    QgsApplication,
+    QgsFeatureSink,
+    QgsProcessingFeedback,
+    QgsProcessingUtils,
+    QgsMessageLog,
+    QgsProcessingException,
+    QgsProcessingFeatureSourceDefinition,
+    QgsProcessingFeatureSource,
+    QgsProcessingParameters,
+    QgsProject,
+    QgsFeatureRequest,
+    QgsFeature,
+    QgsExpression,
+    QgsWkbTypes,
+    QgsGeometry,
+    QgsVectorLayerUtils,
+    QgsVectorLayer,
+)
 from processing.gui.Postprocessing import handleAlgorithmResults
 from processing.tools import dataobjects
 from qgis.utils import iface
@@ -62,7 +64,9 @@ def execute(alg, parameters, context=None, feedback=None, catch_exceptions=True)
             results, ok = alg.run(parameters, context, feedback)
             return ok, results
         except QgsProcessingException as e:
-            QgsMessageLog.logMessage(str(sys.exc_info()[0]), 'Processing', Qgis.Critical)
+            QgsMessageLog.logMessage(
+                str(sys.exc_info()[0]), "Processing", Qgis.MessageLevel.Critical
+            )
             if feedback is not None:
                 feedback.reportError(e.msg)
             return False, {}
@@ -71,7 +75,9 @@ def execute(alg, parameters, context=None, feedback=None, catch_exceptions=True)
         return ok, results
 
 
-def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exceptions=False):
+def execute_in_place_run(
+    alg, parameters, context=None, feedback=None, raise_exceptions=False
+):
     """Executes an algorithm modifying features in-place in the input layer.
 
     :param alg: algorithm to run
@@ -96,13 +102,18 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
 
     # Only feature based algs have sourceFlags
     try:
-        if alg.sourceFlags() & QgsProcessingFeatureSource.FlagSkipGeometryValidityChecks:
-            context.setInvalidGeometryCheck(QgsFeatureRequest.GeometryNoCheck)
+        if (
+            alg.sourceFlags()
+            & QgsProcessingFeatureSource.Flag.FlagSkipGeometryValidityChecks
+        ):
+            context.setInvalidGeometryCheck(
+                QgsFeatureRequest.InvalidGeometryCheck.GeometryNoCheck
+            )
     except AttributeError:
         pass
 
-    in_place_input_parameter_name = 'INPUT'
-    if hasattr(alg, 'inputParameterName'):
+    in_place_input_parameter_name = "INPUT"
+    if hasattr(alg, "inputParameterName"):
         in_place_input_parameter_name = alg.inputParameterName()
 
     active_layer = parameters[in_place_input_parameter_name]
@@ -129,27 +140,39 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
 
         if not active_layer.isEditable():
             if not active_layer.startEditing():
-                raise QgsProcessingException(tr("Active layer is not editable (and editing could not be turned on)."))
+                raise QgsProcessingException(
+                    tr(
+                        "Active layer is not editable (and editing could not be turned on)."
+                    )
+                )
 
         if not alg.supportInPlaceEdit(active_layer):
-            raise QgsProcessingException(tr("Selected algorithm and parameter configuration are not compatible with in-place modifications."))
+            raise QgsProcessingException(
+                tr(
+                    "Selected algorithm and parameter configuration are not compatible with in-place modifications."
+                )
+            )
     except QgsProcessingException as e:
         if raise_exceptions:
             raise e
-        QgsMessageLog.logMessage(str(sys.exc_info()[0]), 'Processing', Qgis.Critical)
+        QgsMessageLog.logMessage(
+            str(sys.exc_info()[0]), "Processing", Qgis.MessageLevel.Critical
+        )
         if feedback is not None:
-            feedback.reportError(getattr(e, 'msg', str(e)), fatalError=True)
+            feedback.reportError(getattr(e, "msg", str(e)), fatalError=True)
         return False, {}
 
     if not active_layer.selectedFeatureIds():
         active_layer.selectAll()
 
     # Make sure we are working on selected features only
-    parameters[in_place_input_parameter_name] = QgsProcessingFeatureSourceDefinition(active_layer.id(), True)
-    parameters['OUTPUT'] = 'memory:'
+    parameters[in_place_input_parameter_name] = QgsProcessingFeatureSourceDefinition(
+        active_layer.id(), True
+    )
+    parameters["OUTPUT"] = "memory:"
 
     req = QgsFeatureRequest(QgsExpression(r"$id < 0"))
-    req.setFlags(QgsFeatureRequest.NoGeometry)
+    req.setFlags(QgsFeatureRequest.Flag.NoGeometry)
     req.setSubsetOfAttributes([])
 
     # Start the execution
@@ -162,15 +185,21 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
         active_layer.beginEditCommand(alg.displayName())
 
         # Checks whether the algorithm has a processFeature method
-        if hasattr(alg, 'processFeature'):  # in-place feature editing
+        if hasattr(alg, "processFeature"):  # in-place feature editing
             # Make a clone or it will crash the second time the dialog
             # is opened and run
-            alg = alg.create({'IN_PLACE': True})
+            alg = alg.create({"IN_PLACE": True})
             if not alg.prepare(parameters, context, feedback):
-                raise QgsProcessingException(tr("Could not prepare selected algorithm."))
+                raise QgsProcessingException(
+                    tr("Could not prepare selected algorithm.")
+                )
             # Check again for compatibility after prepare
             if not alg.supportInPlaceEdit(active_layer):
-                raise QgsProcessingException(tr("Selected algorithm and parameter configuration are not compatible with in-place modifications."))
+                raise QgsProcessingException(
+                    tr(
+                        "Selected algorithm and parameter configuration are not compatible with in-place modifications."
+                    )
+                )
 
             # some algorithms have logic in outputFields/outputCrs/outputWkbType which they require to execute before
             # they can start processing features
@@ -182,7 +211,11 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
             iterator_req = QgsFeatureRequest(active_layer.selectedFeatureIds())
             iterator_req.setInvalidGeometryCheck(context.invalidGeometryCheck())
             feature_iterator = active_layer.getFeatures(iterator_req)
-            step = 100 / len(active_layer.selectedFeatureIds()) if active_layer.selectedFeatureIds() else 1
+            step = (
+                100 / len(active_layer.selectedFeatureIds())
+                if active_layer.selectedFeatureIds()
+                else 1
+            )
             current = 0
             for current, f in enumerate(feature_iterator):
                 if feedback.isCanceled():
@@ -195,7 +228,9 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
                 context.expressionContext().setFeature(input_feature)
 
                 new_features = alg.processFeature(input_feature, context, feedback)
-                new_features = QgsVectorLayerUtils.makeFeaturesCompatible(new_features, active_layer)
+                new_features = QgsVectorLayerUtils.makeFeaturesCompatible(
+                    new_features, active_layer
+                )
 
                 if len(new_features) == 0:
                     active_layer.deleteFeature(f.id())
@@ -204,7 +239,11 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
                     if not f.geometry().equals(new_f.geometry()):
                         active_layer.changeGeometry(f.id(), new_f.geometry())
                     if f.attributes() != new_f.attributes():
-                        active_layer.changeAttributeValues(f.id(), dict(zip(field_idxs, new_f.attributes())), dict(zip(field_idxs, f.attributes())))
+                        active_layer.changeAttributeValues(
+                            f.id(),
+                            dict(zip(field_idxs, new_f.attributes())),
+                            dict(zip(field_idxs, f.attributes())),
+                        )
                     new_feature_ids.append(f.id())
                 else:
                     active_layer.deleteFeature(f.id())
@@ -214,59 +253,93 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
                     # them to createFeatures to manage constraints correctly
                     features_data = []
                     for f in new_features:
-                        features_data.append(QgsVectorLayerUtils.QgsFeatureData(f.geometry(), dict(enumerate(f.attributes()))))
-                    new_features = QgsVectorLayerUtils.createFeatures(active_layer, features_data, context.expressionContext())
+                        features_data.append(
+                            QgsVectorLayerUtils.QgsFeatureData(
+                                f.geometry(), dict(enumerate(f.attributes()))
+                            )
+                        )
+                    new_features = QgsVectorLayerUtils.createFeatures(
+                        active_layer, features_data, context.expressionContext()
+                    )
                     if not active_layer.addFeatures(new_features):
-                        raise QgsProcessingException(tr("Error adding processed features back into the layer."))
+                        raise QgsProcessingException(
+                            tr("Error adding processed features back into the layer.")
+                        )
                     new_ids = {f.id() for f in active_layer.getFeatures(req)}
                     new_feature_ids += list(new_ids - old_ids)
 
                 feedback.setProgress(int((current + 1) * step))
 
-            results, ok = {'__count': current + 1}, True
+            results, ok = {"__count": current + 1}, True
 
         else:  # Traditional 'run' with delete and add features cycle
 
             # There is no way to know if some features have been skipped
             # due to invalid geometries
-            if context.invalidGeometryCheck() == QgsFeatureRequest.GeometrySkipInvalid:
+            if (
+                context.invalidGeometryCheck()
+                == QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid
+            ):
                 selected_ids = active_layer.selectedFeatureIds()
             else:
                 selected_ids = []
 
-            results, ok = alg.run(parameters, context, feedback, configuration={'IN_PLACE': True})
+            results, ok = alg.run(
+                parameters, context, feedback, configuration={"IN_PLACE": True}
+            )
 
             if ok:
-                result_layer = QgsProcessingUtils.mapLayerFromString(results['OUTPUT'], context)
+                result_layer = QgsProcessingUtils.mapLayerFromString(
+                    results["OUTPUT"], context
+                )
                 # TODO: check if features have changed before delete/add cycle
 
                 new_features = []
 
                 # Check if there are any skipped features
-                if context.invalidGeometryCheck() == QgsFeatureRequest.GeometrySkipInvalid:
-                    missing_ids = list(set(selected_ids) - set(result_layer.allFeatureIds()))
+                if (
+                    context.invalidGeometryCheck()
+                    == QgsFeatureRequest.InvalidGeometryCheck.GeometrySkipInvalid
+                ):
+                    missing_ids = list(
+                        set(selected_ids) - set(result_layer.allFeatureIds())
+                    )
                     if missing_ids:
-                        for f in active_layer.getFeatures(QgsFeatureRequest(missing_ids)):
+                        for f in active_layer.getFeatures(
+                            QgsFeatureRequest(missing_ids)
+                        ):
                             if not f.geometry().isGeosValid():
                                 new_features.append(f)
 
                 active_layer.deleteFeatures(active_layer.selectedFeatureIds())
 
-                regenerate_primary_key = result_layer.customProperty('OnConvertFormatRegeneratePrimaryKey', False)
-                sink_flags = QgsFeatureSink.SinkFlags(QgsFeatureSink.RegeneratePrimaryKey) if regenerate_primary_key \
+                regenerate_primary_key = result_layer.customProperty(
+                    "OnConvertFormatRegeneratePrimaryKey", False
+                )
+                sink_flags = (
+                    QgsFeatureSink.SinkFlags(
+                        QgsFeatureSink.SinkFlag.RegeneratePrimaryKey
+                    )
+                    if regenerate_primary_key
                     else QgsFeatureSink.SinkFlags()
+                )
 
                 for f in result_layer.getFeatures():
-                    new_features.extend(QgsVectorLayerUtils.
-                                        makeFeaturesCompatible([f], active_layer, sink_flags))
+                    new_features.extend(
+                        QgsVectorLayerUtils.makeFeaturesCompatible(
+                            [f], active_layer, sink_flags
+                        )
+                    )
 
                 # Get the new ids
                 old_ids = {f.id() for f in active_layer.getFeatures(req)}
                 if not active_layer.addFeatures(new_features):
-                    raise QgsProcessingException(tr("Error adding processed features back into the layer."))
+                    raise QgsProcessingException(
+                        tr("Error adding processed features back into the layer.")
+                    )
                 new_ids = {f.id() for f in active_layer.getFeatures(req)}
                 new_feature_ids += list(new_ids - old_ids)
-                results['__count'] = len(new_feature_ids)
+                results["__count"] = len(new_feature_ids)
 
         active_layer.endEditCommand()
 
@@ -282,9 +355,11 @@ def execute_in_place_run(alg, parameters, context=None, feedback=None, raise_exc
         active_layer.rollBack()
         if raise_exceptions:
             raise e
-        QgsMessageLog.logMessage(str(sys.exc_info()[0]), 'Processing', Qgis.Critical)
+        QgsMessageLog.logMessage(
+            str(sys.exc_info()[0]), "Processing", Qgis.MessageLevel.Critical
+        )
         if feedback is not None:
-            feedback.reportError(getattr(e, 'msg', str(e)), fatalError=True)
+            feedback.reportError(getattr(e, "msg", str(e)), fatalError=True)
 
     return False, {}
 
@@ -312,19 +387,35 @@ def execute_in_place(alg, parameters, context=None, feedback=None):
     if context is None:
         context = dataobjects.createContext(feedback)
 
-    in_place_input_parameter_name = 'INPUT'
-    if hasattr(alg, 'inputParameterName'):
+    in_place_input_parameter_name = "INPUT"
+    if hasattr(alg, "inputParameterName"):
         in_place_input_parameter_name = alg.inputParameterName()
-    in_place_input_layer_name = 'INPUT'
-    if hasattr(alg, 'inputParameterDescription'):
+    in_place_input_layer_name = "INPUT"
+    if hasattr(alg, "inputParameterDescription"):
         in_place_input_layer_name = alg.inputParameterDescription()
 
-    if in_place_input_parameter_name not in parameters or not parameters[in_place_input_parameter_name]:
+    if (
+        in_place_input_parameter_name not in parameters
+        or not parameters[in_place_input_parameter_name]
+    ):
         parameters[in_place_input_parameter_name] = iface.activeLayer()
-    ok, results = execute_in_place_run(alg, parameters, context=context, feedback=feedback)
+    ok, results = execute_in_place_run(
+        alg, parameters, context=context, feedback=feedback
+    )
     if ok:
-        if isinstance(parameters[in_place_input_parameter_name], QgsProcessingFeatureSourceDefinition):
-            layer = alg.parameterAsVectorLayer({in_place_input_parameter_name: parameters[in_place_input_parameter_name].source}, in_place_input_layer_name, context)
+        if isinstance(
+            parameters[in_place_input_parameter_name],
+            QgsProcessingFeatureSourceDefinition,
+        ):
+            layer = alg.parameterAsVectorLayer(
+                {
+                    in_place_input_parameter_name: parameters[
+                        in_place_input_parameter_name
+                    ].source
+                },
+                in_place_input_layer_name,
+                context,
+            )
         elif isinstance(parameters[in_place_input_parameter_name], QgsVectorLayer):
             layer = parameters[in_place_input_parameter_name]
         if layer:
@@ -338,7 +429,9 @@ def executeIterating(alg, parameters, paramToIter, context, feedback):
     if not parameter_definition:
         return False
 
-    iter_source = QgsProcessingParameters.parameterAsSource(parameter_definition, parameters, context)
+    iter_source = QgsProcessingParameters.parameterAsSource(
+        parameter_definition, parameters, context
+    )
     sink_list = []
     if iter_source.featureCount() == 0:
         return False
@@ -348,9 +441,15 @@ def executeIterating(alg, parameters, paramToIter, context, feedback):
         if feedback.isCanceled():
             return False
 
-        sink, sink_id = QgsProcessingUtils.createFeatureSink('memory:', context, iter_source.fields(), iter_source.wkbType(), iter_source.sourceCrs())
+        sink, sink_id = QgsProcessingUtils.createFeatureSink(
+            "memory:",
+            context,
+            iter_source.fields(),
+            iter_source.wkbType(),
+            iter_source.sourceCrs(),
+        )
         sink_list.append(sink_id)
-        sink.addFeature(feat, QgsFeatureSink.FastInsert)
+        sink.addFeature(feat, QgsFeatureSink.Flag.FastInsert)
         del sink
 
         feedback.setProgress(int((current + 1) * step))
@@ -366,14 +465,23 @@ def executeIterating(alg, parameters, paramToIter, context, feedback):
         if feedback.isCanceled():
             return False
 
+        # clear any model result stored in the last iteration
+        context.clearModelResult()
+
         parameters[paramToIter] = f
         for out in alg.destinationParameterDefinitions():
             if out.name() not in outputs:
                 continue
 
             o = outputs[out.name()]
-            parameters[out.name()] = QgsProcessingUtils.generateIteratingDestination(o, i, context)
-        feedback.setProgressText(QCoreApplication.translate('AlgorithmExecutor', 'Executing iteration {0}/{1}…').format(i + 1, len(sink_list)))
+            parameters[out.name()] = QgsProcessingUtils.generateIteratingDestination(
+                o, i, context
+            )
+        feedback.setProgressText(
+            QCoreApplication.translate(
+                "AlgorithmExecutor", "Executing iteration {0}/{1}…"
+            ).format(i + 1, len(sink_list))
+        )
         feedback.setProgress(int((i + 1) * 100 / len(sink_list)))
         ret, results = execute(alg, parameters, context, feedback)
         if not ret:
@@ -383,7 +491,7 @@ def executeIterating(alg, parameters, paramToIter, context, feedback):
     return True
 
 
-def tr(string, context=''):
-    if context == '':
-        context = 'AlgorithmExecutor'
+def tr(string, context=""):
+    if context == "":
+        context = "AlgorithmExecutor"
     return QCoreApplication.translate(context, string)
