@@ -31,14 +31,23 @@ cppcheck --library=qt.cfg --inline-suppr \
          -DSIP_INOUT= \
          -DSIP_OUT= \
          -DSIP_FACTORY= \
+         -DSIP_PYNAME= \
          -DSIP_THROW= \
+         -DFINAL="final" \
          -DCMAKE_SOURCE_DIR="/foo/bar" \
          -DQ_NOWARN_DEPRECATED_PUSH= \
          -DQ_NOWARN_DEPRECATED_POP= \
+         -DQ_NOWARN_UNREACHABLE_PUSH= \
+         -DQ_NOWARN_UNREACHABLE_POP= \
          -DQ_DECLARE_OPAQUE_POINTER= \
          -DQGIS_PROTECT_QOBJECT_THREAD_ACCESS = \
          -DQ_DECLARE_SQLDRIVER_PRIVATE = \
          -DSIP_MONKEYPATCH_SCOPEENUM_UNNEST = \
+         -DSIP_ENUM_BASETYPE = \
+         -DQT3D_FUNCTOR = \
+         -DQgsSetCPLHTTPFetchOverriderInitiatorClass = \
+         -DQgsSetRequestInitiatorClass = \
+         -DBUILTIN_UNREACHABLE="__builtin_unreachable();" \
          -i src/analysis/georeferencing/qgsgcptransformer.cpp \
          -j $(nproc) \
          ${SCRIPT_DIR}/../src \
@@ -60,7 +69,7 @@ ret_code=0
 cat ${LOG_FILE} | grep -v -e "syntaxError," -e "cppcheckError," > ${LOG_FILE}.tmp
 mv ${LOG_FILE}.tmp ${LOG_FILE}
 
-ERROR_CATEGORIES=("clarifyCalculation" "duplicateExpressionTernary" "redundantCondition" "postfixOperator" "functionConst" "unsignedLessThanZero" "duplicateBranch")
+ERROR_CATEGORIES=("clarifyCalculation" "duplicateExpressionTernary" "redundantCondition" "postfixOperator" "functionConst" "unsignedLessThanZero" "duplicateBranch" "missingOverride")
 
 # unusedPrivateFunction not reliable enough in cppcheck 1.72 of Ubuntu 16.04
 if test "$(cppcheck --version)" != "Cppcheck 1.72"; then
