@@ -1,8 +1,11 @@
-from libfuturize.fixes.fix_print_with_import import FixPrintWithImport as FixPrintWithImportOrig
-from lib2to3.fixer_util import Node, Leaf, syms, find_indentation
-
 import re
 
+from lib2to3.fixer_util import Leaf, Node, find_indentation, syms
+
+from libfuturize.fixes.fix_print_with_import import (
+    FixPrintWithImport as FixPrintWithImportOrig,
+)
+
 
 class FixPrintWithImport(FixPrintWithImportOrig):
 
@@ -10,7 +13,7 @@ class FixPrintWithImport(FixPrintWithImportOrig):
         if "fix_print_with_import" in node.prefix:
             return node
 
-        r = super(FixPrintWithImport, self).transform(node, results)
+        r = super().transform(node, results)
 
         if not r or r == node:
             return r
@@ -19,6 +22,6 @@ class FixPrintWithImport(FixPrintWithImportOrig):
             indentation = find_indentation(node)
             r.prefix = "# fix_print_with_import\n" + indentation
         else:
-            r.prefix = re.sub('([ \t]*$)', r'\1# fix_print_with_import\n\1', r.prefix)
+            r.prefix = re.sub("([ \t]*$)", r"\1# fix_print_with_import\n\1", r.prefix)
 
         return r
