@@ -25,25 +25,19 @@
 
 #include "qgscoordinatereferencesystem.h"
 #include "qgsmaplayerref.h"
-#include "qgsmesh3dsymbol.h"
 #include "qgsphongmaterialsettings.h"
-#include "qgspointlightsettings.h"
-#include "qgsdirectionallightsettings.h"
 #include "qgsterraingenerator.h"
 #include "qgsvector3d.h"
 #include "qgs3daxissettings.h"
 #include "qgsskyboxsettings.h"
 #include "qgsshadowsettings.h"
-#include "qgscameracontroller.h"
 #include "qgstemporalrangeobject.h"
 #include "qgsambientocclusionsettings.h"
 
 class QgsMapLayer;
 class QgsRasterLayer;
-
+class QgsLightSource;
 class QgsAbstract3DRenderer;
-
-
 class QgsReadWriteContext;
 class QgsProject;
 
@@ -53,15 +47,15 @@ class QDomElement;
  * \ingroup 3d
  * \brief Definition of the world.
  *
- * \since QGIS 3.0
+ * \warning Qgs3DMapSettings are a QObject subclass, and accordingly are not
+ * safe for access across different threads. See Qgs3DRenderContext instead
+ * for a safe snapshot of settings from Qgs3DMapSettings.
  */
 class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObject
 {
     Q_OBJECT
   public:
-    //! Constructor for Qgs3DMapSettings
     Qgs3DMapSettings();
-    //! Copy constructor
     Qgs3DMapSettings( const Qgs3DMapSettings &other );
     ~Qgs3DMapSettings() override;
 
@@ -74,6 +68,25 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
     //! Resolves references to other objects (map layers) after the call to readXml()
     void resolveReferences( const QgsProject &project );
 
+    /**
+     * Returns the 3D scene's 2D extent in the 3D scene's CRS
+     *
+     * \see crs()
+     * \since QGIS 3.30
+     */
+    QgsRectangle extent() const;
+
+    /**
+     * Sets the 3D scene's 2D \a extent in the 3D scene's CRS, while also setting the scene's origin to the extent's center
+     * This needs to be called during initialization, as terrain will only be generated
+     * within this extent and layer 3D data will only be loaded within this extent too.
+     *
+     * \see setOrigin()
+     * \see setCrs()
+     * \since QGIS 3.30
+     */
+    void setExtent( const QgsRectangle &extent );
+
     /**
      * Sets coordinates in map CRS at which our 3D world has origin (0,0,0)
      *
@@ -84,20 +97,36 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      *
      * Need to look into more advanced techniques like "relative to center" or "relative to eye"
      * to improve the precision.
+     *
+     * \see origin()
      */
-    void setOrigin( const QgsVector3D &origin ) { mOrigin = origin; }
-    //! Returns coordinates in map CRS at which 3D scene has origin (0,0,0)
-    QgsVector3D origin() const { return mOrigin; }
+    void setOrigin( const QgsVector3D &origin );
+
+    /**
+     * Returns coordinates in map CRS at which 3D scene has origin (0,0,0).
+     *
+     * \see setOrigin()
+     */
+    QgsVector3D origin() const;
 
     //! Converts map coordinates to 3D world coordinates (applies offset and turns (x,y,z) into (x,-z,y))
     QgsVector3D mapToWorldCoordinates( const QgsVector3D &mapCoords ) const;
     //! Converts 3D world coordinates to map coordinates (applies offset and turns (x,y,z) into (x,-z,y))
     QgsVector3D worldToMapCoordinates( const QgsVector3D &worldCoords ) const;
 
-    //! Sets coordinate reference system used in the 3D scene
+    /**
+     * Sets coordinate reference system used in the 3D scene.
+     *
+     * \see crs()
+     */
     void setCrs( const QgsCoordinateReferenceSystem &crs );
-    //! Returns coordinate reference system used in the 3D scene
-    QgsCoordinateReferenceSystem crs() const { return mCrs; }
+
+    /**
+     * Returns coordinate reference system used in the 3D scene.
+     *
+     * \see setCrs()
+     */
+    QgsCoordinateReferenceSystem crs() const;
 
     /**
      * Returns the coordinate transform context, which stores various
@@ -122,18 +151,16 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * during rendering operations, e.g. for resolving relative symbol paths.
      *
      * \see setPathResolver()
-     * \since QGIS 3.0
      */
-    const QgsPathResolver &pathResolver() const { return mPathResolver; }
+    const QgsPathResolver &pathResolver() const;
 
     /**
      * Sets the path \a resolver for conversion between relative and absolute paths
      * during rendering operations, e.g. for resolving relative symbol paths.
      *
      * \see pathResolver()
-     * \since QGIS 3.0
      */
-    void setPathResolver( const QgsPathResolver &resolver ) { mPathResolver = resolver; }
+    void setPathResolver( const QgsPathResolver &resolver );
 
     /**
      * Returns pointer to the collection of map themes. Normally this would be QgsProject::mapThemeCollection()
@@ -141,14 +168,14 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * to resolve map themes from their names.
      * \since QGIS 3.6
      */
-    QgsMapThemeCollection *mapThemeCollection() const { return mMapThemes; }
+    QgsMapThemeCollection *mapThemeCollection() const;
 
     /**
      * Sets pointer to the collection of map themes.
      * \see mapThemeCollection()
      * \since QGIS 3.6
      */
-    void setMapThemeCollection( QgsMapThemeCollection *mapThemes ) { mMapThemes = mapThemes; }
+    void setMapThemeCollection( QgsMapThemeCollection *mapThemes );
 
     //! Sets background color of the 3D map view
     void setBackgroundColor( const QColor &color );
@@ -250,10 +277,10 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
     /**
      * Returns the elevation offset of the terrain (used to move the terrain up or down)
      */
-    float terrainElevationOffset() const { return mTerrainElevationOffset; }
+    float terrainElevationOffset() const;
 
     /**
-     * Sets terrain generator.
+     * Sets terrain generator and sets extent() as the generator's extent.
      *
      * It takes care of producing terrain tiles from the input data.
      * Takes ownership of the generator.
@@ -262,6 +289,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      *
      * \see terrainGenerator()
      * \see setTerrainRenderingEnabled()
+     * \see setExtent()
      */
     void setTerrainGenerator( QgsTerrainGenerator *gen SIP_TRANSFER ) SIP_SKIP;
 
@@ -275,10 +303,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \see setTerrainGenerator()
      * \see terrainRenderingEnabled()
      */
-    QgsTerrainGenerator *terrainGenerator() const SIP_SKIP
-    {
-      return mTerrainGenerator.get();
-    }
+    QgsTerrainGenerator *terrainGenerator() const SIP_SKIP;
 
     /**
      * Sets whether terrain shading is enabled.
@@ -293,7 +318,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * terrain normals and terrain shading material (ambient and specular colors, shininess).
      * \since QGIS 3.6
      */
-    bool isTerrainShadingEnabled() const { return mTerrainShadingEnabled; }
+    bool isTerrainShadingEnabled() const;
 
     /**
      * Sets terrain shading material.
@@ -307,7 +332,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * is provided by 2D rendered map texture. Only used when isTerrainShadingEnabled() is TRUE.
      * \since QGIS 3.6
      */
-    QgsPhongMaterialSettings terrainShadingMaterial() const { return mTerrainShadingMaterial; }
+    QgsPhongMaterialSettings terrainShadingMaterial() const;
 
     /**
      * Sets name of the map theme.
@@ -322,25 +347,20 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \note Support for map themes only works if mapThemeCollection() is a valid object (otherwise it is not possible to resolve map themes from names)
      * \since QGIS 3.6
      */
-    QString terrainMapTheme() const { return mTerrainMapTheme; }
+    QString terrainMapTheme() const;
 
     //
     // misc configuration
     //
 
-    //! Sets list of extra 3D renderers to use in the scene. Takes ownership of the objects.
-    void setRenderers( const QList<QgsAbstract3DRenderer *> &renderers SIP_TRANSFER );
-    //! Returns list of extra 3D renderers
-    QList<QgsAbstract3DRenderer *> renderers() const { return mRenderers; }
-
     //! Sets whether to display bounding boxes of terrain tiles (for debugging)
     void setShowTerrainBoundingBoxes( bool enabled );
     //! Returns whether to display bounding boxes of terrain tiles (for debugging)
-    bool showTerrainBoundingBoxes() const { return mShowTerrainBoundingBoxes; }
+    bool showTerrainBoundingBoxes() const;
     //! Sets whether to display extra tile info on top of terrain tiles (for debugging)
     void setShowTerrainTilesInfo( bool enabled );
     //! Returns whether to display extra tile info on top of terrain tiles (for debugging)
-    bool showTerrainTilesInfo() const { return mShowTerrainTileInfo; }
+    bool showTerrainTilesInfo() const;
 
     /**
      * Sets whether to show camera's view center as a sphere (for debugging)
@@ -352,7 +372,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns whether to show camera's view center as a sphere (for debugging)
      * \since QGIS 3.4
      */
-    bool showCameraViewCenter() const { return mShowCameraViewCenter; }
+    bool showCameraViewCenter() const;
 
     /**
      * Sets whether to show camera's rotation center as a sphere (for debugging)
@@ -364,7 +384,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns whether to show camera's rotation center as a sphere (for debugging)
      * \since QGIS 3.24
      */
-    bool showCameraRotationCenter() const { return mShowCameraRotationCenter; }
+    bool showCameraRotationCenter() const;
 
     /**
      * Sets whether to show light source origins as a sphere (for debugging)
@@ -376,12 +396,12 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns whether to show light source origins as a sphere (for debugging)
      * \since QGIS 3.16
      */
-    bool showLightSourceOrigins() const { return mShowLightSources; }
+    bool showLightSourceOrigins() const;
 
     //! Sets whether to display labels on terrain tiles
     void setShowLabels( bool enabled );
     //! Returns whether to display labels on terrain tiles
-    bool showLabels() const { return mShowLabels; }
+    bool showLabels() const;
 
     /**
     * Sets whether eye dome lighting will be used
@@ -390,7 +410,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
     */
     void setEyeDomeLightingEnabled( bool enabled );
     //! Returns whether eye dome lighting is used
-    bool eyeDomeLightingEnabled() const { return mEyeDomeLightingEnabled; }
+    bool eyeDomeLightingEnabled() const;
 
     /**
      * Sets the eye dome lighting strength value
@@ -399,7 +419,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      */
     void setEyeDomeLightingStrength( double strength );
     //! Returns the eye dome lighting strength value
-    double eyeDomeLightingStrength() const { return mEyeDomeLightingStrength; }
+    double eyeDomeLightingStrength() const;
 
     /**
      * Sets the eye dome lighting distance value (contributes to the contrast of the image
@@ -408,33 +428,37 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      */
     void setEyeDomeLightingDistance( int distance );
     //! Returns the eye dome lighting distance value (contributes to the contrast of the image)
-    int eyeDomeLightingDistance() const { return mEyeDomeLightingDistance; }
+    int eyeDomeLightingDistance() const;
 
     /**
      * Sets the debugging settings of the shadow map
-     * \see debugShadowMapEnabled() debugShadowMapCorner() debugShadowMapSize()
+     * \see debugShadowMapEnabled()
+     * \see debugShadowMapCorner()
+     * \see debugShadowMapSize()
      * \since QGIS 3.18
      */
     void setDebugShadowMapSettings( bool enabled, Qt::Corner corner, double size );
     //! Returns whether the shadow map debugging is enabled
-    bool debugShadowMapEnabled() const { return mDebugShadowMapEnabled; }
+    bool debugShadowMapEnabled() const;
     //! Returns the corner where the shadow map preview is displayed
-    Qt::Corner debugShadowMapCorner() const { return mDebugShadowMapCorner; }
+    Qt::Corner debugShadowMapCorner() const;
     //! Returns the size of the shadow map preview
-    double debugShadowMapSize() const { return mDebugShadowMapSize; }
+    double debugShadowMapSize() const;
 
     /**
      * Sets the debugging settings of the depth map
-     * \see debugDepthMapEnabled() debugDepthMapCorner() debugDepthMapSize()
+     * \see debugDepthMapEnabled()
+     * \see debugDepthMapCorner()
+     * \see debugDepthMapSize()
      * \since QGIS 3.18
      */
     void setDebugDepthMapSettings( bool enabled, Qt::Corner corner, double size );
     //! Returns whether the shadow map debugging is enabled
-    bool debugDepthMapEnabled() const { return mDebugDepthMapEnabled; }
+    bool debugDepthMapEnabled() const;
     //! Returns the corner where the shadow map preview is displayed
-    Qt::Corner debugDepthMapCorner() const { return mDebugDepthMapCorner; }
+    Qt::Corner debugDepthMapCorner() const;
     //! Returns the size of the shadow map preview
-    double debugDepthMapSize() const { return mDebugDepthMapSize; }
+    double debugDepthMapSize() const;
 
     /**
      * Returns list of directional light sources defined in the scene.
@@ -457,7 +481,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns the camera lens' field of view
      * \since QGIS 3.8
      */
-    float fieldOfView() const { return mFieldOfView; }
+    float fieldOfView() const;
 
     /**
      * Sets the camera lens' field of view
@@ -469,7 +493,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns the camera lens' projection type
      * \since QGIS 3.18
      */
-    Qt3DRender::QCameraLens::ProjectionType projectionType() const SIP_SKIP { return mProjectionType; }
+    Qt3DRender::QCameraLens::ProjectionType projectionType() const SIP_SKIP;
 
     /**
      * Sets the camera lens' projection type
@@ -483,20 +507,20 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns the navigation mode used by the camera
      * \since QGIS 3.18
      */
-    QgsCameraController::NavigationMode cameraNavigationMode() const { return mCameraNavigationMode; }
+    Qgis::NavigationMode cameraNavigationMode() const;
 
     /**
      * Sets the navigation mode for the camera
      * \since QGIS 3.18
      */
-    void setCameraNavigationMode( QgsCameraController::NavigationMode navigationMode );
+    void setCameraNavigationMode( Qgis::NavigationMode navigationMode );
 #endif
 
     /**
      * Returns the camera movement speed
      * \since QGIS 3.18
      */
-    double cameraMovementSpeed() const { return mCameraMovementSpeed; }
+    double cameraMovementSpeed() const;
 
     /**
      * Sets the camera movement speed
@@ -509,33 +533,32 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \param dpi the number of dot per inch
      * \since QGIS 3.10
      */
-    void setOutputDpi( const double dpi ) {mDpi = dpi;}
-
+    void setOutputDpi( const double dpi );
 
     /**
      * Returns DPI used for conversion between real world units (e.g. mm) and pixels
      * Default value is 96
      * \since QGIS 3.10
      */
-    double outputDpi() const { return mDpi; }
+    double outputDpi() const;
 
     /**
      * Returns the current configuration of the skybox
      * \since QGIS 3.16
      */
-    QgsSkyboxSettings skyboxSettings() const SIP_SKIP { return mSkyboxSettings; }
+    QgsSkyboxSettings skyboxSettings() const SIP_SKIP;
 
     /**
      * Returns the current configuration of shadows
      * \return QGIS 3.16
      */
-    QgsShadowSettings shadowSettings() const SIP_SKIP { return mShadowSettings; }
+    QgsShadowSettings shadowSettings() const SIP_SKIP;
 
     /**
      * Returns the current configuration of screen space ambient occlusion
      * \since QGIS 3.28
      */
-    QgsAmbientOcclusionSettings ambientOcclusionSettings() const SIP_SKIP { return mAmbientOcclusionSettings; }
+    QgsAmbientOcclusionSettings ambientOcclusionSettings() const SIP_SKIP;
 
     /**
      * Sets the current configuration of the skybox
@@ -560,21 +583,21 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \see setIsSkyboxEnabled()
      * \since QGIS 3.16
      */
-    bool isSkyboxEnabled() const { return mIsSkyboxEnabled; }
+    bool isSkyboxEnabled() const;
 
     /**
      * Sets whether the skybox is enabled.
      * \see isSkyboxEnabled()
      * \since QGIS 3.16
      */
-    void setIsSkyboxEnabled( bool enabled ) { mIsSkyboxEnabled = enabled; }
+    void setIsSkyboxEnabled( bool enabled );
 
     /**
      * Returns whether FPS counter label is enabled
      * \see setIsFpsCounterEnabled()
      * \since QGIS 3.18
      */
-    bool isFpsCounterEnabled() const { return mIsFpsCounterEnabled; }
+    bool isFpsCounterEnabled() const;
 
     /**
      * Sets whether FPS counter label is enabled
@@ -588,7 +611,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \see setTerrainRenderingEnabled()
      * \since QGIS 3.22
      */
-    bool terrainRenderingEnabled() const { return mTerrainRenderingEnabled; }
+    bool terrainRenderingEnabled() const;
 
     /**
      * Sets whether the 2D terrain surface will be rendered in.
@@ -618,7 +641,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      *
      * \since QGIS 3.26
      */
-    Qgis::ViewSyncModeFlags viewSyncMode() const { return mViewSyncMode; }
+    Qgis::ViewSyncModeFlags viewSyncMode() const;
 
     /**
      * Sets the view sync mode (used to synchronize the 2D main map canvas and the 3D camera navigation)
@@ -632,7 +655,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      *
      * \since QGIS 3.26
      */
-    bool viewFrustumVisualizationEnabled() const { return mVisualizeViewFrustum; }
+    bool viewFrustumVisualizationEnabled() const;
 
     /**
      * Sets whether the camera's view frustum is visualized on the 2D map canvas
@@ -645,7 +668,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * Returns the current configuration of 3d axis
      * \return QGIS 3.26
      */
-    Qgs3DAxisSettings get3DAxisSettings() const SIP_SKIP { return m3dAxisSettings; }
+    Qgs3DAxisSettings get3DAxisSettings() const SIP_SKIP;
 
     /**
      * Sets the current configuration of 3d axis
@@ -658,7 +681,7 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      * \see setIsDebugOverlayEnabled()
      * \since QGIS 3.26
      */
-    bool isDebugOverlayEnabled() const { return mIsDebugOverlayEnabled; }
+    bool isDebugOverlayEnabled() const;
 
     /**
      * Sets whether debug overlay is enabled
@@ -670,6 +693,19 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      */
     void setIsDebugOverlayEnabled( bool debugOverlayEnabled );
 
+    /**
+     * Returns whether the extent is displayed on the main 2D map canvas
+     * \see setShowExtentIn2DView()
+     * \since QGIS 3.32
+     */
+    bool showExtentIn2DView() const;
+
+    /**
+     * Sets whether the extent is displayed on the main 2D map canvas
+     * \since QGIS 3.32
+     */
+    void setShowExtentIn2DView( bool show );
+
   signals:
 
     /**
@@ -869,6 +905,20 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
      */
     void debugOverlayEnabledChanged( bool debugOverlayEnabled );
 
+    /**
+     * Emitted when the 3d view's 2d extent has changed
+     * \see setExtent()
+     * \since QGIS 3.30
+     */
+    void extentChanged();
+
+    /**
+     * Emitted when the parameter to display 3d view's extent in the 2D canvas has changed
+     * \see setShowExtentIn2DView()
+     * \since QGIS 3.32
+     */
+    void showExtentIn2DViewChanged();
+
   private:
 #ifdef SIP_RUN
     Qgs3DMapSettings &operator=( const Qgs3DMapSettings & );
@@ -881,41 +931,40 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
   private:
     //! Offset in map CRS coordinates at which our 3D world has origin (0,0,0)
     QgsVector3D mOrigin;
-    QgsCoordinateReferenceSystem mCrs;   //!< Destination coordinate system of the world
-    QColor mBackgroundColor = Qt::black;   //!< Background color of the scene
-    QColor mSelectionColor; //!< Color to be used for selected map features
-    double mTerrainVerticalScale = 1;   //!< Multiplier of terrain heights to make the terrain shape more pronounced
-    std::unique_ptr<QgsTerrainGenerator> mTerrainGenerator;  //!< Implementation of the terrain generation
-    int mMapTileResolution = 512;   //!< Size of map textures of tiles in pixels (width/height)
-    float mMaxTerrainScreenError = 3.f;   //!< Maximum allowed terrain error in pixels (determines when tiles are switched to more detailed ones)
-    float mMaxTerrainGroundError = 1.f;  //!< Maximum allowed horizontal map error in map units (determines how many zoom levels will be used)
-    float mTerrainElevationOffset = 0.0f; //!< Terrain elevation offset (used to adjust the position of the terrain and move it up and down)
-    bool mTerrainShadingEnabled = false;   //!< Whether terrain should be shaded taking lights into account
-    QgsPhongMaterialSettings mTerrainShadingMaterial;  //!< Material to use for the terrain (if shading is enabled). Diffuse color is ignored.
-    QString mTerrainMapTheme;  //!< Name of map theme used for terrain's texture (empty means use the current map theme)
-    bool mShowTerrainBoundingBoxes = false;  //!< Whether to show bounding boxes of entities - useful for debugging
-    bool mShowTerrainTileInfo = false;  //!< Whether to draw extra information about terrain tiles to the textures - useful for debugging
-    bool mShowCameraViewCenter = false;  //!< Whether to show camera view center as a sphere - useful for debugging
-    bool mShowCameraRotationCenter = false; //!< Whether to show camera rotation center as a sphere - useful for debugging
-    bool mShowLightSources = false; //!< Whether to show the origin of light sources
-    bool mShowLabels = false; //!< Whether to display labels on terrain tiles
-    QList< QgsLightSource * > mLightSources; //!< List of light sources in the scene (owned by the settings)
-    float mFieldOfView = 45.0f; //<! Camera lens field of view value
-    Qt3DRender::QCameraLens::ProjectionType mProjectionType = Qt3DRender::QCameraLens::PerspectiveProjection;  //<! Camera lens projection type
-    QgsCameraController::NavigationMode mCameraNavigationMode = QgsCameraController::NavigationMode::TerrainBasedNavigation;
+    QgsCoordinateReferenceSystem mCrs;                                                                        //!< Destination coordinate system of the world
+    QColor mBackgroundColor = Qt::black;                                                                      //!< Background color of the scene
+    QColor mSelectionColor;                                                                                   //!< Color to be used for selected map features
+    double mTerrainVerticalScale = 1;                                                                         //!< Multiplier of terrain heights to make the terrain shape more pronounced
+    std::unique_ptr<QgsTerrainGenerator> mTerrainGenerator;                                                   //!< Implementation of the terrain generation
+    int mMapTileResolution = 512;                                                                             //!< Size of map textures of tiles in pixels (width/height)
+    float mMaxTerrainScreenError = 3.f;                                                                       //!< Maximum allowed terrain error in pixels (determines when tiles are switched to more detailed ones)
+    float mMaxTerrainGroundError = 1.f;                                                                       //!< Maximum allowed horizontal map error in map units (determines how many zoom levels will be used)
+    float mTerrainElevationOffset = 0.0f;                                                                     //!< Terrain elevation offset (used to adjust the position of the terrain and move it up and down)
+    bool mTerrainShadingEnabled = false;                                                                      //!< Whether terrain should be shaded taking lights into account
+    QgsPhongMaterialSettings mTerrainShadingMaterial;                                                         //!< Material to use for the terrain (if shading is enabled). Diffuse color is ignored.
+    QString mTerrainMapTheme;                                                                                 //!< Name of map theme used for terrain's texture (empty means use the current map theme)
+    bool mShowTerrainBoundingBoxes = false;                                                                   //!< Whether to show bounding boxes of entities - useful for debugging
+    bool mShowTerrainTileInfo = false;                                                                        //!< Whether to draw extra information about terrain tiles to the textures - useful for debugging
+    bool mShowCameraViewCenter = false;                                                                       //!< Whether to show camera view center as a sphere - useful for debugging
+    bool mShowCameraRotationCenter = false;                                                                   //!< Whether to show camera rotation center as a sphere - useful for debugging
+    bool mShowLightSources = false;                                                                           //!< Whether to show the origin of light sources
+    bool mShowLabels = false;                                                                                 //!< Whether to display labels on terrain tiles
+    QList<QgsLightSource *> mLightSources;                                                                    //!< List of light sources in the scene (owned by the settings)
+    float mFieldOfView = 45.0f;                                                                               //<! Camera lens field of view value
+    Qt3DRender::QCameraLens::ProjectionType mProjectionType = Qt3DRender::QCameraLens::PerspectiveProjection; //<! Camera lens projection type
+    Qgis::NavigationMode mCameraNavigationMode = Qgis::NavigationMode::TerrainBased;
     double mCameraMovementSpeed = 5.0;
-    QList<QgsMapLayerRef> mLayers;   //!< Layers to be rendered
-    QList<QgsAbstract3DRenderer *> mRenderers;  //!< Extra stuff to render as 3D object
+    QList<QgsMapLayerRef> mLayers; //!< Layers to be rendered
     //! Coordinate transform context
     QgsCoordinateTransformContext mTransformContext;
     QgsPathResolver mPathResolver;
-    QgsMapThemeCollection *mMapThemes = nullptr;   //!< Pointer to map themes (e.g. from the current project) to resolve map theme content from the name
-    double mDpi = 96;  //!< Dot per inch value for the screen / painter
+    QgsMapThemeCollection *mMapThemes = nullptr; //!< Pointer to map themes (e.g. from the current project) to resolve map theme content from the name
+    double mDpi = 96;                            //!< Dot per inch value for the screen / painter
     bool mIsFpsCounterEnabled = false;
 
-    bool mIsSkyboxEnabled = false;  //!< Whether the skybox is enabled
-    QgsSkyboxSettings mSkyboxSettings; //!< Skybox related configuration
-    QgsShadowSettings mShadowSettings; //!< Shadow rendering related settings
+    bool mIsSkyboxEnabled = false;                         //!< Whether the skybox is enabled
+    QgsSkyboxSettings mSkyboxSettings;                     //!< Skybox related configuration
+    QgsShadowSettings mShadowSettings;                     //!< Shadow rendering related settings
     QgsAmbientOcclusionSettings mAmbientOcclusionSettings; //!< Screen Space Ambient Occlusion related settings
 
     bool mEyeDomeLightingEnabled = false;
@@ -941,6 +990,9 @@ class _3D_EXPORT Qgs3DMapSettings : public QObject, public QgsTemporalRangeObjec
 
     bool mIsDebugOverlayEnabled = false;
 
+    QgsRectangle mExtent; //!< 2d extent used to limit the 3d view
+
+    bool mShowExtentIn2DView = false;
 };
 
 
