@@ -20,10 +20,12 @@
 #include "qgsblockingnetworkrequest.h"
 #include "qgscoordinatetransform.h"
 #include "qgslogger.h"
+#include "qgsmetalroughmaterial.h"
+#include "qgstexturematerial.h"
 
 #include <Qt3DCore/QEntity>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
 #include <Qt3DRender/QAttribute>
 #include <Qt3DRender/QBuffer>
 #include <Qt3DRender/QGeometry>
@@ -41,18 +43,11 @@ typedef Qt3DCore::QGeometry Qt3DQGeometry;
 
 #include <Qt3DRender/QGeometryRenderer>
 #include <Qt3DRender/QTexture>
-#include <Qt3DExtras/QMetalRoughMaterial>
-#include <Qt3DExtras/QTextureMaterial>
 
 #include <QFile>
 #include <QFileInfo>
 #include <QMatrix4x4>
 
-#define TINYGLTF_NO_STB_IMAGE         // we use QImage-based reading of images
-#define TINYGLTF_NO_STB_IMAGE_WRITE   // we don't need writing of images
-#include "tiny_gltf.h"
-
-
 ///@cond PRIVATE
 
 static Qt3DQAttribute::VertexBaseType parseVertexBaseType( int componentType )
@@ -142,7 +137,7 @@ static Qt3DQAttribute *parseAttribute( tinygltf::Model &model, int accessorIndex
 
   attribute->setBuffer( buffer );
   attribute->setByteOffset( bv.byteOffset + accessor.byteOffset );
-  attribute->setByteStride( bv.byteStride );  // could be zero, it seems that's fine (assuming packed)
+  attribute->setByteStride( bv.byteStride ); // could be zero, it seems that's fine (assuming packed)
   attribute->setCount( accessor.count );
   attribute->setVertexBaseType( parseVertexBaseType( accessor.componentType ) );
   attribute->setVertexSize( tinygltf::GetNumComponentsInType( accessor.type ) );
@@ -172,9 +167,9 @@ static Qt3DQAttribute *reprojectPositions( tinygltf::Model &model, int accessorI
     double z = ( vz[i] * transform.zValueScale ) + transform.zValueOffset - sceneOrigin.z();
 
     // QGIS 3D uses base plane (X,-Z) with Y up - so flip the coordinates
-    out[i * 3 + 0] = static_cast< float >( x );
-    out[i * 3 + 1] = static_cast< float >( z );
-    out[i * 3 + 2] = static_cast< float >( -y );
+    out[i * 3 + 0] = static_cast<float>( x );
+    out[i * 3 + 1] = static_cast<float>( z );
+    out[i * 3 + 2] = static_cast<float>( -y );
   }
 
   Qt3DQBuffer *buffer = new Qt3DQBuffer();
@@ -209,7 +204,7 @@ class TinyGltfTextureImageDataGenerator : public Qt3DRender::QTextureImageDataGe
       return mImagePtr;
     }
 
-    bool operator ==( const QTextureImageDataGenerator &other ) const override
+    bool operator==( const QTextureImageDataGenerator &other ) const override
     {
       const TinyGltfTextureImageDataGenerator *otherFunctor = functor_cast<TinyGltfTextureImageDataGenerator>( &other );
       return mImagePtr.get() == otherFunctor->mImagePtr.get();
@@ -292,12 +287,12 @@ static QByteArray fetchUri( const QUrl &url, QStringList *errors )
 }
 
 // Returns NULLPTR if primitive should not be rendered
-static Qt3DRender::QMaterial *parseMaterial( tinygltf::Model &model, int materialIndex, QString baseUri, QStringList *errors )
+static QgsMaterial *parseMaterial( tinygltf::Model &model, int materialIndex, QString baseUri, QStringList *errors )
 {
   if ( materialIndex < 0 )
   {
     // material unspecified - using default
-    Qt3DExtras::QMetalRoughMaterial *defaultMaterial = new Qt3DExtras::QMetalRoughMaterial;
+    QgsMetalRoughMaterial *defaultMaterial = new QgsMetalRoughMaterial;
     defaultMaterial->setMetalness( 1 );
     defaultMaterial->setRoughness( 1 );
     defaultMaterial->setBaseColor( QColor::fromRgbF( 1, 1, 1 ) );
@@ -311,6 +306,16 @@ static Qt3DRender::QMaterial *parseMaterial( tinygltf::Model &model, int materia
   {
     tinygltf::Texture &tex = model.textures[pbr.baseColorTexture.index];
 
+    // Source can be undefined if texture is provided by an extension
+    if ( tex.source < 0 )
+    {
+      QgsMetalRoughMaterial *pbrMaterial = new QgsMetalRoughMaterial;
+      pbrMaterial->setMetalness( pbr.metallicFactor ); // [0..1] or texture
+      pbrMaterial->setRoughness( pbr.roughnessFactor );
+      pbrMaterial->setBaseColor( QColor::fromRgbF( pbr.baseColorFactor[0], pbr.baseColorFactor[1], pbr.baseColorFactor[2], pbr.baseColorFactor[3] ) );
+      return pbrMaterial;
+    }
+
     tinygltf::Image &img = model.images[tex.source];
 
     if ( !img.uri.empty() )
@@ -330,7 +335,7 @@ static Qt3DRender::QMaterial *parseMaterial( tinygltf::Model &model, int materia
 
     if ( img.image.empty() )
     {
-      Qt3DExtras::QMetalRoughMaterial *pbrMaterial = new Qt3DExtras::QMetalRoughMaterial;
+      QgsMetalRoughMaterial *pbrMaterial = new QgsMetalRoughMaterial;
       pbrMaterial->setMetalness( pbr.metallicFactor ); // [0..1] or texture
       pbrMaterial->setRoughness( pbr.roughnessFactor );
       pbrMaterial->setBaseColor( QColor::fromRgbF( pbr.baseColorFactor[0], pbr.baseColorFactor[1], pbr.baseColorFactor[2], pbr.baseColorFactor[3] ) );
@@ -362,7 +367,7 @@ static Qt3DRender::QMaterial *parseMaterial( tinygltf::Model &model, int materia
     // We should be using PBR material unless unlit material is requested using KHR_materials_unlit
     // GLTF extension, but in various datasets that extension is not used (even though it should have been).
     // In the future we may want to have a switch whether to use unlit material or PBR material...
-    Qt3DExtras::QTextureMaterial *mat = new Qt3DExtras::QTextureMaterial;
+    QgsTextureMaterial *mat = new QgsTextureMaterial;
     mat->setTexture( texture );
     return mat;
   }
@@ -370,7 +375,7 @@ static Qt3DRender::QMaterial *parseMaterial( tinygltf::Model &model, int materia
   if ( qgsDoubleNear( pbr.baseColorFactor[3], 0 ) )
     return nullptr; // completely transparent primitive, just skip it
 
-  Qt3DExtras::QMetalRoughMaterial *pbrMaterial = new Qt3DExtras::QMetalRoughMaterial;
+  QgsMetalRoughMaterial *pbrMaterial = new QgsMetalRoughMaterial;
   pbrMaterial->setMetalness( pbr.metallicFactor ); // [0..1] or texture
   pbrMaterial->setRoughness( pbr.roughnessFactor );
   pbrMaterial->setBaseColor( QColor::fromRgbF( pbr.baseColorFactor[0], pbr.baseColorFactor[1], pbr.baseColorFactor[2], pbr.baseColorFactor[3] ) );
@@ -422,7 +427,7 @@ static QVector<Qt3DCore::QEntity *> parseNode( tinygltf::Model &model, int nodeI
         continue;
       }
 
-      Qt3DRender::QMaterial *material = parseMaterial( model, primitive.material, baseUri, errors );
+      QgsMaterial *material = parseMaterial( model, primitive.material, baseUri, errors );
       if ( !material )
       {
         // primitive should be skipped, eg fully transparent material
@@ -468,8 +473,15 @@ static QVector<Qt3DCore::QEntity *> parseNode( tinygltf::Model &model, int nodeI
       geomRenderer->setPrimitiveType( Qt3DRender::QGeometryRenderer::Triangles ); // looks like same values as "mode"
       geomRenderer->setVertexCount( indexAttribute ? indexAttribute->count() : model.accessors[positionAccessorIndex].count );
 
-      // TODO: if we are using PBR material, and normal vectors are not present in the data,
+      // if we are using PBR material, and normal vectors are not present in the data,
       // they should be auto-generated by us (according to GLTF spec)
+      if ( normalIt == primitive.attributes.end() )
+      {
+        if ( QgsMetalRoughMaterial *pbrMat = qobject_cast<QgsMetalRoughMaterial *>( material ) )
+        {
+          pbrMat->setFlatShadingEnabled( true );
+        }
+      }
 
       Qt3DCore::QEntity *primitiveEntity = new Qt3DCore::QEntity;
       primitiveEntity->addComponent( geomRenderer );
@@ -488,7 +500,7 @@ static QVector<Qt3DCore::QEntity *> parseNode( tinygltf::Model &model, int nodeI
 }
 
 
-static Qt3DCore::QEntity *parseModel( tinygltf::Model &model, const QgsGltf3DUtils::EntityTransform &transform, QString baseUri, QStringList *errors )
+Qt3DCore::QEntity *QgsGltf3DUtils::parsedGltfToEntity( tinygltf::Model &model, const QgsGltf3DUtils::EntityTransform &transform, QString baseUri, QStringList *errors )
 {
   bool sceneOk = false;
   const std::size_t sceneIndex = QgsGltfUtils::sourceSceneForModel( model, sceneOk );
@@ -544,7 +556,7 @@ Qt3DCore::QEntity *QgsGltf3DUtils::gltfToEntity( const QByteArray &data, const Q
     return nullptr;
   }
 
-  return parseModel( model, transform, baseUri, errors );
+  return parsedGltfToEntity( model, transform, baseUri, errors );
 }
 
 // For TinyGltfTextureImage
