@@ -21,14 +21,13 @@
 #include "qgspointcloudlayer3drenderer.h"
 
 #include <QFutureWatcher>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
 #include <Qt3DRender/QGeometry>
 #include <Qt3DRender/QBuffer>
 #else
 #include <Qt3DCore/QGeometry>
 #include <Qt3DCore/QBuffer>
 #endif
-#include <Qt3DRender/QMaterial>
 #include <QVector3D>
 
 #define SIP_NO_FILE
@@ -36,16 +35,18 @@
 class IndexedPointCloudNode;
 class QgsAABB;
 
-class QgsPointCloud3DSymbolHandler // : public QgsFeature3DHandler
+class QgsPointCloud3DSymbolHandler
 {
   public:
     QgsPointCloud3DSymbolHandler();
 
     virtual ~QgsPointCloud3DSymbolHandler() = default;
 
-    virtual bool prepare( const QgsPointCloud3DRenderContext &context ) = 0;// override;
-    virtual void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context ) = 0; // override;
-    virtual void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) = 0;// override;
+    struct PointData;
+
+    virtual bool prepare( const QgsPointCloud3DRenderContext &context ) = 0;                                                                                          // override;
+    virtual void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output = nullptr ) = 0; // override;
+    virtual void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) = 0;                                                              // override;
 
     void triangulate( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, const QgsAABB &bbox );
 
@@ -55,11 +56,13 @@ class QgsPointCloud3DSymbolHandler // : public QgsFeature3DHandler
     //! temporary data we will pass to the tessellator
     struct PointData
     {
-      QVector<QVector3D> positions;  // contains triplets of float x,y,z for each point
-      QVector<float> parameter;
-      QVector<QVector3D> colors;
-      QByteArray triangles; // in case of points triangulation, contains index of point in the array positions
-      QByteArray normals; // in case of points triangulation, contains the normals of the solid surface on each vertex
+        QgsVector3D positionsOrigin;  // All "positions" are relative to this point, defined in map coordinates (with double precision)
+        QVector<QVector3D> positions; // Contains triplets of float x,y,z for each point. These are in map coordinates, relative to "positionsOrigin"
+        QVector<float> parameter;
+        QVector<float> pointSizes; // Contains point sizes, in case they are overridden for classification renderer
+        QVector<QVector3D> colors;
+        QByteArray triangles; // In case of points triangulation, contains index of point in the array positions
+        QByteArray normals;   // In case of points triangulation, contains the normals of the solid surface on each vertex
     };
 
   protected:
@@ -68,7 +71,7 @@ class QgsPointCloud3DSymbolHandler // : public QgsFeature3DHandler
 
     void makeEntity( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context, const PointData &out, bool selected );
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     virtual Qt3DRender::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) = 0;
 #else
     virtual Qt3DCore::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) = 0;
@@ -76,7 +79,7 @@ class QgsPointCloud3DSymbolHandler // : public QgsFeature3DHandler
     std::unique_ptr<QgsPointCloudBlock> pointCloudBlock( QgsPointCloudIndex *pc, const IndexedPointCloudNode &node, const QgsPointCloudRequest &request, const QgsPointCloud3DRenderContext &context );
 
     // outputs
-    PointData outNormal;  //!< Features that are not selected
+    PointData outNormal; //!< Features that are not selected
 
   private:
     //! Returns all vertices of the node \a n, and of its parents contained in \a bbox and in an extension of this box depending of the density of the points
@@ -89,7 +92,7 @@ class QgsPointCloud3DSymbolHandler // : public QgsFeature3DHandler
      * Applies a filter on triangles to improve the rendering:
      *
      * - keeps only triangles that have a least one point in the bounding box \a bbox
-     * - if options are selected, skips triangles with horizontale or vertical size greater than a threshold
+     * - if options are selected, skips triangles with horizontal or vertical size greater than a threshold
      *
      * Must be used only in the method triangulate().
      */
@@ -102,11 +105,11 @@ class QgsSingleColorPointCloud3DSymbolHandler : public QgsPointCloud3DSymbolHand
     QgsSingleColorPointCloud3DSymbolHandler();
 
     bool prepare( const QgsPointCloud3DRenderContext &context ) override;
-    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context ) override;
+    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output = nullptr ) override;
     void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) override;
 
   private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     Qt3DRender::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
 #else
     Qt3DCore::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
@@ -119,11 +122,11 @@ class QgsColorRampPointCloud3DSymbolHandler : public QgsPointCloud3DSymbolHandle
     QgsColorRampPointCloud3DSymbolHandler();
 
     bool prepare( const QgsPointCloud3DRenderContext &context ) override;
-    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context ) override;
+    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output = nullptr ) override;
     void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) override;
 
   private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     Qt3DRender::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
 #else
     Qt3DCore::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
@@ -136,11 +139,11 @@ class QgsRGBPointCloud3DSymbolHandler : public QgsPointCloud3DSymbolHandler
     QgsRGBPointCloud3DSymbolHandler();
 
     bool prepare( const QgsPointCloud3DRenderContext &context ) override;
-    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context ) override;
+    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output = nullptr ) override;
     void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) override;
 
   private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     Qt3DRender::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
 #else
     Qt3DCore::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
@@ -153,21 +156,21 @@ class QgsClassificationPointCloud3DSymbolHandler : public QgsPointCloud3DSymbolH
     QgsClassificationPointCloud3DSymbolHandler();
 
     bool prepare( const QgsPointCloud3DRenderContext &context ) override;
-    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context ) override;
+    void processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output = nullptr ) override;
     void finalize( Qt3DCore::QEntity *parent, const QgsPointCloud3DRenderContext &context ) override;
 
   private:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     Qt3DRender::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
 #else
     Qt3DCore::QGeometry *makeGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride ) override;
 #endif
 };
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class QgsPointCloud3DGeometry: public Qt3DRender::QGeometry
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
+class QgsPointCloud3DGeometry : public Qt3DRender::QGeometry
 #else
-class QgsPointCloud3DGeometry: public Qt3DCore::QGeometry
+class QgsPointCloud3DGeometry : public Qt3DCore::QGeometry
 #endif
 {
     Q_OBJECT
@@ -178,9 +181,10 @@ class QgsPointCloud3DGeometry: public Qt3DCore::QGeometry
   protected:
     virtual void makeVertexBuffer( const QgsPointCloud3DSymbolHandler::PointData &data ) = 0;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     Qt3DRender::QAttribute *mPositionAttribute = nullptr;
     Qt3DRender::QAttribute *mParameterAttribute = nullptr;
+    Qt3DRender::QAttribute *mPointSizeAttribute = nullptr;
     Qt3DRender::QAttribute *mColorAttribute = nullptr;
     Qt3DRender::QAttribute *mTriangleIndexAttribute = nullptr;
     Qt3DRender::QAttribute *mNormalsAttribute = nullptr;
@@ -190,6 +194,7 @@ class QgsPointCloud3DGeometry: public Qt3DCore::QGeometry
 #else
     Qt3DCore::QAttribute *mPositionAttribute = nullptr;
     Qt3DCore::QAttribute *mParameterAttribute = nullptr;
+    Qt3DCore::QAttribute *mPointSizeAttribute = nullptr;
     Qt3DCore::QAttribute *mColorAttribute = nullptr;
     Qt3DCore::QAttribute *mTriangleIndexAttribute = nullptr;
     Qt3DCore::QAttribute *mNormalsAttribute = nullptr;
@@ -230,11 +235,21 @@ class QgsRGBPointCloud3DGeometry : public QgsPointCloud3DGeometry
 
   public:
     QgsRGBPointCloud3DGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride );
+
   private:
     void makeVertexBuffer( const QgsPointCloud3DSymbolHandler::PointData &data ) override;
 };
 
+class QgsClassificationPointCloud3DGeometry : public QgsPointCloud3DGeometry
+{
+    Q_OBJECT
 
+  public:
+    QgsClassificationPointCloud3DGeometry( Qt3DCore::QNode *parent, const QgsPointCloud3DSymbolHandler::PointData &data, unsigned int byteStride );
+
+  private:
+    void makeVertexBuffer( const QgsPointCloud3DSymbolHandler::PointData &data ) override;
+};
 /// @endcond
 
 #endif // QGSPOINTCLOUD3DSYMBOL_P_H
