@@ -20,24 +20,23 @@
 
 ///@cond PRIVATE
 
-const std::vector< QgsStatisticalSummary::Statistic > STATS
-{
-  QgsStatisticalSummary::First,
-  QgsStatisticalSummary::Last,
-  QgsStatisticalSummary::Count,
-  QgsStatisticalSummary::Sum,
-  QgsStatisticalSummary::Mean,
-  QgsStatisticalSummary::Median,
-  QgsStatisticalSummary::StDev,
-  QgsStatisticalSummary::Min,
-  QgsStatisticalSummary::Max,
-  QgsStatisticalSummary::Range,
-  QgsStatisticalSummary::Minority,
-  QgsStatisticalSummary::Majority,
-  QgsStatisticalSummary::Variety,
-  QgsStatisticalSummary::FirstQuartile,
-  QgsStatisticalSummary::ThirdQuartile,
-  QgsStatisticalSummary::InterQuartileRange,
+const std::vector<Qgis::Statistic> STATS {
+  Qgis::Statistic::First,
+  Qgis::Statistic::Last,
+  Qgis::Statistic::Count,
+  Qgis::Statistic::Sum,
+  Qgis::Statistic::Mean,
+  Qgis::Statistic::Median,
+  Qgis::Statistic::StDev,
+  Qgis::Statistic::Min,
+  Qgis::Statistic::Max,
+  Qgis::Statistic::Range,
+  Qgis::Statistic::Minority,
+  Qgis::Statistic::Majority,
+  Qgis::Statistic::Variety,
+  Qgis::Statistic::FirstQuartile,
+  Qgis::Statistic::ThirdQuartile,
+  Qgis::Statistic::InterQuartileRange,
 };
 
 QString QgsExtractZMValuesAlgorithmBase::group() const
@@ -57,26 +56,24 @@ QString QgsExtractZMValuesAlgorithmBase::outputName() const
 
 QList<int> QgsExtractZMValuesAlgorithmBase::inputLayerTypes() const
 {
-  return QList<int>() << QgsProcessing::TypeVectorAnyGeometry;
+  return QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorAnyGeometry );
 }
 
-QgsProcessingFeatureSource::Flag QgsExtractZMValuesAlgorithmBase::sourceFlags() const
+Qgis::ProcessingFeatureSourceFlags QgsExtractZMValuesAlgorithmBase::sourceFlags() const
 {
-  return QgsProcessingFeatureSource::FlagSkipGeometryValidityChecks;
+  return Qgis::ProcessingFeatureSourceFlag::SkipGeometryValidityChecks;
 }
 
 void QgsExtractZMValuesAlgorithmBase::initParameters( const QVariantMap & )
 {
   QStringList statChoices;
   statChoices.reserve( STATS.size() );
-  for ( QgsStatisticalSummary::Statistic stat : STATS )
+  for ( Qgis::Statistic stat : STATS )
   {
     statChoices << QgsStatisticalSummary::displayName( stat );
   }
 
-  addParameter( new QgsProcessingParameterEnum( QStringLiteral( "SUMMARIES" ),
-                QObject::tr( "Summaries to calculate" ),
-                statChoices, true, QVariantList() << 0 ) );
+  addParameter( new QgsProcessingParameterEnum( QStringLiteral( "SUMMARIES" ), QObject::tr( "Summaries to calculate" ), statChoices, true, QVariantList() << 0 ) );
 
   addParameter( new QgsProcessingParameterString( QStringLiteral( "COLUMN_PREFIX" ), QObject::tr( "Output column prefix" ), mDefaultFieldPrefix, false, true ) );
 }
@@ -90,13 +87,13 @@ bool QgsExtractZMValuesAlgorithmBase::prepareAlgorithm( const QVariantMap &param
 {
   mPrefix = parameterAsString( parameters, QStringLiteral( "COLUMN_PREFIX" ), context );
 
-  const QList< int > stats = parameterAsEnums( parameters, QStringLiteral( "SUMMARIES" ), context );
-  mStats = QgsStatisticalSummary::Statistics();
+  const QList<int> stats = parameterAsEnums( parameters, QStringLiteral( "SUMMARIES" ), context );
+  mStats = Qgis::Statistics();
   for ( int s : stats )
   {
     mStats |= STATS.at( s );
     mSelectedStats << STATS.at( s );
-    mNewFields.append( QgsField( mPrefix + QgsStatisticalSummary::shortName( STATS.at( s ) ), STATS.at( s ) == QgsStatisticalSummary::Count || STATS.at( s ) == QgsStatisticalSummary::Variety ? QVariant::Int : QVariant::Double ) );
+    mNewFields.append( QgsField( mPrefix + QgsStatisticalSummary::shortName( STATS.at( s ) ), STATS.at( s ) == Qgis::Statistic::Count || STATS.at( s ) == Qgis::Statistic::Variety ? QMetaType::Type::Int : QMetaType::Type::Double ) );
   }
 
   return true;
@@ -118,7 +115,7 @@ QgsFeatureList QgsExtractZMValuesAlgorithmBase::processFeature( const QgsFeature
     for ( auto it = g.vertices_begin(); it != g.vertices_end(); ++it )
     {
       stat.addValue( mExtractValFunc( *it ) );
-      if ( mStats == QgsStatisticalSummary::First )
+      if ( mStats == Qgis::Statistics( Qgis::Statistic::First ) )
       {
         // only retrieving first vertex info (default behavior), so short cut and
         // don't iterate remaining vertices
@@ -127,7 +124,7 @@ QgsFeatureList QgsExtractZMValuesAlgorithmBase::processFeature( const QgsFeature
     }
     stat.finalize();
 
-    for ( QgsStatisticalSummary::Statistic s : std::as_const( mSelectedStats ) )
+    for ( Qgis::Statistic s : std::as_const( mSelectedStats ) )
       attrs.append( stat.statistic( s ) );
   }
   f.setAttributes( attrs );
@@ -147,12 +144,10 @@ bool QgsExtractZMValuesAlgorithmBase::supportInPlaceEdit( const QgsMapLayer *lay
 
 QgsExtractZValuesAlgorithm::QgsExtractZValuesAlgorithm()
 {
-  mExtractValFunc = []( const QgsPoint & p ) -> double
-  {
+  mExtractValFunc = []( const QgsPoint &p ) -> double {
     return p.z();
   };
-  mTestGeomFunc = []( const QgsGeometry & g ) -> bool
-  {
+  mTestGeomFunc = []( const QgsGeometry &g ) -> bool {
     return QgsWkbTypes::hasZ( g.wkbType() );
   };
   mDefaultFieldPrefix = QStringLiteral( "z_" );
@@ -197,12 +192,10 @@ QString QgsExtractZValuesAlgorithm::shortDescription() const
 
 QgsExtractMValuesAlgorithm::QgsExtractMValuesAlgorithm()
 {
-  mExtractValFunc = []( const QgsPoint & p ) -> double
-  {
+  mExtractValFunc = []( const QgsPoint &p ) -> double {
     return p.m();
   };
-  mTestGeomFunc = []( const QgsGeometry & g ) -> bool
-  {
+  mTestGeomFunc = []( const QgsGeometry &g ) -> bool {
     return QgsWkbTypes::hasM( g.wkbType() );
   };
   mDefaultFieldPrefix = QStringLiteral( "m_" );
@@ -242,4 +235,3 @@ QString QgsExtractMValuesAlgorithm::shortDescription() const
 
 
 ///@endcond
-
