@@ -47,9 +47,9 @@ QString QgsFixGeometriesAlgorithm::groupId() const
   return QStringLiteral( "vectorgeometry" );
 }
 
-QgsProcessingFeatureSource::Flag QgsFixGeometriesAlgorithm::sourceFlags() const
+Qgis::ProcessingFeatureSourceFlags QgsFixGeometriesAlgorithm::sourceFlags() const
 {
-  return QgsProcessingFeatureSource::FlagSkipGeometryValidityChecks;
+  return Qgis::ProcessingFeatureSourceFlag::SkipGeometryValidityChecks;
 }
 
 QString QgsFixGeometriesAlgorithm::outputName() const
@@ -77,25 +77,26 @@ QgsFixGeometriesAlgorithm *QgsFixGeometriesAlgorithm::createInstance() const
 
 bool QgsFixGeometriesAlgorithm::supportInPlaceEdit( const QgsMapLayer *l ) const
 {
-  const QgsVectorLayer *layer = qobject_cast< const QgsVectorLayer * >( l );
+  const QgsVectorLayer *layer = qobject_cast<const QgsVectorLayer *>( l );
   if ( !layer )
     return false;
 
-  if ( !layer->isSpatial() || ! QgsProcessingFeatureBasedAlgorithm::supportInPlaceEdit( layer ) )
+  if ( !layer->isSpatial() || !QgsProcessingFeatureBasedAlgorithm::supportInPlaceEdit( layer ) )
     return false;
   // The algorithm would drop M, so disable it if the layer has M
-  return ! QgsWkbTypes::hasM( layer->wkbType() );
+  return !QgsWkbTypes::hasM( layer->wkbType() );
 }
 
 void QgsFixGeometriesAlgorithm::initParameters( const QVariantMap & )
 {
-  std::unique_ptr< QgsProcessingParameterEnum> methodParameter = std::make_unique< QgsProcessingParameterEnum >(
-        QStringLiteral( "METHOD" ),
-        QObject::tr( "Repair method" ),
-        QStringList{ QObject::tr( "Linework" ), QObject::tr( "Structure" ) },
-        0,
-        false );
-#if GEOS_VERSION_MAJOR==3 && GEOS_VERSION_MINOR<10
+  std::unique_ptr<QgsProcessingParameterEnum> methodParameter = std::make_unique<QgsProcessingParameterEnum>(
+    QStringLiteral( "METHOD" ),
+    QObject::tr( "Repair method" ),
+    QStringList { QObject::tr( "Linework" ), QObject::tr( "Structure" ) },
+    0,
+    false
+  );
+#if GEOS_VERSION_MAJOR == 3 && GEOS_VERSION_MINOR < 10
   methodParameter->setDefaultValue( 0 );
 #else
   methodParameter->setDefaultValue( 1 );
@@ -105,11 +106,11 @@ void QgsFixGeometriesAlgorithm::initParameters( const QVariantMap & )
 
 bool QgsFixGeometriesAlgorithm::prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback * )
 {
-  mMethod = static_cast< Qgis::MakeValidMethod>( parameterAsInt( parameters, QStringLiteral( "METHOD" ), context ) );
-#if GEOS_VERSION_MAJOR==3 && GEOS_VERSION_MINOR<10
+  mMethod = static_cast<Qgis::MakeValidMethod>( parameterAsInt( parameters, QStringLiteral( "METHOD" ), context ) );
+#if GEOS_VERSION_MAJOR == 3 && GEOS_VERSION_MINOR < 10
   if ( mMethod == Qgis::MakeValidMethod::Structure )
   {
-    throw QgsProcessingException( "The structured method to make geometries valid requires a QGIS build based on GEOS 3.10 or later" );
+    throw QgsProcessingException( QObject::tr( "The structured method to make geometries valid requires a QGIS build based on GEOS 3.10 or later" ) );
   }
 #endif
   return true;
@@ -130,12 +131,11 @@ QgsFeatureList QgsFixGeometriesAlgorithm::processFeature( const QgsFeature &feat
     return QgsFeatureList() << outputFeature;
   }
 
-  if ( outputGeometry.wkbType() == Qgis::WkbType::Unknown ||
-       QgsWkbTypes::flatType( outputGeometry.wkbType() ) == Qgis::WkbType::GeometryCollection )
+  if ( outputGeometry.wkbType() == Qgis::WkbType::Unknown || QgsWkbTypes::flatType( outputGeometry.wkbType() ) == Qgis::WkbType::GeometryCollection )
   {
     // keep only the parts of the geometry collection with correct type
-    const QVector< QgsGeometry > tmpGeometries = outputGeometry.asGeometryCollection();
-    QVector< QgsGeometry > matchingParts;
+    const QVector<QgsGeometry> tmpGeometries = outputGeometry.asGeometryCollection();
+    QVector<QgsGeometry> matchingParts;
     for ( const QgsGeometry &g : tmpGeometries )
     {
       if ( g.type() == feature.geometry().type() )
