@@ -51,17 +51,16 @@ QString QgsRandomPointsExtentAlgorithm::groupId() const
 
 void QgsRandomPointsExtentAlgorithm::initAlgorithm( const QVariantMap & )
 {
-
   addParameter( new QgsProcessingParameterExtent( QStringLiteral( "EXTENT" ), QObject::tr( "Input extent" ) ) );
-  addParameter( new QgsProcessingParameterNumber( QStringLiteral( "POINTS_NUMBER" ), QObject::tr( "Number of points" ), QgsProcessingParameterNumber::Integer, 1, false, 1 ) );
+  addParameter( new QgsProcessingParameterNumber( QStringLiteral( "POINTS_NUMBER" ), QObject::tr( "Number of points" ), Qgis::ProcessingNumberParameterType::Integer, 1, false, 1 ) );
   addParameter( new QgsProcessingParameterDistance( QStringLiteral( "MIN_DISTANCE" ), QObject::tr( "Minimum distance between points" ), 0, QStringLiteral( "TARGET_CRS" ), true, 0 ) );
   addParameter( new QgsProcessingParameterCrs( QStringLiteral( "TARGET_CRS" ), QObject::tr( "Target CRS" ), QStringLiteral( "ProjectCrs" ), false ) );
 
-  std::unique_ptr< QgsProcessingParameterNumber > maxAttempts_param = std::make_unique< QgsProcessingParameterNumber >( QStringLiteral( "MAX_ATTEMPTS" ), QObject::tr( "Maximum number of search attempts given the minimum distance" ), QgsProcessingParameterNumber::Integer, 200, true, 1 );
-  maxAttempts_param->setFlags( maxAttempts_param->flags() | QgsProcessingParameterDefinition::FlagAdvanced );
+  std::unique_ptr<QgsProcessingParameterNumber> maxAttempts_param = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "MAX_ATTEMPTS" ), QObject::tr( "Maximum number of search attempts given the minimum distance" ), Qgis::ProcessingNumberParameterType::Integer, 200, true, 1 );
+  maxAttempts_param->setFlags( maxAttempts_param->flags() | Qgis::ProcessingParameterFlag::Advanced );
   addParameter( maxAttempts_param.release() );
 
-  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ), QObject::tr( "Random points" ), QgsProcessing::TypeVectorPoint ) );
+  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ), QObject::tr( "Random points" ), Qgis::ProcessingSourceType::VectorPoint ) );
 }
 
 QString QgsRandomPointsExtentAlgorithm::shortHelpString() const
@@ -73,7 +72,7 @@ QString QgsRandomPointsExtentAlgorithm::shortHelpString() const
                       "makes it impossible to create new points, either "
                       "distance can be decreased or the maximum number of attempts may be "
                       "increased."
-                    );
+  );
 }
 
 QgsRandomPointsExtentAlgorithm *QgsRandomPointsExtentAlgorithm::createInstance() const
@@ -94,12 +93,11 @@ bool QgsRandomPointsExtentAlgorithm::prepareAlgorithm( const QVariantMap &parame
 
 QVariantMap QgsRandomPointsExtentAlgorithm::processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback )
 {
-
   QgsFields fields = QgsFields();
-  fields.append( QgsField( QStringLiteral( "id" ), QVariant::LongLong ) );
+  fields.append( QgsField( QStringLiteral( "id" ), QMetaType::Type::LongLong ) );
 
   QString dest;
-  std::unique_ptr< QgsFeatureSink > sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, Qgis::WkbType::Point, mCrs ) );
+  std::unique_ptr<QgsFeatureSink> sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, Qgis::WkbType::Point, mCrs ) );
   if ( !sink )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
@@ -153,8 +151,7 @@ QVariantMap QgsRandomPointsExtentAlgorithm::processAlgorithm( const QVariantMap
         f.setAttributes( QgsAttributes() << i );
         const QgsGeometry randomPointGeom = QgsGeometry( new QgsPoint( rx, ry ) );
         f.setGeometry( randomPointGeom );
-        if ( !index.addFeature( f ) ||
-             !sink->addFeature( f, QgsFeatureSink::FastInsert ) )
+        if ( !index.addFeature( f ) || !sink->addFeature( f, QgsFeatureSink::FastInsert ) )
           throw QgsProcessingException( writeFeatureError( sink.get(), parameters, QStringLiteral( "OUTPUT" ) ) );
         i++;
         distCheckIterations = 0; //reset distCheckIterations if a point is added
@@ -165,16 +162,17 @@ QVariantMap QgsRandomPointsExtentAlgorithm::processAlgorithm( const QVariantMap
         if ( distCheckIterations == mMaxAttempts )
         {
           throw QgsProcessingException( QObject::tr( "%1 of %2 points have been successfully created, but no more random points could be found "
-                                        "due to the given minimum distance between points. Either choose a larger extent, "
-                                        "lower the minimum distance between points or try increasing the number "
-                                        "of attempts for searching new points." ).arg( i ).arg( mNumPoints ) );
+                                                     "due to the given minimum distance between points. Either choose a larger extent, "
+                                                     "lower the minimum distance between points or try increasing the number "
+                                                     "of attempts for searching new points." )
+                                          .arg( i )
+                                          .arg( mNumPoints ) );
         }
         else
         {
           distCheckIterations++;
           continue; //retry with new point
         }
-
       }
     }
   }
