@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsbookmarklocatorfilter.h"
+#include "moc_qgsbookmarklocatorfilter.cpp"
 #include "qgisapp.h"
 #include "qgsfeedback.h"
 #include "qgsapplication.h"
@@ -66,6 +67,6 @@ void QgsBookmarkLocatorFilter::fetchResults( const QString &string, const QgsLoc
 
 void QgsBookmarkLocatorFilter::triggerResult( const QgsLocatorResult &result )
 {
-  const QModelIndex index = qvariant_cast<QModelIndex>( result.getUserData() );
+  const QModelIndex index = qvariant_cast<QModelIndex>( result.userData() );
   QgisApp::instance()->zoomToBookmarkIndex( index );
 }
