@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsnominatimlocatorfilter.h"
+#include "moc_qgsnominatimlocatorfilter.cpp"
 #include "qgssettings.h"
 #include "qgsmessagebaritem.h"
 #include "qgsmessagebar.h"
@@ -32,9 +33,15 @@ QgsNominatimLocatorFilter::QgsNominatimLocatorFilter( QgsGeocoderInterface *geoc
   setUseWithoutPrefix( false );
 }
 
+QgsNominatimLocatorFilter *QgsNominatimLocatorFilter::clone() const
+{
+  auto filter = std::make_unique< QgsNominatimLocatorFilter >( geocoder(), mCanvas );
+  filter->setFetchResultsDelay( fetchResultsDelay() );
+  return filter.release();
+}
+
 void QgsNominatimLocatorFilter::triggerResult( const QgsLocatorResult &result )
 {
-
   QgsSettings settings;
   if ( !settings.value( "locator_filters/nominatim_geocoder/attribution_shown", false, QgsSettings::App ).toBool() )
   {
@@ -42,8 +49,7 @@ void QgsNominatimLocatorFilter::triggerResult( const QgsLocatorResult &result )
 
     QgsMessageBarItem *messageWidget = QgsMessageBar::createMessage( tr( "The Nominatim geocoder data is made available by OpenStreetMap Foundation and contributors." ) );
     QPushButton *learnMoreButton = new QPushButton( tr( "Learn more" ) );
-    connect( learnMoreButton, &QPushButton::clicked, learnMoreButton, [ = ]
-    {
+    connect( learnMoreButton, &QPushButton::clicked, learnMoreButton, [=] {
       QDesktopServices::openUrl( QStringLiteral( "https://nominatim.org/" ) );
     } );
     messageWidget->layout()->addWidget( learnMoreButton );
