@@ -14,18 +14,23 @@
  ***************************************************************************/
 
 #include "qgsprojectelevationsettingswidget.h"
+#include "moc_qgsprojectelevationsettingswidget.cpp"
 #include "qgsapplication.h"
 #include "qgsproject.h"
 #include "qgsterrainprovider.h"
 #include "qgsprojectelevationproperties.h"
 #include "qgsrasterlayerelevationproperties.h"
 #include "qgselevationshadingrenderersettingswidget.h"
+#include "qgsprojectionselectionwidget.h"
 
 QgsProjectElevationSettingsWidget::QgsProjectElevationSettingsWidget( QWidget *parent )
   : QgsOptionsPageWidget( parent )
 {
   setupUi( this );
 
+  mElevationLowerSpin->setClearValueMode( QgsDoubleSpinBox::ClearValueMode::MinimumValue, tr( "Not set" ) );
+  mElevationUpperSpin->setClearValueMode( QgsDoubleSpinBox::ClearValueMode::MinimumValue, tr( "Not set" ) );
+
   mFlatHeightSpinBox->setClearValue( 0.0 );
 
   mDemOffsetSpinBox->setClearValue( 0.0 );
@@ -40,9 +45,21 @@ QgsProjectElevationSettingsWidget::QgsProjectElevationSettingsWidget( QWidget *p
   mComboTerrainType->addItem( tr( "DEM (Raster Layer)" ), QStringLiteral( "raster" ) );
   mComboTerrainType->addItem( tr( "Mesh" ), QStringLiteral( "mesh" ) );
 
+  mVerticalCrsStackedWidget->setSizeMode( QgsStackedWidget::SizeMode::CurrentPageOnly );
+
+  QVBoxLayout *vl = new QVBoxLayout();
+  vl->setContentsMargins( 0, 0, 0, 0 );
+  mVerticalCrsWidget = new QgsProjectionSelectionWidget( nullptr, QgsCoordinateReferenceSystemProxyModel::FilterVertical );
+  mVerticalCrsWidget->setOptionVisible( QgsProjectionSelectionWidget::CrsNotSet, true );
+  mVerticalCrsWidget->setNotSetText( tr( "Not set" ) );
+  mVerticalCrsWidget->setDialogTitle( tr( "Project Vertical CRS" ) );
+  vl->addWidget( mVerticalCrsWidget );
+  mCrsPageEnabled->setLayout( vl );
+
+  mStackedWidget->setSizeMode( QgsStackedWidget::SizeMode::CurrentPageOnly );
+
   mStackedWidget->setCurrentWidget( mPageFlat );
-  connect( mComboTerrainType, qOverload< int >( &QComboBox::currentIndexChanged ), this, [ = ]
-  {
+  connect( mComboTerrainType, qOverload<int>( &QComboBox::currentIndexChanged ), this, [=] {
     const QString terrainType = mComboTerrainType->currentData().toString();
     if ( terrainType == QLatin1String( "flat" ) )
     {
@@ -60,7 +77,8 @@ QgsProjectElevationSettingsWidget::QgsProjectElevationSettingsWidget( QWidget *p
   } );
 
   // setup with current settings
-  const QgsAbstractTerrainProvider *provider = QgsProject::instance()->elevationProperties()->terrainProvider();
+  QgsProjectElevationProperties *elevationProperties = QgsProject::instance()->elevationProperties();
+  const QgsAbstractTerrainProvider *provider = elevationProperties->terrainProvider();
   mComboTerrainType->setCurrentIndex( mComboTerrainType->findData( provider->type() ) );
   if ( provider->type() == QLatin1String( "flat" ) )
   {
@@ -72,19 +90,31 @@ QgsProjectElevationSettingsWidget::QgsProjectElevationSettingsWidget( QWidget *p
     mStackedWidget->setCurrentWidget( mPageRasterDem );
     mDemOffsetSpinBox->setValue( provider->offset() );
     mDemScaleSpinBox->setValue( provider->scale() );
-    mComboDemLayer->setLayer( qgis::down_cast< const QgsRasterDemTerrainProvider * >( provider )->layer() );
+    mComboDemLayer->setLayer( qgis::down_cast<const QgsRasterDemTerrainProvider *>( provider )->layer() );
   }
   else if ( provider->type() == QLatin1String( "mesh" ) )
   {
     mStackedWidget->setCurrentWidget( mPageMesh );
     mMeshOffsetSpinBox->setValue( provider->offset() );
     mMeshScaleSpinBox->setValue( provider->scale() );
-    mComboMeshLayer->setLayer( qgis::down_cast< const QgsMeshTerrainProvider * >( provider )->layer() );
+    mComboMeshLayer->setLayer( qgis::down_cast<const QgsMeshTerrainProvider *>( provider )->layer() );
   }
 
   connect( mComboDemLayer, &QgsMapLayerComboBox::layerChanged, this, &QgsProjectElevationSettingsWidget::validate );
   connect( mComboMeshLayer, &QgsMapLayerComboBox::layerChanged, this, &QgsProjectElevationSettingsWidget::validate );
 
+  if ( elevationProperties->elevationRange().lower() != std::numeric_limits<double>::lowest() )
+    whileBlocking( mElevationLowerSpin )->setValue( elevationProperties->elevationRange().lower() );
+  else
+    whileBlocking( mElevationLowerSpin )->clear();
+  if ( elevationProperties->elevationRange().upper() != std::numeric_limits<double>::max() )
+    whileBlocking( mElevationUpperSpin )->setValue( elevationProperties->elevationRange().upper() );
+  else
+    whileBlocking( mElevationUpperSpin )->clear();
+
+  updateVerticalCrsOptions();
+  connect( QgsProject::instance(), &QgsProject::crsChanged, this, &QgsProjectElevationSettingsWidget::updateVerticalCrsOptions );
+
   validate();
 
   mElevationShadingSettingsWidget = new QgsElevationShadingRendererSettingsWidget( nullptr, nullptr, this );
@@ -94,36 +124,91 @@ QgsProjectElevationSettingsWidget::QgsProjectElevationSettingsWidget( QWidget *p
 void QgsProjectElevationSettingsWidget::apply()
 {
   const QString terrainType = mComboTerrainType->currentData().toString();
-  std::unique_ptr< QgsAbstractTerrainProvider > provider;
+  std::unique_ptr<QgsAbstractTerrainProvider> provider;
   if ( terrainType == QLatin1String( "flat" ) )
   {
-    provider = std::make_unique< QgsFlatTerrainProvider >();
+    provider = std::make_unique<QgsFlatTerrainProvider>();
     provider->setOffset( mFlatHeightSpinBox->value() );
     provider->setScale( 1.0 );
   }
   else if ( terrainType == QLatin1String( "raster" ) )
   {
-    provider = std::make_unique< QgsRasterDemTerrainProvider >();
+    provider = std::make_unique<QgsRasterDemTerrainProvider>();
     provider->setOffset( mDemOffsetSpinBox->value() );
     provider->setScale( mDemScaleSpinBox->value() );
-    QgsRasterLayer *demLayer = qobject_cast< QgsRasterLayer * >( mComboDemLayer->currentLayer() );
+    QgsRasterLayer *demLayer = qobject_cast<QgsRasterLayer *>( mComboDemLayer->currentLayer() );
     // always mark the terrain layer as a "dem" layer -- it seems odd for a user to have to manually set this after picking a terrain raster!
-    qobject_cast< QgsRasterLayerElevationProperties * >( demLayer->elevationProperties() )->setEnabled( true );
-    qgis::down_cast< QgsRasterDemTerrainProvider * >( provider.get() )->setLayer( demLayer );
+    qobject_cast<QgsRasterLayerElevationProperties *>( demLayer->elevationProperties() )->setEnabled( true );
+    qobject_cast<QgsRasterLayerElevationProperties *>( demLayer->elevationProperties() )->setMode( Qgis::RasterElevationMode::RepresentsElevationSurface );
+    qgis::down_cast<QgsRasterDemTerrainProvider *>( provider.get() )->setLayer( demLayer );
   }
   else if ( terrainType == QLatin1String( "mesh" ) )
   {
-    provider = std::make_unique< QgsMeshTerrainProvider >();
+    provider = std::make_unique<QgsMeshTerrainProvider>();
     provider->setOffset( mMeshOffsetSpinBox->value() );
     provider->setScale( mMeshScaleSpinBox->value() );
-    qgis::down_cast< QgsMeshTerrainProvider * >( provider.get() )->setLayer( qobject_cast< QgsMeshLayer * >( mComboMeshLayer->currentLayer() ) );
+    qgis::down_cast<QgsMeshTerrainProvider *>( provider.get() )->setLayer( qobject_cast<QgsMeshLayer *>( mComboMeshLayer->currentLayer() ) );
   }
 
   QgsProject::instance()->elevationProperties()->setTerrainProvider( provider.release() );
 
+  double zLower = mElevationLowerSpin->value();
+  if ( zLower == mElevationLowerSpin->clearValue() )
+    zLower = std::numeric_limits<double>::lowest();
+  double zUpper = mElevationUpperSpin->value();
+  if ( zUpper == mElevationUpperSpin->clearValue() )
+    zUpper = std::numeric_limits<double>::max();
+
+  QgsProject::instance()->elevationProperties()->setElevationRange( QgsDoubleRange( zLower, zUpper ) );
+
+  QgsProject::instance()->setVerticalCrs( mVerticalCrsWidget->crs() );
+
   mElevationShadingSettingsWidget->apply();
 }
 
+void QgsProjectElevationSettingsWidget::updateVerticalCrsOptions()
+{
+  switch ( QgsProject::instance()->crs().type() )
+  {
+    case Qgis::CrsType::Compound:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Project coordinate reference system is set to a compound CRS (%1), so the project's vertical CRS is the vertical component of this CRS (%2)." ).arg( QgsProject::instance()->crs().userFriendlyIdentifier(), QgsProject::instance()->verticalCrs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Geographic3d:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Project coordinate reference system is set to a geographic 3D CRS (%1), so the vertical CRS cannot be manually specified." ).arg( QgsProject::instance()->crs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Geocentric:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+      mCrsDisabledLabel->setText( tr( "Project coordinate reference system is set to a geocentric CRS (%1), so the vertical CRS cannot be manually specified." ).arg( QgsProject::instance()->crs().userFriendlyIdentifier() ) );
+      break;
+
+    case Qgis::CrsType::Projected:
+      if ( QgsProject::instance()->crs().hasVerticalAxis() )
+      {
+        mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageDisabled );
+        mCrsDisabledLabel->setText( tr( "Project coordinate reference system is set to a projected 3D CRS (%1), so the vertical CRS cannot be manually specified." ).arg( QgsProject::instance()->crs().userFriendlyIdentifier() ) );
+        break;
+      }
+      [[fallthrough]];
+
+    case Qgis::CrsType::Unknown:
+    case Qgis::CrsType::Geodetic:
+    case Qgis::CrsType::Geographic2d:
+    case Qgis::CrsType::Vertical:
+    case Qgis::CrsType::Temporal:
+    case Qgis::CrsType::Engineering:
+    case Qgis::CrsType::Bound:
+    case Qgis::CrsType::Other:
+    case Qgis::CrsType::DerivedProjected:
+      mVerticalCrsStackedWidget->setCurrentWidget( mCrsPageEnabled );
+      mVerticalCrsWidget->setCrs( QgsProject::instance()->verticalCrs() );
+      break;
+  }
+}
+
 bool QgsProjectElevationSettingsWidget::validate()
 {
   mMessageBar->clearWidgets();
@@ -160,7 +245,7 @@ bool QgsProjectElevationSettingsWidget::isValid()
 //
 
 QgsProjectElevationSettingsWidgetFactory::QgsProjectElevationSettingsWidgetFactory( QObject *parent )
-  : QgsOptionsWidgetFactory( tr( "Terrain" ), QgsApplication::getThemeIcon( QStringLiteral( "mLayoutItem3DMap.svg" ) ), QStringLiteral( "terrain" ) )
+  : QgsOptionsWidgetFactory( tr( "Elevation" ), QgsApplication::getThemeIcon( QStringLiteral( "propertyicons/elevationscale.svg" ) ), QStringLiteral( "terrain" ) )
 {
   setParent( parent );
 }
