@@ -16,19 +16,19 @@
  ***************************************************************************/
 
 #include "qgsmaptoolformannotation.h"
+#include "moc_qgsmaptoolformannotation.cpp"
 #include "qgsformannotation.h"
 #include "qgsmapcanvas.h"
 #include "qgsvectorlayer.h"
 #include "qgsproject.h"
 #include <QMouseEvent>
 
-QgsMapToolFormAnnotation::QgsMapToolFormAnnotation( QgsMapCanvas *canvas ): QgsMapToolAnnotation( canvas )
+QgsMapToolFormAnnotation::QgsMapToolFormAnnotation( QgsMapCanvas *canvas )
+  : QgsMapToolAnnotation( canvas )
 {
-
 }
 
 QgsAnnotation *QgsMapToolFormAnnotation::createItem() const
 {
   return new QgsFormAnnotation();
 }
-
