@@ -16,6 +16,7 @@
 #include <QLayout>
 
 #include "qgsselectbyformdialog.h"
+#include "moc_qgsselectbyformdialog.cpp"
 #include "qgsattributeform.h"
 #include "qgsmapcanvas.h"
 #include "qgssettings.h"
@@ -72,16 +73,12 @@ void QgsSelectByFormDialog::zoomToFeatures( const QString &filter )
   {
     if ( mMessageBar )
     {
-      mMessageBar->pushMessage( QString(),
-                                tr( "Zoomed to %n matching feature(s)", "number of matching features", featureCount ),
-                                Qgis::MessageLevel::Info );
+      mMessageBar->pushMessage( QString(), tr( "Zoomed to %n matching feature(s)", "number of matching features", featureCount ), Qgis::MessageLevel::Info );
     }
   }
   else if ( mMessageBar )
   {
-    mMessageBar->pushMessage( QString(),
-                              tr( "No matching features found" ),
-                              Qgis::MessageLevel::Info );
+    mMessageBar->pushMessage( QString(), tr( "No matching features found" ), Qgis::MessageLevel::Info );
   }
 }
 
@@ -90,9 +87,7 @@ void QgsSelectByFormDialog::flashFeatures( const QString &filter )
   const long featureCount = QgsMapCanvasUtils::flashMatchingFeatures( mMapCanvas, mLayer, filter );
   if ( featureCount == 0 && mMessageBar )
   {
-    mMessageBar->pushMessage( QString(),
-                              tr( "No matching features found" ),
-                              Qgis::MessageLevel::Info );
+    mMessageBar->pushMessage( QString(), tr( "No matching features found" ), Qgis::MessageLevel::Info );
   }
 }
 
@@ -109,9 +104,7 @@ void QgsSelectByFormDialog::openFeaturesAttributeTable( const QString &filter )
   {
     if ( mMessageBar )
     {
-      mMessageBar->pushMessage( QString(),
-                                tr( "No matching features found" ),
-                                Qgis::MessageLevel::Info );
+      mMessageBar->pushMessage( QString(), tr( "No matching features found" ), Qgis::MessageLevel::Info );
     }
   }
 }
