@@ -17,10 +17,10 @@
 
 
 #include "qgspoint.h"
+#include "moc_qgspoint.cpp"
 #include "qgsapplication.h"
 #include "qgscoordinatetransform.h"
 #include "qgsgeometryutils.h"
-#include "qgsmaptopixel.h"
 #include "qgswkbptr.h"
 #include "qgsgeometrytransformer.h"
 #include "qgsbox3d.h"
@@ -107,7 +107,7 @@ QgsPoint *QgsPoint::clone() const
   return new QgsPoint( *this );
 }
 
-QgsPoint *QgsPoint::snappedToGrid( double hSpacing, double vSpacing, double dSpacing, double mSpacing ) const
+QgsPoint *QgsPoint::snappedToGrid( double hSpacing, double vSpacing, double dSpacing, double mSpacing, bool ) const
 {
   // helper function
   auto gridifyValue = []( double value, double spacing, bool extraCondition = true ) -> double
@@ -128,6 +128,11 @@ QgsPoint *QgsPoint::snappedToGrid( double hSpacing, double vSpacing, double dSpa
   return new QgsPoint( mWkbType, x, y, z, m );
 }
 
+QgsPoint *QgsPoint::simplifyByDistance( double ) const
+{
+  return clone();
+}
+
 bool QgsPoint::removeDuplicateNodes( double, bool )
 {
   return false;
@@ -179,11 +184,7 @@ bool QgsPoint::fromWkt( const QString &wkt )
     return true;
 
   const thread_local QRegularExpression rx( QStringLiteral( "\\s" ) );
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-  QStringList coordinates = parts.second.split( rx, QString::SkipEmptyParts );
-#else
   QStringList coordinates = parts.second.split( rx, Qt::SkipEmptyParts );
-#endif
 
   // So far the parser hasn't looked at the coordinates. We'll avoid having anything but numbers and return NULL instead of 0 as a coordinate.
   // Without this check, "POINT (a, b)" or "POINT (( 4, 3 ))" returned "POINT (0 ,0)"
@@ -683,42 +684,6 @@ void QgsPoint::transformVertices( const std::function<QgsPoint( const QgsPoint &
   clearCache();
 }
 
-double QgsPoint::distance3D( double x, double y, double z ) const
-{
-  double zDistSquared = 0.0;
-  if ( is3D() || !std::isnan( z ) )
-    zDistSquared = ( mZ - z ) * ( mZ - z );
-
-  return std::sqrt( ( mX - x ) * ( mX - x ) + ( mY - y ) * ( mY - y ) + zDistSquared );
-}
-
-double QgsPoint::distance3D( const QgsPoint &other ) const
-{
-  double zDistSquared = 0.0;
-  if ( is3D() || other.is3D() )
-    zDistSquared = ( mZ - other.z() ) * ( mZ - other.z() );
-
-  return std::sqrt( ( mX - other.x() ) * ( mX - other.x() ) + ( mY - other.y() ) * ( mY - other.y() ) + zDistSquared );
-}
-
-double QgsPoint::distanceSquared3D( double x, double y, double z ) const
-{
-  double zDistSquared = 0.0;
-  if ( is3D() || !std::isnan( z ) )
-    zDistSquared = ( mZ - z ) * ( mZ - z );
-
-  return ( mX - x ) * ( mX - x ) + ( mY - y ) * ( mY - y ) + zDistSquared;
-}
-
-double QgsPoint::distanceSquared3D( const QgsPoint &other ) const
-{
-  double zDistSquared = 0.0;
-  if ( is3D() || other.is3D() )
-    zDistSquared = ( mZ - other.z() ) * ( mZ - other.z() );
-
-  return ( mX - other.x() ) * ( mX - other.x() ) + ( mY - other.y() ) * ( mY - other.y() ) + zDistSquared;
-}
-
 double QgsPoint::azimuth( const QgsPoint &other ) const
 {
   const double dx = other.x() - mX;
