@@ -25,6 +25,7 @@
 #include <QElapsedTimer>
 
 #include "qgsmeshlayerrenderer.h"
+#include "moc_qgsmeshlayerrenderer.cpp"
 
 #include "qgslogger.h"
 #include "qgsmeshlayer.h"
@@ -34,11 +35,15 @@
 #include "qgsmeshlayerinterpolator.h"
 #include "qgsmeshlayerutils.h"
 #include "qgsmeshvectorrenderer.h"
+#include "qgsmeshlayerlabeling.h"
+#include "qgsmeshlayerlabelprovider.h"
 #include "qgsmapclippingutils.h"
 #include "qgscolorrampshader.h"
 #include "qgsmaplayerelevationproperties.h"
 #include "qgsapplication.h"
 #include "qgsruntimeprofiler.h"
+#include "qgsexpressioncontextutils.h"
+#include "qgsmeshlayerelevationproperties.h"
 
 QgsMeshLayerRenderer::QgsMeshLayerRenderer(
   QgsMeshLayer *layer,
@@ -70,6 +75,77 @@ QgsMeshLayerRenderer::QgsMeshLayerRenderer(
   mNativeMesh = *( layer->nativeMesh() );
   mLayerExtent = layer->extent();
 
+  if ( layer->elevationProperties() && layer->elevationProperties()->hasElevation() )
+  {
+    QgsMeshLayerElevationProperties *elevProp = qobject_cast<QgsMeshLayerElevationProperties *>( layer->elevationProperties() );
+
+    mRenderElevationMap = true;
+    mElevationScale = elevProp->zScale();
+    mElevationOffset = elevProp->zOffset();
+
+    if ( !context.zRange().isInfinite() )
+    {
+      switch ( elevProp->mode() )
+      {
+        case Qgis::MeshElevationMode::FixedElevationRange:
+          // don't need to handle anything here -- the layer renderer will never be created if the
+          // render context range doesn't match the layer's fixed elevation range
+          break;
+
+        case Qgis::MeshElevationMode::FromVertices:
+        {
+          // TODO -- filtering by mesh z values is not currently implemented
+          break;
+        }
+
+        case Qgis::MeshElevationMode::FixedRangePerGroup:
+        {
+          // find the top-most group which matches the map range and parent group
+          int currentMatchingVectorGroup = -1;
+          int currentMatchingScalarGroup = -1;
+          QgsDoubleRange currentMatchingVectorRange;
+          QgsDoubleRange currentMatchingScalarRange;
+
+          const QMap<int, QgsDoubleRange > rangePerGroup = elevProp->fixedRangePerGroup();
+
+          const int activeVectorDatasetGroup = mRendererSettings.activeVectorDatasetGroup();
+          const int activeScalarDatasetGroup = mRendererSettings.activeScalarDatasetGroup();
+
+          for ( auto it = rangePerGroup.constBegin(); it != rangePerGroup.constEnd(); ++it )
+          {
+            if ( it.value().overlaps( context.zRange() ) )
+            {
+              const bool matchesVectorParentGroup = QgsMeshLayerUtils::haveSameParentQuantity( layer, QgsMeshDatasetIndex( activeVectorDatasetGroup ), QgsMeshDatasetIndex( it.key() ) );
+              const bool matchesScalarParentGroup = QgsMeshLayerUtils::haveSameParentQuantity( layer, QgsMeshDatasetIndex( activeScalarDatasetGroup ), QgsMeshDatasetIndex( it.key() ) );
+
+              if ( matchesVectorParentGroup && (
+                     currentMatchingVectorRange.isInfinite()
+                     || ( it.value().includeUpper() && it.value().upper() >= currentMatchingVectorRange.upper() )
+                     || ( !currentMatchingVectorRange.includeUpper() && it.value().upper() >= currentMatchingVectorRange.upper() ) ) )
+              {
+                currentMatchingVectorGroup = it.key();
+                currentMatchingVectorRange = it.value();
+              }
+
+              if ( matchesScalarParentGroup && (
+                     currentMatchingScalarRange.isInfinite()
+                     || ( it.value().includeUpper() && it.value().upper() >= currentMatchingScalarRange.upper() )
+                     || ( !currentMatchingScalarRange.includeUpper() && it.value().upper() >= currentMatchingScalarRange.upper() ) ) )
+              {
+                currentMatchingScalarGroup = it.key();
+                currentMatchingScalarRange = it.value();
+              }
+            }
+          }
+          if ( currentMatchingVectorGroup >= 0 )
+            mRendererSettings.setActiveVectorDatasetGroup( currentMatchingVectorGroup );
+          if ( currentMatchingScalarGroup >= 0 )
+            mRendererSettings.setActiveScalarDatasetGroup( currentMatchingScalarGroup );
+        }
+      }
+    }
+  }
+
   // copy triangular mesh
   copyTriangularMeshes( layer, context );
 
@@ -79,14 +155,10 @@ QgsMeshLayerRenderer::QgsMeshLayerRenderer(
 
   calculateOutputSize();
 
-  mClippingRegions = QgsMapClippingUtils::collectClippingRegionsForLayer( *renderContext(), layer );
+  QSet<QString> attrs;
+  prepareLabeling( layer, attrs );
 
-  if ( layer->elevationProperties() && layer->elevationProperties()->hasElevation() )
-  {
-    mRenderElevationMap = true;
-    mElevationScale = layer->elevationProperties()->zScale();
-    mElevationOffset = layer->elevationProperties()->zOffset();
-  }
+  mClippingRegions = QgsMapClippingUtils::collectClippingRegionsForLayer( *renderContext(), layer );
 
   mPreparationTime = timer.elapsed();
 }
@@ -128,9 +200,9 @@ void QgsMeshLayerRenderer::copyScalarDatasetValues( QgsMeshLayer *layer )
 {
   QgsMeshDatasetIndex datasetIndex;
   if ( renderContext()->isTemporal() )
-    datasetIndex = layer->activeScalarDatasetAtTime( renderContext()->temporalRange() );
+    datasetIndex = layer->activeScalarDatasetAtTime( renderContext()->temporalRange(), mRendererSettings.activeScalarDatasetGroup() );
   else
-    datasetIndex = layer->staticScalarDatasetIndex();
+    datasetIndex = layer->staticScalarDatasetIndex( mRendererSettings.activeScalarDatasetGroup() );
 
   // Find out if we can use cache up to date. If yes, use it and return
   const int datasetGroupCount = layer->datasetGroupCount();
@@ -181,7 +253,7 @@ void QgsMeshLayerRenderer::copyScalarDatasetValues( QgsMeshLayer *layer )
                                     mNativeMesh.faces.count() );
 
     // for data on faces, there could be request to interpolate the data to vertices
-    if ( method != QgsMeshRendererScalarSettings::None )
+    if ( method != QgsMeshRendererScalarSettings::NoResampling )
     {
       if ( mScalarDataType == QgsMeshDatasetGroupMetadata::DataType::DataOnFaces )
       {
@@ -229,9 +301,9 @@ void QgsMeshLayerRenderer::copyVectorDatasetValues( QgsMeshLayer *layer )
 {
   QgsMeshDatasetIndex datasetIndex;
   if ( renderContext()->isTemporal() )
-    datasetIndex = layer->activeVectorDatasetAtTime( renderContext()->temporalRange() );
+    datasetIndex = layer->activeVectorDatasetAtTime( renderContext()->temporalRange(), mRendererSettings.activeVectorDatasetGroup() );
   else
-    datasetIndex = layer->staticVectorDatasetIndex();
+    datasetIndex = layer->staticVectorDatasetIndex( mRendererSettings.activeVectorDatasetGroup() );
 
   // Find out if we can use cache up to date. If yes, use it and return
   const int datasetGroupCount = layer->datasetGroupCount();
@@ -333,6 +405,8 @@ bool QgsMeshLayerRenderer::render()
   renderMesh();
   renderVectorDataset();
 
+  registerLabelFeatures();
+
   return !renderContext()->renderingStopped();
 }
 
@@ -529,14 +603,14 @@ void QgsMeshLayerRenderer::renderScalarDatasetOnEdges( const QgsMeshRendererScal
   QgsRenderContext &context = *renderContext();
   const QVector<QgsMeshEdge> edges = mTriangularMesh.edges();
   const QVector<QgsMeshVertex> vertices = mTriangularMesh.vertices();
-  const QList<int> egdesInExtent = mTriangularMesh.edgeIndexesForRectangle( context.mapExtent() );
+  const QList<int> edgesInExtent = mTriangularMesh.edgeIndexesForRectangle( context.mapExtent() );
 
   QgsInterpolatedLineRenderer edgePlotter;
   edgePlotter.setInterpolatedColor( QgsInterpolatedLineColor( scalarSettings.colorRampShader() ) );
   edgePlotter.setInterpolatedWidth( QgsInterpolatedLineWidth( scalarSettings.edgeStrokeWidth() ) );
   edgePlotter.setWidthUnit( scalarSettings.edgeStrokeWidthUnit() );
 
-  for ( const int i : egdesInExtent )
+  for ( const int i : edgesInExtent )
   {
     if ( context.renderingStopped() )
       break;
@@ -648,3 +722,89 @@ void QgsMeshLayerRenderer::renderVectorDataset()
     renderer->draw();
 }
 
+void QgsMeshLayerRenderer::prepareLabeling( QgsMeshLayer *layer, QSet<QString> &attributeNames )
+{
+  QgsRenderContext &context = *renderContext();
+
+  if ( QgsLabelingEngine *engine = context.labelingEngine() )
+  {
+    if ( layer->labelsEnabled() )
+    {
+      mLabelProvider = layer->labeling()->provider( layer );
+      if ( mLabelProvider )
+      {
+        auto c = context.expressionContext();
+
+        c.appendScope( QgsExpressionContextUtils::meshExpressionScope( mLabelProvider->labelFaces() ? QgsMesh::Face : QgsMesh::Vertex ) );
+        c.lastScope()->setVariable( QStringLiteral( "_native_mesh" ), QVariant::fromValue( mNativeMesh ) );
+        context.setExpressionContext( c );
+
+        engine->addProvider( mLabelProvider );
+        if ( !mLabelProvider->prepare( context, attributeNames ) )
+        {
+          engine->removeProvider( mLabelProvider );
+          mLabelProvider = nullptr; // deleted by engine
+        }
+      }
+    }
+  }
+}
+
+void QgsMeshLayerRenderer::registerLabelFeatures()
+{
+  if ( !mLabelProvider )
+    return;
+
+  QgsRenderContext &context = *renderContext();
+
+  QgsExpressionContextScope *scope = context.expressionContext().activeScopeForVariable( QStringLiteral( "_native_mesh" ) );
+
+  const QList<int> trianglesInExtent = mTriangularMesh.faceIndexesForRectangle( renderContext()->mapExtent() );
+
+  if ( mLabelProvider->labelFaces() )
+  {
+    if ( !mTriangularMesh.contains( QgsMesh::ElementType::Face ) )
+      return;
+    const QSet<int> nativeFacesInExtent = QgsMeshUtils::nativeFacesFromTriangles( trianglesInExtent,
+                                          mTriangularMesh.trianglesToNativeFaces() );
+
+    for ( const int i : nativeFacesInExtent )
+    {
+      if ( context.renderingStopped() )
+        break;
+
+      if ( i < 0 || i >= mNativeMesh.faces.count() )
+        continue;
+
+      scope->setVariable( QStringLiteral( "_mesh_face_index" ), i, false );
+
+      QgsFeature f( i );
+      QgsGeometry geom = QgsMeshUtils::toGeometry( mNativeMesh.face( i ), mNativeMesh.vertices );
+      f.setGeometry( geom );
+      mLabelProvider->registerFeature( f, context );
+    }
+  }
+  else
+  {
+    if ( !mTriangularMesh.contains( QgsMesh::ElementType::Vertex ) )
+      return;
+    const QSet<int> nativeVerticesInExtent = QgsMeshUtils::nativeVerticesFromTriangles( trianglesInExtent,
+        mTriangularMesh.triangles() );
+
+    for ( const int i : nativeVerticesInExtent )
+    {
+      if ( context.renderingStopped() )
+        break;
+
+      if ( i < 0 || i >= mNativeMesh.vertexCount() )
+        continue;
+
+      scope->setVariable( QStringLiteral( "_mesh_vertex_index" ), i, false );
+
+      QgsFeature f( i );
+      QgsGeometry geom = QgsGeometry( new QgsPoint( mNativeMesh.vertex( i ) ) );
+      f.setGeometry( geom );
+      mLabelProvider->registerFeature( f, context );
+    }
+  }
+}
