@@ -28,7 +28,6 @@
  */
 
 #include "pal.h"
-#include "palstat.h"
 #include "layer.h"
 #include "feature.h"
 #include "geomfunction.h"
@@ -37,6 +36,7 @@
 #include "util.h"
 #include "priorityqueue.h"
 #include "internalexception.h"
+#include "qgslabelingenginerule.h"
 #include <cfloat>
 #include <limits> //for std::numeric_limits<int>::max()
 
@@ -70,60 +70,52 @@ Problem::~Problem() = default;
 
 void Problem::reduce()
 {
-  int i;
-  int j;
   int k;
 
   int counter = 0;
 
   int lpid;
 
-  bool *ok = new bool[mTotalCandidates];
-  bool run = true;
+  std::vector<bool> ok( mTotalCandidates, false );
 
-  for ( i = 0; i < mTotalCandidates; i++ )
-    ok[i] = false;
-
-
-  double amin[2];
-  double amax[2];
   LabelPosition *lp2 = nullptr;
 
-  while ( run )
+  while ( true )
   {
     if ( pal->isCanceled() )
       break;
 
-    run = false;
-    for ( i = 0; i < static_cast< int >( mFeatureCount ); i++ )
+    bool finished = true;
+    for ( std::size_t feature = 0; feature < mFeatureCount; feature++ )
     {
       if ( pal->isCanceled() )
         break;
 
-      // ok[i] = true;
-      for ( j = 0; j < mFeatNbLp[i]; j++ )  // for each candidate
+      // for each candidate
+      const int totalCandidatesForFeature = mCandidateCountForFeature[feature];
+      for ( int candidateIndex = 0; candidateIndex < totalCandidatesForFeature; candidateIndex++ )
       {
-        if ( !ok[mFeatStartId[i] + j] )
+        if ( !ok[mFirstCandidateIndexForFeature[feature] + candidateIndex] )
         {
-          if ( mLabelPositions.at( mFeatStartId[i] + j )->getNumOverlaps() == 0 ) // if candidate has no overlap
+          if ( mLabelPositions.at( mFirstCandidateIndexForFeature[feature] + candidateIndex )->getNumOverlaps() == 0 ) // if candidate has no overlap
           {
-            run = true;
-            ok[mFeatStartId[i] + j] = true;
+            finished = false;
+            ok[mFirstCandidateIndexForFeature[feature] + candidateIndex] = true;
             // 1) remove worse candidates from candidates
             // 2) update nb_overlaps
-            counter += mFeatNbLp[i] - j - 1;
+            counter += totalCandidatesForFeature - candidateIndex - 1;
 
-            for ( k = j + 1; k < mFeatNbLp[i]; k++ )
+            for ( k = candidateIndex + 1; k < totalCandidatesForFeature; k++ )
             {
 
-              lpid = mFeatStartId[i] + k;
+              lpid = mFirstCandidateIndexForFeature[feature] + k;
               ok[lpid] = true;
               lp2 = mLabelPositions[lpid ].get();
 
-              lp2->getBoundingBox( amin, amax );
-
               mNbOverlap -= lp2->getNumOverlaps();
-              mAllCandidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [&lp2, this]( const LabelPosition * lp ) -> bool
+
+              const QgsRectangle searchBounds = lp2->boundingBoxForCandidateConflicts( pal );
+              mAllCandidatesIndex.intersects( searchBounds, [&lp2, this]( const LabelPosition * lp ) -> bool
               {
                 if ( candidatesAreConflicting( lp2, lp ) )
                 {
@@ -136,16 +128,18 @@ void Problem::reduce()
               lp2->removeFromIndex( mAllCandidatesIndex );
             }
 
-            mFeatNbLp[i] = j + 1;
+            mCandidateCountForFeature[feature] = candidateIndex + 1;
             break;
           }
         }
       }
     }
+
+    if ( finished )
+      break;
   }
 
   this->mTotalCandidates -= counter;
-  delete[] ok;
 }
 
 void Problem::ignoreLabel( const LabelPosition *lp, PriorityQueue &list, PalRtree< LabelPosition > &candidatesIndex )
@@ -154,10 +148,8 @@ void Problem::ignoreLabel( const LabelPosition *lp, PriorityQueue &list, PalRtre
   {
     list.remove( lp->getId() );
 
-    double amin[2];
-    double amax[2];
-    lp->getBoundingBox( amin, amax );
-    candidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [lp, &list, this]( const LabelPosition * lp2 )->bool
+    const QgsRectangle searchBounds = lp->boundingBoxForCandidateConflicts( pal );
+    candidatesIndex.intersects( searchBounds, [lp, &list, this]( const LabelPosition * lp2 )->bool
     {
       if ( lp2->getId() != lp->getId() && list.isIn( lp2->getId() ) && candidatesAreConflicting( lp2, lp ) )
       {
@@ -179,15 +171,14 @@ void Problem::init_sol_falp()
 
   PriorityQueue list( mTotalCandidates, mAllNblp, true );
 
-  double amin[2];
-  double amax[2];
-
   LabelPosition *lp = nullptr;
 
-  for ( int i = 0; i < static_cast< int >( mFeatureCount ); i++ )
-    for ( int j = 0; j < mFeatNbLp[i]; j++ )
+  for ( int feature = 0; feature < static_cast< int >( mFeatureCount ); feature++ )
+  {
+    const int totalCandidatesForFeature = mCandidateCountForFeature[feature];
+    for ( int candidateIndex = 0; candidateIndex < totalCandidatesForFeature; candidateIndex++ )
     {
-      label = mFeatStartId[i] + j;
+      label = mFirstCandidateIndexForFeature[feature] + candidateIndex;
       try
       {
         list.insert( label, mLabelPositions.at( label )->getNumOverlaps() );
@@ -197,6 +188,7 @@ void Problem::init_sol_falp()
         continue;
       }
     }
+  }
 
   while ( list.getSize() > 0 ) // O (log size)
   {
@@ -217,16 +209,15 @@ void Problem::init_sol_falp()
     const int probFeatId = lp->getProblemFeatureId();
     mSol.activeLabelIds[probFeatId] = label;
 
-    for ( int i = mFeatStartId[probFeatId]; i < mFeatStartId[probFeatId] + mFeatNbLp[probFeatId]; i++ )
+    for ( int candidateIndex = mFirstCandidateIndexForFeature[probFeatId]; candidateIndex < mFirstCandidateIndexForFeature[probFeatId] + mCandidateCountForFeature[probFeatId]; candidateIndex++ )
     {
-      ignoreLabel( mLabelPositions[ i ].get(), list, mAllCandidatesIndex );
+      ignoreLabel( mLabelPositions[ candidateIndex ].get(), list, mAllCandidatesIndex );
     }
 
 
-    lp->getBoundingBox( amin, amax );
-
+    const QgsRectangle searchBounds = lp->boundingBoxForCandidateConflicts( pal );
     std::vector< const LabelPosition * > conflictingPositions;
-    mAllCandidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [lp, &conflictingPositions, this]( const LabelPosition * lp2 ) ->bool
+    mAllCandidatesIndex.intersects( searchBounds, [lp, &conflictingPositions, this]( const LabelPosition * lp2 ) ->bool
     {
       if ( candidatesAreConflicting( lp, lp2 ) )
       {
@@ -240,31 +231,27 @@ void Problem::init_sol_falp()
       ignoreLabel( conflict, list, mAllCandidatesIndex );
     }
 
-    mActiveCandidatesIndex.insert( lp, QgsRectangle( amin[0], amin[1], amax[0], amax[1] ) );
+    mActiveCandidatesIndex.insert( lp, lp->outerBoundingBox() );
   }
 
   if ( mDisplayAll )
   {
-    int nbOverlap;
-    int start_p;
     LabelPosition *retainedLabel = nullptr;
-    int p;
 
     for ( std::size_t i = 0; i < mFeatureCount; i++ ) // forearch hidden feature
     {
       if ( mSol.activeLabelIds[i] == -1 )
       {
-        nbOverlap = std::numeric_limits<int>::max();
-        start_p = mFeatStartId[i];
-        for ( p = 0; p < mFeatNbLp[i]; p++ )
+        int nbOverlap = std::numeric_limits<int>::max();
+        const int firstCandidateIdForFeature = mFirstCandidateIndexForFeature[i];
+        const int totalCandidatesForFeature = mCandidateCountForFeature[i];
+        for ( int candidateIndexForFeature = 0; candidateIndexForFeature < totalCandidatesForFeature; candidateIndexForFeature++ )
         {
-          lp = mLabelPositions[ start_p + p ].get();
+          lp = mLabelPositions[ firstCandidateIdForFeature + candidateIndexForFeature ].get();
           lp->resetNumOverlaps();
 
-          lp->getBoundingBox( amin, amax );
-
-
-          mActiveCandidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [&lp, this]( const LabelPosition * lp2 )->bool
+          const QgsRectangle searchBounds = lp->boundingBoxForCandidateConflicts( pal );
+          mActiveCandidatesIndex.intersects( searchBounds, [&lp, this]( const LabelPosition * lp2 )->bool
           {
             if ( candidatesAreConflicting( lp, lp2 ) )
             {
@@ -290,7 +277,7 @@ void Problem::init_sol_falp()
 
 bool Problem::candidatesAreConflicting( const LabelPosition *lp1, const LabelPosition *lp2 ) const
 {
-  return  pal->candidatesAreConflicting( lp1, lp2 );
+  return pal->candidatesAreConflicting( lp1, lp2 );
 }
 
 inline Chain *Problem::chain( int seed )
@@ -308,8 +295,6 @@ inline Chain *Problem::chain( int seed )
 
   const int max_degree = pal->mEjChainDeg;
 
-  int seedNbLp;
-
   QLinkedList<ElemTrans *> currentChain;
   QLinkedList<int> conflicts;
 
@@ -317,13 +302,12 @@ inline Chain *Problem::chain( int seed )
 
   LabelPosition *lp = nullptr;
 
-  double amin[2];
-  double amax[2];
-
+  // delta is actually related to the cost?
   delta = 0;
+  // seed is actually the feature number!
   while ( seed != -1 )
   {
-    seedNbLp = mFeatNbLp[seed];
+    const int totalCandidatesForThisFeature = mCandidateCountForFeature[seed];
     delta_min = std::numeric_limits<double>::max();
 
     next_seed = -1;
@@ -331,28 +315,27 @@ inline Chain *Problem::chain( int seed )
 
     // sol[seed] is ejected
     if ( tmpsol[seed] == -1 )
-      delta -= mInactiveCost[seed];
+      delta -= mUnlabeledCostForFeature[seed];
     else
       delta -= mLabelPositions.at( tmpsol[seed] )->cost();
 
-    for ( int i = -1; i < seedNbLp; i++ )
+    for ( int i = -1; i < totalCandidatesForThisFeature ; i++ )
     {
       try
       {
         // Skip active label !
-        if ( !( tmpsol[seed] == -1 && i == -1 ) && i + mFeatStartId[seed] != tmpsol[seed] )
+        if ( !( tmpsol[seed] == -1 && i == -1 ) && i + mFirstCandidateIndexForFeature[seed] != tmpsol[seed] )
         {
           if ( i != -1 ) // new_label
           {
-            lid = mFeatStartId[seed] + i;
+            lid = mFirstCandidateIndexForFeature[seed] + i;
             delta_tmp = delta;
 
             lp = mLabelPositions[ lid ].get();
 
+            const QgsRectangle searchBounds = lp->boundingBoxForCandidateConflicts( pal );
             // evaluate conflicts graph in solution after moving seed's label
-
-            lp->getBoundingBox( amin, amax );
-            mActiveCandidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [lp, &delta_tmp, &conflicts, &currentChain, this]( const LabelPosition * lp2 ) -> bool
+            mActiveCandidatesIndex.intersects( searchBounds, [lp, &delta_tmp, &conflicts, &currentChain, this]( const LabelPosition * lp2 ) -> bool
             {
               if ( candidatesAreConflicting( lp2, lp ) )
               {
@@ -371,7 +354,7 @@ inline Chain *Problem::chain( int seed )
                 if ( !conflicts.contains( feat ) )
                 {
                   conflicts.append( feat );
-                  delta_tmp += lp2->cost() + mInactiveCost[feat];
+                  delta_tmp += lp2->cost() + mUnlabeledCostForFeature[feat];
                 }
               }
               return true;
@@ -461,7 +444,7 @@ inline Chain *Problem::chain( int seed )
                 const int ftid = conflicts.takeFirst();
                 newChain->feat[j] = ftid;
                 newChain->label[j] = -1;
-                newChain->delta += mInactiveCost[ftid];
+                newChain->delta += mUnlabeledCostForFeature[ftid];
                 j++;
               }
 
@@ -482,7 +465,7 @@ inline Chain *Problem::chain( int seed )
           }
           else   // Current label == -1   end of chain ...
           {
-            if ( !retainedChain || delta + mInactiveCost[seed] < delta_best )
+            if ( !retainedChain || delta + mUnlabeledCostForFeature[seed] < delta_best )
             {
               if ( retainedChain )
               {
@@ -492,7 +475,7 @@ inline Chain *Problem::chain( int seed )
               else
                 retainedChain = new Chain();
 
-              delta_best = delta + mInactiveCost[seed];
+              delta_best = delta + mUnlabeledCostForFeature[seed];
 
               retainedChain->degree = currentChain.size() + 1;
               retainedChain->feat  = new int[retainedChain->degree];
@@ -510,7 +493,7 @@ inline Chain *Problem::chain( int seed )
               }
               retainedChain->feat[j] = seed;
               retainedChain->label[j] = -1;
-              retainedChain->delta = delta + mInactiveCost[seed];
+              retainedChain->delta = delta + mUnlabeledCostForFeature[seed];
             }
           }
         }
@@ -581,7 +564,6 @@ void Problem::chainSearch( QgsRenderContext & )
     return;
 
   int i;
-  int seed;
   bool *ok = new bool[mFeatureCount];
   int fid;
   int lid;
@@ -594,9 +576,8 @@ void Problem::chainSearch( QgsRenderContext & )
 
   int iter = 0;
 
-  double amin[2];
-  double amax[2];
-
+  // seed is actually the feature ID, maybe should be renamed?
+  int seed;
   while ( true )
   {
     for ( seed = ( iter + 1 ) % mFeatureCount;
@@ -625,8 +606,9 @@ void Problem::chainSearch( QgsRenderContext & )
         {
           LabelPosition *old = mLabelPositions[ mSol.activeLabelIds[fid] ].get();
           old->removeFromIndex( mActiveCandidatesIndex );
-          old->getBoundingBox( amin, amax );
-          mAllCandidatesIndex.intersects( QgsRectangle( amin[0], amin[1], amax[0], amax[1] ), [&ok, old, this]( const LabelPosition * lp ) ->bool
+
+          const QgsRectangle searchBounds = old->boundingBoxForCandidateConflicts( pal );
+          mAllCandidatesIndex.intersects( searchBounds, [&ok, old, this]( const LabelPosition * lp ) ->bool
           {
             if ( candidatesAreConflicting( old, lp ) )
             {
@@ -669,7 +651,7 @@ QList<LabelPosition *> Problem::getSolution( bool returnInactive, QList<LabelPos
   {
     const int labelId = mSol.activeLabelIds[i];
     const bool foundNonOverlappingPlacement = labelId != -1;
-    const int startIndexForLabelPlacements = mFeatStartId[i];
+    const int startIndexForLabelPlacements = mFirstCandidateIndexForFeature[i];
     const bool foundCandidatesForFeature = startIndexForLabelPlacements < static_cast< int >( mLabelPositions.size() );
 
     if ( foundNonOverlappingPlacement )
@@ -686,7 +668,7 @@ QList<LabelPosition *> Problem::getSolution( bool returnInactive, QList<LabelPos
     else if ( unlabeled )
     {
       // need to be careful here -- if the next feature's start id is the same as this one, then this feature had no candidates!
-      if ( foundCandidatesForFeature && ( i == mFeatureCount - 1 || startIndexForLabelPlacements != mFeatStartId[i + 1] ) )
+      if ( foundCandidatesForFeature && ( i == mFeatureCount - 1 || startIndexForLabelPlacements != mFirstCandidateIndexForFeature[i + 1] ) )
         unlabeled->push_back( mLabelPositions[ startIndexForLabelPlacements ].get() );
     }
   }
