@@ -34,6 +34,11 @@ QgsPointCloudBlock::QgsPointCloudBlock(
 {
 }
 
+QgsPointCloudBlock *QgsPointCloudBlock::clone() const
+{
+  return new QgsPointCloudBlock( *this );
+}
+
 const char *QgsPointCloudBlock::data() const
 {
   return mStorage.data();
