@@ -21,11 +21,9 @@
 #include "qgis_core.h"
 
 #include "qgsrasterlayer.h"
-#include "qgsmessagelog.h"
-#include "qgsspatialindex.h"
-#include "qgsprocessing.h"
 #include "qgsfeaturesink.h"
 #include "qgsfeaturesource.h"
+#include "qgsprocessing.h"
 #include "qgsproxyfeaturesink.h"
 #include "qgsremappingproxyfeaturesink.h"
 
@@ -40,6 +38,8 @@ class QgsProcessingAlgorithm;
 class QgsVectorTileLayer;
 class QgsPointCloudLayer;
 class QgsAnnotationLayer;
+class QgsVectorTileLayer;
+class QgsTiledSceneLayer;
 
 #include <QString>
 #include <QVariant>
@@ -48,10 +48,11 @@ class QgsAnnotationLayer;
  * \class QgsProcessingUtils
  * \ingroup core
  * \brief Utility functions for use with processing classes.
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsProcessingUtils
 {
+    Q_GADGET
+
   public:
 
     /**
@@ -65,6 +66,8 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatiblePluginLayers()
      * \see compatiblePointCloudLayers()
      * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      */
     static QList< QgsRasterLayer * > compatibleRasterLayers( QgsProject *project, bool sort = true );
@@ -85,6 +88,8 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatiblePluginLayers()
      * \see compatiblePointCloudLayers()
      * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      */
     static QList< QgsVectorLayer * > compatibleVectorLayers( QgsProject *project,
@@ -103,6 +108,8 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatiblePluginLayers()
      * \see compatiblePointCloudLayers()
      * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      *
      * \since QGIS 3.6
@@ -121,6 +128,8 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatibleMeshLayers()
      * \see compatiblePointCloudLayers()
      * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      *
      * \since QGIS 3.22
@@ -139,6 +148,8 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatibleMeshLayers()
      * \see compatiblePluginLayers()
      * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      *
      * \since QGIS 3.22
@@ -157,12 +168,54 @@ class CORE_EXPORT QgsProcessingUtils
      * \see compatibleMeshLayers()
      * \see compatiblePluginLayers()
      * \see compatiblePointCloudLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleTiledSceneLayers()
      * \see compatibleLayers()
      *
      * \since QGIS 3.22
      */
     static QList<QgsAnnotationLayer *> compatibleAnnotationLayers( QgsProject *project, bool sort = true );
 
+    /**
+     * Returns a list of vector tile layers from a \a project which are compatible with the processing
+     * framework.
+     *
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
+     * value.
+     *
+     * \see compatibleRasterLayers()
+     * \see compatibleVectorLayers()
+     * \see compatibleMeshLayers()
+     * \see compatiblePluginLayers()
+     * \see compatiblePointCloudLayers()
+     * \see compatibleAnnotationLayers()
+     * \see compatibleTiledSceneLayers()
+     * \see compatibleLayers()
+     *
+     * \since QGIS 3.32
+     */
+    static QList<QgsVectorTileLayer *> compatibleVectorTileLayers( QgsProject *project, bool sort = true );
+
+    /**
+     * Returns a list of tiled scene layers from a \a project which are compatible with the processing
+     * framework.
+     *
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
+     * value.
+     *
+     * \see compatibleRasterLayers()
+     * \see compatibleVectorLayers()
+     * \see compatibleMeshLayers()
+     * \see compatiblePluginLayers()
+     * \see compatiblePointCloudLayers()
+     * \see compatibleAnnotationLayers()
+     * \see compatibleVectorTileLayers()
+     * \see compatibleLayers()
+     *
+     * \since QGIS 3.34
+     */
+    static QList<QgsTiledSceneLayer *> compatibleTiledSceneLayers( QgsProject *project, bool sort = true );
+
     /**
      * Returns a list of map layers from a \a project which are compatible with the processing
      * framework.
@@ -207,7 +260,10 @@ class CORE_EXPORT QgsProcessingUtils
       Mesh, //!< Mesh layer type, since QGIS 3.6
       PointCloud, //!< Point cloud layer type, since QGIS 3.22
       Annotation, //!< Annotation layer type, since QGIS 3.22
+      VectorTile, //!< Vector tile layer type, since QGIS 3.32
+      TiledScene, //!< Tiled scene layer type, since QGIS 3.34
     };
+    Q_ENUM( LayerHint )
 
     /**
      * Interprets a string as a map layer within the supplied \a context.
@@ -221,7 +277,7 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * The \a typeHint can be used to dictate the type of map layer expected.
      */
-    static QgsMapLayer *mapLayerFromString( const QString &string, QgsProcessingContext &context, bool allowLoadingNewLayers = true, QgsProcessingUtils::LayerHint typeHint = QgsProcessingUtils::LayerHint::UnknownType );
+    static QgsMapLayer *mapLayerFromString( const QString &string, QgsProcessingContext &context, bool allowLoadingNewLayers = true, QgsProcessingUtils::LayerHint typeHint = QgsProcessingUtils::LayerHint::UnknownType, QgsProcessing::LayerOptionsFlags flags = QgsProcessing::LayerOptionsFlags() );
 
     /**
      * Converts a variant \a value to a new feature source.
@@ -250,13 +306,22 @@ class CORE_EXPORT QgsProcessingUtils
      * Normalizes a layer \a source string for safe comparison across different
      * operating system environments.
      */
-    static QString normalizeLayerSource( const QString &source );
+    static QString normalizeLayerSource( const QString &source ) SIP_HOLDGIL;
+
+    /**
+     * Returns a string representation of the source for a \a layer. The returned
+     * value is suitable for storage for subsequent executions of an algorithm
+     * using the same layer source.
+     *
+     * \since QGIS 3.34
+     */
+    static QString layerToStringIdentifier( const QgsMapLayer *layer, const QString &layerName = QString() ) SIP_HOLDGIL;
 
     /**
      * Converts a variant to a Python literal.
      *
      * \see stringToPythonLiteral()
-     * \since QGSIS 3.6
+     * \since QGIS 3.6
      */
     static QString variantToPythonLiteral( const QVariant &value );
 
@@ -265,7 +330,7 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * \see variantToPythonLiteral()
      */
-    static QString stringToPythonLiteral( const QString &string );
+    static QString stringToPythonLiteral( const QString &string ) SIP_HOLDGIL;
 
     /**
      * Creates a feature sink ready for adding features. The \a destination specifies a destination
@@ -288,7 +353,7 @@ class CORE_EXPORT QgsProcessingUtils
     static QgsFeatureSink *createFeatureSink( QString &destination,
         QgsProcessingContext &context,
         const QgsFields &fields,
-        QgsWkbTypes::Type geometryType,
+        Qgis::WkbType geometryType,
         const QgsCoordinateReferenceSystem &crs,
         const QVariantMap &createOptions = QVariantMap(),
         const QStringList &datasourceOptions = QStringList(),
@@ -316,7 +381,7 @@ class CORE_EXPORT QgsProcessingUtils
      * SIP bindings. c++ code should call the other createFeatureSink() version.
      * \note available in Python bindings as createFeatureSink()
      */
-    static void createFeatureSinkPython( QgsFeatureSink **sink SIP_OUT SIP_TRANSFERBACK, QString &destination SIP_INOUT, QgsProcessingContext &context, const QgsFields &fields, QgsWkbTypes::Type geometryType, const QgsCoordinateReferenceSystem &crs, const QVariantMap &createOptions = QVariantMap() ) SIP_THROW( QgsProcessingException ) SIP_PYNAME( createFeatureSink );
+    static void createFeatureSinkPython( QgsFeatureSink **sink SIP_OUT SIP_TRANSFERBACK, QString &destination SIP_INOUT, QgsProcessingContext &context, const QgsFields &fields, Qgis::WkbType geometryType, const QgsCoordinateReferenceSystem &crs, const QVariantMap &createOptions = QVariantMap() ) SIP_THROW( QgsProcessingException ) SIP_PYNAME( createFeatureSink );
 
 
     /**
@@ -330,7 +395,7 @@ class CORE_EXPORT QgsProcessingUtils
     /**
      * Combines the extent of several map \a layers. If specified, the target \a crs
      * will be used to transform the layer's extent to the desired output reference system.
-     * \deprecated Use version with QgsProcessingContext argument instead
+     * \deprecated QGIS 3.40. Use version with QgsProcessingContext argument instead.
      */
     Q_DECL_DEPRECATED static QgsRectangle combineLayerExtents( const QList<QgsMapLayer *> &layers, const QgsCoordinateReferenceSystem &crs = QgsCoordinateReferenceSystem() ) SIP_DEPRECATED;
 
@@ -346,7 +411,7 @@ class CORE_EXPORT QgsProcessingUtils
      * Returns a session specific processing temporary folder for use in processing algorithms.
      * \see generateTempFilename()
      */
-    static QString tempFolder();
+    static QString tempFolder( const QgsProcessingContext *context = nullptr );
 
     /**
      * Returns a temporary filename for a given file, putting it into
@@ -354,7 +419,7 @@ class CORE_EXPORT QgsProcessingUtils
      * but not changing the \a basename.
      * \see tempFolder()
      */
-    static QString generateTempFilename( const QString &basename );
+    static QString generateTempFilename( const QString &basename, const QgsProcessingContext *context = nullptr );
 
     /**
      * Returns a HTML formatted version of the help text encoded in a variant \a map for
@@ -376,6 +441,9 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * The \a featureLimit argument can be used to specify a limit on the number of features read from the layer.
      *
+     * Since QGIS 3.32, the optional \a filterExpression argument can be used to specify a expression to use
+     * to filter the features read from the layer.
+     *
      * When an algorithm is capable of handling multi-layer input files (such as Geopackage), it is preferable
      * to use convertToCompatibleFormatAndLayerName() which may avoid conversion in more situations.
      *
@@ -387,7 +455,9 @@ class CORE_EXPORT QgsProcessingUtils
         const QStringList &compatibleFormats,
         const QString &preferredFormat,
         QgsProcessingContext &context,
-        QgsProcessingFeedback *feedback, long long featureLimit = -1 );
+        QgsProcessingFeedback *feedback,
+        long long featureLimit = -1,
+        const QString &filterExpression = QString() );
 
     /**
      * Converts a source vector \a layer to a file path and layer name of a vector layer of compatible format.
@@ -416,6 +486,7 @@ class CORE_EXPORT QgsProcessingUtils
      * \param feedback feedback object
      * \param layerName will be set to the target layer name for multi-layer sources (e.g. Geopackage)
      * \param featureLimit can be used to place a limit on the maximum number of features read from the layer
+     * \param filterExpression optional expression for filtering features read from the layer (since QGIS 3.32)
      *
      * \returns path to source layer, or nearly converted compatible layer
      *
@@ -429,7 +500,9 @@ class CORE_EXPORT QgsProcessingUtils
         const QString &preferredFormat,
         QgsProcessingContext &context,
         QgsProcessingFeedback *feedback,
-        QString &layerName SIP_OUT, long long featureLimit = -1 );
+        QString &layerName SIP_OUT,
+        long long featureLimit = -1,
+        const QString &filterExpression = QString() );
 
     /**
      * Combines two field lists, avoiding duplicate field names (in a case-insensitive manner).
@@ -441,20 +514,20 @@ class CORE_EXPORT QgsProcessingUtils
      * length of field names, so be aware that the results of calling this method may
      * be truncated when saving to these formats.
      */
-    static QgsFields combineFields( const QgsFields &fieldsA, const QgsFields &fieldsB, const QString &fieldsBPrefix = QString() );
+    static QgsFields combineFields( const QgsFields &fieldsA, const QgsFields &fieldsB, const QString &fieldsBPrefix = QString() ) SIP_HOLDGIL;
 
     /**
      * Returns a list of field indices parsed from the given list of field names. Unknown field names are ignored.
      * If the list of field names is empty, it is assumed that all fields are required.
      * \since QGIS 3.2
      */
-    static QList<int> fieldNamesToIndices( const QStringList &fieldNames, const QgsFields &fields );
+    static QList<int> fieldNamesToIndices( const QStringList &fieldNames, const QgsFields &fields ) SIP_HOLDGIL;
 
     /**
      * Returns a subset of fields based on the indices of desired fields.
      * \since QGIS 3.2
      */
-    static QgsFields indicesToFields( const QList<int> &indices, const QgsFields &fields );
+    static QgsFields indicesToFields( const QList<int> &indices, const QgsFields &fields ) SIP_HOLDGIL;
 
     /**
      * Returns the default vector extension to use, in the absence of all other constraints (e.g.
@@ -465,6 +538,7 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * \see defaultRasterExtension()
      * \see defaultPointCloudExtension()
+     * \see defaultVectorTileExtension()
      * \since QGIS 3.10
      */
     static QString defaultVectorExtension();
@@ -478,6 +552,7 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * \see defaultVectorExtension()
      * \see defaultPointCloudExtension()
+     * \see defaultVectorTileExtension()
      * \since QGIS 3.10
      */
     static QString defaultRasterExtension();
@@ -490,10 +565,24 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * \see defaultVectorExtension()
      * \see defaultRasterExtension()
+     * \see defaultVectorTileExtension()
      * \since QGIS 3.24
      */
     static QString defaultPointCloudExtension();
 
+    /**
+     * Returns the default vector tile extension to use, in the absence of all other constraints (e.g.
+     * provider based support for extensions).
+     *
+     * This method returns a fallback value of "mbtiles".
+     *
+     * \see defaultVectorExtension()
+     * \see defaultRasterExtension()
+     * \see defaultPointCloudExtension()
+     * \since QGIS 3.32
+     */
+    static QString defaultVectorTileExtension();
+
     /**
      * Removes any raw pointer values from an input \a map, replacing them with
      * appropriate string values where possible.
@@ -502,13 +591,22 @@ class CORE_EXPORT QgsProcessingUtils
      */
     static QVariantMap removePointerValuesFromMap( const QVariantMap &map );
 
+    /**
+     * Pre-processes a set of \a parameter values for the qgis_process command.
+     *
+     * In particular, this function upgrades encoded data defined values to QgsProperty objects.
+     *
+     * \since QGIS 3.30
+     */
+    static QVariantMap preprocessQgisProcessParameters( const QVariantMap &parameters, bool &ok, QString &error );
+
     /**
      * Returns the default encoding.
      *
      * The default encoding could be the one from "/Processing/encoding" or when it's not an allowed encoding name
      * like "System", the default encoding system (mostly UTF-8 on Unix-like, windows-1252 on Windows).
      *
-     * \since QGIS 3.28
+     * \since QGIS 3.32
      */
     static QString resolveDefaultEncoding( const QString &defaultEncoding = "System" );
 
@@ -519,6 +617,7 @@ class CORE_EXPORT QgsProcessingUtils
     static bool canUseLayer( const QgsVectorTileLayer *layer );
     static bool canUseLayer( const QgsPointCloudLayer *layer );
     static bool canUseLayer( const QgsAnnotationLayer *layer );
+    static bool canUseLayer( const QgsTiledSceneLayer *layer );
     static bool canUseLayer( const QgsVectorLayer *layer,
                              const QList< int > &sourceTypes = QList< int >() );
 
@@ -558,7 +657,7 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * \since QGIS 3.8
      */
-    static QgsMapLayer *loadMapLayerFromString( const QString &string, const QgsCoordinateTransformContext &transformContext, LayerHint typeHint = LayerHint::UnknownType );
+    static QgsMapLayer *loadMapLayerFromString( const QString &string, const QgsCoordinateTransformContext &transformContext, LayerHint typeHint = LayerHint::UnknownType, QgsProcessing::LayerOptionsFlags flags = QgsProcessing::LayerOptionsFlags() );
 
     /**
      * Interprets a string as a map layer. The method will attempt to
@@ -566,7 +665,7 @@ class CORE_EXPORT QgsProcessingUtils
      * then the layer at this file path will be loaded.
      * The caller takes responsibility for deleting the returned map layer.
      *
-     * \deprecated use mapLayerFromString() that takes QgsCoordinateTransformContext as an argument instead
+     * \deprecated QGIS 3.40. Use mapLayerFromString() that takes QgsCoordinateTransformContext as an argument instead.
      */
     Q_DECL_DEPRECATED static QgsMapLayer *loadMapLayerFromString( const QString &string, LayerHint typeHint = LayerHint::UnknownType ) SIP_DEPRECATED ;
 
@@ -582,19 +681,11 @@ class CORE_EXPORT QgsProcessingUtils
  * \ingroup core
  * \brief QgsFeatureSource subclass which proxies methods to an underlying QgsFeatureSource, modifying
  * results according to the settings in a QgsProcessingContext.
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
 {
   public:
 
-    //! Flags controlling how QgsProcessingFeatureSource fetches features
-    enum Flag
-    {
-      FlagSkipGeometryValidityChecks = 1 << 1, //!< Invalid geometry checks should always be skipped. This flag can be useful for algorithms which always require invalid geometries, regardless of any user settings (e.g. "repair geometry" type algorithms).
-    };
-    Q_DECLARE_FLAGS( Flags, Flag )
-
     /**
      * Constructor for QgsProcessingFeatureSource, accepting an original feature source \a originalSource
      * and processing \a context.
@@ -604,9 +695,11 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
      *
      * If \a featureLimit is set to a value > 0, then a limit is placed on the maximum number of features which will be
      * read from the source.
+     *
+     * Since QGIS 3.32, the optional \a filterExpression can be used to specify an expression based filter for the source.
      */
     QgsProcessingFeatureSource( QgsFeatureSource *originalSource, const QgsProcessingContext &context, bool ownsOriginalSource = false,
-                                long long featureLimit = -1 );
+                                long long featureLimit = -1, const QString &filterExpression = QString() );
 
     ~QgsProcessingFeatureSource() override;
 
@@ -615,14 +708,14 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
      * An optional \a request can be used to optimise the returned
      * iterator, eg by restricting the returned attributes or geometry.
      */
-    QgsFeatureIterator getFeatures( const QgsFeatureRequest &request, Flags flags ) const;
+    QgsFeatureIterator getFeatures( const QgsFeatureRequest &request, Qgis::ProcessingFeatureSourceFlags flags ) const;
 
-    QgsFeatureSource::FeatureAvailability hasFeatures() const override;
+    Qgis::FeatureAvailability hasFeatures() const override;
 
     QgsFeatureIterator getFeatures( const QgsFeatureRequest &request = QgsFeatureRequest() ) const override;
     QgsCoordinateReferenceSystem sourceCrs() const override;
     QgsFields fields() const override;
-    QgsWkbTypes::Type wkbType() const override;
+    Qgis::WkbType wkbType() const override;
     long long featureCount() const override;
     QString sourceName() const override;
     QSet<QVariant> uniqueValues( int fieldIndex, int limit = -1 ) const override;
@@ -630,7 +723,7 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
     QVariant maximumValue( int fieldIndex ) const override;
     QgsRectangle sourceExtent() const override;
     QgsFeatureIds allFeatureIds() const override;
-    SpatialIndexPresence hasSpatialIndex() const override;
+    Qgis::SpatialIndexPresence hasSpatialIndex() const override;
 
     /**
      * Returns an expression context scope suitable for this source.
@@ -640,15 +733,31 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
     /**
      * Overrides the default geometry check method for the source.
      *
+     * \see invalidGeometryCheck()
      * \since QGIS 3.14
      */
-    void setInvalidGeometryCheck( QgsFeatureRequest::InvalidGeometryCheck method );
+    void setInvalidGeometryCheck( Qgis::InvalidGeometryCheck method );
+
+    /**
+     * Returns the geometry check method for the source.
+     *
+     * \see setInvalidGeometryCheck()
+     * \since QGIS 3.36
+     */
+    Qgis::InvalidGeometryCheck invalidGeometryCheck() const;
 
   private:
 
     QgsFeatureSource *mSource = nullptr;
     bool mOwnsSource = false;
-    QgsFeatureRequest::InvalidGeometryCheck mInvalidGeometryCheck = QgsFeatureRequest::GeometryNoCheck;
+    QgsCoordinateReferenceSystem mSourceCrs;
+    QgsFields mSourceFields;
+    Qgis::WkbType mSourceWkbType = Qgis::WkbType::Unknown;
+    QString mSourceName;
+    QgsRectangle mSourceExtent;
+    Qgis::SpatialIndexPresence mSourceSpatialIndexPresence = Qgis::SpatialIndexPresence::Unknown;
+
+    Qgis::InvalidGeometryCheck mInvalidGeometryCheck = Qgis::InvalidGeometryCheck::NoCheck;
     std::function< void( const QgsFeature & ) > mInvalidGeometryCallback;
     std::function< void( const QgsFeature & ) > mTransformErrorCallback;
 
@@ -656,6 +765,7 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
     std::function< void( const QgsFeature & ) > mInvalidGeometryCallbackAbort;
 
     long long mFeatureLimit = -1;
+    QString mFilterExpression;
 
 };
 
@@ -666,7 +776,6 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
  * \ingroup core
  * \brief QgsProxyFeatureSink subclass which reports feature addition errors to a QgsProcessingContext.
  * \note Not available in Python bindings.
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsProcessingFeatureSink : public QgsProxyFeatureSink
 {
