@@ -87,7 +87,6 @@ class CORE_EXPORT QgsCoordinateTransform
      * based on the current code context, or use the constructor variant which
      * accepts a QgsProject argument instead.
      *
-     * \since QGIS 3.0
      */
     explicit QgsCoordinateTransform( const QgsCoordinateReferenceSystem &source,
                                      const QgsCoordinateReferenceSystem &destination,
@@ -118,7 +117,6 @@ class CORE_EXPORT QgsCoordinateTransform
      * \warning Since QGIS 3.20 The QgsCoordinateTransform class can perform time-dependent transformations
      * between a static and dynamic CRS based on either the source OR destination CRS coordinate epoch,
      * however dynamic CRS to dynamic CRS transformations are not currently supported.
-     * \since QGIS 3.0
      */
     explicit QgsCoordinateTransform( const QgsCoordinateReferenceSystem &source,
                                      const QgsCoordinateReferenceSystem &destination,
@@ -130,26 +128,21 @@ class CORE_EXPORT QgsCoordinateTransform
      * to \a destination coordinate reference system, with the specified
      * datum transforms (see QgsDatumTransform).
      *
-     * \deprecated will be removed in QGIS 4.0. Use the constructor with a QgsCoordinateTransformContext argument instead.
-     * \since QGIS 3.0
+     * \deprecated QGIS 3.40. Will be removed in QGIS 4.0. Use the constructor with a QgsCoordinateTransformContext argument instead.
      */
     Q_DECL_DEPRECATED explicit QgsCoordinateTransform( const QgsCoordinateReferenceSystem &source,
         const QgsCoordinateReferenceSystem &destination,
         int sourceDatumTransformId,
         int destinationDatumTransformId ) SIP_DEPRECATED;
 
-    /**
-     * Copy constructor
-     */
     QgsCoordinateTransform( const QgsCoordinateTransform &o );
-
-    /**
-     * Assignment operator
-     */
     QgsCoordinateTransform &operator=( const QgsCoordinateTransform &o );
 
     ~QgsCoordinateTransform();
 
+    bool operator==( const QgsCoordinateTransform &other ) const;
+    bool operator!=( const QgsCoordinateTransform &other ) const;
+
     /**
      * Returns TRUE if it is theoretically possible to transform between \a source and \a destination CRSes.
      *
@@ -167,7 +160,6 @@ class CORE_EXPORT QgsCoordinateTransform
     /**
      * Returns TRUE if the coordinate transform is valid, ie both the source and destination
      * CRS have been set and are valid.
-     * \since QGIS 3.0
      */
     bool isValid() const;
 
@@ -191,7 +183,6 @@ class CORE_EXPORT QgsCoordinateTransform
      * Sets the \a context in which the coordinate transform should be
      * calculated.
      * \see context()
-     * \since QGIS 3.0
      */
     void setContext( const QgsCoordinateTransformContext &context );
 
@@ -266,6 +257,7 @@ class CORE_EXPORT QgsCoordinateTransform
      * \param handle180Crossover set to TRUE if destination CRS is geographic and handling of extents
      * crossing the 180 degree longitude line is required
      * \returns rectangle in destination CRS
+     * \warning Do not call this method if the transformation involves geocentric CRS -- in this situation transformation of a 2D bounding box is meaningless! Calling this method with a geocentric CRS will result in a QgsCsException being thrown.
      * \throws QgsCsException if the transformation fails
      */
     QgsRectangle transformBoundingBox( const QgsRectangle &rectangle, Qgis::TransformDirection direction = Qgis::TransformDirection::Forward, bool handle180Crossover = false ) const SIP_THROW( QgsCsException );
@@ -383,6 +375,14 @@ class CORE_EXPORT QgsCoordinateTransform
      */
     bool isShortCircuited() const;
 
+    /**
+     * Returns TRUE if the transform includes a vertical component, i.e. if both the sourceCrs()
+     * and destinationCrs() have a vertical axis.
+     *
+     * \since QGIS 3.40
+     */
+    bool hasVerticalComponent() const;
+
     /**
      * Returns a Proj string representing the coordinate operation which will be used to transform
      * coordinates.
@@ -530,7 +530,7 @@ class CORE_EXPORT QgsCoordinateTransform
      * \see setSourceDatumTransformId()
      * \see destinationDatumTransformId()
      *
-     * \deprecated Unused on builds based on Proj 6.0 or later
+     * \deprecated QGIS 3.40. Unused on builds based on Proj 6.0 or later.
      */
     Q_DECL_DEPRECATED int sourceDatumTransformId() const SIP_DEPRECATED;
 
@@ -545,7 +545,7 @@ class CORE_EXPORT QgsCoordinateTransform
      * \see sourceDatumTransformId()
      * \see setDestinationDatumTransformId()
      *
-     * \deprecated Unused on builds based on Proj 6.0 or later
+     * \deprecated QGIS 3.40. Unused on builds based on Proj 6.0 or later.
      */
     Q_DECL_DEPRECATED void setSourceDatumTransformId( int datumId ) SIP_DEPRECATED;
 
@@ -560,7 +560,7 @@ class CORE_EXPORT QgsCoordinateTransform
      * \see setDestinationDatumTransformId()
      * \see sourceDatumTransformId()
      *
-     * \deprecated Unused on builds based on Proj 6.0 or later
+     * \deprecated QGIS 3.40. Unused on builds based on Proj 6.0 or later.
      */
     Q_DECL_DEPRECATED int destinationDatumTransformId() const SIP_DEPRECATED;
 
@@ -575,7 +575,7 @@ class CORE_EXPORT QgsCoordinateTransform
      * \see destinationDatumTransformId()
      * \see setSourceDatumTransformId()
      *
-     * \deprecated Unused on builds based on Proj 6.0 or later
+     * \deprecated QGIS 3.40. Unused on builds based on Proj 6.0 or later.
      */
     Q_DECL_DEPRECATED void setDestinationDatumTransformId( int datumId ) SIP_DEPRECATED;
 
@@ -589,7 +589,6 @@ class CORE_EXPORT QgsCoordinateTransform
      * If \a disableCache is TRUE then the inbuilt cache will be completely disabled. This
      * argument is for internal use only.
      *
-     * \since QGIS 3.0
      */
     static void invalidateCache( bool disableCache = false );
 #else
@@ -599,7 +598,6 @@ class CORE_EXPORT QgsCoordinateTransform
      * This should be called whenever the srs database has
      * been modified in order to ensure that outdated CRS transforms are not created.
      *
-     * \since QGIS 3.0
      */
     static void invalidateCache( bool disableCache SIP_PYARGREMOVE = false );
 #endif
