@@ -16,6 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgis.h"
+#include "moc_qgis.cpp"
 #ifndef QGSVERSION
 #include "qgsversion.h"
 #endif
@@ -117,55 +118,144 @@ void qgsFree( void *ptr )
   free( ptr );
 }
 
-bool qgsVariantLessThan( const QVariant &lhs, const QVariant &rhs )
+int qgsVariantCompare( const QVariant &lhs, const QVariant &rhs )
 {
   // invalid < NULL < any value
   if ( !lhs.isValid() )
-    return rhs.isValid();
-  else if ( lhs.isNull() )
-    return rhs.isValid() && !rhs.isNull();
-  else if ( !rhs.isValid() || rhs.isNull() )
-    return false;
-
-  switch ( lhs.type() )
   {
-    case QVariant::Int:
-      return lhs.toInt() < rhs.toInt();
-    case QVariant::UInt:
-      return lhs.toUInt() < rhs.toUInt();
-    case QVariant::LongLong:
-      return lhs.toLongLong() < rhs.toLongLong();
-    case QVariant::ULongLong:
-      return lhs.toULongLong() < rhs.toULongLong();
-    case QVariant::Double:
-      return lhs.toDouble() < rhs.toDouble();
-    case QVariant::Char:
-      return lhs.toChar() < rhs.toChar();
-    case QVariant::Date:
-      return lhs.toDate() < rhs.toDate();
-    case QVariant::Time:
-      return lhs.toTime() < rhs.toTime();
-    case QVariant::DateTime:
-      return lhs.toDateTime() < rhs.toDateTime();
-    case QVariant::Bool:
-      return lhs.toBool() < rhs.toBool();
+    return rhs.isValid() ? -1 : 0;
+  }
+  else if ( lhs.isNull() )
+  {
+    if ( !rhs.isValid() )
+      return 1;
+    if ( rhs.isNull() )
+      return 0;
+    return -1;
+  }
+  else if ( !rhs.isValid() || rhs.isNull() )
+  {
+    return 1;
+  }
 
-    case QVariant::List:
+  // both valid
+  switch ( lhs.userType() )
+  {
+    case QMetaType::Type::Int:
+    case QMetaType::Type::Char:
+    case QMetaType::Type::Short:
+    {
+      const int lhsInt = lhs.toInt();
+      const int rhsInt = rhs.toInt();
+      return lhsInt < rhsInt ? -1 : ( lhsInt == rhsInt ? 0 : 1 );
+    }
+    case QMetaType::Type::UInt:
+    case QMetaType::Type::UChar:
+    case QMetaType::Type::UShort:
+    {
+      const uint lhsUInt = lhs.toUInt();
+      const uint rhsUInt = rhs.toUInt();
+      return lhsUInt < rhsUInt ? -1 : ( lhsUInt == rhsUInt ? 0 : 1 );
+    }
+    case QMetaType::Type::LongLong:
+    case QMetaType::Type::Long:
+    {
+      const qlonglong lhsLongLong = lhs.toLongLong();
+      const qlonglong rhsLongLong = rhs.toLongLong();
+      return lhsLongLong < rhsLongLong ? -1 : ( lhsLongLong == rhsLongLong ? 0 : 1 );
+    }
+    case QMetaType::Type::ULongLong:
+    case QMetaType::Type::ULong:
+    {
+      const qulonglong lhsULongLong = lhs.toULongLong();
+      const qulonglong rhsULongLong = rhs.toULongLong();
+      return lhsULongLong < rhsULongLong ? -1 : ( lhsULongLong == rhsULongLong ? 0 : 1 );
+    }
+    case QMetaType::Type::Double:
+    {
+      const double lhsDouble = lhs.toDouble();
+      const double rhsDouble = rhs.toDouble();
+
+      // consider NaN < any non-NaN
+      const bool lhsIsNan = std::isnan( lhsDouble );
+      const bool rhsIsNan = std::isnan( rhsDouble );
+      if ( lhsIsNan )
+      {
+        return rhsIsNan ? 0 : -1;
+      }
+      else if ( rhsIsNan )
+      {
+        return 1;
+      }
+
+      return lhsDouble < rhsDouble ? -1 : ( lhsDouble == rhsDouble ? 0 : 1 );
+    }
+    case QMetaType::Type::Float:
+    {
+      const float lhsFloat = lhs.toFloat();
+      const float rhsFloat = rhs.toFloat();
+
+      // consider NaN < any non-NaN
+      const bool lhsIsNan = std::isnan( lhsFloat );
+      const bool rhsIsNan = std::isnan( rhsFloat );
+      if ( lhsIsNan )
+      {
+        return rhsIsNan ? 0 : -1;
+      }
+      else if ( rhsIsNan )
+      {
+        return 1;
+      }
+
+      return lhsFloat < rhsFloat ? -1 : ( lhsFloat == rhsFloat ? 0 : 1 );
+    }
+    case QMetaType::Type::QChar:
+    {
+      const QChar lhsChar = lhs.toChar();
+      const QChar rhsChar = rhs.toChar();
+      return lhsChar < rhsChar ? -1 : ( lhsChar == rhsChar ? 0 : 1 );
+    }
+    case QMetaType::Type::QDate:
+    {
+      const QDate lhsDate = lhs.toDate();
+      const QDate rhsDate = rhs.toDate();
+      return lhsDate < rhsDate ? -1 : ( lhsDate == rhsDate ? 0 : 1 );
+    }
+    case QMetaType::Type::QTime:
+    {
+      const QTime lhsTime = lhs.toTime();
+      const QTime rhsTime = rhs.toTime();
+      return lhsTime < rhsTime ? -1 : ( lhsTime == rhsTime ? 0 : 1 );
+    }
+    case QMetaType::Type::QDateTime:
+    {
+      const QDateTime lhsTime = lhs.toDateTime();
+      const QDateTime rhsTime = rhs.toDateTime();
+      return lhsTime < rhsTime ? -1 : ( lhsTime == rhsTime ? 0 : 1 );
+    }
+    case QMetaType::Type::Bool:
+    {
+      const bool lhsBool = lhs.toBool();
+      const bool rhsBool = rhs.toBool();
+      return lhsBool == rhsBool ? 0 : ( lhsBool ? 1 : -1 );
+    }
+
+    case QMetaType::Type::QVariantList:
     {
       const QList<QVariant> &lhsl = lhs.toList();
       const QList<QVariant> &rhsl = rhs.toList();
 
       int i, n = std::min( lhsl.size(), rhsl.size() );
-      for ( i = 0; i < n && lhsl[i].type() == rhsl[i].type() && qgsVariantEqual( lhsl[i], rhsl[i] ); i++ )
+      for ( i = 0; i < n && lhsl[i].userType() == rhsl[i].userType() && qgsVariantCompare( lhsl[i], rhsl[i] ) == 0; i++ )
         ;
 
       if ( i == n )
-        return lhsl.size() < rhsl.size();
+        return lhsl.size() < rhsl.size() ? -1 : ( lhsl.size() > rhsl.size() ? 1 : 0 );
       else
-        return qgsVariantLessThan( lhsl[i], rhsl[i] );
+        return qgsVariantCompare( lhsl[i], rhsl[i] );
     }
 
-    case QVariant::StringList:
+    case QMetaType::Type::QStringList:
     {
       const QStringList &lhsl = lhs.toStringList();
       const QStringList &rhsl = rhs.toStringList();
@@ -175,21 +265,27 @@ bool qgsVariantLessThan( const QVariant &lhs, const QVariant &rhs )
         ;
 
       if ( i == n )
-        return lhsl.size() < rhsl.size();
+        return lhsl.size() < rhsl.size() ? -1 : ( lhsl.size() > rhsl.size() ? 1 : 0 );
       else
-        return lhsl[i] < rhsl[i];
+        return lhsl[i] < rhsl[i] ? -1 : ( lhsl[i] == rhsl[i] ? 0 : 1 );
     }
 
     default:
-      return QString::localeAwareCompare( lhs.toString(), rhs.toString() ) < 0;
+      return QString::localeAwareCompare( lhs.toString(), rhs.toString() );
   }
 }
 
+bool qgsVariantLessThan( const QVariant &lhs, const QVariant &rhs )
+{
+  return qgsVariantCompare( lhs, rhs ) < 0;
+}
+
 bool qgsVariantGreaterThan( const QVariant &lhs, const QVariant &rhs )
 {
-  return ! qgsVariantLessThan( lhs, rhs );
+  return qgsVariantCompare( lhs, rhs ) > 0;
 }
 
+
 QString qgsVsiPrefix( const QString &path )
 {
   return QgsGdalUtils::vsiPrefixForPath( path );
@@ -200,41 +296,41 @@ uint qHash( const QVariant &variant )
   if ( !variant.isValid() || variant.isNull() )
     return std::numeric_limits<uint>::max();
 
-  switch ( variant.type() )
+  switch ( variant.userType() )
   {
-    case QVariant::Int:
+    case QMetaType::Type::Int:
       return qHash( variant.toInt() );
-    case QVariant::UInt:
+    case QMetaType::Type::UInt:
       return qHash( variant.toUInt() );
-    case QVariant::Bool:
+    case QMetaType::Type::Bool:
       return qHash( variant.toBool() );
-    case QVariant::Double:
+    case QMetaType::Type::Double:
       return qHash( variant.toDouble() );
-    case QVariant::LongLong:
+    case QMetaType::Type::LongLong:
       return qHash( variant.toLongLong() );
-    case QVariant::ULongLong:
+    case QMetaType::Type::ULongLong:
       return qHash( variant.toULongLong() );
-    case QVariant::String:
+    case QMetaType::Type::QString:
       return qHash( variant.toString() );
-    case QVariant::Char:
+    case QMetaType::Type::QChar:
       return qHash( variant.toChar() );
-    case QVariant::List:
+    case QMetaType::Type::QVariantList:
       return qHash( variant.toList() );
-    case QVariant::StringList:
+    case QMetaType::Type::QStringList:
       return qHash( variant.toStringList() );
-    case QVariant::ByteArray:
+    case QMetaType::Type::QByteArray:
       return qHash( variant.toByteArray() );
-    case QVariant::Date:
+    case QMetaType::Type::QDate:
       return qHash( variant.toDate() );
-    case QVariant::Time:
+    case QMetaType::Type::QTime:
       return qHash( variant.toTime() );
-    case QVariant::DateTime:
+    case QMetaType::Type::QDateTime:
       return qHash( variant.toDateTime() );
-    case QVariant::Url:
-    case QVariant::Locale:
-    case QVariant::RegularExpression:
+    case QMetaType::Type::QUrl:
+    case QMetaType::Type::QLocale:
+    case QMetaType::Type::QRegularExpression:
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    case QVariant::RegExp:
+    case QMetaType::Type::QRegExp:
 #endif
       return qHash( variant.toString() );
     default:
