@@ -17,8 +17,9 @@
 
 #include "qgslegendstyle.h"
 #include "qgsfontutils.h"
-#include "qgssettings.h"
 #include "qgis.h"
+#include "qgsreadwritecontext.h"
+#include "qgspropertycollection.h"
 
 #include <QFont>
 #include <QMap>
@@ -31,6 +32,21 @@ QgsLegendStyle::QgsLegendStyle()
 {
 }
 
+void QgsLegendStyle::setFont( const QFont &font )
+{
+  mTextFormat.setFont( font );
+  if ( font.pointSizeF() > 0 )
+  {
+    mTextFormat.setSize( font.pointSizeF() );
+    mTextFormat.setSizeUnit( Qgis::RenderUnit::Points );
+  }
+  else if ( font.pixelSize() > 0 )
+  {
+    mTextFormat.setSize( font.pixelSize() );
+    mTextFormat.setSizeUnit( Qgis::RenderUnit::Pixels );
+  }
+}
+
 void QgsLegendStyle::setMargin( double margin )
 {
   mMarginMap[Top] = margin;
@@ -39,7 +55,7 @@ void QgsLegendStyle::setMargin( double margin )
   mMarginMap[Right] = margin;
 }
 
-void QgsLegendStyle::writeXml( const QString &name, QDomElement &elem, QDomDocument &doc ) const
+void QgsLegendStyle::writeXml( const QString &name, QDomElement &elem, QDomDocument &doc, const QgsReadWriteContext &context ) const
 {
   if ( elem.isNull() )
     return;
@@ -48,6 +64,7 @@ void QgsLegendStyle::writeXml( const QString &name, QDomElement &elem, QDomDocum
 
   styleElem.setAttribute( QStringLiteral( "name" ), name );
   styleElem.setAttribute( QStringLiteral( "alignment" ), QString::number( mAlignment ) );
+  styleElem.setAttribute( QStringLiteral( "indent" ), QString::number( mIndent ) );
 
   if ( !qgsDoubleNear( mMarginMap[Top], 0.0 ) )
     styleElem.setAttribute( QStringLiteral( "marginTop" ), QString::number( mMarginMap[Top] ) );
@@ -58,19 +75,31 @@ void QgsLegendStyle::writeXml( const QString &name, QDomElement &elem, QDomDocum
   if ( !qgsDoubleNear( mMarginMap[Right], 0.0 ) )
     styleElem.setAttribute( QStringLiteral( "marginRight" ), QString::number( mMarginMap[Right] ) );
 
-  styleElem.appendChild( QgsFontUtils::toXmlElement( mFont, doc, QStringLiteral( "styleFont" ) ) );
+  QDomElement textElem = mTextFormat.writeXml( doc, context );
+  styleElem.appendChild( textElem );
 
   elem.appendChild( styleElem );
 }
 
-void QgsLegendStyle::readXml( const QDomElement &elem, const QDomDocument &doc )
+void QgsLegendStyle::readXml( const QDomElement &elem, const QDomDocument &doc, const QgsReadWriteContext &context )
 {
   Q_UNUSED( doc )
   if ( elem.isNull() ) return;
 
-  if ( !QgsFontUtils::setFromXmlChildNode( mFont, elem, QStringLiteral( "styleFont" ) ) )
+  QDomNodeList textFormatNodeList = elem.elementsByTagName( QStringLiteral( "text-style" ) );
+  if ( !textFormatNodeList.isEmpty() )
   {
-    mFont.fromString( elem.attribute( QStringLiteral( "font" ) ) );
+    QDomElement textFormatElem = textFormatNodeList.at( 0 ).toElement();
+    mTextFormat.readXml( textFormatElem, context );
+  }
+  else
+  {
+    QFont f;
+    if ( !QgsFontUtils::setFromXmlChildNode( f, elem, QStringLiteral( "styleFont" ) ) )
+    {
+      f.fromString( elem.attribute( QStringLiteral( "font" ) ) );
+    }
+    mTextFormat = QgsTextFormat::fromQFont( f );
   }
 
   mMarginMap[Top] = elem.attribute( QStringLiteral( "marginTop" ), QStringLiteral( "0" ) ).toDouble();
@@ -79,6 +108,14 @@ void QgsLegendStyle::readXml( const QDomElement &elem, const QDomDocument &doc )
   mMarginMap[Right] = elem.attribute( QStringLiteral( "marginRight" ), QStringLiteral( "0" ) ).toDouble();
 
   mAlignment = static_cast< Qt::Alignment >( elem.attribute( QStringLiteral( "alignment" ), QString::number( Qt::AlignLeft ) ).toInt() );
+  mIndent = elem.attribute( QStringLiteral( "indent" ), QStringLiteral( "0" ) ).toDouble();
+}
+
+void QgsLegendStyle::updateDataDefinedProperties( QgsRenderContext &context )
+{
+  if ( mTextFormat.dataDefinedProperties().hasActiveProperties() ) // note, we use format instead of tmpFormat here, it's const and potentially avoids a detach
+    mTextFormat.updateDataDefinedProperties( context );
+
 }
 
 QString QgsLegendStyle::styleName( Style s )
