@@ -40,7 +40,6 @@
  * \see QgsDoubleRange
  * \see QgsIntRange
  * \note not available in Python bindings (but class provided for template-based inheritance)
- * \since QGIS 3.0
  */
 template <typename T>
 class QgsRange
@@ -58,6 +57,19 @@ class QgsRange
       , mIncludeUpper( includeUpper )
     {}
 
+    /**
+     * Constructor for QgsRange. The \a lower and \a upper bounds are specified,
+     * and whether or not these bounds are included in the range.
+     *
+     * \since QGIS 3.38
+     */
+    QgsRange( T lower, T upper, Qgis::RangeLimits limits )
+      : mLower( lower )
+      , mUpper( upper )
+      , mIncludeLower( limits == Qgis::RangeLimits::IncludeLowerExcludeUpper || limits == Qgis::RangeLimits::IncludeBoth )
+      , mIncludeUpper( limits == Qgis::RangeLimits::ExcludeLowerIncludeUpper || limits == Qgis::RangeLimits::IncludeBoth )
+    {}
+
     /**
      * Returns the lower bound of the range.
      * \see upper()
@@ -88,6 +100,23 @@ class QgsRange
      */
     bool includeUpper() const { return mIncludeUpper; }
 
+    /**
+     * Returns the limit handling of the range.
+     *
+     * \since QGIS 3.38
+     */
+    Qgis::RangeLimits rangeLimits() const
+    {
+      if ( mIncludeLower && mIncludeUpper )
+        return Qgis::RangeLimits::IncludeBoth;
+      else if ( mIncludeLower && !mIncludeUpper )
+        return Qgis::RangeLimits::IncludeLowerExcludeUpper;
+      else if ( !mIncludeLower && mIncludeUpper )
+        return Qgis::RangeLimits::ExcludeLowerIncludeUpper;
+      else
+        return Qgis::RangeLimits::ExcludeBoth;
+    }
+
     /**
      * Returns TRUE if the range is empty, ie the lower bound equals (or exceeds) the upper bound
      * and either the bounds are exclusive.
@@ -146,25 +175,21 @@ class QgsRange
      */
     bool overlaps( const QgsRange<T> &other ) const
     {
-      if ( ( ( mIncludeLower && mLower <= other.mLower ) || ( !mIncludeLower && mLower < other.mLower ) )
-           && ( ( mIncludeUpper  && mUpper >= other.mUpper ) || ( !mIncludeUpper && mUpper > other.mUpper ) ) )
+      // other range is completely before or completely after self range
+      if ( other.mUpper < mLower || other.mLower > mUpper )
+        return false;
+
+      // other overlaps self for sure
+      if ( other.mUpper > mLower && other.mLower < mUpper )
         return true;
 
-      if ( ( ( mIncludeLower && mLower <= other.mLower ) || ( !mIncludeLower && mLower < other.mLower ) )
-           && ( ( mIncludeUpper  && mUpper >= other.mLower ) || ( !mIncludeUpper && mUpper > other.mLower ) ) )
-        return true;
+      if ( other.mUpper == mLower )
+        return other.mIncludeUpper && mIncludeLower;
 
-      if ( ( ( mIncludeLower && mLower <= other.mUpper ) || ( !mIncludeLower && mLower < other.mUpper ) )
-           && ( ( mIncludeUpper && mUpper >= other.mUpper ) || ( !mIncludeUpper && mUpper > other.mUpper ) ) )
-        return true;
-
-      if ( ( ( mIncludeLower && mLower >= other.mLower ) || ( !mIncludeLower && mLower > other.mLower ) )
-           && ( ( mIncludeLower && mLower <= other.mUpper ) || ( !mIncludeLower && mLower < other.mUpper ) ) )
-        return true;
-
-      if ( mLower == other.mLower && mUpper == other.mUpper )
-        return true;
+      if ( other.mLower == mUpper )
+        return other.mIncludeLower && mIncludeUpper;
 
+      // UNREACHABLE CODE
       return false;
     }
 
@@ -197,12 +222,21 @@ class QgsRange
  * \see QgsIntRange
  * \see QgsDateRange
  * \see QgsDateTimeRange
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsDoubleRange : public QgsRange< double >
 {
   public:
 
+    /**
+     * Constructor for QgsDoubleRange. The \a lower and \a upper bounds are specified,
+     * and whether or not these bounds are included in the range.
+     *
+     * \since QGIS 3.38
+     */
+    QgsDoubleRange( double lower, double upper, Qgis::RangeLimits limits )
+      : QgsRange( lower, upper, limits )
+    {}
+
 #ifndef SIP_RUN
 
     /**
@@ -275,6 +309,8 @@ class CORE_EXPORT QgsDoubleRange : public QgsRange< double >
 
 };
 
+Q_DECLARE_METATYPE( QgsDoubleRange )
+
 
 /**
  * \brief QgsRange which stores a range of integer values.
@@ -282,12 +318,21 @@ class CORE_EXPORT QgsDoubleRange : public QgsRange< double >
  * \see QgsDoubleRange
  * \see QgsDateRange
  * \see QgsDateTimeRange
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsIntRange : public QgsRange< int >
 {
   public:
 
+    /**
+     * Constructor for QgsIntRange. The \a lower and \a upper bounds are specified,
+     * and whether or not these bounds are included in the range.
+     *
+     * \since QGIS 3.38
+     */
+    QgsIntRange( int lower, int upper, Qgis::RangeLimits limits )
+      : QgsRange( lower, upper, limits )
+    {}
+
 #ifndef SIP_RUN
 
     /**
@@ -347,6 +392,8 @@ class CORE_EXPORT QgsIntRange : public QgsRange< int >
 
 };
 
+Q_DECLARE_METATYPE( QgsIntRange )
+
 
 /**
  * \class QgsTemporalRange
@@ -362,7 +409,6 @@ class CORE_EXPORT QgsIntRange : public QgsRange< int >
  *
  * \see QgsDateRange
  * \note not available in Python bindings (but class provided for template-based inheritance)
- * \since QGIS 3.0
  */
 template <typename T>
 class QgsTemporalRange
@@ -515,31 +561,47 @@ class QgsTemporalRange
 
     /**
      * Returns TRUE if this range overlaps another range.
+     * \see contains()
      */
     bool overlaps( const QgsTemporalRange<T> &other ) const
     {
-      if ( !mUpper.isValid() && ( ( mIncludeLower && mLower <= other.mUpper ) || ( !mIncludeLower && mLower < other.mUpper ) ) )
+      // one or both range is infinite
+      if ( isInfinite() || other.isInfinite() )
         return true;
 
-      if ( ( ( mIncludeLower && mLower <= other.mLower ) || ( !mIncludeLower && mLower < other.mLower ) )
-           && ( ( mIncludeUpper  && mUpper >= other.mUpper ) || ( !mIncludeUpper && mUpper > other.mUpper ) ) )
-        return true;
+      // all bounds are fixed
+      if ( mLower.isValid() && mUpper.isValid() && other.mLower.isValid() && other.mUpper.isValid() )
+      {
+        // other range is completely before or completely after self range
+        if ( other.mUpper < mLower || other.mLower > mUpper )
+          return false;
 
-      if ( ( ( mIncludeLower && mLower <= other.mLower ) || ( !mIncludeLower && mLower < other.mLower ) )
-           && ( ( mIncludeUpper  && mUpper >= other.mLower ) || ( !mIncludeUpper && mUpper > other.mLower ) ) )
-        return true;
+        // other overlaps self for sure
+        if ( other.mUpper > mLower && other.mLower < mUpper )
+          return true;
+      }
 
-      if ( ( ( mIncludeLower && mLower <= other.mUpper ) || ( !mIncludeLower && mLower < other.mUpper ) )
-           && ( ( mIncludeUpper && mUpper >= other.mUpper ) || ( !mIncludeUpper && mUpper > other.mUpper ) ) )
-        return true;
+      // other is just before and has a bound in common
+      if ( other.mUpper == mLower && mLower.isValid() )
+        return other.mIncludeUpper && mIncludeLower;
 
-      if ( ( ( mIncludeLower && mLower >= other.mLower ) || ( !mIncludeLower && mLower > other.mLower ) )
-           && ( ( mIncludeLower && mLower <= other.mUpper ) || ( !mIncludeLower && mLower < other.mUpper ) ) )
-        return true;
+      // other is just after and has a bound in common
+      if ( other.mLower == mUpper && mUpper.isValid() )
+        return other.mIncludeLower && mIncludeUpper;
 
-      if ( mLower == other.mLower && mUpper == other.mUpper )
-        return true;
+      if ( !mLower.isValid() )
+        return other.mLower < mUpper || !other.mLower.isValid();
 
+      if ( !mUpper.isValid() )
+        return other.mUpper > mLower || !other.mUpper.isValid();
+
+      if ( !other.mLower.isValid() )
+        return other.mUpper > mLower || !mLower.isValid();
+
+      if ( !other.mUpper.isValid() )
+        return other.mLower < mUpper || !mUpper.isValid();
+
+      // UNREACHABLE CODE
       return false;
     }
 
@@ -675,7 +737,6 @@ class QgsTemporalRange
  * is treated as a range containing all dates before 2017-1-1.
  * QgsDateRange(QDate(2017,1,1),QDate()) is treated as a range containing all dates after 2017-1-1.
  * \see QgsDateTimeRange
- * \since QGIS 3.0
  */
 typedef QgsTemporalRange< QDate > QgsDateRange SIP_DOC_TEMPLATE;
 
@@ -689,7 +750,6 @@ Q_DECLARE_METATYPE( QgsDateRange )
  * is treated as a range containing all dates before 2017-1-1.
  * QgsDateTimeRange(QDateTime(2017,1,1),QDateTime()) is treated as a range containing all dates after 2017-1-1.
  * \see QgsDateRange
- * \since QGIS 3.0
  */
 typedef QgsTemporalRange< QDateTime > QgsDateTimeRange SIP_DOC_TEMPLATE;
 
