@@ -20,6 +20,7 @@
 
 #include "qgis_core.h"
 #include "qgis_sip.h"
+#include "qgis.h"
 #include <QObject>
 
 /***************************************************************************
@@ -32,7 +33,6 @@
  * \ingroup core
  * \class QgsUnitTypes
  * \brief Helper functions for various unit types.
- * \since QGIS 2.14
  */
 
 class CORE_EXPORT QgsUnitTypes
@@ -40,168 +40,10 @@ class CORE_EXPORT QgsUnitTypes
     Q_GADGET
 
   public:
-    //! Systems of unit measurement
-    enum SystemOfMeasurement
-    {
-      UnknownSystem = 0, //!< Unknown system of measurement
-      MetricSystem, //!< International System of Units (SI)
-      ImperialSystem, //!< British Imperial
-      USCSSystem //!< United States customary system
-    };
-    Q_ENUM( SystemOfMeasurement )
-
-    /**
-     * Unit types.
-     * \since QGIS 3.10
-     */
-    enum UnitType
-    {
-      TypeDistance = 0, //!< Distance unit
-      TypeArea, //!< Area unit
-      TypeVolume, //!< Volume unit
-      TypeUnknown, //!< Unknown unit type
-      TypeTemporal, //!< Temporal unit
-    };
-
-    //! Units of distance
-    enum DistanceUnit
-    {
-      DistanceMeters = 0, //!< Meters
-      DistanceKilometers, //!< Kilometers
-      DistanceFeet, //!< Imperial feet
-      DistanceNauticalMiles, //!< Nautical miles
-      DistanceYards, //!< Imperial yards
-      DistanceMiles, //!< Terrestrial miles
-      DistanceDegrees, //!< Degrees, for planar geographic CRS distance measurements
-      DistanceCentimeters, //!< Centimeters
-      DistanceMillimeters, //!< Millimeters
-      DistanceUnknownUnit, //!< Unknown distance unit
-    };
-    Q_ENUM( DistanceUnit )
-
-    /**
-     * Types of distance units
-     */
-    enum DistanceUnitType
-    {
-      Standard = 0, //!< Unit is a standard measurement unit
-      Geographic,   //!< Unit is a geographic (e.g., degree based) unit
-      UnknownType,  //!< Unknown unit type
-    };
-
-    //! Units of area
-    enum AreaUnit
-    {
-      AreaSquareMeters = 0, //!< Square meters
-      AreaSquareKilometers, //!< Square kilometers
-      AreaSquareFeet, //!< Square feet
-      AreaSquareYards, //!< Square yards
-      AreaSquareMiles, //!< Square miles
-      AreaHectares, //!< Hectares
-      AreaAcres, //!< Acres
-      AreaSquareNauticalMiles, //!< Square nautical miles
-      AreaSquareDegrees, //!< Square degrees, for planar geographic CRS area measurements
-      AreaSquareCentimeters, //!< Square centimeters
-      AreaSquareMillimeters, //!< Square millimeters
-      AreaUnknownUnit, //!< Unknown areal unit
-    };
-    Q_ENUM( AreaUnit )
-
-    /**
-     * Units of volume.
-     * \since QGIS 3.10
-     */
-    enum VolumeUnit
-    {
-      VolumeCubicMeters = 0, //!< Cubic meters
-      VolumeCubicFeet, //!< Cubic feet
-      VolumeCubicYards, //!< Cubic yards
-      VolumeBarrel, //!< Barrels
-      VolumeCubicDecimeter, //!< Cubic decimeters
-      VolumeLiters, //!< Litres
-      VolumeGallonUS, //!< US Gallons
-      VolumeCubicInch, //!< Cubic inches
-      VolumeCubicCentimeter, //!< Cubic Centimeters
-      VolumeCubicDegrees, //!< Cubic degrees, for planar geographic CRS volume measurements
-      VolumeUnknownUnit, //!< Unknown volume unit
-    };
-    Q_ENUM( VolumeUnit )
-
-    //! Units of angles
-    enum AngleUnit
-    {
-      AngleDegrees = 0, //!< Degrees
-      AngleRadians, //!< Square kilometers
-      AngleGon, //!< Gon/gradian
-      AngleMinutesOfArc, //!< Minutes of arc
-      AngleSecondsOfArc, //!< Seconds of arc
-      AngleTurn, //!< Turn/revolutions
-      AngleMilliradiansSI, //!< Angular milliradians (SI definition, 1/1000 of radian)
-      AngleMilNATO, //!< Angular mil (NATO definition, 6400 mil = 2PI radians)
-      AngleUnknownUnit, //!< Unknown angle unit
-    };
-    Q_ENUM( AngleUnit )
-
-    /**
-     * Temporal units.
-     * \since QGIS 3.14
-     */
-    enum TemporalUnit
-    {
-      TemporalMilliseconds, //!< Milliseconds
-      TemporalSeconds, //!< Seconds
-      TemporalMinutes, //!< Minutes
-      TemporalHours, //!< Hours
-      TemporalDays, //!< Days
-      TemporalWeeks, //!< Weeks
-      TemporalMonths,  //!< Months
-      TemporalYears, //!< Years
-      TemporalDecades, //!< Decades
-      TemporalCenturies, //!< Centuries
-      TemporalIrregularStep, //!< Special "irregular step" time unit, used for temporal data which uses irregular, non-real-world unit steps (since QGIS 3.20)
-      TemporalUnknownUnit //!< Unknown time unit
-    };
-    Q_ENUM( TemporalUnit )
-
-    //! Rendering size units
-    enum RenderUnit
-    {
-      RenderMillimeters = 0, //!< Millimeters
-      RenderMapUnits, //!< Map units
-      RenderPixels, //!< Pixels
-      RenderPercentage, //!< Percentage of another measurement (e.g., canvas size, feature size)
-      RenderPoints, //!< Points (e.g., for font sizes)
-      RenderInches, //!< Inches
-      RenderUnknownUnit, //!< Mixed or unknown units
-      RenderMetersInMapUnits, //!< Meters value as Map units
-    };
-    Q_ENUM( RenderUnit )
-
-    //! Layout measurement units
-    enum LayoutUnit
-    {
-      LayoutMillimeters = 0, //!< Millimeters
-      LayoutCentimeters, //!< Centimeters
-      LayoutMeters, //!< Meters
-      LayoutInches, //!< Inches
-      LayoutFeet, //!< Feet
-      LayoutPoints, //!< Typographic points
-      LayoutPicas, //!< Typographic picas
-      LayoutPixels //!< Pixels
-    };
-    Q_ENUM( LayoutUnit )
-
-    //! Types of layout units
-    enum LayoutUnitType
-    {
-      LayoutPaperUnits = 0, //!< Unit is a paper based measurement unit
-      LayoutScreenUnits //!< Unit is a screen based measurement unit
-    };
 
     /**
      * A combination of distance value and unit.
      *
-     * \since QGIS 3.0
      */
     struct DistanceValue
     {
@@ -214,13 +56,12 @@ class CORE_EXPORT QgsUnitTypes
       /**
        * The value part of the distance. For 3.7 meters, this will be QgsUnitTypes::DistanceMeters.
        */
-      QgsUnitTypes::DistanceUnit unit;
+      Qgis::DistanceUnit unit;
     };
 
     /**
      * A combination of area value and unit.
      *
-     * \since QGIS 3.0
      */
     struct AreaValue
     {
@@ -233,11 +74,11 @@ class CORE_EXPORT QgsUnitTypes
       /**
        * The value part of the distance. For 3.7 square meters, this will be QgsUnitTypes::AreaSquareMeters.
        */
-      QgsUnitTypes::AreaUnit unit;
+      Qgis::AreaUnit unit;
     };
 
     //! List of render units
-    typedef QList<QgsUnitTypes::RenderUnit> RenderUnitList;
+    typedef QList<Qgis::RenderUnit> RenderUnitList;
 
     /**
      * Encodes a unit \a type to a string.
@@ -245,7 +86,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see decodeUnitType()
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QString encodeUnitType( QgsUnitTypes::UnitType type );
+    Q_INVOKABLE static QString encodeUnitType( Qgis::UnitType type );
 
     /**
      * Decodes a unit type from a \a string.
@@ -255,7 +96,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see encodeUnitType()
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QgsUnitTypes::UnitType decodeUnitType( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::UnitType decodeUnitType( const QString &string, bool *ok SIP_OUT = nullptr );
 
 
     // DISTANCE UNITS
@@ -263,7 +104,7 @@ class CORE_EXPORT QgsUnitTypes
     /**
      * Returns the type for a distance unit.
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceUnitType unitType( QgsUnitTypes::DistanceUnit unit );
+    Q_INVOKABLE static Qgis::DistanceUnitType unitType( Qgis::DistanceUnit unit );
 
     /**
      * Encodes a distance unit to a string.
@@ -271,7 +112,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns encoded string
      * \see decodeDistanceUnit()
      */
-    Q_INVOKABLE static QString encodeUnit( QgsUnitTypes::DistanceUnit unit );
+    Q_INVOKABLE static QString encodeUnit( Qgis::DistanceUnit unit );
 
     /**
      * Decodes a distance unit from a string.
@@ -280,23 +121,22 @@ class CORE_EXPORT QgsUnitTypes
      * \returns decoded units
      * \see encodeUnit()
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceUnit decodeDistanceUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::DistanceUnit decodeDistanceUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns a translated string representing a distance unit.
      * \param unit unit to convert to string
      * \see stringToDistanceUnit()
      */
-    Q_INVOKABLE static QString toString( QgsUnitTypes::DistanceUnit unit );
+    Q_INVOKABLE static QString toString( Qgis::DistanceUnit unit );
 
     /**
      * Returns a translated abbreviation representing a distance unit.
      * \param unit unit to convert to string
      * \see stringToDistanceUnit()
      *
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QString toAbbreviatedString( QgsUnitTypes::DistanceUnit unit );
+    Q_INVOKABLE static QString toAbbreviatedString( Qgis::DistanceUnit unit );
 
     /**
      * Converts a translated string to a distance unit.
@@ -305,7 +145,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns the distance unit
      * \see toString()
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceUnit stringToDistanceUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::DistanceUnit stringToDistanceUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns the conversion factor between the specified distance units.
@@ -313,14 +153,14 @@ class CORE_EXPORT QgsUnitTypes
      * \param toUnit distance unit to convert to
      * \returns multiplication factor to convert between units
      */
-    Q_INVOKABLE static double fromUnitToUnitFactor( QgsUnitTypes::DistanceUnit fromUnit, QgsUnitTypes::DistanceUnit toUnit );
+    Q_INVOKABLE static double fromUnitToUnitFactor( Qgis::DistanceUnit fromUnit, Qgis::DistanceUnit toUnit );
 
     // AREAL UNITS
 
     /**
      * Returns the type for an areal unit.
     */
-    static QgsUnitTypes::DistanceUnitType unitType( QgsUnitTypes::AreaUnit unit );
+    static Qgis::DistanceUnitType unitType( Qgis::AreaUnit unit );
 
     /**
      * Encodes an areal unit to a string.
@@ -328,7 +168,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns encoded string
      * \see decodeAreaUnit()
     */
-    static QString encodeUnit( QgsUnitTypes::AreaUnit unit );
+    static QString encodeUnit( Qgis::AreaUnit unit );
 
     /**
      * Decodes an areal unit from a string.
@@ -337,23 +177,22 @@ class CORE_EXPORT QgsUnitTypes
      * \returns decoded units
      * \see encodeUnit()
     */
-    Q_INVOKABLE static QgsUnitTypes::AreaUnit decodeAreaUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::AreaUnit decodeAreaUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns a translated string representing an areal unit.
      * \param unit unit to convert to string
      * \see stringToAreaUnit()
      */
-    static QString toString( QgsUnitTypes::AreaUnit unit );
+    static QString toString( Qgis::AreaUnit unit );
 
     /**
      * Returns a translated abbreviation representing an areal unit.
      * \param unit unit to convert to string
      * \see stringToAreaUnit()
      *
-     * \since QGIS 3.0
      */
-    static QString toAbbreviatedString( QgsUnitTypes::AreaUnit unit );
+    static QString toAbbreviatedString( Qgis::AreaUnit unit );
 
     /**
      * Converts a translated string to an areal unit.
@@ -362,7 +201,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns the area unit
      * \see toString()
      */
-    Q_INVOKABLE static QgsUnitTypes::AreaUnit stringToAreaUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::AreaUnit stringToAreaUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns the conversion factor between the specified areal units.
@@ -370,14 +209,14 @@ class CORE_EXPORT QgsUnitTypes
      * \param toUnit area unit to convert to
      * \returns multiplication factor to convert between units
      */
-    static double fromUnitToUnitFactor( QgsUnitTypes::AreaUnit fromUnit, QgsUnitTypes::AreaUnit toUnit );
+    static double fromUnitToUnitFactor( Qgis::AreaUnit fromUnit, Qgis::AreaUnit toUnit );
 
     /**
      * Converts a distance unit to its corresponding area unit, e.g., meters to square meters
      * \param distanceUnit distance unit to convert
      * \returns matching areal unit
      */
-    Q_INVOKABLE static QgsUnitTypes::AreaUnit distanceToAreaUnit( QgsUnitTypes::DistanceUnit distanceUnit );
+    Q_INVOKABLE static Qgis::AreaUnit distanceToAreaUnit( Qgis::DistanceUnit distanceUnit );
 
     /**
      * Converts an area unit to its corresponding distance unit, e.g., square meters to meters
@@ -385,7 +224,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns matching distance unit
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceUnit areaToDistanceUnit( QgsUnitTypes::AreaUnit areaUnit );
+    Q_INVOKABLE static Qgis::DistanceUnit areaToDistanceUnit( Qgis::AreaUnit areaUnit );
 
     // TEMPORAL UNITS
 
@@ -395,7 +234,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see decodeTemporalUnit()
      * \since QGIS 3.14
     */
-    static QString encodeUnit( QgsUnitTypes::TemporalUnit unit );
+    static QString encodeUnit( Qgis::TemporalUnit unit );
 
     /**
      * Decodes a temporal unit from a \a string.
@@ -405,14 +244,14 @@ class CORE_EXPORT QgsUnitTypes
      * \see encodeUnit()
      * \since QGIS 3.14
     */
-    Q_INVOKABLE static QgsUnitTypes::TemporalUnit decodeTemporalUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::TemporalUnit decodeTemporalUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns a translated string representing a temporal \a unit.
      * \see stringToTemporalUnit()
      * \since QGIS 3.14
      */
-    static QString toString( QgsUnitTypes::TemporalUnit unit );
+    static QString toString( Qgis::TemporalUnit unit );
 
     /**
      * Returns a translated abbreviation representing a temporal \a unit.
@@ -420,7 +259,7 @@ class CORE_EXPORT QgsUnitTypes
      *
      * \since QGIS 3.14
      */
-    static QString toAbbreviatedString( QgsUnitTypes::TemporalUnit unit );
+    static QString toAbbreviatedString( Qgis::TemporalUnit unit );
 
     /**
      * Converts a translated \a string to a temporal unit.
@@ -430,7 +269,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see toString()
      * \since QGIS 3.14
      */
-    Q_INVOKABLE static QgsUnitTypes::TemporalUnit stringToTemporalUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::TemporalUnit stringToTemporalUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns the conversion factor between the specified temporal units.
@@ -443,7 +282,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns multiplication factor to convert between units
      * \since QGIS 3.14
      */
-    static double fromUnitToUnitFactor( QgsUnitTypes::TemporalUnit fromUnit, QgsUnitTypes::TemporalUnit toUnit );
+    static double fromUnitToUnitFactor( Qgis::TemporalUnit fromUnit, Qgis::TemporalUnit toUnit );
 
     // VOLUME UNITS
 
@@ -451,7 +290,7 @@ class CORE_EXPORT QgsUnitTypes
      * Returns the type for an volume unit.
      * \since QGIS 3.10
     */
-    static QgsUnitTypes::DistanceUnitType unitType( QgsUnitTypes::VolumeUnit unit );
+    static Qgis::DistanceUnitType unitType( Qgis::VolumeUnit unit );
 
     /**
      * Encodes a volume \a unit to a string.
@@ -459,7 +298,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see decodeVolumeUnit()
      * \since QGIS 3.10
     */
-    static QString encodeUnit( QgsUnitTypes::VolumeUnit unit );
+    static QString encodeUnit( Qgis::VolumeUnit unit );
 
     /**
      * Decodes a volume unit from a \a string.
@@ -469,14 +308,14 @@ class CORE_EXPORT QgsUnitTypes
      * \see encodeUnit()
      * \since QGIS 3.10
     */
-    Q_INVOKABLE static QgsUnitTypes::VolumeUnit decodeVolumeUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::VolumeUnit decodeVolumeUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns a translated string representing a volume \a unit.
      * \see stringToVolumeUnit()
      * \since QGIS 3.10
      */
-    static QString toString( QgsUnitTypes::VolumeUnit unit );
+    static QString toString( Qgis::VolumeUnit unit );
 
     /**
      * Returns a translated abbreviation representing a volume \a unit.
@@ -484,7 +323,7 @@ class CORE_EXPORT QgsUnitTypes
      *
      * \since QGIS 3.10
      */
-    static QString toAbbreviatedString( QgsUnitTypes::VolumeUnit unit );
+    static QString toAbbreviatedString( Qgis::VolumeUnit unit );
 
     /**
      * Converts a translated \a string to a volume unit.
@@ -494,7 +333,7 @@ class CORE_EXPORT QgsUnitTypes
      * \see toString()
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QgsUnitTypes::VolumeUnit stringToVolumeUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::VolumeUnit stringToVolumeUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns the conversion factor between the specified volume units.
@@ -503,7 +342,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns multiplication factor to convert between units
      * \since QGIS 3.10
      */
-    static double fromUnitToUnitFactor( QgsUnitTypes::VolumeUnit fromUnit, QgsUnitTypes::VolumeUnit toUnit );
+    static double fromUnitToUnitFactor( Qgis::VolumeUnit fromUnit, Qgis::VolumeUnit toUnit );
 
     /**
      * Converts a distance unit to its corresponding volume unit, e.g., meters to cubic meters
@@ -511,7 +350,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns matching volume unit
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QgsUnitTypes::VolumeUnit distanceToVolumeUnit( QgsUnitTypes::DistanceUnit distanceUnit );
+    Q_INVOKABLE static Qgis::VolumeUnit distanceToVolumeUnit( Qgis::DistanceUnit distanceUnit );
 
     /**
      * Converts a volume unit to its corresponding distance unit, e.g., cubic meters to meters
@@ -519,7 +358,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns matching distance unit
      * \since QGIS 3.10
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceUnit volumeToDistanceUnit( QgsUnitTypes::VolumeUnit volumeUnit );
+    Q_INVOKABLE static Qgis::DistanceUnit volumeToDistanceUnit( Qgis::VolumeUnit volumeUnit );
 
     // ANGULAR UNITS
 
@@ -529,7 +368,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns encoded string
      * \see decodeAngleUnit()
     */
-    static QString encodeUnit( QgsUnitTypes::AngleUnit unit );
+    static QString encodeUnit( Qgis::AngleUnit unit );
 
     /**
      * Decodes an angular unit from a string.
@@ -538,13 +377,13 @@ class CORE_EXPORT QgsUnitTypes
      * \returns decoded units
      * \see encodeUnit()
     */
-    Q_INVOKABLE static QgsUnitTypes::AngleUnit decodeAngleUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::AngleUnit decodeAngleUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns a translated string representing an angular unit.
      * \param unit unit to convert to string
      */
-    static QString toString( QgsUnitTypes::AngleUnit unit );
+    static QString toString( Qgis::AngleUnit unit );
 
     /**
      * Returns the conversion factor between the specified angular units.
@@ -552,7 +391,7 @@ class CORE_EXPORT QgsUnitTypes
      * \param toUnit angle unit to convert to
      * \returns multiplication factor to convert between units
      */
-    static double fromUnitToUnitFactor( QgsUnitTypes::AngleUnit fromUnit, QgsUnitTypes::AngleUnit toUnit );
+    static double fromUnitToUnitFactor( Qgis::AngleUnit fromUnit, Qgis::AngleUnit toUnit );
 
     /**
      * Returns an angle formatted as a friendly string.
@@ -561,7 +400,7 @@ class CORE_EXPORT QgsUnitTypes
      * \param unit unit of angle
      * \returns formatted angle string
      */
-    Q_INVOKABLE static QString formatAngle( double angle, int decimals, QgsUnitTypes::AngleUnit unit );
+    Q_INVOKABLE static QString formatAngle( double angle, int decimals, Qgis::AngleUnit unit );
 
     /**
      * Will convert a \a distance with a given \a unit to a distance value which is nice to display.
@@ -570,9 +409,8 @@ class CORE_EXPORT QgsUnitTypes
      * The value will also be rounded to \a decimals (be prepared that the returned value is still a double so it will require
      * further formatting when converting to a string).
      *
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QgsUnitTypes::DistanceValue scaledDistance( double distance, QgsUnitTypes::DistanceUnit unit, int decimals, bool keepBaseUnit = false );
+    Q_INVOKABLE static QgsUnitTypes::DistanceValue scaledDistance( double distance, Qgis::DistanceUnit unit, int decimals, bool keepBaseUnit = false );
 
     /**
      * Will convert an \a area with a given \a unit to an area value which is nice to display.
@@ -581,9 +419,8 @@ class CORE_EXPORT QgsUnitTypes
      * The value will also be rounded to \a decimals (be prepared that the returned value is still a double so it will require
      * further formatting when converting to a string).
      *
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QgsUnitTypes::AreaValue scaledArea( double area, QgsUnitTypes::AreaUnit unit, int decimals, bool keepBaseUnit = false );
+    Q_INVOKABLE static QgsUnitTypes::AreaValue scaledArea( double area, Qgis::AreaUnit unit, int decimals, bool keepBaseUnit = false );
 
     /**
      * Returns an distance formatted as a friendly string.
@@ -594,9 +431,8 @@ class CORE_EXPORT QgsUnitTypes
      * kilometers
      * \returns formatted distance string
      * \see formatArea()
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QString formatDistance( double distance, int decimals, QgsUnitTypes::DistanceUnit unit, bool keepBaseUnit = false );
+    Q_INVOKABLE static QString formatDistance( double distance, int decimals, Qgis::DistanceUnit unit, bool keepBaseUnit = false );
 
     /**
      * Returns an area formatted as a friendly string.
@@ -607,9 +443,8 @@ class CORE_EXPORT QgsUnitTypes
      * square kilometers
      * \returns formatted area string
      * \see formatDistance()
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QString formatArea( double area, int decimals, QgsUnitTypes::AreaUnit unit, bool keepBaseUnit = false );
+    Q_INVOKABLE static QString formatArea( double area, int decimals, Qgis::AreaUnit unit, bool keepBaseUnit = false );
 
     // RENDER UNITS
 
@@ -619,7 +454,7 @@ class CORE_EXPORT QgsUnitTypes
      * \returns encoded string
      * \see decodeRenderUnit()
      */
-    static QString encodeUnit( QgsUnitTypes::RenderUnit unit );
+    static QString encodeUnit( Qgis::RenderUnit unit );
 
     /**
      * Decodes a render unit from a string.
@@ -628,14 +463,13 @@ class CORE_EXPORT QgsUnitTypes
      * \returns decoded units
      * \see encodeUnit()
      */
-    Q_INVOKABLE static QgsUnitTypes::RenderUnit decodeRenderUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::RenderUnit decodeRenderUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
 
     /**
      * Returns a translated string representing a render \a unit.
-     * \since QGIS 3.0
      */
-    static QString toString( QgsUnitTypes::RenderUnit unit );
+    static QString toString( Qgis::RenderUnit unit );
 
     /**
      * Returns a translated abbreviation representing a render unit.
@@ -643,7 +477,7 @@ class CORE_EXPORT QgsUnitTypes
      *
      * \since QGIS 3.8
      */
-    static QString toAbbreviatedString( QgsUnitTypes::RenderUnit unit );
+    static QString toAbbreviatedString( Qgis::RenderUnit unit );
 
 
     // LAYOUT UNITS
@@ -653,9 +487,8 @@ class CORE_EXPORT QgsUnitTypes
      * \param unit unit to encode
      * \returns encoded string
      * \see decodeLayoutUnit()
-     * \since QGIS 3.0
      */
-    static QString encodeUnit( QgsUnitTypes::LayoutUnit unit );
+    static QString encodeUnit( Qgis::LayoutUnit unit );
 
     /**
      * Decodes a layout unit from a string.
@@ -663,30 +496,26 @@ class CORE_EXPORT QgsUnitTypes
      * \param ok optional boolean, will be set to TRUE if string was converted successfully
      * \returns decoded units
      * \see encodeUnit()
-     * \since QGIS 3.0
      */
-    Q_INVOKABLE static QgsUnitTypes::LayoutUnit decodeLayoutUnit( const QString &string, bool *ok SIP_OUT = nullptr );
+    Q_INVOKABLE static Qgis::LayoutUnit decodeLayoutUnit( const QString &string, bool *ok SIP_OUT = nullptr );
 
     /**
      * Returns the type for a unit of measurement.
      *
-     * \since QGIS 3.0
     */
-    Q_INVOKABLE static QgsUnitTypes::LayoutUnitType unitType( QgsUnitTypes::LayoutUnit units );
+    Q_INVOKABLE static Qgis::LayoutUnitType unitType( Qgis::LayoutUnit units );
 
     /**
      * Returns a translated abbreviation representing a layout \a unit (e.g. "mm").
      *
-     * \since QGIS 3.0
      */
-    static QString toAbbreviatedString( QgsUnitTypes::LayoutUnit unit );
+    static QString toAbbreviatedString( Qgis::LayoutUnit unit );
 
     /**
      * Returns a translated string representing a layout \a unit.
      *
-     * \since QGIS 3.0
      */
-    static QString toString( QgsUnitTypes::LayoutUnit unit );
+    static QString toString( Qgis::LayoutUnit unit );
 
 };
 
