@@ -25,6 +25,8 @@ bool QgsRaster::isRepresentableValue( double value, Qgis::DataType dataType )
   {
     case Qgis::DataType::Byte:
       return value >= std::numeric_limits<quint8>::min() && value <= std::numeric_limits<quint8>::max();
+    case Qgis::DataType::Int8:
+      return value >= std::numeric_limits<qint8>::min() && value <= std::numeric_limits<qint8>::max();
     case Qgis::DataType::UInt16:
       return value >= std::numeric_limits<quint16>::min() && value <= std::numeric_limits<quint16>::max();
     case Qgis::DataType::Int16:
@@ -36,10 +38,18 @@ bool QgsRaster::isRepresentableValue( double value, Qgis::DataType dataType )
     case Qgis::DataType::Float32:
       return std::isnan( value ) || std::isinf( value ) ||
              ( value >= -std::numeric_limits<float>::max() && value <= std::numeric_limits<float>::max() );
-    default:
+    case Qgis::DataType::Float64:
       return true;
+    case Qgis::DataType::CInt16:
+    case Qgis::DataType::CInt32:
+    case Qgis::DataType::CFloat32:
+    case Qgis::DataType::CFloat64:
+    case Qgis::DataType::ARGB32:
+    case Qgis::DataType::ARGB32_Premultiplied:
+    case Qgis::DataType::UnknownDataType:
       break;
   }
+  return true;
 }
 
 double QgsRaster::representableValue( double value, Qgis::DataType dataType )
@@ -48,6 +58,8 @@ double QgsRaster::representableValue( double value, Qgis::DataType dataType )
   {
     case Qgis::DataType::Byte:
       return static_cast<quint8>( value );
+    case Qgis::DataType::Int8:
+      return static_cast<qint8>( value );
     case Qgis::DataType::UInt16:
       return static_cast<quint16>( value );
     case Qgis::DataType::Int16:
@@ -58,7 +70,15 @@ double QgsRaster::representableValue( double value, Qgis::DataType dataType )
       return static_cast<qint32>( value );
     case Qgis::DataType::Float32:
       return static_cast<float>( value );
-    default:
+    case Qgis::DataType::Float64:
+      return value;
+    case Qgis::DataType::CInt16:
+    case Qgis::DataType::CInt32:
+    case Qgis::DataType::CFloat32:
+    case Qgis::DataType::CFloat64:
+    case Qgis::DataType::ARGB32:
+    case Qgis::DataType::ARGB32_Premultiplied:
+    case Qgis::DataType::UnknownDataType:
       break;
   }
   return value;
