@@ -16,12 +16,14 @@
  ***************************************************************************/
 
 #include "qgscesiumtilesdataprovider.h"
+#include "moc_qgscesiumtilesdataprovider.cpp"
 #include "qgsauthmanager.h"
 #include "qgsproviderutils.h"
 #include "qgsapplication.h"
 #include "qgsprovidersublayerdetails.h"
 #include "qgsthreadingutils.h"
 #include "qgsnetworkaccessmanager.h"
+#include "qgssetrequestinitiator_p.h"
 #include "qgsblockingnetworkrequest.h"
 #include "qgscesiumutils.h"
 #include "qgssphere.h"
@@ -47,6 +49,7 @@
 #include <QUrlQuery>
 #include <QApplication>
 #include <nlohmann/json.hpp>
+#include <qstringliteral.h>
 
 ///@cond PRIVATE
 
@@ -195,7 +198,11 @@ std::unique_ptr< QgsTiledSceneTile > QgsCesiumTiledSceneIndex::tileFromJson( con
   std::unique_ptr< QgsTiledSceneTile > tile = std::make_unique< QgsTiledSceneTile >( mNextTileId++ );
 
   tile->setBaseUrl( baseUrl );
-  tile->setMetadata( {{ QStringLiteral( "gltfUpAxis" ), static_cast< int >( gltfUpAxis ) }} );
+  tile->setMetadata(
+  {
+    { QStringLiteral( "gltfUpAxis" ), static_cast< int >( gltfUpAxis ) },
+    { QStringLiteral( "contentFormat" ), QStringLiteral( "cesiumtiles" ) },
+  } );
 
   QgsMatrix4x4 transform;
   if ( json.contains( "transform" ) && !json["transform"].is_null() )
@@ -892,7 +899,7 @@ void QgsCesiumTilesDataProviderSharedData::initialize( const QString &tileset, c
 // QgsCesiumTilesDataProvider
 //
 
-QgsCesiumTilesDataProvider::QgsCesiumTilesDataProvider( const QString &uri, const ProviderOptions &providerOptions, ReadFlags flags )
+QgsCesiumTilesDataProvider::QgsCesiumTilesDataProvider( const QString &uri, const ProviderOptions &providerOptions, Qgis::DataProviderReadFlags flags )
   : QgsTiledSceneDataProvider( uri, providerOptions, flags )
   , mShared( std::make_shared< QgsCesiumTilesDataProviderSharedData >() )
 {
@@ -914,6 +921,11 @@ QgsCesiumTilesDataProvider::QgsCesiumTilesDataProvider( const QgsCesiumTilesData
   mShared = other.mShared;
 }
 
+Qgis::DataProviderFlags QgsCesiumTilesDataProvider::flags() const
+{
+  return Qgis::DataProviderFlag::FastExtent2D;
+}
+
 Qgis::TiledSceneProviderCapabilities QgsCesiumTilesDataProvider::capabilities() const
 {
   return Qgis::TiledSceneProviderCapability::ReadLayerMetadata;
@@ -1273,7 +1285,7 @@ QIcon QgsCesiumTilesProviderMetadata::icon() const
   return QgsApplication::getThemeIcon( QStringLiteral( "mIconCesium3dTiles.svg" ) );
 }
 
-QgsCesiumTilesDataProvider *QgsCesiumTilesProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, QgsDataProvider::ReadFlags flags )
+QgsCesiumTilesDataProvider *QgsCesiumTilesProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, Qgis::DataProviderReadFlags flags )
 {
   return new QgsCesiumTilesDataProvider( uri, options, flags );
 }
