@@ -15,11 +15,10 @@
 
 #include <QTextCodec>
 
-#include <cfloat>
-#include <climits>
 #include <limits>
 
 #include "qgsvectordataprovider.h"
+#include "moc_qgsvectordataprovider.cpp"
 #include "qgscircularstring.h"
 #include "qgscompoundcurve.h"
 #include "qgsfeature.h"
@@ -35,11 +34,13 @@
 #include "qgsogrproxytextcodec.h"
 #include "qgsthreadingutils.h"
 #include <mutex>
+#include "qgsdataproviderelevationproperties.h"
 
 QgsVectorDataProvider::QgsVectorDataProvider( const QString &uri, const ProviderOptions &options,
-    QgsDataProvider::ReadFlags flags )
+    Qgis::DataProviderReadFlags flags )
   : QgsDataProvider( uri, options, flags )
   , mTemporalCapabilities( std::make_unique< QgsVectorDataProviderTemporalCapabilities >() )
+  , mElevationProperties( std::make_unique< QgsDataProviderElevationProperties >() )
 {
 }
 
@@ -57,7 +58,7 @@ bool QgsVectorDataProvider::empty() const
   QgsFeature f;
   QgsFeatureRequest request;
   request.setNoAttributes();
-  request.setFlags( QgsFeatureRequest::NoGeometry );
+  request.setFlags( Qgis::FeatureRequestFlag::NoGeometry );
   request.setLimit( 1 );
   if ( getFeatures( request ).nextFeature( f ) )
     return false;
@@ -79,14 +80,14 @@ Qgis::VectorLayerTypeFlags QgsVectorDataProvider::vectorLayerTypeFlags() const
   return Qgis::VectorLayerTypeFlags();
 }
 
-QgsFeatureSource::FeatureAvailability QgsVectorDataProvider::hasFeatures() const
+Qgis::FeatureAvailability QgsVectorDataProvider::hasFeatures() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
   if ( empty() )
-    return QgsFeatureSource::FeatureAvailability::NoFeaturesAvailable;
+    return Qgis::FeatureAvailability::NoFeaturesAvailable;
   else
-    return QgsFeatureSource::FeatureAvailability::FeaturesAvailable;
+    return Qgis::FeatureAvailability::FeaturesAvailable;
 }
 
 QgsCoordinateReferenceSystem QgsVectorDataProvider::sourceCrs() const
@@ -103,6 +104,13 @@ QgsRectangle QgsVectorDataProvider::sourceExtent() const
   return extent();
 }
 
+QgsBox3D QgsVectorDataProvider::sourceExtent3D() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return extent3D();
+}
+
 QString QgsVectorDataProvider::dataComment() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
@@ -138,11 +146,11 @@ bool QgsVectorDataProvider::truncate()
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( !( capabilities() & DeleteFeatures ) )
+  if ( !( capabilities() & Qgis::VectorProviderCapability::DeleteFeatures ) )
     return false;
 
   QgsFeatureIds toDelete;
-  QgsFeatureIterator it = getFeatures( QgsFeatureRequest().setFlags( QgsFeatureRequest::NoGeometry ).setNoAttributes() );
+  QgsFeatureIterator it = getFeatures( QgsFeatureRequest().setFlags( Qgis::FeatureRequestFlag::NoGeometry ).setNoAttributes() );
   QgsFeature f;
   while ( it.nextFeature( f ) )
     toDelete << f.id();
@@ -229,7 +237,7 @@ bool QgsVectorDataProvider::changeFeatures( const QgsChangedAttributesMap &attr_
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  if ( !( capabilities() & ChangeAttributeValues ) || !( capabilities() & ChangeGeometries ) )
+  if ( !( capabilities() & Qgis::VectorProviderCapability::ChangeAttributeValues ) || !( capabilities() & Qgis::VectorProviderCapability::ChangeGeometries ) )
     return false;
 
   bool result = true;
@@ -253,11 +261,11 @@ bool QgsVectorDataProvider::createAttributeIndex( int field )
   return true;
 }
 
-QgsVectorDataProvider::Capabilities QgsVectorDataProvider::capabilities() const
+Qgis::VectorProviderCapabilities QgsVectorDataProvider::capabilities() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
-  return QgsVectorDataProvider::NoCapabilities;
+  return Qgis::VectorProviderCapability::NoCapabilities;
 }
 
 void QgsVectorDataProvider::setEncoding( const QString &e )
@@ -317,85 +325,85 @@ QString QgsVectorDataProvider::capabilitiesString() const
 
   QStringList abilitiesList;
 
-  const int abilities = capabilities();
+  const Qgis::VectorProviderCapabilities abilities = capabilities();
 
-  if ( abilities & QgsVectorDataProvider::AddFeatures )
+  if ( abilities & Qgis::VectorProviderCapability::AddFeatures )
   {
     abilitiesList += tr( "Add Features" );
   }
 
-  if ( abilities & QgsVectorDataProvider::DeleteFeatures )
+  if ( abilities & Qgis::VectorProviderCapability::DeleteFeatures )
   {
     abilitiesList += tr( "Delete Features" );
   }
 
-  if ( abilities & QgsVectorDataProvider::ChangeAttributeValues )
+  if ( abilities & Qgis::VectorProviderCapability::ChangeAttributeValues )
   {
     abilitiesList += tr( "Change Attribute Values" );
   }
 
-  if ( abilities & QgsVectorDataProvider::AddAttributes )
+  if ( abilities & Qgis::VectorProviderCapability::AddAttributes )
   {
     abilitiesList += tr( "Add Attributes" );
   }
 
-  if ( abilities & QgsVectorDataProvider::DeleteAttributes )
+  if ( abilities & Qgis::VectorProviderCapability::DeleteAttributes )
   {
     abilitiesList += tr( "Delete Attributes" );
   }
 
-  if ( abilities & QgsVectorDataProvider::RenameAttributes )
+  if ( abilities & Qgis::VectorProviderCapability::RenameAttributes )
   {
     abilitiesList += tr( "Rename Attributes" );
   }
 
-  if ( abilities & QgsVectorDataProvider::CreateSpatialIndex )
+  if ( abilities & Qgis::VectorProviderCapability::CreateSpatialIndex )
   {
     // TODO: Tighten up this test.  See QgsOgrProvider for details.
     abilitiesList += tr( "Create Spatial Index" );
   }
 
-  if ( abilities & QgsVectorDataProvider::CreateAttributeIndex )
+  if ( abilities & Qgis::VectorProviderCapability::CreateAttributeIndex )
   {
     abilitiesList += tr( "Create Attribute Indexes" );
   }
 
-  if ( abilities & QgsVectorDataProvider::SelectAtId )
+  if ( abilities & Qgis::VectorProviderCapability::SelectAtId )
   {
     abilitiesList += tr( "Fast Access to Features at ID" );
   }
 
-  if ( abilities & QgsVectorDataProvider::ChangeGeometries )
+  if ( abilities & Qgis::VectorProviderCapability::ChangeGeometries )
   {
     abilitiesList += tr( "Change Geometries" );
   }
 
-  if ( abilities & QgsVectorDataProvider::SimplifyGeometries )
+  if ( abilities & Qgis::VectorProviderCapability::SimplifyGeometries )
   {
     abilitiesList += tr( "Presimplify Geometries" );
   }
 
-  if ( abilities & QgsVectorDataProvider::SimplifyGeometriesWithTopologicalValidation )
+  if ( abilities & Qgis::VectorProviderCapability::SimplifyGeometriesWithTopologicalValidation )
   {
     abilitiesList += tr( "Presimplify Geometries with Validity Check" );
   }
 
-  if ( abilities & QgsVectorDataProvider::ChangeFeatures )
+  if ( abilities & Qgis::VectorProviderCapability::ChangeFeatures )
   {
     abilitiesList += tr( "Simultaneous Geometry and Attribute Updates" );
   }
 
-  if ( abilities & QgsVectorDataProvider::TransactionSupport )
+  if ( abilities & Qgis::VectorProviderCapability::TransactionSupport )
   {
     abilitiesList += tr( "Transactions" );
   }
 
-  if ( abilities & QgsVectorDataProvider::CircularGeometries )
+  if ( abilities & Qgis::VectorProviderCapability::CircularGeometries )
   {
     abilitiesList += tr( "Curved Geometries" );
   }
 
-  if ( abilities & QgsVectorDataProvider::FeatureSymbology )
+  if ( abilities & Qgis::VectorProviderCapability::FeatureSymbology )
   {
     abilitiesList += tr( "Feature Symbology" );
   }
@@ -444,6 +452,13 @@ QgsAttributeList QgsVectorDataProvider::pkAttributeIndexes() const
   return QgsAttributeList();
 }
 
+QString QgsVectorDataProvider::geometryColumnName() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return QString();
+}
+
 QList<QgsVectorDataProvider::NativeType> QgsVectorDataProvider::nativeTypes() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
@@ -562,7 +577,7 @@ QStringList QgsVectorDataProvider::uniqueStringsMatching( int index, const QStri
 
   QgsFeatureRequest request;
   request.setSubsetOfAttributes( keys );
-  request.setFlags( QgsFeatureRequest::NoGeometry );
+  request.setFlags( Qgis::FeatureRequestFlag::NoGeometry );
   const QString fieldName = fields().at( index ).name();
   request.setFilterExpression( QStringLiteral( "\"%1\" ILIKE '%%2%'" ).arg( fieldName, substring ) );
   QgsFeatureIterator fi = getFeatures( request );
@@ -584,7 +599,7 @@ QStringList QgsVectorDataProvider::uniqueStringsMatching( int index, const QStri
   return results;
 }
 
-QVariant QgsVectorDataProvider::aggregate( QgsAggregateCalculator::Aggregate aggregate, int index,
+QVariant QgsVectorDataProvider::aggregate( Qgis::Aggregate aggregate, int index,
     const QgsAggregateCalculator::AggregateParameters &parameters, QgsExpressionContext *context, bool &ok, QgsFeatureIds *fids ) const
 {
   // non fatal for now -- the "aggregate" functions are not thread safe and call this
@@ -620,17 +635,17 @@ void QgsVectorDataProvider::fillMinMaxCache() const
   const QgsFields flds = fields();
   for ( int i = 0; i < flds.count(); ++i )
   {
-    if ( flds.at( i ).type() == QVariant::Int )
+    if ( flds.at( i ).type() == QMetaType::Type::Int )
     {
       mCacheMinValues[i] = QVariant( std::numeric_limits<int>::max() );
       mCacheMaxValues[i] = QVariant( std::numeric_limits<int>::lowest() );
     }
-    else if ( flds.at( i ).type() == QVariant::LongLong )
+    else if ( flds.at( i ).type() == QMetaType::Type::LongLong )
     {
       mCacheMinValues[i] = QVariant( std::numeric_limits<qlonglong>::max() );
       mCacheMaxValues[i] = QVariant( std::numeric_limits<qlonglong>::lowest() );
     }
-    else if ( flds.at( i ).type() == QVariant::Double )
+    else if ( flds.at( i ).type() == QMetaType::Type::Double )
     {
       mCacheMinValues[i] = QVariant( std::numeric_limits<double>::max() );
       mCacheMaxValues[i] = QVariant( std::numeric_limits<double>::lowest() );
@@ -646,7 +661,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
   QgsFeature f;
   const QgsAttributeList keys = mCacheMinValues.keys();
   QgsFeatureIterator fi = getFeatures( QgsFeatureRequest().setSubsetOfAttributes( keys )
-                                       .setFlags( QgsFeatureRequest::NoGeometry ) );
+                                       .setFlags( Qgis::FeatureRequestFlag::NoGeometry ) );
 
   while ( fi.nextFeature( f ) )
   {
@@ -660,7 +675,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
 
       switch ( flds.at( attributeIndex ).type() )
       {
-        case QVariant::Int:
+        case QMetaType::Type::Int:
         {
           const int value = varValue.toInt();
           if ( value < mCacheMinValues[ attributeIndex ].toInt() )
@@ -669,7 +684,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
             mCacheMaxValues[ attributeIndex ] = value;
           break;
         }
-        case QVariant::LongLong:
+        case QMetaType::Type::LongLong:
         {
           const qlonglong value = varValue.toLongLong();
           if ( value < mCacheMinValues[ attributeIndex ].toLongLong() )
@@ -678,7 +693,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
             mCacheMaxValues[ attributeIndex ] = value;
           break;
         }
-        case QVariant::Double:
+        case QMetaType::Type::Double:
         {
           const double value = varValue.toDouble();
           if ( value < mCacheMinValues[ attributeIndex ].toDouble() )
@@ -687,7 +702,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
             mCacheMaxValues[ attributeIndex ] = value;
           break;
         }
-        case QVariant::DateTime:
+        case QMetaType::Type::QDateTime:
         {
           const QDateTime value = varValue.toDateTime();
           if ( value < mCacheMinValues[ attributeIndex ].toDateTime() || !mCacheMinValues[ attributeIndex ].isValid() )
@@ -696,7 +711,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
             mCacheMaxValues[ attributeIndex ] = value;
           break;
         }
-        case QVariant::Date:
+        case QMetaType::Type::QDate:
         {
           const QDate value = varValue.toDate();
           if ( value < mCacheMinValues[ attributeIndex ].toDate() || !mCacheMinValues[ attributeIndex ].isValid() )
@@ -705,7 +720,7 @@ void QgsVectorDataProvider::fillMinMaxCache() const
             mCacheMaxValues[ attributeIndex ] = value;
           break;
         }
-        case QVariant::Time:
+        case QMetaType::Type::QTime:
         {
           const QTime value = varValue.toTime();
           if ( value < mCacheMinValues[ attributeIndex ].toTime() || !mCacheMinValues[ attributeIndex ].isValid() )
@@ -734,16 +749,21 @@ void QgsVectorDataProvider::fillMinMaxCache() const
   mCacheMinMaxDirty = false;
 }
 
-QVariant QgsVectorDataProvider::convertValue( QVariant::Type type, const QString &value )
+QVariant QgsVectorDataProvider::convertValue( QMetaType::Type type, const QString &value )
 {
   QVariant v( value );
 
   if ( !v.convert( type ) || value.isNull() )
-    v = QVariant( type );
+    v = QgsVariantUtils::createNullVariant( type );
 
   return v;
 }
 
+QVariant QgsVectorDataProvider::convertValue( QVariant::Type type, const QString &value )
+{
+  return convertValue( QgsVariantUtils::variantTypeToMetaType( type ), value );
+}
+
 QgsTransaction *QgsVectorDataProvider::transaction() const
 {
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
@@ -1056,3 +1076,17 @@ const QgsVectorDataProviderTemporalCapabilities *QgsVectorDataProvider::temporal
 
   return mTemporalCapabilities.get();
 }
+
+QgsDataProviderElevationProperties *QgsVectorDataProvider::elevationProperties()
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return mElevationProperties.get();
+}
+
+const QgsDataProviderElevationProperties *QgsVectorDataProvider::elevationProperties() const
+{
+  QGIS_PROTECT_QOBJECT_THREAD_ACCESS
+
+  return mElevationProperties.get();
+}
