@@ -16,6 +16,7 @@
 
 #include "qgsapplication.h"
 #include "qgscodeeditor.h"
+#include "moc_qgscodeeditor.cpp"
 #include "qgssettings.h"
 #include "qgssymbollayerutils.h"
 #include "qgsgui.h"
@@ -35,47 +36,47 @@
 #include <QClipboard>
 #include <QScrollBar>
 #include <QMessageBox>
+#include "Qsci/qscilexer.h"
 
-QMap< QgsCodeEditorColorScheme::ColorRole, QString > QgsCodeEditor::sColorRoleToSettingsKey
-{
-  {QgsCodeEditorColorScheme::ColorRole::Default, QStringLiteral( "defaultFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Keyword, QStringLiteral( "keywordFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Class, QStringLiteral( "classFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Method, QStringLiteral( "methodFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Decoration, QStringLiteral( "decoratorFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Number, QStringLiteral( "numberFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Comment, QStringLiteral( "commentFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::CommentLine, QStringLiteral( "commentLineFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::CommentBlock, QStringLiteral( "commentBlockFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Background, QStringLiteral( "paperBackgroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Cursor, QStringLiteral( "cursorColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::CaretLine, QStringLiteral( "caretLineColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Operator, QStringLiteral( "operatorFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::QuotedOperator, QStringLiteral( "quotedOperatorFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Identifier, QStringLiteral( "identifierFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::QuotedIdentifier, QStringLiteral( "quotedIdentifierFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Tag, QStringLiteral( "tagFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::UnknownTag, QStringLiteral( "unknownTagFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::SingleQuote, QStringLiteral( "singleQuoteFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::DoubleQuote, QStringLiteral( "doubleQuoteFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::TripleSingleQuote, QStringLiteral( "tripleSingleQuoteFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::TripleDoubleQuote, QStringLiteral( "tripleDoubleQuoteFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::MarginBackground, QStringLiteral( "marginBackgroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::MarginForeground, QStringLiteral( "marginForegroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::SelectionBackground, QStringLiteral( "selectionBackgroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::SelectionForeground, QStringLiteral( "selectionForegroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::MatchedBraceBackground, QStringLiteral( "matchedBraceBackground" ) },
-  {QgsCodeEditorColorScheme::ColorRole::MatchedBraceForeground, QStringLiteral( "matchedBraceColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Edge, QStringLiteral( "edgeColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Fold, QStringLiteral( "foldColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::Error, QStringLiteral( "stderrFontColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::ErrorBackground, QStringLiteral( "stderrBackgroundColor" ) },
-  {QgsCodeEditorColorScheme::ColorRole::FoldIconForeground, QStringLiteral( "foldIconForeground" ) },
-  {QgsCodeEditorColorScheme::ColorRole::FoldIconHalo, QStringLiteral( "foldIconHalo" ) },
-  {QgsCodeEditorColorScheme::ColorRole::IndentationGuide, QStringLiteral( "indentationGuide" ) },
+QMap<QgsCodeEditorColorScheme::ColorRole, QString> QgsCodeEditor::sColorRoleToSettingsKey {
+  { QgsCodeEditorColorScheme::ColorRole::Default, QStringLiteral( "defaultFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Keyword, QStringLiteral( "keywordFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Class, QStringLiteral( "classFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Method, QStringLiteral( "methodFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Decoration, QStringLiteral( "decoratorFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Number, QStringLiteral( "numberFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Comment, QStringLiteral( "commentFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::CommentLine, QStringLiteral( "commentLineFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::CommentBlock, QStringLiteral( "commentBlockFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Background, QStringLiteral( "paperBackgroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Cursor, QStringLiteral( "cursorColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::CaretLine, QStringLiteral( "caretLineColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Operator, QStringLiteral( "operatorFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::QuotedOperator, QStringLiteral( "quotedOperatorFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Identifier, QStringLiteral( "identifierFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::QuotedIdentifier, QStringLiteral( "quotedIdentifierFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Tag, QStringLiteral( "tagFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::UnknownTag, QStringLiteral( "unknownTagFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::SingleQuote, QStringLiteral( "singleQuoteFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::DoubleQuote, QStringLiteral( "doubleQuoteFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::TripleSingleQuote, QStringLiteral( "tripleSingleQuoteFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::TripleDoubleQuote, QStringLiteral( "tripleDoubleQuoteFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::MarginBackground, QStringLiteral( "marginBackgroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::MarginForeground, QStringLiteral( "marginForegroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::SelectionBackground, QStringLiteral( "selectionBackgroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::SelectionForeground, QStringLiteral( "selectionForegroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::MatchedBraceBackground, QStringLiteral( "matchedBraceBackground" ) },
+  { QgsCodeEditorColorScheme::ColorRole::MatchedBraceForeground, QStringLiteral( "matchedBraceColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Edge, QStringLiteral( "edgeColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Fold, QStringLiteral( "foldColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::Error, QStringLiteral( "stderrFontColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::ErrorBackground, QStringLiteral( "stderrBackgroundColor" ) },
+  { QgsCodeEditorColorScheme::ColorRole::FoldIconForeground, QStringLiteral( "foldIconForeground" ) },
+  { QgsCodeEditorColorScheme::ColorRole::FoldIconHalo, QStringLiteral( "foldIconHalo" ) },
+  { QgsCodeEditorColorScheme::ColorRole::IndentationGuide, QStringLiteral( "indentationGuide" ) },
+  { QgsCodeEditorColorScheme::ColorRole::SearchMatchBackground, QStringLiteral( "searchMatchBackground" ) }
 };
 
-
 QgsCodeEditor::QgsCodeEditor( QWidget *parent, const QString &title, bool folding, bool margin, QgsCodeEditor::Flags flags, QgsCodeEditor::Mode mode )
   : QsciScintilla( parent )
   , mWidgetTitle( title )
@@ -104,13 +105,12 @@ QgsCodeEditor::QgsCodeEditor( QWidget *parent, const QString &title, bool foldin
   SendScintilla( SCI_SETMULTIPASTE, 1 );
   SendScintilla( SCI_SETVIRTUALSPACEOPTIONS, SCVS_RECTANGULARSELECTION );
 
-  SendScintilla( SCI_SETMARGINTYPEN, static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), SC_MARGIN_SYMBOL );
-  SendScintilla( SCI_SETMARGINMASKN, static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), 1 << MARKER_NUMBER );
-  setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
+  SendScintilla( SCI_SETMARGINTYPEN, static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), SC_MARGIN_SYMBOL );
+  SendScintilla( SCI_SETMARGINMASKN, static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), 1 << MARKER_NUMBER );
+  setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
   setAnnotationDisplay( QsciScintilla::AnnotationBoxed );
 
-  connect( QgsGui::instance(), &QgsGui::optionsChanged, this, [ = ]
-  {
+  connect( QgsGui::instance(), &QgsGui::optionsChanged, this, [=] {
     setSciWidget();
     initializeLexer();
   } );
@@ -239,6 +239,11 @@ void QgsCodeEditor::keyPressEvent( QKeyEvent *event )
 
   QsciScintilla::keyPressEvent( event );
 
+  // Update calltips unless event is autorepeat
+  if ( !event->isAutoRepeat() )
+  {
+    callTip();
+  }
 }
 
 void QgsCodeEditor::contextMenuEvent( QContextMenuEvent *event )
@@ -250,8 +255,7 @@ void QgsCodeEditor::contextMenuEvent( QContextMenuEvent *event )
       QMenu *menu = createStandardContextMenu();
       menu->setAttribute( Qt::WA_DeleteOnClose );
 
-      if ( ( languageCapabilities() & Qgis::ScriptLanguageCapability::Reformat ) ||
-           ( languageCapabilities() & Qgis::ScriptLanguageCapability::CheckSyntax ) )
+      if ( ( languageCapabilities() & Qgis::ScriptLanguageCapability::Reformat ) || ( languageCapabilities() & Qgis::ScriptLanguageCapability::CheckSyntax ) )
       {
         menu->addSeparator();
       }
@@ -278,7 +282,7 @@ void QgsCodeEditor::contextMenuEvent( QContextMenuEvent *event )
       {
         QAction *toggleCommentAction = new QAction( tr( "Toggle Comment" ), menu );
         toggleCommentAction->setShortcut( QStringLiteral( "Ctrl+:" ) );
-        toggleCommentAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "console/iconCommentEditorConsole.svg" ) ) );
+        toggleCommentAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "console/iconCommentEditorConsole.svg" ), palette().color( QPalette::ColorRole::WindowText ) ) );
         toggleCommentAction->setEnabled( !isReadOnly() );
         connect( toggleCommentAction, &QAction::triggered, this, &QgsCodeEditor::toggleComment );
         menu->addAction( toggleCommentAction );
@@ -336,7 +340,6 @@ bool QgsCodeEditor::eventFilter( QObject *watched, QEvent *event )
 
 void QgsCodeEditor::initializeLexer()
 {
-
 }
 
 QColor QgsCodeEditor::lexerColor( QgsCodeEditorColorScheme::ColorRole role ) const
@@ -396,11 +399,17 @@ void QgsCodeEditor::runPostLexerConfigurationTasks()
   setMatchedBraceBackgroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MatchedBraceBackground ) );
 
   SendScintilla( SCI_MARKERSETFORE, SC_MARKNUM_FOLDEROPEN, lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconHalo ) );
-  SendScintilla( SCI_MARKERSETBACK, SC_MARKNUM_FOLDEROPEN,  lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconForeground ) );
+  SendScintilla( SCI_MARKERSETBACK, SC_MARKNUM_FOLDEROPEN, lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconForeground ) );
   SendScintilla( SCI_MARKERSETFORE, SC_MARKNUM_FOLDER, lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconHalo ) );
-  SendScintilla( SCI_MARKERSETBACK, SC_MARKNUM_FOLDER,  lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconForeground ) );
+  SendScintilla( SCI_MARKERSETBACK, SC_MARKNUM_FOLDER, lexerColor( QgsCodeEditorColorScheme::ColorRole::FoldIconForeground ) );
   SendScintilla( SCI_STYLESETFORE, STYLE_INDENTGUIDE, lexerColor( QgsCodeEditorColorScheme::ColorRole::IndentationGuide ) );
-  SendScintilla( SCI_STYLESETBACK, STYLE_INDENTGUIDE,  lexerColor( QgsCodeEditorColorScheme::ColorRole::IndentationGuide ) );
+  SendScintilla( SCI_STYLESETBACK, STYLE_INDENTGUIDE, lexerColor( QgsCodeEditorColorScheme::ColorRole::IndentationGuide ) );
+
+  SendScintilla( QsciScintilla::SCI_INDICSETSTYLE, SEARCH_RESULT_INDICATOR, QsciScintilla::INDIC_STRAIGHTBOX );
+  SendScintilla( QsciScintilla::SCI_INDICSETFORE, SEARCH_RESULT_INDICATOR, lexerColor( QgsCodeEditorColorScheme::ColorRole::SearchMatchBackground ) );
+  SendScintilla( QsciScintilla::SCI_INDICSETALPHA, SEARCH_RESULT_INDICATOR, 100 );
+  SendScintilla( QsciScintilla::SCI_INDICSETUNDER, SEARCH_RESULT_INDICATOR, true );
+  SendScintilla( QsciScintilla::SCI_INDICGETOUTLINEALPHA, SEARCH_RESULT_INDICATOR, 255 );
 
   if ( mMode == QgsCodeEditor::Mode::CommandInput )
   {
@@ -435,9 +444,9 @@ void QgsCodeEditor::setSciWidget()
 
   // temporarily disable folding, will be enabled later if required by updateFolding()
   setFolding( QsciScintilla::NoFoldStyle );
-  setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
+  setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
 
-  setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
+  setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
 
   setMarginsForegroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginForeground ) );
   setMarginsBackgroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginBackground ) );
@@ -457,8 +466,7 @@ void QgsCodeEditor::setSciWidget()
   setAutoCompletionThreshold( 2 );
   setAutoCompletionSource( QsciScintilla::AcsAPIs );
 
-  markerDefine( QgsApplication::getThemePixmap( "console/iconSyntaxErrorConsoleParams.svg", lexerColor( QgsCodeEditorColorScheme::ColorRole::Error ),
-                lexerColor( QgsCodeEditorColorScheme::ColorRole::ErrorBackground ), 16 ), MARKER_NUMBER );
+  markerDefine( QgsApplication::getThemePixmap( "console/iconSyntaxErrorConsoleParams.svg", lexerColor( QgsCodeEditorColorScheme::ColorRole::Error ), lexerColor( QgsCodeEditorColorScheme::ColorRole::ErrorBackground ), 16 ), MARKER_NUMBER );
 }
 
 void QgsCodeEditor::setTitle( const QString &title )
@@ -515,15 +523,15 @@ void QgsCodeEditor::setMarginVisible( bool margin )
     marginFont.setPointSize( 10 );
     setMarginLineNumbers( 0, true );
     setMarginsFont( marginFont );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), QStringLiteral( "00000" ) );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), QStringLiteral( "00000" ) );
     setMarginsForegroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginForeground ) );
     setMarginsBackgroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginBackground ) );
   }
   else
   {
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), 0 );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), 0 );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
   }
 }
 
@@ -533,22 +541,22 @@ void QgsCodeEditor::setLineNumbersVisible( bool visible )
   {
     QFont marginFont = lexerFont();
     marginFont.setPointSize( 10 );
-    setMarginLineNumbers( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), true );
+    setMarginLineNumbers( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), true );
     setMarginsFont( marginFont );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), QStringLiteral( "00000" ) );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), QStringLiteral( "00000" ) );
     setMarginsForegroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginForeground ) );
     setMarginsBackgroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginBackground ) );
   }
   else
   {
-    setMarginLineNumbers( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), false );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ), 0 );
+    setMarginLineNumbers( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), false );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ), 0 );
   }
 }
 
 bool QgsCodeEditor::lineNumbersVisible() const
 {
-  return marginLineNumbers( static_cast< int >( QgsCodeEditor::MarginRole::LineNumbers ) );
+  return marginLineNumbers( static_cast<int>( QgsCodeEditor::MarginRole::LineNumbers ) );
 }
 
 void QgsCodeEditor::setFoldingVisible( bool folding )
@@ -559,7 +567,7 @@ void QgsCodeEditor::setFoldingVisible( bool folding )
   }
   else
   {
-    mFlags &= ~( static_cast< int >( QgsCodeEditor::Flag::CodeFolding ) );
+    mFlags &= ~( static_cast<int>( QgsCodeEditor::Flag::CodeFolding ) );
   }
   updateFolding();
 }
@@ -573,7 +581,7 @@ void QgsCodeEditor::updateFolding()
 {
   if ( ( mFlags & QgsCodeEditor::Flag::CodeFolding ) && mMode == QgsCodeEditor::Mode::ScriptEditor )
   {
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::FoldingControls ), "0" );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::FoldingControls ), "0" );
     setMarginsForegroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginForeground ) );
     setMarginsBackgroundColor( lexerColor( QgsCodeEditorColorScheme::ColorRole::MarginBackground ) );
     setFolding( QsciScintilla::PlainFoldStyle );
@@ -581,7 +589,7 @@ void QgsCodeEditor::updateFolding()
   else
   {
     setFolding( QsciScintilla::NoFoldStyle );
-    setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
+    setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::FoldingControls ), 0 );
   }
 }
 
@@ -594,7 +602,7 @@ bool QgsCodeEditor::readHistoryFile()
   if ( file.open( QIODevice::ReadOnly ) )
   {
     QTextStream stream( &file );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     // Always use UTF-8
     stream.setCodec( "UTF-8" );
 #endif
@@ -642,7 +650,6 @@ void QgsCodeEditor::updateHistory( const QStringList &commands, bool skipSoftHis
 
 void QgsCodeEditor::populateContextMenu( QMenu * )
 {
-
 }
 
 QString QgsCodeEditor::reformatCodeString( const QString &string )
@@ -675,7 +682,7 @@ void QgsCodeEditor::updatePrompt()
   if ( mInterpreter )
   {
     const QString prompt = mInterpreter->promptForState( mInterpreter->currentState() );
-    SendScintilla( QsciScintilla::SCI_MARGINSETTEXT, static_cast< uintptr_t >( 0 ), prompt.toUtf8().constData() );
+    SendScintilla( QsciScintilla::SCI_MARGINSETTEXT, static_cast<uintptr_t>( 0 ), prompt.toUtf8().constData() );
   }
 }
 
@@ -752,13 +759,8 @@ void QgsCodeEditor::reformatCode()
   if ( !( languageCapabilities() & Qgis::ScriptLanguageCapability::Reformat ) )
     return;
 
-  int line = 0;
-  int index = 0;
-  getCursorPosition( &line, &index );
-  const QString textBeforeCursor = text( 0, positionFromLineIndex( line, index ) );
-
+  const QString textBeforeCursor = text( 0, linearPosition() );
   const QString originalText = text();
-
   const QString newText = reformatCodeString( originalText );
 
   if ( originalText == newText )
@@ -766,14 +768,13 @@ void QgsCodeEditor::reformatCode()
 
   // try to preserve the cursor position and scroll position
   const int oldScrollValue = verticalScrollBar()->value();
-  const int linearPosition = findMinimalDistanceIndex( newText, textBeforeCursor );
+  const int linearIndex = findMinimalDistanceIndex( newText, textBeforeCursor );
 
   beginUndoAction();
   selectAll();
   removeSelectedText();
   insert( newText );
-  lineIndexFromPosition( linearPosition, &line, &index );
-  setCursorPosition( line, index );
+  setLinearPosition( linearIndex );
   verticalScrollBar()->setValue( oldScrollValue );
   endUndoAction();
 }
@@ -785,7 +786,6 @@ bool QgsCodeEditor::checkSyntax()
 
 void QgsCodeEditor::toggleComment()
 {
-
 }
 
 QStringList QgsCodeEditor::history() const
@@ -843,7 +843,7 @@ bool QgsCodeEditor::writeHistoryFile()
   }
 
   QTextStream ts( &f );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
   ts.setCodec( "UTF-8" );
 #endif
   for ( const QString &command : std::as_const( mHistory ) )
@@ -933,43 +933,43 @@ QColor QgsCodeEditor::defaultColor( QgsCodeEditorColorScheme::ColorRole role, co
     // non default theme (e.g. Blend of Gray). Take colors from theme ini file...
     const QSettings ini( QgsApplication::uiThemes().value( QgsApplication::themeName() ) + "/qscintilla.ini", QSettings::IniFormat );
 
-    static const QMap< QgsCodeEditorColorScheme::ColorRole, QString > sColorRoleToIniKey
-    {
-      {QgsCodeEditorColorScheme::ColorRole::Default, QStringLiteral( "python/defaultFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Keyword, QStringLiteral( "python/keywordFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Class, QStringLiteral( "python/classFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Method, QStringLiteral( "python/methodFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Decoration, QStringLiteral( "python/decoratorFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Number, QStringLiteral( "python/numberFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Comment, QStringLiteral( "python/commentFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::CommentLine, QStringLiteral( "sql/commentLineFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::CommentBlock, QStringLiteral( "python/commentBlockFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Background, QStringLiteral( "python/paperBackgroundColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Cursor, QStringLiteral( "cursorColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::CaretLine, QStringLiteral( "caretLineColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Operator, QStringLiteral( "sql/operatorFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::QuotedOperator, QStringLiteral( "sql/QuotedOperatorFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Identifier, QStringLiteral( "sql/identifierFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::QuotedIdentifier, QStringLiteral( "sql/QuotedIdentifierFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Tag, QStringLiteral( "html/tagFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::UnknownTag, QStringLiteral( "html/unknownTagFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::SingleQuote, QStringLiteral( "sql/singleQuoteFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::DoubleQuote, QStringLiteral( "sql/doubleQuoteFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::TripleSingleQuote, QStringLiteral( "python/tripleSingleQuoteFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::TripleDoubleQuote, QStringLiteral( "python/tripleDoubleQuoteFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::MarginBackground, QStringLiteral( "marginBackgroundColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::MarginForeground, QStringLiteral( "marginForegroundColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::SelectionBackground, QStringLiteral( "selectionBackgroundColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::SelectionForeground, QStringLiteral( "selectionForegroundColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::MatchedBraceBackground, QStringLiteral( "matchedBraceBackground" ) },
-      {QgsCodeEditorColorScheme::ColorRole::MatchedBraceForeground, QStringLiteral( "matchedBraceColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Edge, QStringLiteral( "edgeColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Fold, QStringLiteral( "foldColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::Error, QStringLiteral( "stderrFontColor" ) },
-      {QgsCodeEditorColorScheme::ColorRole::ErrorBackground, QStringLiteral( "stderrBackground" ) },
-      {QgsCodeEditorColorScheme::ColorRole::FoldIconForeground, QStringLiteral( "foldIconForeground" ) },
-      {QgsCodeEditorColorScheme::ColorRole::FoldIconHalo, QStringLiteral( "foldIconHalo" ) },
-      {QgsCodeEditorColorScheme::ColorRole::IndentationGuide, QStringLiteral( "indentationGuide" ) },
+    static const QMap<QgsCodeEditorColorScheme::ColorRole, QString> sColorRoleToIniKey {
+      { QgsCodeEditorColorScheme::ColorRole::Default, QStringLiteral( "python/defaultFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Keyword, QStringLiteral( "python/keywordFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Class, QStringLiteral( "python/classFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Method, QStringLiteral( "python/methodFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Decoration, QStringLiteral( "python/decoratorFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Number, QStringLiteral( "python/numberFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Comment, QStringLiteral( "python/commentFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::CommentLine, QStringLiteral( "sql/commentLineFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::CommentBlock, QStringLiteral( "python/commentBlockFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Background, QStringLiteral( "python/paperBackgroundColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Cursor, QStringLiteral( "cursorColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::CaretLine, QStringLiteral( "caretLineColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Operator, QStringLiteral( "sql/operatorFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::QuotedOperator, QStringLiteral( "sql/QuotedOperatorFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Identifier, QStringLiteral( "sql/identifierFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::QuotedIdentifier, QStringLiteral( "sql/QuotedIdentifierFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Tag, QStringLiteral( "html/tagFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::UnknownTag, QStringLiteral( "html/unknownTagFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::SingleQuote, QStringLiteral( "sql/singleQuoteFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::DoubleQuote, QStringLiteral( "sql/doubleQuoteFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::TripleSingleQuote, QStringLiteral( "python/tripleSingleQuoteFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::TripleDoubleQuote, QStringLiteral( "python/tripleDoubleQuoteFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::MarginBackground, QStringLiteral( "marginBackgroundColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::MarginForeground, QStringLiteral( "marginForegroundColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::SelectionBackground, QStringLiteral( "selectionBackgroundColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::SelectionForeground, QStringLiteral( "selectionForegroundColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::MatchedBraceBackground, QStringLiteral( "matchedBraceBackground" ) },
+      { QgsCodeEditorColorScheme::ColorRole::MatchedBraceForeground, QStringLiteral( "matchedBraceColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Edge, QStringLiteral( "edgeColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Fold, QStringLiteral( "foldColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::Error, QStringLiteral( "stderrFontColor" ) },
+      { QgsCodeEditorColorScheme::ColorRole::ErrorBackground, QStringLiteral( "stderrBackground" ) },
+      { QgsCodeEditorColorScheme::ColorRole::FoldIconForeground, QStringLiteral( "foldIconForeground" ) },
+      { QgsCodeEditorColorScheme::ColorRole::FoldIconHalo, QStringLiteral( "foldIconHalo" ) },
+      { QgsCodeEditorColorScheme::ColorRole::IndentationGuide, QStringLiteral( "indentationGuide" ) },
+      { QgsCodeEditorColorScheme::ColorRole::SearchMatchBackground, QStringLiteral( "searchMatchBackground" ) },
     };
 
     const QgsCodeEditorColorScheme defaultScheme = QgsGui::codeEditorColorSchemeRegistry()->scheme( QStringLiteral( "default" ) );
@@ -1061,15 +1061,11 @@ void QgsCodeEditor::setCustomAppearance( const QString &scheme, const QMap<QgsCo
 
 void QgsCodeEditor::addWarning( const int lineNumber, const QString &warning )
 {
-  setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), "000" );
+  setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), "000" );
   markerAdd( lineNumber, MARKER_NUMBER );
   QFont font = lexerFont();
   font.setItalic( true );
-  const QsciStyle styleAnn = QsciStyle( -1, QStringLiteral( "Annotation" ),
-                                        lexerColor( QgsCodeEditorColorScheme::ColorRole::Error ),
-                                        lexerColor( QgsCodeEditorColorScheme::ColorRole::ErrorBackground ),
-                                        font,
-                                        true );
+  const QsciStyle styleAnn = QsciStyle( -1, QStringLiteral( "Annotation" ), lexerColor( QgsCodeEditorColorScheme::ColorRole::Error ), lexerColor( QgsCodeEditorColorScheme::ColorRole::ErrorBackground ), font, true );
   annotate( lineNumber, warning, styleAnn );
   mWarningLines.push_back( lineNumber );
 }
@@ -1081,7 +1077,7 @@ void QgsCodeEditor::clearWarnings()
     markerDelete( line );
     clearAnnotations( line );
   }
-  setMarginWidth( static_cast< int >( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
+  setMarginWidth( static_cast<int>( QgsCodeEditor::MarginRole::ErrorIndicators ), 0 );
   mWarningLines.clear();
 }
 
@@ -1121,6 +1117,48 @@ void QgsCodeEditor::moveCursorToEnd()
     updatePrompt();
 }
 
+int QgsCodeEditor::linearPosition() const
+{
+  return static_cast<int>( SendScintilla( SCI_GETCURRENTPOS ) );
+}
+
+void QgsCodeEditor::setLinearPosition( int linearIndex )
+{
+  int line, index;
+  lineIndexFromPosition( linearIndex, &line, &index );
+  setCursorPosition( line, index );
+}
+
+int QgsCodeEditor::selectionStart() const
+{
+  int startLine, startIndex, _;
+  getSelection( &startLine, &startIndex, &_, &_ );
+  if ( startLine == -1 )
+  {
+    return linearPosition();
+  }
+  return positionFromLineIndex( startLine, startIndex );
+}
+
+int QgsCodeEditor::selectionEnd() const
+{
+  int endLine, endIndex, _;
+  getSelection( &_, &_, &endLine, &endIndex );
+  if ( endLine == -1 )
+  {
+    return linearPosition();
+  }
+  return positionFromLineIndex( endLine, endIndex );
+}
+
+void QgsCodeEditor::setLinearSelection( int start, int end )
+{
+  int startLine, startIndex, endLine, endIndex;
+  lineIndexFromPosition( start, &startLine, &startIndex );
+  lineIndexFromPosition( end, &endLine, &endIndex );
+  setSelection( startLine, startIndex, endLine, endIndex );
+}
+
 QgsCodeInterpreter::~QgsCodeInterpreter() = default;
 
 int QgsCodeInterpreter::exec( const QString &command )
@@ -1128,3 +1166,233 @@ int QgsCodeInterpreter::exec( const QString &command )
   mState = execCommandImpl( command );
   return mState;
 }
+
+
+int QgsCodeEditor::wrapPosition( int line )
+{
+  // If wrapping is disabled, return -1
+  if ( wrapMode() == WrapNone )
+  {
+    return -1;
+  }
+  // Get the current line
+  if ( line == -1 )
+  {
+    int _index;
+    lineIndexFromPosition( linearPosition(), &line, &_index );
+  }
+
+  // If line isn't wrapped, return -1
+  if ( SendScintilla( SCI_WRAPCOUNT, line ) <= 1 )
+  {
+    return -1;
+  }
+
+  // Get the linear position at the end of the current line
+  const long endLine = SendScintilla( SCI_GETLINEENDPOSITION, line );
+  // Get the y coordinates of the start of the last wrapped line
+  const long y = SendScintilla( SCI_POINTYFROMPOSITION, 0, endLine );
+  // Return the linear position of the start of the last wrapped line
+  return static_cast<int>( SendScintilla( SCI_POSITIONFROMPOINT, 0, y ) );
+}
+
+
+// Adapted from QsciScintilla source code (qsciscintilla.cpp) to handle line wrap
+void QgsCodeEditor::callTip()
+{
+  if ( callTipsStyle() == CallTipsNone || lexer() == nullptr )
+  {
+    return;
+  }
+
+  QsciAbstractAPIs *apis = lexer()->apis();
+
+  if ( !apis )
+    return;
+
+  int pos, commas = 0;
+  bool found = false;
+  char ch;
+
+  pos = linearPosition();
+
+  // Move backwards through the line looking for the start of the current
+  // call tip and working out which argument it is.
+  while ( ( ch = getCharacter( pos ) ) != '\0' )
+  {
+    if ( ch == ',' )
+      ++commas;
+    else if ( ch == ')' )
+    {
+      int depth = 1;
+
+      // Ignore everything back to the start of the corresponding
+      // parenthesis.
+      while ( ( ch = getCharacter( pos ) ) != '\0' )
+      {
+        if ( ch == ')' )
+          ++depth;
+        else if ( ch == '(' && --depth == 0 )
+          break;
+      }
+    }
+    else if ( ch == '(' )
+    {
+      found = true;
+      break;
+    }
+  }
+
+  // Cancel any existing call tip.
+  SendScintilla( SCI_CALLTIPCANCEL );
+
+  // Done if there is no new call tip to set.
+  if ( !found )
+    return;
+
+  int contextStart, lastWordStart;
+  QStringList context = apiContext( pos, contextStart, lastWordStart );
+
+  if ( context.isEmpty() )
+    return;
+
+  // The last word is complete, not partial.
+  context << QString();
+
+  QList<int> ctShifts;
+  QStringList ctEntries = apis->callTips( context, commas, callTipsStyle(), ctShifts );
+
+  int nbEntries = ctEntries.count();
+
+  if ( nbEntries == 0 )
+    return;
+
+  const int maxNumberOfCallTips = callTipsVisible();
+
+  // Clip to at most maxNumberOfCallTips entries.
+  if ( maxNumberOfCallTips > 0 && maxNumberOfCallTips < nbEntries )
+  {
+    ctEntries = ctEntries.mid( 0, maxNumberOfCallTips );
+    nbEntries = maxNumberOfCallTips;
+  }
+
+  int shift;
+  QString ct;
+
+  int nbShifts = ctShifts.count();
+
+  if ( maxNumberOfCallTips < 0 && nbEntries > 1 )
+  {
+    shift = ( nbShifts > 0 ? ctShifts.first() : 0 );
+    ct = ctEntries[0];
+    ct.prepend( '\002' );
+  }
+  else
+  {
+    if ( nbShifts > nbEntries )
+      nbShifts = nbEntries;
+
+    // Find the biggest shift.
+    shift = 0;
+
+    for ( int i = 0; i < nbShifts; ++i )
+    {
+      int sh = ctShifts[i];
+
+      if ( shift < sh )
+        shift = sh;
+    }
+
+    ct = ctEntries.join( "\n" );
+  }
+
+  QByteArray ctBa = ct.toLatin1();
+  const char *cts = ctBa.data();
+
+  const int currentWrapPosition = wrapPosition();
+
+  if ( currentWrapPosition != -1 )
+  {
+    SendScintilla( SCI_CALLTIPSHOW, currentWrapPosition, cts );
+  }
+  else
+  {
+    // Shift the position of the call tip (to take any context into account) but
+    // don't go before the start of the line.
+    if ( shift )
+    {
+      int ctmin = static_cast<int>( SendScintilla( SCI_POSITIONFROMLINE, SendScintilla( SCI_LINEFROMPOSITION, ct ) ) );
+      if ( lastWordStart - shift < ctmin )
+        lastWordStart = ctmin;
+    }
+
+    int line, index;
+    lineIndexFromPosition( lastWordStart, &line, &index );
+    SendScintilla( SCI_CALLTIPSHOW, positionFromLineIndex( line, index ), cts );
+  }
+
+  // Done if there is more than one call tip.
+  if ( nbEntries > 1 )
+    return;
+
+  // Highlight the current argument.
+  const char *astart;
+
+  if ( commas == 0 )
+    astart = strchr( cts, '(' );
+  else
+    for ( astart = strchr( cts, ',' ); astart && --commas > 0; astart = strchr( astart + 1, ',' ) )
+      ;
+
+  if ( !astart )
+    return;
+
+  astart++;
+  if ( !*astart )
+    return;
+
+  // The end is at the next comma or unmatched closing parenthesis.
+  const char *aend;
+  int depth = 0;
+
+  for ( aend = astart; *aend; ++aend )
+  {
+    char ch = *aend;
+
+    if ( ch == ',' && depth == 0 )
+      break;
+    else if ( ch == '(' )
+      ++depth;
+    else if ( ch == ')' )
+    {
+      if ( depth == 0 )
+        break;
+
+      --depth;
+    }
+  }
+
+  if ( astart != aend )
+    SendScintilla( SCI_CALLTIPSETHLT, astart - cts, aend - cts );
+}
+
+
+// Duplicated from QsciScintilla source code (qsciscintilla.cpp)
+// Get the "next" character (ie. the one before the current position) in the
+// current line.  The character will be '\0' if there are no more.
+char QgsCodeEditor::getCharacter( int &pos ) const
+{
+  if ( pos <= 0 )
+    return '\0';
+
+  char ch = static_cast<char>( SendScintilla( SCI_GETCHARAT, --pos ) );
+
+  // Don't go past the end of the previous line.
+  if ( ch == '\n' || ch == '\r' )
+  {
+    ++pos;
+    return '\0';
+  }
+
+  return ch;
+}
