@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsdatetimeeditconfig.h"
+#include "moc_qgsdatetimeeditconfig.cpp"
 #include "qgsdatetimeeditfactory.h"
 #include "qgsvectorlayer.h"
 #include "qgsdatetimefieldformatter.h"
@@ -26,8 +27,8 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
   mFieldFormatComboBox->clear();
   mFieldFormatComboBox->addItem( tr( "Date" ), QgsDateTimeFieldFormatter::DATE_FORMAT );
   mFieldFormatComboBox->addItem( tr( "Time" ), QgsDateTimeFieldFormatter::TIME_FORMAT );
-  mFieldFormatComboBox->addItem( tr( "Date time" ), QgsDateTimeFieldFormatter::DATETIME_FORMAT );
-  mFieldFormatComboBox->addItem( tr( "ISO date time" ), QgsDateTimeFieldFormatter::QT_ISO_FORMAT );
+  mFieldFormatComboBox->addItem( tr( "Date Time" ), QgsDateTimeFieldFormatter::DATETIME_FORMAT );
+  mFieldFormatComboBox->addItem( tr( "ISO Date Time" ), QgsDateTimeFieldFormatter::QT_ISO_FORMAT );
   mFieldFormatComboBox->addItem( tr( "Custom" ), QString() );
 
   mHelpLabel->setTextFormat( Qt::RichText );
@@ -37,7 +38,8 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
       "<table border=\"0\" style=\"margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px;\" cellspacing=\"2\" cellpadding=\"0\" bgcolor=\"#f6f6f6\">"
       "<thead><tr>"
       "<td style=\"vertical-align:top; padding-left:10; padding-right:15; padding-top:5; padding-bottom:5;\">"
-      "<p align=\"left\"><span style=\"font-family:'Open Sans,sans-serif'; font-size:12px; font-weight:600; color:#363534;\">" )
+      "<p align=\"left\"><span style=\"font-family:'Open Sans,sans-serif'; font-size:12px; font-weight:600; color:#363534;\">"
+    )
     + tr( "Qt ISO Date format" )
     + QStringLiteral( "</span></p>"
                       "</td>"
@@ -45,7 +47,7 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
                       "<tr>"
                       "<td bgcolor=\"#ffffff\" style=\"vertical-align:top; padding-left:10; padding-right:10; padding-top:3; padding-bottom:3;\">"
                       "<p><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e; background-color:#ffffff;\">"
-                      "<a href=\"http://www.iso.org/iso/catalogue_detail?csnumber=40874\">" )  //#spellok
+                      "<a href=\"http://www.iso.org/iso/catalogue_detail?csnumber=40874\">" ) //#spellok
     + tr( "ISO 8601" )
     + QStringLiteral( "</a> " )
     + tr( "extended format: either <code>yyyy-MM-dd</code> for dates or <code>yyyy-MM-ddTHH:mm:ss</code> (e.g. 2017-07-24T15:46:29), or with a time-zone suffix (Z for UTC otherwise an offset as [+|-]HH:mm) where appropriate for combined dates and times." )
@@ -58,7 +60,8 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
       "<table border=\"0\" style=\"margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px;\" cellspacing=\"2\" cellpadding=\"0\" bgcolor=\"#f6f6f6\">"
       "<thead><tr>"
       "<td style=\"vertical-align:top; padding-left:10; padding-right:15; padding-top:5; padding-bottom:5;\">"
-      "<p align=\"center\"><span style=\"font-family:'Open Sans,sans-serif'; font-size:12px; font-weight:600; color:#363534;\">" )
+      "<p align=\"center\"><span style=\"font-family:'Open Sans,sans-serif'; font-size:12px; font-weight:600; color:#363534;\">"
+    )
     + tr( "Format" )
     + QStringLiteral( "</span></p>"
                       "</td>"
@@ -142,7 +145,7 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
                       "<td bgcolor=\"#f6f6f6\" style=\"vertical-align:top; padding-left:10; padding-right:10; padding-top:3; padding-bottom:3;\">"
                       "<p><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e; background-color:#f6f6f6;\">" )
     + tr( "the abbreviated localized day name (e.g. 'Mon' to 'Sun'). Uses the system locale to localize the name, i.e. " )
-    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,FreeSans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
+    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,Open Sans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
                       "</td>"
                       "</tr>"
                       "<tr>"
@@ -152,9 +155,9 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
                       "<td bgcolor=\"#ffffff\" style=\"vertical-align:top; padding-left:10; padding-right:10; padding-top:3; padding-bottom:3;\">"
                       "<p><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e; background-color:#ffffff;\">" )
     + tr( "the long localized day name (e.g. 'Monday' to '" )
-    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qt.html#DayOfWeek-enum\"><span style=\"font-family:'Arial,FreeSans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">Qt::Sunday</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">')." )
+    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qt.html#DayOfWeek-enum\"><span style=\"font-family:'Arial,Open Sans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">Qt::Sunday</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">')." )
     + tr( "Uses the system locale to localize the name, i.e. " )
-    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,FreeSans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
+    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,Open Sans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
                       "</td>"
                       "</tr>"
                       "<tr>"
@@ -184,7 +187,7 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
                       "<td bgcolor=\"#f6f6f6\" style=\"vertical-align:top; padding-left:10; padding-right:10; padding-top:3; padding-bottom:3;\">"
                       "<p><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e; background-color:#f6f6f6;\">" )
     + tr( "the abbreviated localized month name (e.g. 'Jan' to 'Dec'). Uses the system locale to localize the name, i.e." )
-    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,FreeSans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
+    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,Open Sans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
                       "</td>"
                       "</tr>"
                       "<tr>"
@@ -194,7 +197,7 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
                       "<td bgcolor=\"#ffffff\" style=\"vertical-align:top; padding-left:10; padding-right:10; padding-top:3; padding-bottom:3;\">"
                       "<p><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e; background-color:#ffffff;\">" )
     + tr( "the long localized month name (e.g. 'January' to 'December'). Uses the system locale to localize the name, i.e." )
-    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,FreeSans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
+    + QStringLiteral( "</span><a href=\"http://qt-project.org/doc/qt-5/qlocale.html#system\"><span style=\"font-family:'Arial,Open Sans,sans-serif'; font-size:12px; font-weight:600; text-decoration: underline; color:#00732f;\">QLocale</span></a><span style=\"font-family:'Open Sans,sans-serif'; font-size:11px; color:#66666e;\">().</span></p>"
                       "</td>"
                       "</tr>"
                       "<tr>"
@@ -392,6 +395,15 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
   connect( mDisplayFormatEdit, &QLineEdit::textChanged, this, &QgsEditorConfigWidget::changed );
   connect( mCalendarPopupCheckBox, &QAbstractButton::toggled, this, &QgsEditorConfigWidget::changed );
   connect( mAllowNullCheckBox, &QAbstractButton::toggled, this, &QgsEditorConfigWidget::changed );
+  connect( mFieldFormatGroupBox, &QGroupBox::toggled, this, [=]( bool checked ) {
+    //reset to default value when unchecking
+    if ( !checked )
+    {
+      const QgsField fieldDef = layer()->fields().at( field() );
+      const QString fieldFormat = QgsDateTimeFieldFormatter::defaultFormat( fieldDef.type() );
+      setFieldFormatCombo( fieldFormat );
+    }
+  } );
 
   // initialize
   updateFieldFormat( mFieldFormatComboBox->currentIndex() );
@@ -401,6 +413,18 @@ QgsDateTimeEditConfig::QgsDateTimeEditConfig( QgsVectorLayer *vl, int fieldIdx,
 
 void QgsDateTimeEditConfig::updateDemoWidget()
 {
+  // Use a UTC datetime if the format string includes a Z
+  if ( mDisplayFormatEdit->text().indexOf( "Z" ) > 0 )
+  {
+    mDemoDateTimeEdit->setTimeSpec( Qt::UTC );
+    mDemoDateTimeEdit->setDateTime( QDateTime::currentDateTimeUtc() );
+  }
+  else
+  {
+    mDemoDateTimeEdit->setTimeSpec( Qt::LocalTime );
+    mDemoDateTimeEdit->setDateTime( QDateTime::currentDateTime() );
+  }
+
   mDemoDateTimeEdit->setDisplayFormat( mDisplayFormatEdit->text() );
   mDemoDateTimeEdit->setCalendarPopup( mCalendarPopupCheckBox->isChecked() );
 }
@@ -410,11 +434,15 @@ void QgsDateTimeEditConfig::updateFieldFormat( int idx )
 {
   Q_UNUSED( idx )
   const QString format = mFieldFormatComboBox->currentData().toString();
-  bool custom = format.isEmpty();
+  const bool custom = format.isEmpty();
   if ( !custom )
   {
     mFieldFormatEdit->setText( format );
   }
+  else if ( mFieldFormatEdit->text() == QgsDateTimeFieldFormatter::QT_ISO_FORMAT )
+  {
+    mFieldFormatEdit->setText( QgsDateTimeFieldFormatter::DISPLAY_FOR_ISO_FORMAT );
+  }
 
   mFieldFormatEdit->setEnabled( custom );
   mFieldHelpToolButton->setVisible( custom );
@@ -434,6 +462,14 @@ void QgsDateTimeEditConfig::updateDisplayFormat( const QString &fieldFormat )
     {
       mDisplayFormatEdit->setText( QgsDateTimeFieldFormatter::DISPLAY_FOR_ISO_FORMAT );
     }
+    else if ( fieldFormat == QgsDateTimeFieldFormatter::DATE_FORMAT )
+    {
+      mDisplayFormatEdit->setText( QgsDateTimeFieldFormatter::DATE_DISPLAY_FORMAT );
+    }
+    else if ( fieldFormat == QgsDateTimeFieldFormatter::DATETIME_FORMAT )
+    {
+      mDisplayFormatEdit->setText( QgsDateTimeFieldFormatter::DATETIME_DISPLAY_FORMAT );
+    }
     else
     {
       mDisplayFormatEdit->setText( fieldFormat );
@@ -453,7 +489,14 @@ void QgsDateTimeEditConfig::displayFormatChanged( int idx )
   }
   if ( !custom )
   {
-    mDisplayFormatEdit->setText( mFieldFormatEdit->text() );
+    if ( mFieldFormatComboBox->currentData() == QgsDateTimeFieldFormatter::QT_ISO_FORMAT )
+    {
+      mDisplayFormatEdit->setText( QgsDateTimeFieldFormatter::DISPLAY_FOR_ISO_FORMAT );
+    }
+    else
+    {
+      mDisplayFormatEdit->setText( mFieldFormatEdit->text() );
+    }
   }
 }
 
@@ -469,6 +512,7 @@ QVariantMap QgsDateTimeEditConfig::config()
 {
   QVariantMap myConfig;
 
+  myConfig.insert( QStringLiteral( "field_format_overwrite" ), mFieldFormatGroupBox->isChecked() );
   myConfig.insert( QStringLiteral( "field_iso_format" ), mFieldFormatEdit->text() == QgsDateTimeFieldFormatter::QT_ISO_FORMAT );
   myConfig.insert( QStringLiteral( "field_format" ), mFieldFormatEdit->text() );
   myConfig.insert( QStringLiteral( "display_format" ), mDisplayFormatEdit->text() );
@@ -480,21 +524,12 @@ QVariantMap QgsDateTimeEditConfig::config()
 
 void QgsDateTimeEditConfig::setConfig( const QVariantMap &config )
 {
+  mFieldFormatGroupBox->setChecked( config.value( QStringLiteral( "field_format_overwrite" ), false ).toBool() );
   const QgsField fieldDef = layer()->fields().at( field() );
   const QString fieldFormat = config.value( QStringLiteral( "field_format" ), QgsDateTimeFieldFormatter::defaultFormat( fieldDef.type() ) ).toString();
-  mFieldFormatEdit->setText( fieldFormat );
+  setFieldFormatCombo( fieldFormat );
 
-  const int idx = mFieldFormatComboBox->findData( fieldFormat );
-  if ( idx >= 0 )
-  {
-    mFieldFormatComboBox->setCurrentIndex( idx );
-  }
-  else
-  {
-    mFieldFormatComboBox->setCurrentIndex( 4 );
-  }
-
-  QString displayFormat = config.value( QStringLiteral( "display_format" ), QgsDateTimeFieldFormatter::defaultFormat( fieldDef.type() ) ).toString();
+  const QString displayFormat = config.value( QStringLiteral( "display_format" ), QgsDateTimeFieldFormatter::defaultDisplayFormat( fieldDef.type() ) ).toString();
   mDisplayFormatEdit->setText( displayFormat );
   if ( displayFormat == mFieldFormatEdit->text() )
   {
@@ -508,3 +543,18 @@ void QgsDateTimeEditConfig::setConfig( const QVariantMap &config )
   mCalendarPopupCheckBox->setChecked( config.value( QStringLiteral( "calendar_popup" ), true ).toBool() );
   mAllowNullCheckBox->setChecked( config.value( QStringLiteral( "allow_null" ), true ).toBool() );
 }
+
+void QgsDateTimeEditConfig::setFieldFormatCombo( const QString &fieldFormat )
+{
+  mFieldFormatEdit->setText( fieldFormat );
+
+  const int idx = mFieldFormatComboBox->findData( fieldFormat );
+  if ( idx >= 0 )
+  {
+    mFieldFormatComboBox->setCurrentIndex( idx );
+  }
+  else
+  {
+    mFieldFormatComboBox->setCurrentIndex( 4 );
+  }
+}
