@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsvaluemapwidgetwrapper.h"
+#include "moc_qgsvaluemapwidgetwrapper.cpp"
 #include "qgsvaluemapconfigdlg.h"
 #include "qgsvaluemapfieldformatter.h"
 #include "qgsapplication.h"
@@ -37,7 +38,7 @@ QVariant QgsValueMapWidgetWrapper::value() const
   }
 
   if ( v == QgsValueMapFieldFormatter::NULL_VALUE )
-    v = QVariant( field().type() );
+    v = QgsVariantUtils::createNullVariant( field().type() );
 
   return v;
 }
@@ -66,8 +67,7 @@ void QgsValueMapWidgetWrapper::initWidget( QWidget *editor )
   {
     QgsValueMapConfigDlg::populateComboBox( mComboBox, config(), false );
     mComboBox->view()->setVerticalScrollBarPolicy( Qt::ScrollBarAsNeeded );
-    connect( mComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ),
-             this, static_cast<void ( QgsEditorWidgetWrapper::* )()>( &QgsEditorWidgetWrapper::emitValueChanged ) );
+    connect( mComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, static_cast<void ( QgsEditorWidgetWrapper::* )()>( &QgsEditorWidgetWrapper::emitValueChanged ) );
   }
 }
 
