@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgscustomlayerorderwidget.h"
+#include "moc_qgscustomlayerorderwidget.cpp"
 
 #include <QCheckBox>
 #include <QListView>
@@ -27,8 +28,6 @@
 #include "qgsproject.h"
 
 
-
-
 QgsCustomLayerOrderWidget::QgsCustomLayerOrderWidget( QgsLayerTreeMapCanvasBridge *bridge, QWidget *parent )
   : QWidget( parent )
   , mBridge( bridge )
@@ -57,7 +56,7 @@ QgsCustomLayerOrderWidget::QgsCustomLayerOrderWidget( QgsLayerTreeMapCanvasBridg
   connect( bridge->rootGroup(), &QgsLayerTreeNode::visibilityChanged, this, &QgsCustomLayerOrderWidget::nodeVisibilityChanged );
 
   QVBoxLayout *l = new QVBoxLayout;
-  l->setMargin( 0 );
+  l->setContentsMargins( 0, 0, 0, 0 );
   l->addWidget( mView );
   l->addWidget( mChkOverride );
   setLayout( l );
@@ -88,7 +87,6 @@ void QgsCustomLayerOrderWidget::modelUpdated()
 }
 
 
-
 ///@cond PRIVATE
 
 CustomLayerOrderModel::CustomLayerOrderModel( QgsLayerTreeMapCanvasBridge *bridge, QObject *parent )
@@ -104,7 +102,7 @@ int CustomLayerOrderModel::rowCount( const QModelIndex & ) const
 
 QVariant CustomLayerOrderModel::data( const QModelIndex &index, int role ) const
 {
-  QString id = mOrder.at( index.row() );
+  const QString id = mOrder.at( index.row() );
 
   if ( role == Qt::DisplayRole )
   {
@@ -135,11 +133,11 @@ bool CustomLayerOrderModel::setData( const QModelIndex &index, const QVariant &v
   Q_UNUSED( value ); // Toggle
   if ( role == Qt::CheckStateRole )
   {
-    QString id = mOrder.at( index.row() );
+    const QString id = mOrder.at( index.row() );
     QgsLayerTreeLayer *nodeLayer = mBridge->rootGroup()->findLayer( id );
     if ( nodeLayer )
     {
-      nodeLayer->setItemVisibilityChecked( ! nodeLayer->itemVisibilityChecked() );
+      nodeLayer->setItemVisibilityChecked( !nodeLayer->itemVisibilityChecked() );
       return true;
     }
   }
@@ -173,7 +171,7 @@ QMimeData *CustomLayerOrderModel::mimeData( const QModelIndexList &indexes ) con
     lst << data( index, Qt::UserRole + 1 ).toString();
 
   QMimeData *mimeData = new QMimeData();
-  mimeData->setData( QStringLiteral( "application/qgis.layerorderdata" ), lst.join( QStringLiteral( "\n" ) ).toUtf8() );
+  mimeData->setData( QStringLiteral( "application/qgis.layerorderdata" ), lst.join( QLatin1Char( '\n' ) ).toUtf8() );
   return mimeData;
 }
 
@@ -188,7 +186,7 @@ bool CustomLayerOrderModel::dropMimeData( const QMimeData *data, Qt::DropAction
   if ( !data->hasFormat( QStringLiteral( "application/qgis.layerorderdata" ) ) )
     return false;
 
-  QByteArray encodedData = data->data( QStringLiteral( "application/qgis.layerorderdata" ) );
+  const QByteArray encodedData = data->data( QStringLiteral( "application/qgis.layerorderdata" ) );
   QStringList lst = QString::fromUtf8( encodedData ).split( '\n' );
 
   if ( row < 0 )
@@ -235,11 +233,10 @@ void CustomLayerOrderModel::refreshModel( const QList<QgsMapLayer *> &order )
 
 void CustomLayerOrderModel::updateLayerVisibility( const QString &layerId )
 {
-  int row = mOrder.indexOf( layerId );
+  const int row = mOrder.indexOf( layerId );
   if ( row != -1 )
     emit dataChanged( index( row ), index( row ) );
 }
 
 
-
 ///@endcond
