@@ -18,10 +18,10 @@
 #define QGSATTRIBUTEDIALOG_H
 
 #include "qgsattributeeditorcontext.h"
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "qgsattributeform.h"
 #include "qgstrackedvectorlayertools.h"
-#include "qgsactionmenu.h"
+#include "qgsmaplayeractioncontextgenerator.h"
 
 #include <QDialog>
 #include <QMenuBar>
@@ -29,25 +29,25 @@
 #include "qgis_gui.h"
 
 class QgsHighlight;
+class QgsActionMenu;
 
 /**
  * \ingroup gui
  * \class QgsAttributeDialog
  */
-class GUI_EXPORT QgsAttributeDialog : public QDialog
+class GUI_EXPORT QgsAttributeDialog : public QDialog, public QgsMapLayerActionContextGenerator
 {
     Q_OBJECT
 
   public:
-
     /**
      * Create an attribute dialog for a given layer and feature
      *
      * \param vl                The layer for which the dialog will be generated
      * \param thepFeature       A feature for which the dialog will be generated
-     * \param featureOwner      Set to true, if the dialog should take ownership of the feature
+     * \param featureOwner      Set to TRUE, if the dialog should take ownership of the feature
      * \param parent            A parent widget for the dialog
-     * \param showDialogButtons True: Show the dialog buttons accept/cancel
+     * \param showDialogButtons TRUE: Show the dialog buttons accept/cancel
      * \param context           The context in which this dialog is created
      *
      */
@@ -68,7 +68,7 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
     /**
      * Is this dialog editable?
      *
-     * \returns returns true, if this dialog was created in an editable manner.
+     * \returns returns TRUE, if this dialog was created in an editable manner.
      */
     bool editable() { return mAttributeForm->editable(); }
 
@@ -95,6 +95,18 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
      */
     bool event( QEvent *e ) override;
 
+    void showEvent( QShowEvent *event ) override;
+
+    /**
+     * Sets \a extraScope as an additional expression context scope to be used
+     * for calculations in this form.
+     *
+     * \since QGIS 3.16
+     */
+    void setExtraContextScope( QgsExpressionContextScope *extraScope SIP_TRANSFER );
+
+    QgsMapLayerActionContext createActionContext() override;
+
   public slots:
     void accept() override;
     void reject() override;
@@ -108,22 +120,19 @@ class GUI_EXPORT QgsAttributeDialog : public QDialog
     QString mSettingsPath;
     // Used to sync multiple widgets for the same field
     QgsHighlight *mHighlight = nullptr;
-    int mFormNr;
-    bool mShowDialogButtons;
     QString mReturnvarname;
     QgsAttributeForm *mAttributeForm = nullptr;
     QgsFeature *mOwnedFeature = nullptr;
+    QgsMessageBar *mMessageBar = nullptr;
 
     QgsTrackedVectorLayerTools mTrackedVectorLayerTools;
 
-    // true if this dialog is editable
-    bool mEditable;
-
     QgsActionMenu *mMenu;
+    QMenuBar *mMenuBar = nullptr;
 
     static int sFormCounter;
-    static QString sSettingsPath;
 
+    bool mFirstShow = true;
     void saveGeometry();
     void restoreGeometry();
 };
