@@ -30,7 +30,6 @@
 class QgsVectorLayer;
 
 
-
 /**
  * \ingroup gui
  * \brief An expression item that can be used in the QgsExpressionBuilderWidget tree.
@@ -45,10 +44,7 @@ class GUI_EXPORT QgsExpressionItem : public QStandardItem
       ExpressionNode
     };
 
-    QgsExpressionItem( const QString &label,
-                       const QString &expressionText,
-                       const QString &helpText,
-                       QgsExpressionItem::ItemType itemType = ExpressionNode )
+    QgsExpressionItem( const QString &label, const QString &expressionText, const QString &helpText, QgsExpressionItem::ItemType itemType = ExpressionNode )
       : QStandardItem( label )
     {
       mExpressionText = expressionText;
@@ -57,9 +53,7 @@ class GUI_EXPORT QgsExpressionItem : public QStandardItem
       setData( itemType, ITEM_TYPE_ROLE );
     }
 
-    QgsExpressionItem( const QString &label,
-                       const QString &expressionText,
-                       QgsExpressionItem::ItemType itemType = ExpressionNode )
+    QgsExpressionItem( const QString &label, const QString &expressionText, QgsExpressionItem::ItemType itemType = ExpressionNode )
       : QStandardItem( label )
     {
       mExpressionText = expressionText;
@@ -131,11 +125,9 @@ class GUI_EXPORT QgsExpressionItemSearchProxy : public QSortFilterProxyModel
     void setFilterString( const QString &string );
 
   protected:
-
     bool lessThan( const QModelIndex &left, const QModelIndex &right ) const override;
 
   private:
-
     QString mFilterString;
 };
 
@@ -151,7 +143,6 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
 {
     Q_OBJECT
   public:
-
     /**
      * \ingroup gui
      * \class MenuProvider
@@ -162,12 +153,15 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
     class MenuProvider
     {
       public:
-        //! Constructor
         explicit MenuProvider() = default;
         virtual ~MenuProvider() = default;
 
         //! Returns a newly created menu instance
-        virtual QMenu *createContextMenu( QgsExpressionItem *item ) SIP_FACTORY {Q_UNUSED( item ) return nullptr;}
+        virtual QMenu *createContextMenu( QgsExpressionItem *item ) SIP_FACTORY
+        {
+          Q_UNUSED( item )
+          return nullptr;
+        }
     };
 
     //! Constructor
@@ -231,7 +225,7 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
      * Returns a pointer to the dialog's function item model.
      * This method is exposed for testing purposes only - it should not be used to modify the model
      * \note will be removed in QGIS 4
-     * \deprecated since QGIS 3.14
+     * \deprecated QGIS 3.14
      */
     Q_DECL_DEPRECATED QStandardItemModel *model() SIP_SKIP; // TODO remove QGIS 4
 
@@ -261,7 +255,7 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
      * Loads the user expressions.
      * This is done on request since it can be very slow if there are thousands of user expressions
      */
-    void loadUserExpressions( );
+    void loadUserExpressions();
 
     /**
      * Returns the list of expression items matching a \a label.
@@ -320,13 +314,7 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
      * \param tags tags to find function
      * \param name name of the item
      */
-    QgsExpressionItem *registerItem( const QString &group, const QString &label, const QString &expressionText,
-                                     const QString &helpText = QString(),
-                                     QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode,
-                                     bool highlightedItem = false, int sortOrder = 1,
-                                     const QIcon &icon = QIcon(),
-                                     const QStringList &tags = QStringList(),
-                                     const QString &name = QString() );
+    QgsExpressionItem *registerItem( const QString &group, const QString &label, const QString &expressionText, const QString &helpText = QString(), QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode, bool highlightedItem = false, int sortOrder = 1, const QIcon &icon = QIcon(), const QStringList &tags = QStringList(), const QString &name = QString() );
 
     /**
      * Registers a node item for the expression builder, adding multiple items when the function exists in multiple groups
@@ -339,10 +327,7 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
      * \param sortOrder sort ranking for item
      * \param tags tags to find function
      */
-    void registerItemForAllGroups( const QStringList &groups, const QString &label, const QString &expressionText,
-                                   const QString &helpText = QString(),
-                                   QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode,
-                                   bool highlightedItem = false, int sortOrder = 1, const QStringList &tags = QStringList() );
+    void registerItemForAllGroups( const QStringList &groups, const QString &label, const QString &expressionText, const QString &helpText = QString(), QgsExpressionItem::ItemType type = QgsExpressionItem::ExpressionNode, bool highlightedItem = false, int sortOrder = 1, const QStringList &tags = QStringList() );
 
     void loadExpressionContext();
     void loadRelations();
@@ -371,7 +356,7 @@ class GUI_EXPORT QgsExpressionTreeView : public QTreeView
     MenuProvider *mMenuProvider = nullptr;
 
     QgsVectorLayer *mLayer = nullptr;
-    QPointer< QgsProject > mProject;
+    QPointer<QgsProject> mProject;
     QgsExpressionContext mExpressionContext;
     QString mRecentKey;
 
