@@ -18,14 +18,13 @@
 #include <QComboBox>
 
 #include "qgsfeature.h"
-#include "qgsfeaturerequest.h"
 #include "qgis_gui.h"
 
 class QgsVectorLayer;
 class QgsFeatureFilterModel;
 class QgsAnimatedIcon;
 class QgsFilterLineEdit;
-
+class QgsFeatureRequest;
 
 /**
  * \ingroup gui
@@ -34,7 +33,6 @@ class QgsFilterLineEdit;
  * It will show up to 100 entries at a time. The entries can be chosen based on the displayExpression
  * and whenever text is typed into the combobox, the completer and popup will adjust to features matching the typed text.
  *
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
 {
@@ -49,7 +47,6 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
     Q_PROPERTY( bool allowNull READ allowNull WRITE setAllowNull NOTIFY allowNullChanged )
 
   public:
-
     /**
      * Create a new QgsFeatureListComboBox, optionally specifying a \a parent.
      */
@@ -83,12 +80,6 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
      */
     void setDisplayExpression( const QString &displayExpression );
 
-    /**
-     * An additional expression to further restrict the available features.
-     * This can be used to integrate additional spatial or other constraints.
-     */
-    QString filterExpression() const;
-
     /**
      * Returns the current index of the NULL value, or -1 if NULL values are
      * not allowed.
@@ -97,16 +88,46 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
      */
     int nullIndex() const;
 
+    /**
+     * An additional expression to further restrict the available features.
+     * This can be used to integrate additional spatial or other constraints.
+     */
+    QString filterExpression() const;
+
     /**
      * An additional expression to further restrict the available features.
      * This can be used to integrate additional spatial or other constraints.
      */
     void setFilterExpression( const QString &filterExpression );
 
+    /**
+     * Returns an attribute form feature to be used with the filter expression.
+     * \since QGIS 3.42.2
+     */
+    QgsFeature formFeature() const;
+
+    /**
+     * Sets an attribute form \a feature to be used with the filter expression.
+     * \since QGIS 3.42.2
+     */
+    void setFormFeature( const QgsFeature &feature );
+
+    /**
+     * Returns a parent attribute form feature to be used with the filter expression.
+     * \since QGIS 3.42.2
+     */
+    QgsFeature parentFormFeature() const;
+
+    /**
+     * Sets a parent attribute form \a feature to be used with the filter expression.
+     * \since QGIS 3.42.2
+     */
+    void setParentFormFeature( const QgsFeature &feature );
+
     /**
      * The identifier value of the currently selected feature. A value from the
      * identifierField.
-     * \deprecated since QGIS 3.10
+     * \deprecated QGIS 3.10
      */
     Q_DECL_DEPRECATED QVariant identifierValue() const SIP_DEPRECATED;
 
@@ -121,7 +142,7 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
     /**
      * The identifier value of the currently selected feature. A value from the
      * identifierField.
-     * \deprecated since QGIS 3.10 use setIdentifierValues
+     * \deprecated QGIS 3.10. Use setIdentifierValues.
      */
     Q_DECL_DEPRECATED void setIdentifierValue( const QVariant &identifierValue ) SIP_DEPRECATED;
 
@@ -170,7 +191,7 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
     /**
      * Field name that will be used to uniquely identify the current feature.
      * Normally the primary key of the layer.
-     * \deprecated since QGIS 3.10
+     * \deprecated QGIS 3.10
      */
     Q_DECL_DEPRECATED QString identifierField() const SIP_DEPRECATED;
 
@@ -184,7 +205,7 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
     /**
      * Field name that will be used to uniquely identify the current feature.
      * Normally the primary key of the layer.
-     * \deprecated since QGIS 3.10
+     * \deprecated QGIS 3.10
      */
     Q_DECL_DEPRECATED void setIdentifierField( const QString &identifierField ) SIP_DEPRECATED;
 
@@ -230,6 +251,18 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
      */
     void filterExpressionChanged();
 
+    /**
+     * An attribute form feature to be used alongside the filter expression.
+     * \since QGIS 3.42.2
+     */
+    void formFeatureChanged();
+
+    /**
+     * A parent attribute form feature to be used alongside the filter expression.
+     * \since QGIS 3.42.2
+     */
+    void parentFormFeatureChanged();
+
     /**
      * The identifier value of the currently selected feature. A value from the
      * identifierField.
@@ -253,6 +286,12 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
      */
     void currentFeatureChanged();
 
+    /**
+     * Emitted when the feature picker model changes its feature \a found state
+     * \since QGIS 3.38
+     */
+    void currentFeatureFoundChanged( bool found );
+
   private slots:
     void onCurrentTextChanged( const QString &text );
     void onFilterLineEditCleared();
@@ -276,5 +315,4 @@ class GUI_EXPORT QgsFeatureListComboBox : public QComboBox
 };
 
 
-
 #endif // QGSFIELDLISTCOMBOBOX_H
