@@ -14,6 +14,7 @@
 ***************************************************************************/
 
 #include "qgsfieldcombobox.h"
+#include "moc_qgsfieldcombobox.cpp"
 #include "qgsfieldproxymodel.h"
 #include "qgsmaplayer.h"
 #include "qgsvectorlayer.h"
@@ -25,7 +26,7 @@ QgsFieldComboBox::QgsFieldComboBox( QWidget *parent )
   mFieldProxyModel = new QgsFieldProxyModel( this );
   setModel( mFieldProxyModel );
 
-  connect( this, static_cast < void ( QComboBox::* )( int ) > ( &QComboBox::activated ), this, &QgsFieldComboBox::indexChanged );
+  connect( this, static_cast<void ( QComboBox::* )( int )>( &QComboBox::activated ), this, &QgsFieldComboBox::indexChanged );
 }
 
 void QgsFieldComboBox::setFilters( QgsFieldProxyModel::Filters filters )
@@ -99,7 +100,7 @@ QString QgsFieldComboBox::currentField() const
     return QString();
   }
 
-  QString name = mFieldProxyModel->data( proxyIndex, QgsFieldModel::FieldNameRole ).toString();
+  QString name = mFieldProxyModel->data( proxyIndex, static_cast<int>( QgsFieldModel::CustomRole::FieldName ) ).toString();
   return name;
 }
 
