@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsfindfilesbypatternwidget.h"
+#include "moc_qgsfindfilesbypatternwidget.cpp"
 #include "qgsgui.h"
 #include "qgssettings.h"
 
@@ -39,13 +40,11 @@ QgsFindFilesByPatternWidget::QgsFindFilesByPatternWidget( QWidget *parent )
   const QgsSettings settings;
   mFolderWidget->setFilePath( settings.value( QStringLiteral( "qgis/lastFindRecursiveFolder" ) ).toString() );
   mFindButton->setEnabled( !mFolderWidget->filePath().isEmpty() );
-  connect( mFolderWidget, &QgsFileWidget::fileChanged, this, [ = ]( const QString & filePath )
-  {
+  connect( mFolderWidget, &QgsFileWidget::fileChanged, this, [=]( const QString &filePath ) {
     QgsSettings settings;
     settings.setValue( QStringLiteral( "qgis/lastFindRecursiveFolder" ), filePath );
     mFindButton->setEnabled( !filePath.isEmpty() );
   } );
-
 }
 
 void QgsFindFilesByPatternWidget::find()
@@ -68,7 +67,6 @@ void QgsFindFilesByPatternWidget::find()
     filter << pattern;
 
   QDirIterator it( path, filter, QDir::AllEntries | QDir::NoSymLinks | QDir::NoDotAndDotDot, mRecursiveCheckBox->isChecked() ? QDirIterator::Subdirectories : QDirIterator::NoIteratorFlags );
-  const QStringList files;
   while ( it.hasNext() )
   {
     const QString fullPath = it.next();
@@ -135,8 +133,7 @@ QgsFindFilesByPatternDialog::QgsFindFilesByPatternDialog( QWidget *parent )
   setLayout( vLayout );
 
   mButtonBox->button( QDialogButtonBox::Ok )->setEnabled( false );
-  connect( mWidget, &QgsFindFilesByPatternWidget::findComplete, this, [ = ]( const QStringList & files )
-  {
+  connect( mWidget, &QgsFindFilesByPatternWidget::findComplete, this, [=]( const QStringList &files ) {
     mButtonBox->button( QDialogButtonBox::Ok )->setEnabled( !files.empty() );
   } );
 }
