@@ -20,6 +20,7 @@
 #include <QCheckBox>
 
 #include "qgsmaskingwidget.h"
+#include "moc_qgsmaskingwidget.cpp"
 #include "qgsmasksourceselectionwidget.h"
 #include "qgssymbollayerselectionwidget.h"
 #include "qgssymbollayerreference.h"
@@ -33,10 +34,13 @@
 #include "qgsvectorlayerlabeling.h"
 #include "qgsmessagebaritem.h"
 
-QgsMaskingWidget::QgsMaskingWidget( QWidget *parent ) :
-  QgsPanelWidget( parent )
+QgsMaskingWidget::QgsMaskingWidget( QWidget *parent )
+  : QgsPanelWidget( parent )
 {
   setupUi( this );
+
+  connect( mMaskTargetsWidget, &QgsSymbolLayerSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
+  connect( mMaskSourcesWidget, &QgsMaskSourceSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
 }
 
 void QgsMaskingWidget::onSelectionChanged()
@@ -51,36 +55,13 @@ void QgsMaskingWidget::onSelectionChanged()
   }
   else if ( !mMessageBarItem && printMessage )
   {
-    mMessageBarItem = new QgsMessageBarItem( tr( "Select both sources and symbol layers or your configuration will be lost" ), Qgis::MessageLevel::Warning, 0, this );
+    mMessageBarItem = new QgsMessageBarItem( tr( "Select both masking and masked symbol layers or your configuration will be lost" ), Qgis::MessageLevel::Warning, 0, this );
     mMessageBar->pushItem( mMessageBarItem );
   }
 
   emit widgetChanged();
 }
 
-void QgsMaskingWidget::showEvent( QShowEvent *event )
-{
-  Q_UNUSED( event );
-
-  // populate is quite long, so we delay it when the widget is first shown
-  if ( mMustPopulate )
-  {
-    disconnect( mMaskTargetsWidget, &QgsSymbolLayerSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
-    disconnect( mMaskSourcesWidget, &QgsMaskSourceSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
-
-    mMustPopulate = false;
-    populate();
-
-    connect( mMaskTargetsWidget, &QgsSymbolLayerSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
-    connect( mMaskSourcesWidget, &QgsMaskSourceSelectionWidget::changed, this, &QgsMaskingWidget::onSelectionChanged );
-
-    onSelectionChanged();
-  }
-}
-
-
-
-
 /**
  * Symbol layer masks collector. It is an enhanced version of QgsVectorLayerUtils::symbolLayerMasks.
  * Indeed, we need here to know both mask sources and targets for all masks
@@ -92,13 +73,12 @@ void QgsMaskingWidget::showEvent( QShowEvent *event )
  */
 QList<QPair<QString, QList<QgsSymbolLayerReference>>> symbolLayerMasks( const QgsVectorLayer *layer )
 {
-  if ( ! layer->renderer() )
+  if ( !layer->renderer() )
     return {};
 
   QList<QPair<QString, QList<QgsSymbolLayerReference>>> mMasks;
-  SymbolLayerVisitor collector( [&]( const QgsSymbolLayer * sl, const QString & lid )
-  {
-    if ( ! sl->masks().isEmpty() )
+  SymbolLayerVisitor collector( [&]( const QgsSymbolLayer *sl, const QString &lid ) {
+    if ( !sl->masks().isEmpty() )
       mMasks.push_back( qMakePair( lid, sl->masks() ) );
   } );
   layer->renderer()->accept( &collector );
@@ -107,15 +87,15 @@ QList<QPair<QString, QList<QgsSymbolLayerReference>>> symbolLayerMasks( const Qg
 
 void QgsMaskingWidget::setLayer( QgsVectorLayer *layer )
 {
-  if ( mLayer != layer )
-  {
-    mLayer = layer;
-    mMustPopulate = true;
-  }
+  mLayer = layer;
+  populate();
 }
 
 void QgsMaskingWidget::populate()
 {
+  const QSignalBlocker blockerSourceWidget( mMaskSourcesWidget );
+  const QSignalBlocker blockerTargetWidget( mMaskTargetsWidget );
+
   mMaskSourcesWidget->update();
   mMaskTargetsWidget->setLayer( mLayer );
 
@@ -129,7 +109,7 @@ void QgsMaskingWidget::populate()
   {
     const QString layerId = layerIt.key();
     QgsVectorLayer *vl = qobject_cast<QgsVectorLayer *>( layerIt.value() );
-    if ( ! vl )
+    if ( !vl )
       continue;
 
     // collect symbol layer masks
@@ -188,13 +168,12 @@ void QgsMaskingWidget::apply()
   for ( auto layerIt = layers.begin(); layerIt != layers.end(); layerIt++ )
   {
     QgsVectorLayer *vl = qobject_cast<QgsVectorLayer *>( layerIt.value() );
-    if ( ! vl )
+    if ( !vl )
       continue;
 
     //
     // First reset symbol layer masks
-    SymbolLayerVisitor maskSetter( [&]( const QgsSymbolLayer * sl, const QString & slId )
-    {
+    SymbolLayerVisitor maskSetter( [&]( const QgsSymbolLayer *sl, const QString &slId ) {
       if ( sl->layerType() == "MaskMarker" )
       {
         QgsMaskMarkerSymbolLayer *maskSl = const_cast<QgsMaskMarkerSymbolLayer *>( static_cast<const QgsMaskMarkerSymbolLayer *>( sl ) );
@@ -209,7 +188,7 @@ void QgsMaskingWidget::apply()
         }
         for ( const QgsMaskSourceSelectionWidget::MaskSource &source : maskSources )
         {
-          if ( ! source.isLabeling && source.layerId == layerIt.key() && source.symbolLayerId == slId )
+          if ( !source.isLabeling && source.layerId == layerIt.key() && source.symbolLayerId == slId )
           {
             // ... then add the new masked symbol layers, if any
             for ( const QString &maskedId : maskedSymbolLayers )
@@ -228,14 +207,14 @@ void QgsMaskingWidget::apply()
 
     //
     // Now reset label masks
-    if ( ! vl->labeling() )
+    if ( !vl->labeling() )
       continue;
     for ( const QString &labelProvider : vl->labeling()->subProviders() )
     {
       // clear symbol layers
       QgsPalLayerSettings settings = vl->labeling()->settings( labelProvider );
       QgsTextFormat format = settings.format();
-      if ( ! format.mask().enabled() )
+      if ( !format.mask().enabled() )
         continue;
       const QgsSymbolLayerReferenceList masks = format.mask().maskedSymbolLayers();
       QgsSymbolLayerReferenceList newMasks;
@@ -276,13 +255,8 @@ void QgsMaskingWidget::apply()
   }
 }
 
-bool QgsMaskingWidget::hasBeenPopulated()
-{
-  return !mMustPopulate;
-}
-
-SymbolLayerVisitor::SymbolLayerVisitor( SymbolLayerVisitor::SymbolLayerCallback callback ) :
-  mCallback( callback )
+SymbolLayerVisitor::SymbolLayerVisitor( SymbolLayerVisitor::SymbolLayerCallback callback )
+  : mCallback( callback )
 {}
 
 bool SymbolLayerVisitor::visitEnter( const QgsStyleEntityVisitorInterface::Node &node )
@@ -290,17 +264,13 @@ bool SymbolLayerVisitor::visitEnter( const QgsStyleEntityVisitorInterface::Node
   if ( node.type != QgsStyleEntityVisitorInterface::NodeType::SymbolRule )
     return false;
 
-  mSymbolKey = node.identifier;
   return true;
 }
 
-void SymbolLayerVisitor::visitSymbol( const QgsSymbol *symbol, const QString &leafIdentifier, QVector<int> rootPath )
+void SymbolLayerVisitor::visitSymbol( const QgsSymbol *symbol, const QString &leafIdentifier )
 {
   for ( int idx = 0; idx < symbol->symbolLayerCount(); idx++ )
   {
-    QVector<int> indexPath = rootPath;
-    indexPath.push_back( idx );
-
     const QgsSymbolLayer *sl = symbol->symbolLayer( idx );
 
     mCallback( sl, sl->id() );
@@ -308,7 +278,7 @@ void SymbolLayerVisitor::visitSymbol( const QgsSymbol *symbol, const QString &le
     // recurse over sub symbols
     const QgsSymbol *subSymbol = const_cast<QgsSymbolLayer *>( sl )->subSymbol();
     if ( subSymbol )
-      visitSymbol( subSymbol, leafIdentifier, indexPath );
+      visitSymbol( subSymbol, leafIdentifier );
   }
 }
 
@@ -318,7 +288,7 @@ bool SymbolLayerVisitor::visit( const QgsStyleEntityVisitorInterface::StyleLeaf
   {
     auto symbolEntity = static_cast<const QgsStyleSymbolEntity *>( leaf.entity );
     if ( symbolEntity->symbol() )
-      visitSymbol( symbolEntity->symbol(), leaf.identifier, {} );
+      visitSymbol( symbolEntity->symbol(), leaf.identifier );
   }
   return true;
 }
