@@ -18,6 +18,7 @@
 #include "qgis.h"
 #include "qgssettingsregistrycore.h"
 #include "qgsscalecombobox.h"
+#include "moc_qgsscalecombobox.cpp"
 #include "qgssettingsentryimpl.h"
 
 #include <QAbstractItemView>
@@ -32,34 +33,29 @@ QgsScaleComboBox::QgsScaleComboBox( QWidget *parent )
   setEditable( true );
   setInsertPolicy( QComboBox::NoInsert );
   setCompleter( nullptr );
-  connect( this, qOverload< int >( &QComboBox::activated ), this, &QgsScaleComboBox::fixupScale );
+  connect( this, qOverload<int>( &QComboBox::activated ), this, &QgsScaleComboBox::fixupScale );
   connect( lineEdit(), &QLineEdit::editingFinished, this, &QgsScaleComboBox::fixupScale );
   fixupScale();
 }
 
 void QgsScaleComboBox::updateScales( const QStringList &scales )
 {
-  QStringList myScalesList;
+  QStringList scalesList;
   const QString oldScale = currentText();
 
   if ( scales.isEmpty() )
   {
-    myScalesList = QgsSettingsRegistryCore::settingsMapScales->value();
+    scalesList = QgsSettingsRegistryCore::settingsMapScales->value();
   }
   else
   {
-    QStringList::const_iterator scaleIt = scales.constBegin();
-    for ( ; scaleIt != scales.constEnd(); ++scaleIt )
-    {
-      myScalesList.append( *scaleIt );
-    }
+    scalesList = scales;
   }
 
-  QStringList  myCleanedScalesList;
-
-  for ( int i = 0; i < myScalesList.size(); ++i )
+  QStringList cleanedScalesList;
+  for ( const QString &scale : std::as_const( scalesList ) )
   {
-    const QStringList parts = myScalesList[ i ] .split( ':' );
+    const QStringList parts = scale.split( ':' );
     if ( parts.size() < 2 )
       continue;
 
@@ -67,21 +63,45 @@ void QgsScaleComboBox::updateScales( const QStringList &scales )
     const double denominator = QLocale().toDouble( parts[1], &ok );
     if ( ok )
     {
-      myCleanedScalesList.push_back( toString( denominator ) );
+      cleanedScalesList.push_back( toString( denominator ) );
     }
     else
     {
       const double denominator = parts[1].toDouble( &ok );
       if ( ok )
       {
-        myCleanedScalesList.push_back( toString( denominator ) );
+        cleanedScalesList.push_back( toString( denominator ) );
       }
     }
   }
 
   blockSignals( true );
   clear();
-  addItems( myCleanedScalesList );
+  addItems( cleanedScalesList );
+  setScaleString( oldScale );
+  blockSignals( false );
+}
+
+void QgsScaleComboBox::setPredefinedScales( const QVector<double> &scales )
+{
+  if ( scales.isEmpty() )
+  {
+    updateScales();
+    return;
+  }
+
+  const QString oldScale = currentText();
+
+  QStringList scalesStringList;
+  scalesStringList.reserve( scales.size() );
+  for ( double denominator : scales )
+  {
+    scalesStringList.push_back( toString( denominator ) );
+  }
+
+  blockSignals( true );
+  clear();
+  addItems( scalesStringList );
   setScaleString( oldScale );
   blockSignals( false );
 }
@@ -128,7 +148,7 @@ bool QgsScaleComboBox::setScaleString( const QString &string )
   const double oldScale = mScale;
   if ( mAllowNull && string.trimmed().isEmpty() )
   {
-    mScale = std::numeric_limits< double >::quiet_NaN();
+    mScale = std::numeric_limits<double>::quiet_NaN();
     setEditText( toString( mScale ) );
     clearFocus();
     if ( !std::isnan( oldScale ) )
@@ -144,7 +164,7 @@ bool QgsScaleComboBox::setScaleString( const QString &string )
   {
     newScale = mMinScale;
   }
-  if ( ! ok )
+  if ( !ok )
   {
     return false;
   }
@@ -180,7 +200,7 @@ void QgsScaleComboBox::fixupScale()
 {
   if ( mAllowNull && currentText().trimmed().isEmpty() )
   {
-    setScale( std::numeric_limits< double >::quiet_NaN() );
+    setScale( std::numeric_limits<double>::quiet_NaN() );
     return;
   }
 
@@ -218,11 +238,11 @@ QString QgsScaleComboBox::toString( double scale )
   }
   else if ( scale <= 1 )
   {
-    return QStringLiteral( "%1:1" ).arg( QLocale().toString( static_cast< int >( std::round( 1.0 / scale ) ) ) );
+    return QStringLiteral( "%1:1" ).arg( QLocale().toString( static_cast<int>( std::round( 1.0 / scale ) ) ) );
   }
   else
   {
-    return QStringLiteral( "1:%1" ).arg( QLocale().toString( static_cast< float >( std::round( scale ) ), 'f', 0 ) );
+    return QStringLiteral( "1:%1" ).arg( QLocale().toString( static_cast<float>( std::round( scale ) ), 'f', 0 ) );
   }
 }
 
@@ -247,12 +267,12 @@ double QgsScaleComboBox::toDouble( const QString &scaleString, bool *returnOk )
     {
       bool okX = false;
       bool okY = false;
-      const int x = qgsPermissiveToInt( txtList[ 0 ], okX );
-      const int y = qgsPermissiveToInt( txtList[ 1 ], okY );
+      const int x = qgsPermissiveToInt( txtList[0], okX );
+      const int y = qgsPermissiveToInt( txtList[1], okY );
       if ( okX && okY && x != 0 )
       {
         // Scale is fraction of x and y
-        scale = static_cast<  double >( y ) / static_cast< double >( x );
+        scale = static_cast<double>( y ) / static_cast<double>( x );
         ok = true;
       }
     }
@@ -290,5 +310,5 @@ void QgsScaleComboBox::setMinScale( double scale )
 void QgsScaleComboBox::setNull()
 {
   if ( allowNull() )
-    setScale( std::numeric_limits< double >::quiet_NaN() );
+    setScale( std::numeric_limits<double>::quiet_NaN() );
 }
