@@ -40,7 +40,6 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
 {
     Q_OBJECT
   public:
-
     /**
       * Constructor for QgsTemporalControllerWidget, with the specified \a parent widget.
       */
@@ -67,11 +66,9 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
 #endif
 
   protected:
-
     void keyPressEvent( QKeyEvent *e ) override;
 
   private:
-
     //! Handles all non-GUI navigation logic
     QgsTemporalNavigationObject *mNavigationObject = nullptr;
 
@@ -80,16 +77,11 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
 
     bool mHasTemporalLayersLoaded = false;
 
-    void togglePlayForward();
-    void togglePlayBackward();
-    void togglePause();
-    bool mPlayingForward = true;
-
-    std::unique_ptr< QMenu > mRangeMenu;
+    std::unique_ptr<QMenu> mRangeMenu;
     QAction *mRangeSetToProjectAction = nullptr;
     QAction *mRangeSetToAllLayersAction = nullptr;
 
-    std::unique_ptr< QMenu > mRangeLayersSubMenu;
+    std::unique_ptr<QMenu> mRangeLayersSubMenu;
     QgsMapLayerModel *mMapLayerModel = nullptr;
 
     void firstTemporalLayerLoaded( QgsMapLayer *layer );
@@ -108,7 +100,7 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
      *
      * \note Updates will only be made if the \a timeStep is valid.
      *
-     * \since 3.18
+     * \since QGIS 3.18
      */
     void updateTimeStepInputs( const QgsInterval &timeStep );
 
@@ -147,6 +139,8 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
      */
     void updateSlider( const QgsDateTimeRange &range );
 
+    void totalMovieFramesChanged( long long frames );
+
     /**
      * Updates the current range label
      */
@@ -167,7 +161,8 @@ class GUI_EXPORT QgsTemporalControllerWidget : public QgsPanelWidget, private Ui
     void mNavigationOff_clicked();
     void mNavigationFixedRange_clicked();
     void mNavigationAnimated_clicked();
-    void setWidgetStateFromNavigationMode( const QgsTemporalNavigationObject::NavigationMode mode );
+    void mNavigationMovie_clicked();
+    void setWidgetStateFromNavigationMode( Qgis::TemporalNavigationMode mode );
 
     void onLayersAdded( const QList<QgsMapLayer *> &layers );
     void onProjectCleared();
