@@ -19,6 +19,7 @@
 #include "qgsguiutils.h"
 #include "qgsrasterrendererwidget.h"
 #include "qgsrasterhistogramwidget.h"
+#include "moc_qgsrasterhistogramwidget.cpp"
 #include "qgsrasterminmaxwidget.h"
 #include "qgsdoublevalidator.h"
 #include "qgssettings.h"
@@ -98,10 +99,7 @@ QgsRasterHistogramWidget::QgsRasterHistogramWidget( QgsRasterLayer *lyr, QWidget
     {
       cboHistoBand->addItem( mRasterLayer->bandName( myIteratorInt ) );
       const Qgis::DataType mySrcDataType = mRasterLayer->dataProvider()->sourceDataType( myIteratorInt );
-      if ( !( mySrcDataType == Qgis::DataType::Byte ||
-              mySrcDataType == Qgis::DataType::Int8 ||
-              mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 ||
-              mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 ) )
+      if ( !( mySrcDataType == Qgis::DataType::Byte || mySrcDataType == Qgis::DataType::Int8 || mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 || mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 ) )
         isInt = false;
     }
 
@@ -242,7 +240,6 @@ QgsRasterHistogramWidget::QgsRasterHistogramWidget( QgsRasterLayer *lyr, QWidget
     action = new QAction( tr( "Recompute Histogram" ), group );
     action->setData( QVariant( "Compute histogram" ) );
     menu->addAction( action );
-
   }
 
 } // QgsRasterHistogramWidget ctor
@@ -273,10 +270,10 @@ void QgsRasterHistogramWidget::setActive( bool activeFlag )
 
 void QgsRasterHistogramWidget::btnHistoCompute_clicked()
 {
-// Histogram computation can be called either by clicking the "Compute Histogram" button
-// which is only visible if there is no cached histogram or by calling the
-// "Compute Histogram" action. Due to limitations in the gdal api, it is not possible
-// to re-calculate the histogram if it has already been calculated
+  // Histogram computation can be called either by clicking the "Compute Histogram" button
+  // which is only visible if there is no cached histogram or by calling the
+  // "Compute Histogram" action. Due to limitations in the gdal api, it is not possible
+  // to re-calculate the histogram if it has already been calculated
   computeHistogram( true );
   refreshHistogram();
 }
@@ -287,41 +284,36 @@ void QgsRasterHistogramWidget::btnHistoCompute_clicked()
 // unreadable (see https://github.com/qgis/QGIS/issues/38298)
 // NOTE: the number of bins should probably be let to the user, and/or adaptative
 // to the width in pixels of the chart.
-static int getBinCount( QgsRasterInterface *rasterInterface,
-                        int bandNo,
-                        int sampleSize )
+static int getBinCount( QgsRasterInterface *rasterInterface, int bandNo, int sampleSize )
 {
   const Qgis::DataType mySrcDataType = rasterInterface->sourceDataType( bandNo );
-  const double statsMin = mySrcDataType == Qgis::DataType::Byte ? 0 :
-                          rasterInterface->bandStatistics( bandNo, QgsRasterBandStats::Min, QgsRectangle(), sampleSize ).minimumValue;
-  const double statsMax = mySrcDataType == Qgis::DataType::Byte ? 255 :
-                          rasterInterface->bandStatistics( bandNo, QgsRasterBandStats::Max, QgsRectangle(), sampleSize ).maximumValue;
+  const double statsMin = mySrcDataType == Qgis::DataType::Byte ? 0 : rasterInterface->bandStatistics( bandNo, Qgis::RasterBandStatistic::Min, QgsRectangle(), sampleSize ).minimumValue;
+  const double statsMax = mySrcDataType == Qgis::DataType::Byte ? 255 : rasterInterface->bandStatistics( bandNo, Qgis::RasterBandStatistic::Max, QgsRectangle(), sampleSize ).maximumValue;
   const QgsRectangle extent( rasterInterface->extent() );
 
   // Calc resolution from sampleSize
   double xRes, yRes;
-  xRes = yRes = std::sqrt( ( static_cast<double>( extent.width( ) ) * extent.height() ) / sampleSize );
+  xRes = yRes = std::sqrt( ( static_cast<double>( extent.width() ) * extent.height() ) / sampleSize );
 
   // But limit by physical resolution
-  if ( rasterInterface->capabilities() & QgsRasterInterface::Size )
+  if ( rasterInterface->capabilities() & Qgis::RasterInterfaceCapability::Size )
   {
     const double srcXRes = extent.width() / rasterInterface->xSize();
     const double srcYRes = extent.height() / rasterInterface->ySize();
-    if ( xRes < srcXRes ) xRes = srcXRes;
-    if ( yRes < srcYRes ) yRes = srcYRes;
+    if ( xRes < srcXRes )
+      xRes = srcXRes;
+    if ( yRes < srcYRes )
+      yRes = srcYRes;
   }
 
-  const int histogramWidth = static_cast <int>( extent.width() / xRes );
-  const int histogramHeight = static_cast <int>( extent.height() / yRes );
+  const int histogramWidth = static_cast<int>( extent.width() / xRes );
+  const int histogramHeight = static_cast<int>( extent.height() / yRes );
 
-  int binCount = static_cast<int>( std::min( static_cast<qint64>( 1000 ),
-                                   static_cast<qint64>( histogramWidth ) * histogramHeight ) );
+  int binCount = static_cast<int>( std::min( static_cast<qint64>( 1000 ), static_cast<qint64>( histogramWidth ) * histogramHeight ) );
 
-  if ( mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 ||
-       mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 )
+  if ( mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 || mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 )
   {
-    binCount = static_cast<int>( std::min( static_cast<qint64>( binCount ),
-                                           static_cast<qint64>( std::ceil( statsMax - statsMin + 1 ) ) ) );
+    binCount = static_cast<int>( std::min( static_cast<qint64>( binCount ), static_cast<qint64>( std::ceil( statsMax - statsMin + 1 ) ) ) );
   }
 
   return binCount;
@@ -329,13 +321,12 @@ static int getBinCount( QgsRasterInterface *rasterInterface,
 
 bool QgsRasterHistogramWidget::computeHistogram( bool forceComputeFlag )
 {
-
   //bool myIgnoreOutOfRangeFlag = true;
   //bool myThoroughBandScanFlag = false;
   const int myBandCountInt = mRasterLayer->bandCount();
 
   // if forceComputeFlag = false make sure raster has cached histogram, else return false
-  if ( ! forceComputeFlag )
+  if ( !forceComputeFlag )
   {
     for ( int myIteratorInt = 1;
           myIteratorInt <= myBandCountInt;
@@ -354,7 +345,7 @@ bool QgsRasterHistogramWidget::computeHistogram( bool forceComputeFlag )
   // compute histogram
   stackedWidget2->setCurrentIndex( 1 );
 
-  const std::unique_ptr< QgsRasterBlockFeedback > feedback( new QgsRasterBlockFeedback() );
+  const std::unique_ptr<QgsRasterBlockFeedback> feedback( new QgsRasterBlockFeedback() );
   connect( feedback.get(), &QgsRasterBlockFeedback::progressChanged, mHistogramProgress, &QProgressBar::setValue );
   QApplication::setOverrideCursor( Qt::WaitCursor );
 
@@ -389,7 +380,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
   const int myBandCountInt = mRasterLayer->bandCount();
 
 
-  if ( ! computeHistogram( false ) )
+  if ( !computeHistogram( false ) )
   {
     QgsDebugMsgLevel( QStringLiteral( "raster does not have cached histogram" ), 2 );
     stackedWidget2->setCurrentIndex( 2 );
@@ -423,15 +414,12 @@ void QgsRasterHistogramWidget::refreshHistogram()
   QRandomGenerator colorGenerator( myBandCountInt * 100 );
   while ( myColors.size() <= myBandCountInt )
   {
-    myColors <<
-             QColor( colorGenerator.bounded( 1, 256 ),
-                     colorGenerator.bounded( 1, 256 ),
-                     colorGenerator.bounded( 1, 256 ) );
+    myColors << QColor( colorGenerator.bounded( 1, 256 ), colorGenerator.bounded( 1, 256 ), colorGenerator.bounded( 1, 256 ) );
   }
 
   // assign colors to each band, depending on the current RGB/gray band selection
   // grayscale
-  QList< int > mySelectedBands = rendererSelectedBands();
+  QList<int> mySelectedBands = rendererSelectedBands();
   if ( mRendererName == QLatin1String( "singlebandgray" ) )
   {
     const int myGrayBand = mySelectedBands[0];
@@ -444,7 +432,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
       }
       else
       {
-        if ( ! myColors.isEmpty() )
+        if ( !myColors.isEmpty() )
         {
           mHistoColors << myColors.first();
           myColors.pop_front();
@@ -477,7 +465,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
         myColor = Qt::blue;
       else
       {
-        if ( ! myColors.isEmpty() )
+        if ( !myColors.isEmpty() )
         {
           myColor = myColors.first();
           myColors.pop_front();
@@ -488,7 +476,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
         }
         cboHistoBand->setItemData( i - 1, QColor( Qt::black ), Qt::ForegroundRole );
       }
-      if ( i == myRedBand ||  i == myGreenBand || i == myBlueBand )
+      if ( i == myRedBand || i == myGreenBand || i == myBlueBand )
       {
         cboHistoBand->setItemData( i - 1, myColor, Qt::ForegroundRole );
       }
@@ -525,13 +513,13 @@ void QgsRasterHistogramWidget::refreshHistogram()
     /* skip this band if mHistoShowBands != ShowAll and this band is not selected */
     if ( mHistoShowBands != ShowAll )
     {
-      if ( ! mySelectedBands.contains( bandNumber ) )
+      if ( !mySelectedBands.contains( bandNumber ) )
         continue;
     }
 
     const int sampleSize = SAMPLE_SIZE; // number of sample cells
 
-    const std::unique_ptr< QgsRasterBlockFeedback > feedback( new QgsRasterBlockFeedback() );
+    const std::unique_ptr<QgsRasterBlockFeedback> feedback( new QgsRasterBlockFeedback() );
     connect( feedback.get(), &QgsRasterBlockFeedback::progressChanged, mHistogramProgress, &QProgressBar::setValue );
 
     const int binCount = getBinCount( mRasterLayer->dataProvider(), bandNumber, sampleSize );
@@ -541,10 +529,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
 
     const Qgis::DataType mySrcDataType = mRasterLayer->dataProvider()->sourceDataType( bandNumber );
     bool myDrawLines = true;
-    if ( ! mHistoDrawLines &&
-         ( mySrcDataType == Qgis::DataType::Byte ||
-           mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 ||
-           mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 ) )
+    if ( !mHistoDrawLines && ( mySrcDataType == Qgis::DataType::Byte || mySrcDataType == Qgis::DataType::Int16 || mySrcDataType == Qgis::DataType::Int32 || mySrcDataType == Qgis::DataType::UInt16 || mySrcDataType == Qgis::DataType::UInt32 ) )
     {
       myDrawLines = false;
     }
@@ -559,7 +544,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
     }
 
     QwtPlotHistogram *mypHisto = nullptr;
-    if ( ! myDrawLines )
+    if ( !myDrawLines )
     {
       mypHisto = new QwtPlotHistogram( tr( "Band %1" ).arg( bandNumber ) );
       mypHisto->setRenderHint( QwtPlotItem::RenderAntialiased );
@@ -619,9 +604,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
     // subtract -0.5 to prevent rounding errors
     // see http://www.gdal.org/classGDALRasterBand.html#3f8889607d3b2294f7e0f11181c201c8
     // fix x range for non-Byte data
-    mpPlot->setAxisScale( QwtPlot::xBottom,
-                          mHistoMin - myBinXStep / 2,
-                          mHistoMax + myBinXStep / 2 );
+    mpPlot->setAxisScale( QwtPlot::xBottom, mHistoMin - myBinXStep / 2, mHistoMax + myBinXStep / 2 );
     mpPlot->setEnabled( true );
     mpPlot->replot();
 
@@ -641,7 +624,7 @@ void QgsRasterHistogramWidget::refreshHistogram()
       mHistoPicker->setTrackerMode( QwtPicker::AlwaysOff );
       mHistoPicker->setRubberBand( QwtPicker::VLineRubberBand );
       mHistoPicker->setStateMachine( new QwtPickerDragPointMachine );
-      connect( mHistoPicker, static_cast < void ( QwtPlotPicker::* )( const QPointF & ) > ( &QwtPlotPicker::selected ), this, &QgsRasterHistogramWidget::histoPickerSelected );
+      connect( mHistoPicker, static_cast<void ( QwtPlotPicker::* )( const QPointF & )>( &QwtPlotPicker::selected ), this, &QgsRasterHistogramWidget::histoPickerSelected );
     }
     mHistoPicker->setEnabled( false );
 
@@ -675,7 +658,7 @@ void QgsRasterHistogramWidget::mSaveAsImageButton_clicked()
   if ( !mpPlot )
     return;
 
-  const QPair< QString, QString> myFileNameAndFilter = QgsGuiUtils::getSaveAsImageName( this, tr( "Choose a file name to save the map image as" ) );
+  const QPair<QString, QString> myFileNameAndFilter = QgsGuiUtils::getSaveAsImageName( this, tr( "Choose a file name to save the map image as" ) );
   const QFileInfo myInfo( myFileNameAndFilter.first );
   if ( !myInfo.baseName().isEmpty() )
   {
@@ -683,13 +666,12 @@ void QgsRasterHistogramWidget::mSaveAsImageButton_clicked()
   }
 }
 
-bool QgsRasterHistogramWidget::histoSaveAsImage( const QString &filename,
-    int width, int height, int quality )
+bool QgsRasterHistogramWidget::histoSaveAsImage( const QString &filename, int width, int height, int quality )
 {
   // make sure dir. exists
   const QFileInfo myInfo( filename );
   const QDir myDir( myInfo.dir() );
-  if ( ! myDir.exists() )
+  if ( !myDir.exists() )
   {
     QgsDebugError( QStringLiteral( "Error, directory %1 non-existent (theFilename = %2)" ).arg( myDir.absolutePath(), filename ) );
     return false;
@@ -698,11 +680,10 @@ bool QgsRasterHistogramWidget::histoSaveAsImage( const QString &filename,
   // prepare the pixmap
   QPixmap myPixmap( width, height );
   const QRect myQRect( 5, 5, width - 10, height - 10 ); // leave a 5px border on all sides
-  myPixmap.fill( Qt::white ); // Qt::transparent ?
+  myPixmap.fill( Qt::white );                           // Qt::transparent ?
 
   QwtPlotRenderer myRenderer;
-  myRenderer.setDiscardFlags( QwtPlotRenderer::DiscardBackground |
-                              QwtPlotRenderer::DiscardCanvasBackground );
+  myRenderer.setDiscardFlags( QwtPlotRenderer::DiscardBackground | QwtPlotRenderer::DiscardCanvasBackground );
   myRenderer.setLayoutFlags( QwtPlotRenderer::FrameWithScales );
 
   QPainter myPainter;
@@ -739,7 +720,7 @@ void QgsRasterHistogramWidget::cboHistoBand_currentIndexChanged( int index )
   btnHistoMin->setEnabled( true );
   btnHistoMax->setEnabled( true );
 
-  const QPair< QString, QString > myMinMax = rendererMinMax( index + 1 );
+  const QPair<QString, QString> myMinMax = rendererMinMax( index + 1 );
   leHistoMin->setText( myMinMax.first );
   leHistoMax->setText( myMinMax.second );
 
@@ -749,7 +730,7 @@ void QgsRasterHistogramWidget::cboHistoBand_currentIndexChanged( int index )
 
 void QgsRasterHistogramWidget::histoActionTriggered( QAction *action )
 {
-  if ( ! action )
+  if ( !action )
     return;
   histoAction( action->data().toString(), action->isChecked() );
 }
@@ -929,11 +910,11 @@ void QgsRasterHistogramWidget::histoAction( const QString &actionName, bool acti
 
 void QgsRasterHistogramWidget::applyHistoMin()
 {
-  if ( ! mRendererWidget )
+  if ( !mRendererWidget )
     return;
 
   const int bandNo = cboHistoBand->currentIndex() + 1;
-  const QList< int > selectedBands = rendererSelectedBands();
+  const QList<int> selectedBands = rendererSelectedBands();
   QString min;
   for ( int i = 0; i <= selectedBands.size(); i++ )
   {
@@ -957,7 +938,7 @@ void QgsRasterHistogramWidget::applyHistoMin()
 
   updateHistoMarkers();
 
-  if ( ! min.isEmpty() && mHistoZoomToMinMax && mHistoZoomer )
+  if ( !min.isEmpty() && mHistoZoomToMinMax && mHistoZoomer )
   {
     QRectF rect = mHistoZoomer->zoomRect();
     rect.setLeft( min.toDouble() );
@@ -968,11 +949,11 @@ void QgsRasterHistogramWidget::applyHistoMin()
 
 void QgsRasterHistogramWidget::applyHistoMax()
 {
-  if ( ! mRendererWidget )
+  if ( !mRendererWidget )
     return;
 
   const int bandNo = cboHistoBand->currentIndex() + 1;
-  const QList< int > mySelectedBands = rendererSelectedBands();
+  const QList<int> mySelectedBands = rendererSelectedBands();
   QString max;
   for ( int i = 0; i <= mySelectedBands.size(); i++ )
   {
@@ -996,7 +977,7 @@ void QgsRasterHistogramWidget::applyHistoMax()
 
   updateHistoMarkers();
 
-  if ( ! max.isEmpty() && mHistoZoomToMinMax && mHistoZoomer )
+  if ( !max.isEmpty() && mHistoZoomToMinMax && mHistoZoomer )
   {
     QRectF rect = mHistoZoomer->zoomRect();
     rect.setRight( max.toDouble() );
@@ -1017,7 +998,7 @@ void QgsRasterHistogramWidget::btnHistoMin_toggled()
       QApplication::setOverrideCursor( Qt::PointingHandCursor );
     }
     if ( mHistoZoomer )
-      mHistoZoomer->setEnabled( ! btnHistoMin->isChecked() );
+      mHistoZoomer->setEnabled( !btnHistoMin->isChecked() );
     mHistoPicker->setEnabled( btnHistoMin->isChecked() );
   }
   updateHistoMarkers();
@@ -1035,7 +1016,7 @@ void QgsRasterHistogramWidget::btnHistoMax_toggled()
       QApplication::setOverrideCursor( Qt::PointingHandCursor );
     }
     if ( mHistoZoomer )
-      mHistoZoomer->setEnabled( ! btnHistoMax->isChecked() );
+      mHistoZoomer->setEnabled( !btnHistoMax->isChecked() );
     mHistoPicker->setEnabled( btnHistoMax->isChecked() );
   }
   updateHistoMarkers();
@@ -1045,10 +1026,11 @@ void QgsRasterHistogramWidget::btnHistoMax_toggled()
 // this is sensitive and may not always be correct, needs more testing
 QString findClosestTickVal( double target, const QwtScaleDiv *scale, int div = 100 )
 {
-  if ( !scale ) return QString();
+  if ( !scale )
+    return QString();
 
-  QList< double > minorTicks = scale->ticks( QwtScaleDiv::MinorTick );
-  QList< double > majorTicks = scale->ticks( QwtScaleDiv::MajorTick );
+  QList<double> minorTicks = scale->ticks( QwtScaleDiv::MinorTick );
+  QList<double> majorTicks = scale->ticks( QwtScaleDiv::MajorTick );
   const double diff = ( minorTicks[1] - minorTicks[0] ) / div;
   double min = majorTicks[0] - diff;
   if ( min > target )
@@ -1109,10 +1091,9 @@ void QgsRasterHistogramWidget::updateHistoMarkers()
     return;
 
   const int bandNo = cboHistoBand->currentIndex() + 1;
-  const QList< int > mySelectedBands = histoSelectedBands();
+  const QList<int> mySelectedBands = histoSelectedBands();
 
-  if ( ( ! mHistoShowMarkers && ! btnHistoMin->isChecked() && ! btnHistoMax->isChecked() ) ||
-       ( ! mySelectedBands.isEmpty() && ! mySelectedBands.contains( bandNo ) ) )
+  if ( ( !mHistoShowMarkers && !btnHistoMin->isChecked() && !btnHistoMax->isChecked() ) || ( !mySelectedBands.isEmpty() && !mySelectedBands.contains( bandNo ) ) )
   {
     mHistoMarkerMin->hide();
     mHistoMarkerMax->hide();
@@ -1144,9 +1125,9 @@ void QgsRasterHistogramWidget::updateHistoMarkers()
 }
 
 
-QList< int > QgsRasterHistogramWidget::histoSelectedBands()
+QList<int> QgsRasterHistogramWidget::histoSelectedBands()
 {
-  QList< int > mySelectedBands;
+  QList<int> mySelectedBands;
 
   if ( mHistoShowBands != ShowAll )
   {
@@ -1163,18 +1144,17 @@ QList< int > QgsRasterHistogramWidget::histoSelectedBands()
   return mySelectedBands;
 }
 
-QList< int > QgsRasterHistogramWidget::rendererSelectedBands()
+QList<int> QgsRasterHistogramWidget::rendererSelectedBands()
 {
-  QList< int > mySelectedBands;
+  QList<int> mySelectedBands;
 
-  if ( ! mRendererWidget )
+  if ( !mRendererWidget )
   {
     mySelectedBands << -1 << -1 << -1; // make sure we return 3 elements
     return mySelectedBands;
   }
 
-  if ( mRendererName == QLatin1String( "singlebandgray" ) ||
-       mRendererName == QLatin1String( "singlebandpseudocolor" ) )
+  if ( mRendererName == QLatin1String( "singlebandgray" ) || mRendererName == QLatin1String( "singlebandpseudocolor" ) )
   {
     mySelectedBands << mRendererWidget->selectedBand();
   }
@@ -1189,15 +1169,14 @@ QList< int > QgsRasterHistogramWidget::rendererSelectedBands()
   return mySelectedBands;
 }
 
-QPair< QString, QString > QgsRasterHistogramWidget::rendererMinMax( int bandNo )
+QPair<QString, QString> QgsRasterHistogramWidget::rendererMinMax( int bandNo )
 {
-  QPair< QString, QString > myMinMax;
+  QPair<QString, QString> myMinMax;
 
-  if ( ! mRendererWidget )
+  if ( !mRendererWidget )
     return myMinMax;
 
-  if ( mRendererName == QLatin1String( "singlebandgray" ) ||
-       mRendererName == QLatin1String( "singlebandpseudocolor" ) )
+  if ( mRendererName == QLatin1String( "singlebandgray" ) || mRendererName == QLatin1String( "singlebandpseudocolor" ) )
   {
     if ( bandNo == mRendererWidget->selectedBand() )
     {
@@ -1240,5 +1219,4 @@ QPair< QString, QString > QgsRasterHistogramWidget::rendererMinMax( int bandNo )
 
 void QgsRasterHistogramWidget::apply()
 {
-
 }
