@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsvectortilelayerproperties.h"
+#include "moc_qgsvectortilelayerproperties.cpp"
 #include "qgshelp.h"
 #include "qgsmaplayerstylemanager.h"
 #include "qgsmaplayerstyleguiutils.h"
@@ -106,8 +107,7 @@ QgsVectorTileLayerProperties::QgsVectorTileLayerProperties( QgsVectorTileLayer *
   // this will be read by restoreOptionsBaseUi()
   if ( !settings.contains( QStringLiteral( "/Windows/VectorTileLayerProperties/tab" ) ) )
   {
-    settings.setValue( QStringLiteral( "Windows/VectorTileLayerProperties/tab" ),
-                       mOptStackedWidget->indexOf( mOptsPage_Style ) );
+    settings.setValue( QStringLiteral( "Windows/VectorTileLayerProperties/tab" ), mOptStackedWidget->indexOf( mOptsPage_Style ) );
   }
 
   mBtnStyle = new QPushButton( tr( "Style" ) );
@@ -153,6 +153,22 @@ void QgsVectorTileLayerProperties::apply()
   mLayer->setScaleBasedVisibility( chkUseScaleDependentRendering->isChecked() );
   mLayer->setMinimumScale( mScaleRangeWidget->minimumScale() );
   mLayer->setMaximumScale( mScaleRangeWidget->maximumScale() );
+
+  //layer title and abstract
+  mLayer->serverProperties()->setShortName( mLayerShortNameLineEdit->text() );
+  mLayer->serverProperties()->setTitle( mLayerTitleLineEdit->text() );
+  mLayer->serverProperties()->setAbstract( mLayerAbstractTextEdit->toPlainText() );
+  mLayer->serverProperties()->setKeywordList( mLayerKeywordListLineEdit->text() );
+  mLayer->serverProperties()->setDataUrl( mLayerDataUrlLineEdit->text() );
+  mLayer->serverProperties()->setDataUrlFormat( mLayerDataUrlFormatComboBox->currentText() );
+
+  //layer attribution
+  mLayer->serverProperties()->setAttribution( mLayerAttributionLineEdit->text() );
+  mLayer->serverProperties()->setAttributionUrl( mLayerAttributionUrlLineEdit->text() );
+
+  // LegendURL
+  mLayer->setLegendUrl( mLayerLegendUrlLineEdit->text() );
+  mLayer->setLegendUrlFormat( mLayerLegendUrlFormatComboBox->currentText() );
 }
 
 void QgsVectorTileLayerProperties::syncToLayer()
@@ -180,10 +196,11 @@ void QgsVectorTileLayerProperties::syncToLayer()
       QHBoxLayout *layout = new QHBoxLayout();
       layout->addWidget( mSourceWidget );
       mSourceGroupBox->setLayout( layout );
+      if ( !mSourceWidget->groupTitle().isEmpty() )
+        mSourceGroupBox->setTitle( mSourceWidget->groupTitle() );
       mSourceGroupBox->show();
 
-      connect( mSourceWidget, &QgsProviderSourceWidget::validChanged, this, [ = ]( bool isValid )
-      {
+      connect( mSourceWidget, &QgsProviderSourceWidget::validChanged, this, [=]( bool isValid ) {
         buttonBox->button( QDialogButtonBox::Apply )->setEnabled( isValid );
         buttonBox->button( QDialogButtonBox::Ok )->setEnabled( isValid );
       } );
@@ -211,6 +228,32 @@ void QgsVectorTileLayerProperties::syncToLayer()
    */
   chkUseScaleDependentRendering->setChecked( mLayer->hasScaleBasedVisibility() );
   mScaleRangeWidget->setScaleRange( mLayer->minimumScale(), mLayer->maximumScale() );
+
+  /*
+   * Server
+   */
+  //layer title and abstract
+  mLayerShortNameLineEdit->setText( mLayer->serverProperties()->shortName() );
+  mLayerTitleLineEdit->setText( mLayer->serverProperties()->title() );
+  mLayerAbstractTextEdit->setPlainText( mLayer->serverProperties()->abstract() );
+  mLayerKeywordListLineEdit->setText( mLayer->serverProperties()->keywordList() );
+  mLayerDataUrlLineEdit->setText( mLayer->serverProperties()->dataUrl() );
+  mLayerDataUrlFormatComboBox->setCurrentIndex(
+    mLayerDataUrlFormatComboBox->findText(
+      mLayer->serverProperties()->dataUrlFormat()
+    )
+  );
+  //layer attribution
+  mLayerAttributionLineEdit->setText( mLayer->serverProperties()->attribution() );
+  mLayerAttributionUrlLineEdit->setText( mLayer->serverProperties()->attributionUrl() );
+
+  // layer legend url
+  mLayerLegendUrlLineEdit->setText( mLayer->legendUrl() );
+  mLayerLegendUrlFormatComboBox->setCurrentIndex(
+    mLayerLegendUrlFormatComboBox->findText(
+      mLayer->legendUrlFormat()
+    )
+  );
 }
 
 void QgsVectorTileLayerProperties::saveDefaultStyle()
@@ -220,7 +263,7 @@ void QgsVectorTileLayerProperties::saveDefaultStyle()
 
 void QgsVectorTileLayerProperties::loadStyle()
 {
-  const QgsSettings settings;  // where we keep last used filter in persistent state
+  const QgsSettings settings; // where we keep last used filter in persistent state
 
   QgsMapLayerLoadStyleDialog dlg( mLayer );
 
@@ -257,7 +300,7 @@ void QgsVectorTileLayerProperties::loadStyle()
       else
       {
         QTextStream in( &file );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
         in.setCodec( "UTF-8" );
 #endif
         const QString content = in.readAll();
@@ -334,4 +377,3 @@ void QgsVectorTileLayerProperties::crsChanged( const QgsCoordinateReferenceSyste
   mLayer->setCrs( crs );
   mMetadataWidget->crsChanged();
 }
-
