@@ -21,6 +21,7 @@
 #include "qgsgrass.h"
 #include "qgsrasteridentifyresult.h"
 #include "qgsgrassrasterprovider.h"
+#include "moc_qgsgrassrasterprovider.cpp"
 #include "qgsconfig.h"
 
 #include "qgsapplication.h"
@@ -39,8 +40,8 @@
 #include <QFile>
 #include <QHash>
 
-#define ERR(message) QGS_ERROR_MESSAGE(message,"GRASS provider")
-#define QGS_ERROR(message) QgsError(message,"GRASS provider")
+#define ERR( message ) QGS_ERROR_MESSAGE( message, "GRASS provider" )
+#define QGS_ERROR( message ) QgsError( message, "GRASS provider" )
 
 // Do not use warning dialogs, providers are also created on threads (rendering) where dialogs cannot be used (constructing QPixmap icon)
 
@@ -101,8 +102,7 @@ QgsGrassRasterProvider::QgsGrassRasterProvider( QString const &uri )
   appendIfError( error );
 
   error.clear();
-  mInfo = QgsGrass::info( mGisdbase, mLocation, mMapset, mMapName, QgsGrassObject::Raster,
-                          QStringLiteral( "info" ), QgsRectangle(), 0, 0, 3000, error );
+  mInfo = QgsGrass::info( mGisdbase, mLocation, mMapset, mMapName, QgsGrassObject::Raster, QStringLiteral( "info" ), QgsRectangle(), 0, 0, 3000, error );
   appendIfError( error );
 
   mGrassDataType = mInfo[QStringLiteral( "TYPE" )].toInt();
@@ -180,10 +180,10 @@ bool QgsGrassRasterProvider::readBlock( int bandNo, int xBlock, int yBlock, void
   clearLastError();
   // TODO: optimize, see extent()
 
-  QgsDebugMsgLevel( "yBlock = "  + QString::number( yBlock ), 2 );
+  QgsDebugMsgLevel( "yBlock = " + QString::number( yBlock ), 2 );
 
   QStringList arguments;
-  arguments.append( "map=" +  mMapName + "@" + mMapset );
+  arguments.append( "map=" + mMapName + "@" + mMapset );
 
   QgsRectangle ext = extent();
 
@@ -195,11 +195,9 @@ bool QgsGrassRasterProvider::readBlock( int bandNo, int xBlock, int yBlock, void
 
   QgsDebugMsgLevel( "mYBlockSize = " + QString::number( mYBlockSize ), 2 );
   arguments.append( ( QStringLiteral( "window=%1,%2,%3,%4,%5,%6" )
-                      .arg( QgsRasterBlock::printValue( ext.xMinimum() ),
-                            QgsRasterBlock::printValue( yMinimum ),
-                            QgsRasterBlock::printValue( ext.xMaximum() ),
-                            QgsRasterBlock::printValue( yMaximum ) )
-                      .arg( mCols ).arg( mYBlockSize ) ) );
+                        .arg( QgsRasterBlock::printValue( ext.xMinimum() ), QgsRasterBlock::printValue( yMinimum ), QgsRasterBlock::printValue( ext.xMaximum() ), QgsRasterBlock::printValue( yMaximum ) )
+                        .arg( mCols )
+                        .arg( mYBlockSize ) ) );
 
   arguments.append( QStringLiteral( "format=value" ) );
   QString cmd = QgsApplication::libexecPath() + "grass/modules/qgis.d.rast";
@@ -233,11 +231,11 @@ bool QgsGrassRasterProvider::readBlock( int bandNo, int xBlock, int yBlock, void
   return true;
 }
 
-bool QgsGrassRasterProvider::readBlock( int bandNo, QgsRectangle  const &viewExtent, int pixelWidth, int pixelHeight, void *block, QgsRasterBlockFeedback *feedback )
+bool QgsGrassRasterProvider::readBlock( int bandNo, QgsRectangle const &viewExtent, int pixelWidth, int pixelHeight, void *block, QgsRasterBlockFeedback *feedback )
 {
   Q_UNUSED( feedback )
-  QgsDebugMsgLevel( "pixelWidth = "  + QString::number( pixelWidth ), 2 );
-  QgsDebugMsgLevel( "pixelHeight = "  + QString::number( pixelHeight ), 2 );
+  QgsDebugMsgLevel( "pixelWidth = " + QString::number( pixelWidth ), 2 );
+  QgsDebugMsgLevel( "pixelHeight = " + QString::number( pixelHeight ), 2 );
   QgsDebugMsgLevel( "viewExtent: " + viewExtent.toString(), 2 );
   clearLastError();
 
@@ -245,14 +243,12 @@ bool QgsGrassRasterProvider::readBlock( int bandNo, QgsRectangle  const &viewExt
     return false;
 
   QStringList arguments;
-  arguments.append( "map=" +  mMapName + "@" + mMapset );
+  arguments.append( "map=" + mMapName + "@" + mMapset );
 
   arguments.append( ( QStringLiteral( "window=%1,%2,%3,%4,%5,%6" )
-                      .arg( QgsRasterBlock::printValue( viewExtent.xMinimum() ),
-                            QgsRasterBlock::printValue( viewExtent.yMinimum() ),
-                            QgsRasterBlock::printValue( viewExtent.xMaximum() ),
-                            QgsRasterBlock::printValue( viewExtent.yMaximum() ) )
-                      .arg( pixelWidth ).arg( pixelHeight ) ) );
+                        .arg( QgsRasterBlock::printValue( viewExtent.xMinimum() ), QgsRasterBlock::printValue( viewExtent.yMinimum() ), QgsRasterBlock::printValue( viewExtent.xMaximum() ), QgsRasterBlock::printValue( viewExtent.yMaximum() ) )
+                        .arg( pixelWidth )
+                        .arg( pixelHeight ) ) );
   arguments.append( QStringLiteral( "format=value" ) );
   QString cmd = QgsApplication::libexecPath() + "grass/modules/qgis.d.rast";
   QByteArray data;
@@ -285,7 +281,7 @@ bool QgsGrassRasterProvider::readBlock( int bandNo, QgsRectangle  const &viewExt
   return true;
 }
 
-QgsRasterBandStats QgsGrassRasterProvider::bandStatistics( int bandNo, int stats, const QgsRectangle &boundingBox, int sampleSize, QgsRasterBlockFeedback * )
+QgsRasterBandStats QgsGrassRasterProvider::bandStatistics( int bandNo, Qgis::RasterBandStatistics stats, const QgsRectangle &boundingBox, int sampleSize, QgsRasterBlockFeedback * )
 {
   QgsDebugMsgLevel( QString( "theBandNo = %1 sampleSize = %2" ).arg( bandNo ).arg( sampleSize ), 2 );
   QgsRasterBandStats myRasterBandStats;
@@ -311,8 +307,7 @@ QgsRasterBandStats QgsGrassRasterProvider::bandStatistics( int bandNo, int stats
   int timeout = 30000 + 0.005 * xSize() * ySize();
 
   QString error;
-  QHash<QString, QString> info = QgsGrass::info( mGisdbase, mLocation, mMapset, mMapName, QgsGrassObject::Raster,
-                                 QStringLiteral( "stats" ), extent, sampleRows, sampleCols, timeout, error );
+  QHash<QString, QString> info = QgsGrass::info( mGisdbase, mLocation, mMapset, mMapName, QgsGrassObject::Raster, QStringLiteral( "stats" ), extent, sampleRows, sampleCols, timeout, error );
 
   if ( info.isEmpty() || !error.isEmpty() )
   {
@@ -333,16 +328,13 @@ QgsRasterBandStats QgsGrassRasterProvider::bandStatistics( int bandNo, int stats
   QgsDebugMsgLevel( QString( "count = %1" ).arg( myRasterBandStats.elementCount ), 2 );
   QgsDebugMsgLevel( QString( "stdev = %1" ).arg( myRasterBandStats.stdDev ), 2 );
 
-  myRasterBandStats.statsGathered = QgsRasterBandStats::Min | QgsRasterBandStats::Max |
-                                    QgsRasterBandStats::Range | QgsRasterBandStats::Mean |
-                                    QgsRasterBandStats::Sum | QgsRasterBandStats::SumOfSquares |
-                                    QgsRasterBandStats::StdDev;
+  myRasterBandStats.statsGathered = Qgis::RasterBandStatistic::Min | Qgis::RasterBandStatistic::Max | Qgis::RasterBandStatistic::Range | Qgis::RasterBandStatistic::Mean | Qgis::RasterBandStatistic::Sum | Qgis::RasterBandStatistic::SumOfSquares | Qgis::RasterBandStatistic::StdDev;
 
   mStatistics.append( myRasterBandStats );
   return myRasterBandStats;
 }
 
-QList<QgsColorRampShader::ColorRampItem> QgsGrassRasterProvider::colorTable( int bandNo )const
+QList<QgsColorRampShader::ColorRampItem> QgsGrassRasterProvider::colorTable( int bandNo ) const
 {
   Q_UNUSED( bandNo )
   QList<QgsColorRampShader::ColorRampItem> ct;
@@ -464,11 +456,11 @@ QgsRasterIdentifyResult QgsGrassRasterProvider::identify( const QgsPointXY &poin
   return QgsRasterIdentifyResult( Qgis::RasterIdentifyFormat::Value, results );
 }
 
-int QgsGrassRasterProvider::capabilities() const
+Qgis::RasterInterfaceCapabilities QgsGrassRasterProvider::capabilities() const
 {
-  int capability = QgsRasterDataProvider::Identify
-                   | QgsRasterDataProvider::IdentifyValue
-                   | QgsRasterDataProvider::Size;
+  Qgis::RasterInterfaceCapabilities capability = Qgis::RasterInterfaceCapability::Identify
+                                                 | Qgis::RasterInterfaceCapability::IdentifyValue
+                                                 | Qgis::RasterInterfaceCapability::Size;
   return capability;
 }
 
@@ -509,7 +501,7 @@ Qgis::RasterColorInterpretation QgsGrassRasterProvider::colorInterpretation( int
   return Qgis::RasterColorInterpretation::GrayIndex;
 }
 
-QString QgsGrassRasterProvider::htmlMetadata()
+QString QgsGrassRasterProvider::htmlMetadata() const
 {
   QString myMetadata;
   QStringList myList;
@@ -518,10 +510,9 @@ QString QgsGrassRasterProvider::htmlMetadata()
   myList.append( "MAPSET: " + mMapset );
   myList.append( "MAP: " + mMapName );
 
-  QHash<QString, QString>::iterator i;
-  for ( i = mInfo.begin(); i != mInfo.end(); ++i )
+  for ( auto it = mInfo.constBegin(); it != mInfo.constEnd(); ++it )
   {
-    myList.append( i.key() + " : " + i.value() );
+    myList.append( it.key() + " : " + it.value() );
   }
   myMetadata += QgsHtmlUtils::buildBulletList( myList );
   return myMetadata;
@@ -562,12 +553,12 @@ QString QgsGrassRasterProvider::lastError()
   return mLastError;
 }
 
-QString  QgsGrassRasterProvider::name() const
+QString QgsGrassRasterProvider::name() const
 {
   return QStringLiteral( "grassraster" );
 }
 
-QString  QgsGrassRasterProvider::description() const
+QString QgsGrassRasterProvider::description() const
 {
   return QStringLiteral( "GRASS %1 raster provider" ).arg( GRASS_VERSION_MAJOR );
 }
@@ -630,7 +621,7 @@ void QgsGrassRasterValue::start()
   QStringList arguments;
 
   arguments.append( QStringLiteral( "info=query" ) );
-  arguments.append( "rast=" +  mMapName + "@" + mMapset );
+  arguments.append( "rast=" + mMapName + "@" + mMapset );
   try
   {
     mProcess = QgsGrass::startModule( mGisdbase, mLocation, mMapset, module, arguments, mGisrcFile );
@@ -671,8 +662,7 @@ double QgsGrassRasterValue::value( double x, double y, bool *ok )
     return value;
   }
 
-  QString coor = QStringLiteral( "%1 %2\n" ).arg( QgsRasterBlock::printValue( x ),
-                 QgsRasterBlock::printValue( y ) );
+  QString coor = QStringLiteral( "%1 %2\n" ).arg( QgsRasterBlock::printValue( x ), QgsRasterBlock::printValue( y ) );
   QgsDebugMsgLevel( "coor : " + coor, 2 );
   mProcess->write( coor.toLatin1() ); // how to flush, necessary?
   mProcess->waitForReadyRead();
@@ -684,10 +674,9 @@ double QgsGrassRasterValue::value( double x, double y, bool *ok )
   QStringList list = str.trimmed().split( ':' );
   if ( list.size() == 2 )
   {
-    if ( list[1] == QLatin1String( "error" ) ) return value;
+    if ( list[1] == QLatin1String( "error" ) )
+      return value;
     value = list[1].toDouble( ok );
   }
   return value;
 }
-
-
