@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsoracleconn.h"
+#include "moc_qgsoracleconn.cpp"
 #include "qgslogger.h"
 #include "qgsdatasourceuri.h"
 #include "qgsmessagelog.h"
@@ -37,6 +38,7 @@ QMap<QString, QDateTime> QgsOracleConn::sBrokenConnections;
 QgsOracleConn *QgsOracleConn::connectDb( const QgsDataSourceUri &uri, bool transaction )
 {
   const QString conninfo = toPoolName( uri );
+  QgsDebugMsgLevel( QStringLiteral( "Trying to connect to %1 (in transaction: %2)" ).arg( conninfo ).arg( transaction ? QStringLiteral( "YES" ) : QStringLiteral( "NO" ) ), 2 );
   const QPair<QString, QThread *> connInfoThread( conninfo, QThread::currentThread() );
 
   if ( !transaction )
@@ -49,16 +51,19 @@ QgsOracleConn *QgsOracleConn::connectDb( const QgsDataSourceUri &uri, bool trans
     }
   }
 
+  QgsDebugMsgLevel( QStringLiteral( "Making new connection" ), 2 );
   QgsOracleConn *conn = new QgsOracleConn( uri, transaction );
 
   if ( conn->mRef == 0 )
   {
+    QgsDebugMsgLevel( QStringLiteral( "Connection has no references, deleting..." ), 2 );
     delete conn;
     return nullptr;
   }
 
   if ( !transaction )
   {
+    QgsDebugMsgLevel( QStringLiteral( "Storing connection for this thread" ), 2 );
     sConnections.insert( connInfoThread, conn );
   }
 
@@ -75,7 +80,7 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
 
   // will be used for logging and access connection from connection pool by name,
   // so we don't want login/password here
-  mConnInfo = uri.connectionInfo( false );
+  mConnInfo = toPoolName( uri );
 
   uri = QgsDataSourceUri( uri.connectionInfo( true ) );
 
@@ -88,6 +93,7 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
   if ( mTransaction )
     options += ( !options.isEmpty() ? QStringLiteral( ";" ) : QString() ) + QStringLiteral( "COMMIT_ON_SUCCESS=false" );
   QString workspace = uri.hasParam( QStringLiteral( "dbworkspace" ) ) ? uri.param( QStringLiteral( "dbworkspace" ) ) : QString();
+  QgsDebugMsgLevel( QStringLiteral( "Using workspace %1" ).arg( workspace ), 2 );
   mDatabase.setConnectOptions( options );
   mDatabase.setUserName( uri.username() );
   mDatabase.setPassword( uri.password() );
@@ -98,7 +104,7 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
   if ( sBrokenConnections.contains( mConnInfo ) )
   {
     QDateTime now( QDateTime::currentDateTime() );
-    QDateTime since( sBrokenConnections[ mConnInfo ] );
+    QDateTime since( sBrokenConnections[mConnInfo] );
     QgsDebugError( QStringLiteral( "Broken since %1 [%2s ago]" ).arg( since.toString( Qt::ISODate ) ).arg( since.secsTo( now ) ) );
 
     if ( since.secsTo( now ) < 30 )
@@ -155,8 +161,7 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
   }
 
   QSqlQuery qry( mDatabase );
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "alter session set nls_date_format = 'yyyy-mm-dd\"T\"HH24:MI:ss'" ),
-                           QVariantList() ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "alter session set nls_date_format = 'yyyy-mm-dd\"T\"HH24:MI:ss'" ), QVariantList() ) )
   {
     mDatabase.close();
     const QString error { tr( "Error: Failed to switch the default format date to ISO" ) };
@@ -241,7 +246,12 @@ QString QgsOracleConn::getLastExecutedQuery( const QSqlQuery &query )
   for ( QVariant value : query.boundValues() )
   {
     const QVariant &var { value.toString() };
-    QSqlField field( QString( ), var.type() );
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
+    QSqlField field( QString(), var.type() );
+#else
+    QSqlField field( QString(), var.metaType() );
+#endif
+
     if ( var.isNull() )
     {
       field.clear();
@@ -277,12 +287,10 @@ bool QgsOracleConn::exec( QSqlQuery &qry, const QString &sql, const QVariantList
   if ( !res )
   {
     QgsDebugError( QStringLiteral( "SQL: %1\nERROR: %2" )
-                   .arg( qry.lastQuery(),
-                         qry.lastError().text() ) );
+                     .arg( qry.lastQuery(), qry.lastError().text() ) );
   }
 
   return res;
-
 }
 
 bool QgsOracleConn::execLogged( QSqlQuery &qry, const QString &sql, const QVariantList &params, const QString &originatorClass, const QString &queryOrigin )
@@ -309,8 +317,7 @@ bool QgsOracleConn::execLogged( QSqlQuery &qry, const QString &sql, const QVaria
   {
     logWrapper.setError( qry.lastError().text() );
     QgsDebugError( QStringLiteral( "SQL: %1\nERROR: %2" )
-                   .arg( qry.lastQuery(),
-                         qry.lastError().text() ) );
+                     .arg( qry.lastQuery(), qry.lastError().text() ) );
   }
   else
   {
@@ -333,8 +340,7 @@ QStringList QgsOracleConn::pkCandidates( const QString &ownerName, const QString
 
   QSqlQuery qry( mDatabase );
 
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name FROM all_tab_columns WHERE owner=? AND table_name=? ORDER BY column_id" ),
-                           QVariantList() << ownerName << viewName ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name FROM all_tab_columns WHERE owner=? AND table_name=? ORDER BY column_id" ), QVariantList() << ownerName << viewName ) )
   {
     const QString error { tr( "SQL: %1 [owner: %2 table_name: %3]\nerror: %4\n" ).arg( qry.lastQuery(), qry.lastError().text(), ownerName, viewName ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
@@ -360,17 +366,12 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
   QString sql;
 
   QString prefix( userTablesOnly ? QStringLiteral( "user" ) : QStringLiteral( "all" ) ),
-          owner( userTablesOnly ? QStringLiteral( "user AS owner" ) : QStringLiteral( "c.owner" ) );
+    owner( userTablesOnly ? QStringLiteral( "user AS owner" ) : QStringLiteral( "c.owner" ) );
 
   sql = QStringLiteral( "SELECT %1,c.table_name,c.column_name,%2,o.object_type AS type"
                         " FROM %3_%4 c"
                         " JOIN %3_objects o ON c.table_name=o.object_name AND o.object_type IN ('TABLE','VIEW','SYNONYM')%5%6" )
-        .arg( owner,
-              geometryColumnsOnly ? QStringLiteral( "c.srid" ) : QStringLiteral( "NULL AS srid" ),
-              prefix,
-              geometryColumnsOnly ? QStringLiteral( "sdo_geom_metadata" ) : QStringLiteral( "tab_columns" ),
-              userTablesOnly ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( schema.isEmpty() ? QStringLiteral( "o.owner" ) : quotedValue( schema ) ),
-              geometryColumnsOnly ? QString() : QStringLiteral( " WHERE c.data_type='SDO_GEOMETRY'" ) );
+          .arg( owner, geometryColumnsOnly ? QStringLiteral( "c.srid" ) : QStringLiteral( "NULL AS srid" ), prefix, geometryColumnsOnly ? QStringLiteral( "sdo_geom_metadata" ) : QStringLiteral( "tab_columns" ), userTablesOnly ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( schema.isEmpty() ? QStringLiteral( "o.owner" ) : quotedValue( schema ) ), geometryColumnsOnly ? QString() : QStringLiteral( " WHERE c.data_type='SDO_GEOMETRY'" ) );
 
   if ( allowGeometrylessTables )
   {
@@ -379,9 +380,7 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
                            " FROM %2_objects c WHERE c.object_type IN ('TABLE','VIEW','SYNONYM') "
                            // get only geometry table without geometry column
                            " AND NOT EXISTS( SELECT 1 FROM %2_tab_columns cols WHERE cols.table_name=c.object_name AND cols.data_type='SDO_GEOMETRY') %3" )
-           .arg( owner,
-                 prefix,
-                 userTablesOnly || schema.isEmpty() ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( quotedValue( schema ) ) );
+             .arg( owner, prefix, userTablesOnly || schema.isEmpty() ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( quotedValue( schema ) ) );
   }
 
   QSqlQuery qry( mDatabase );
@@ -396,16 +395,15 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
   while ( qry.next() )
   {
     QgsOracleLayerProperty layerProperty;
-    layerProperty.ownerName       = qry.value( 0 ).toString();
-    layerProperty.tableName       = qry.value( 1 ).toString();
+    layerProperty.ownerName = qry.value( 0 ).toString();
+    layerProperty.tableName = qry.value( 1 ).toString();
     layerProperty.geometryColName = qry.value( 2 ).toString();
-    layerProperty.types           = QList<Qgis::WkbType>() << ( qry.value( 2 ).isNull() ? Qgis::WkbType::NoGeometry : Qgis::WkbType::Unknown );
-    layerProperty.srids           = QList<int>() << qry.value( 3 ).toInt();
-    layerProperty.isView          = qry.value( 4 ) != QLatin1String( "TABLE" );
+    layerProperty.types = QList<Qgis::WkbType>() << ( qry.value( 2 ).isNull() ? Qgis::WkbType::NoGeometry : Qgis::WkbType::Unknown );
+    layerProperty.srids = QList<int>() << qry.value( 3 ).toInt();
+    layerProperty.isView = qry.value( 4 ) != QLatin1String( "TABLE" );
     layerProperty.pkCols.clear();
 
     mLayersSupported << layerProperty;
-
   }
 
 
@@ -440,24 +438,24 @@ QString QgsOracleConn::quotedIdentifier( QString ident )
   return ident;
 }
 
-QString QgsOracleConn::quotedValue( const QVariant &value, QVariant::Type type )
+QString QgsOracleConn::quotedValue( const QVariant &value, QMetaType::Type type )
 {
   if ( value.isNull() )
     return QStringLiteral( "NULL" );
 
-  if ( type == QVariant::Invalid )
-    type = value.type();
+  if ( type == QMetaType::Type::UnknownType )
+    type = static_cast<QMetaType::Type>( value.userType() );
 
   if ( value.canConvert( type ) )
   {
     switch ( type )
     {
-      case QVariant::Int:
-      case QVariant::LongLong:
-      case QVariant::Double:
+      case QMetaType::Type::Int:
+      case QMetaType::Type::LongLong:
+      case QMetaType::Type::Double:
         return value.toString();
 
-      case QVariant::DateTime:
+      case QMetaType::Type::QDateTime:
       {
         QDateTime datetime( value.toDateTime() );
         if ( datetime.isValid() )
@@ -465,7 +463,7 @@ QString QgsOracleConn::quotedValue( const QVariant &value, QVariant::Type type )
         break;
       }
 
-      case QVariant::Date:
+      case QMetaType::Type::QDate:
       {
         QDate date( value.toDate() );
         if ( date.isValid() )
@@ -473,7 +471,7 @@ QString QgsOracleConn::quotedValue( const QVariant &value, QVariant::Type type )
         break;
       }
 
-      case QVariant::Time:
+      case QMetaType::Type::QTime:
       {
         QDateTime datetime( value.toDateTime() );
         if ( datetime.isValid() )
@@ -505,14 +503,13 @@ bool QgsOracleConn::exec( const QString &query, bool logError, QString *errorMes
     if ( logError )
     {
       const QString errorMsg { tr( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
-      QgsMessageLog::logMessage( errorMsg,
-                                 tr( "Oracle" ) );
+                                 .arg( query, error ) };
+      QgsMessageLog::logMessage( errorMsg, tr( "Oracle" ) );
     }
     else
     {
       const QString errorMsg { QStringLiteral( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
+                                 .arg( query, error ) };
       QgsDebugError( errorMsg );
     }
     if ( errorMessage )
@@ -524,7 +521,6 @@ bool QgsOracleConn::exec( const QString &query, bool logError, QString *errorMes
 
 bool QgsOracleConn::execLogged( const QString &query, bool logError, QString *errorMessage, const QString &originatorClass, const QString &queryOrigin )
 {
-
   QMutexLocker locker( &mLock );
   QgsDatabaseQueryLogWrapper logWrapper { query, mConnInfo, QStringLiteral( "oracle" ), originatorClass, queryOrigin };
 
@@ -536,21 +532,20 @@ bool QgsOracleConn::execLogged( const QString &query, bool logError, QString *er
 
   logWrapper.setQuery( qry.lastQuery() );
 
-  if ( ! res )
+  if ( !res )
   {
     const QString error = qry.lastError().text();
     logWrapper.setError( error );
     if ( logError )
     {
       const QString errorMsg { tr( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
-      QgsMessageLog::logMessage( errorMsg,
-                                 tr( "Oracle" ) );
+                                 .arg( query, error ) };
+      QgsMessageLog::logMessage( errorMsg, tr( "Oracle" ) );
     }
     else
     {
       const QString errorMsg { QStringLiteral( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
+                                 .arg( query, error ) };
       QgsDebugError( errorMsg );
     }
     if ( errorMessage )
@@ -656,9 +651,7 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
     layerProperty.pkCols = pkCandidates( layerProperty.ownerName, layerProperty.tableName );
     if ( layerProperty.pkCols.isEmpty() )
     {
-      QgsMessageLog::logMessage( tr( "View %1.%2 doesn't have integer columns for use as keys." )
-                                 .arg( layerProperty.ownerName, layerProperty.tableName ),
-                                 tr( "Oracle" ) );
+      QgsMessageLog::logMessage( tr( "View %1.%2 doesn't have integer columns for use as keys." ).arg( layerProperty.ownerName, layerProperty.tableName ), tr( "Oracle" ) );
     }
   }
 
@@ -671,17 +664,13 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
   if ( useEstimatedMetadata )
   {
     table = QStringLiteral( "(SELECT %1 FROM %2.%3 WHERE %1 IS NOT NULL%4 AND rownum<=%5)" )
-            .arg( quotedIdentifier( layerProperty.geometryColName ),
-                  quotedIdentifier( layerProperty.ownerName ),
-                  quotedIdentifier( layerProperty.tableName ),
-                  layerProperty.sql.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( layerProperty.sql ) )
-            .arg( sGeomTypeSelectLimit );
+              .arg( quotedIdentifier( layerProperty.geometryColName ), quotedIdentifier( layerProperty.ownerName ), quotedIdentifier( layerProperty.tableName ), layerProperty.sql.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( layerProperty.sql ) )
+              .arg( sGeomTypeSelectLimit );
   }
   else if ( !layerProperty.ownerName.isEmpty() )
   {
     table = QStringLiteral( "%1.%2" )
-            .arg( quotedIdentifier( layerProperty.ownerName ),
-                  quotedIdentifier( layerProperty.tableName ) );
+              .arg( quotedIdentifier( layerProperty.ownerName ), quotedIdentifier( layerProperty.tableName ) );
     where = layerProperty.sql;
   }
   else
@@ -715,16 +704,11 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
 
   sql += QLatin1String( " FROM %2 t WHERE NOT t.%1 IS NULL%3" );
 
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql
-                           .arg( quotedIdentifier( layerProperty.geometryColName ),
-                                 table,
-                                 where.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( where ) ), QVariantList() ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql.arg( quotedIdentifier( layerProperty.geometryColName ), table, where.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( where ) ), QVariantList() ) )
   {
     const QString error { tr( "SQL: %1\nerror: %2\n" )
-                          .arg( qry.lastQuery(),
-                                qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( qry.lastQuery(), qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return;
   }
 
@@ -739,10 +723,7 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
       Qgis::WkbType type = wkbTypeFromDatabase( qry.value( 0 ).toInt() );
       if ( type == Qgis::WkbType::Unknown )
       {
-        QgsMessageLog::logMessage( tr( "Unsupported geometry type %1 in %2.%3.%4 ignored" )
-                                   .arg( qry.value( 0 ).toInt() )
-                                   .arg( layerProperty.ownerName, layerProperty.tableName,  layerProperty.geometryColName ),
-                                   tr( "Oracle" ) );
+        QgsMessageLog::logMessage( tr( "Unsupported geometry type %1 in %2.%3.%4 ignored" ).arg( qry.value( 0 ).toInt() ).arg( layerProperty.ownerName, layerProperty.tableName, layerProperty.geometryColName ), tr( "Oracle" ) );
         continue;
       }
       QgsDebugMsgLevel( QStringLiteral( "add type %1" ).arg( qgsEnumValueToKey( type ) ), 2 );
@@ -916,20 +897,53 @@ void QgsOracleConn::deleteConnection( const QString &connName )
   settings.remove( key + QStringLiteral( "/host" ) );
   settings.remove( key + QStringLiteral( "/port" ) );
   settings.remove( key + QStringLiteral( "/database" ) );
+  settings.remove( key + QStringLiteral( "/schema" ) );
   settings.remove( key + QStringLiteral( "/username" ) );
   settings.remove( key + QStringLiteral( "/password" ) );
+  settings.remove( key + QStringLiteral( "/authcfg" ) );
+  settings.remove( key + QStringLiteral( "/dboptions" ) );
+  settings.remove( key + QStringLiteral( "/dbworkspace" ) );
   settings.remove( key + QStringLiteral( "/userTablesOnly" ) );
   settings.remove( key + QStringLiteral( "/geometryColumnsOnly" ) );
   settings.remove( key + QStringLiteral( "/allowGeometrylessTables" ) );
   settings.remove( key + QStringLiteral( "/estimatedMetadata" ) );
   settings.remove( key + QStringLiteral( "/onlyExistingTypes" ) );
   settings.remove( key + QStringLiteral( "/includeGeoAttributes" ) );
+  settings.remove( key + QStringLiteral( "/projectsInDatabase" ) );
   settings.remove( key + QStringLiteral( "/saveUsername" ) );
   settings.remove( key + QStringLiteral( "/savePassword" ) );
   settings.remove( key + QStringLiteral( "/save" ) );
   settings.remove( key );
 }
 
+void QgsOracleConn::duplicateConnection( const QString &src, const QString &dst )
+{
+  const QString key( QStringLiteral( "/Oracle/connections/" ) + src );
+  const QString newKey( QStringLiteral( "/Oracle/connections/" ) + dst );
+
+  QgsSettings settings;
+  settings.setValue( newKey + QStringLiteral( "/host" ), settings.value( key + QStringLiteral( "/host" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/port" ), settings.value( key + QStringLiteral( "/port" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/database" ), settings.value( key + QStringLiteral( "/database" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/schema" ), settings.value( key + QStringLiteral( "/schema" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/username" ), settings.value( key + QStringLiteral( "/username" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/password" ), settings.value( key + QStringLiteral( "/password" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/authcfg" ), settings.value( key + QStringLiteral( "/authcfg" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/dboptions" ), settings.value( key + QStringLiteral( "/dboptions" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/dbworkspace" ), settings.value( key + QStringLiteral( "/dbworkspace" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/userTablesOnly" ), settings.value( key + QStringLiteral( "/userTablesOnly" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/geometryColumnsOnly" ), settings.value( key + QStringLiteral( "/geometryColumnsOnly" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/allowGeometrylessTables" ), settings.value( key + QStringLiteral( "/allowGeometrylessTables" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/estimatedMetadata" ), settings.value( key + QStringLiteral( "/estimatedMetadata" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/onlyExistingTypes" ), settings.value( key + QStringLiteral( "/onlyExistingTypes" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/includeGeoAttributes" ), settings.value( key + QStringLiteral( "/includeGeoAttributes" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/projectsInDatabase" ), settings.value( key + QStringLiteral( "/projectsInDatabase" ) ).toBool() );
+  settings.setValue( newKey + QStringLiteral( "/saveUsername" ), settings.value( key + QStringLiteral( "/saveUsername" ) ).toString() );
+  settings.setValue( newKey + QStringLiteral( "/savePassword" ), settings.value( key + QStringLiteral( "/savePassword" ) ).toString() );
+
+  settings.sync();
+}
+
 QString QgsOracleConn::selectedConnection()
 {
   QgsSettings settings;
@@ -986,7 +1000,7 @@ QgsDataSourceUri QgsOracleConn::connUri( const QString &connName )
     uri.setParam( QStringLiteral( "dbworkspace" ), settings.value( key + QStringLiteral( "/dbworkspace" ) ).toString() );
   }
 
-  QString authcfg = settings.value( key + "/authcfg" ).toString();
+  QString authcfg = settings.value( key + QStringLiteral( "/authcfg" ) ).toString();
   if ( !authcfg.isEmpty() )
   {
     uri.setAuthConfigId( authcfg );
@@ -1004,37 +1018,37 @@ bool QgsOracleConn::userTablesOnly( const QString &connName )
 QString QgsOracleConn::restrictToSchema( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/schema" ).toString();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/schema" ) ).toString();
 }
 
 bool QgsOracleConn::geometryColumnsOnly( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/geometryColumnsOnly", true ).toBool();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/geometryColumnsOnly" ), true ).toBool();
 }
 
 bool QgsOracleConn::allowGeometrylessTables( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/allowGeometrylessTables", false ).toBool();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/allowGeometrylessTables" ), false ).toBool();
 }
 
 bool QgsOracleConn::allowProjectsInDatabase( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/projectsInDatabase", false ).toBool();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/projectsInDatabase" ), false ).toBool();
 }
 
 bool QgsOracleConn::estimatedMetadata( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/estimatedMetadata", false ).toBool();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/estimatedMetadata" ), false ).toBool();
 }
 
 bool QgsOracleConn::onlyExistingTypes( const QString &connName )
 {
   QgsSettings settings;
-  return settings.value( "/Oracle/connections/" + connName + "/onlyExistingTypes", false ).toBool();
+  return settings.value( QStringLiteral( "/Oracle/connections/" ) + connName + QStringLiteral( "/onlyExistingTypes" ), false ).toBool();
 }
 
 QString QgsOracleConn::databaseName( const QString &database, const QString &host, const QString &port )
@@ -1087,8 +1101,8 @@ int QgsOracleConn::version()
   else
   {
     const QString error { tr( "Unable to execute the query.\nThe error message from the database was:\n%1.\nSQL: %2" )
-                          .arg( qry.lastError().text() )
-                          .arg( qry.lastQuery() ) };
+                            .arg( qry.lastError().text() )
+                            .arg( qry.lastQuery() ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return -1;
   }
@@ -1115,23 +1129,23 @@ QList<QgsVectorDataProvider::NativeType> QgsOracleConn::nativeTypes()
 {
   return QList<QgsVectorDataProvider::NativeType>()
          // integer types
-         << QgsVectorDataProvider::NativeType( tr( "Whole Number" ), "number(10,0)", QVariant::Int )
-         << QgsVectorDataProvider::NativeType( tr( "Whole Big Number" ), "number(20,0)", QVariant::LongLong )
-         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (numeric)" ), "number", QVariant::Double, 1, 38, 0, 38 )
-         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (decimal)" ), "double precision", QVariant::Double )
+         << QgsVectorDataProvider::NativeType( tr( "Whole Number" ), "number(10,0)", QMetaType::Type::Int )
+         << QgsVectorDataProvider::NativeType( tr( "Whole Big Number" ), "number(20,0)", QMetaType::Type::LongLong )
+         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (numeric)" ), "number", QMetaType::Type::Double, 1, 38, 0, 38 )
+         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (decimal)" ), "double precision", QMetaType::Type::Double )
 
          // floating point
-         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), "binary_float", QVariant::Double )
-         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (double)" ), "binary_double", QVariant::Double )
+         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), "binary_float", QMetaType::Type::Double )
+         << QgsVectorDataProvider::NativeType( tr( "Decimal Number (double)" ), "binary_double", QMetaType::Type::Double )
 
          // string types
-         << QgsVectorDataProvider::NativeType( tr( "Text, fixed length (char)" ), "CHAR", QVariant::String, 1, 255 )
-         << QgsVectorDataProvider::NativeType( tr( "Text, limited variable length (varchar2)" ), "VARCHAR2", QVariant::String, 1, 255 )
-         << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (long)" ), "LONG", QVariant::String )
+         << QgsVectorDataProvider::NativeType( tr( "Text, fixed length (char)" ), "CHAR", QMetaType::Type::QString, 1, 255 )
+         << QgsVectorDataProvider::NativeType( tr( "Text, limited variable length (varchar2)" ), "VARCHAR2", QMetaType::Type::QString, 1, 255 )
+         << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (long)" ), "LONG", QMetaType::Type::QString )
 
          // date type
-         << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Date ), "DATE", QVariant::Date, 38, 38, 0, 0 )
-         << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::DateTime ), "TIMESTAMP(6)", QVariant::DateTime, 38, 38, 6, 6 );
+         << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDate ), "DATE", QMetaType::Type::QDate, 38, 38, 0, 0 )
+         << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDateTime ), "TIMESTAMP(6)", QMetaType::Type::QDateTime, 38, 38, 6, 6 );
 }
 
 QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QString &tableName, const QString &geometryColumn, bool &isValid )
@@ -1141,9 +1155,9 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
   QSqlQuery qry( mDatabase );
 
   if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT i.index_name,i.domidx_opstatus"
-                          " FROM all_indexes i"
-                          " JOIN all_ind_columns c ON i.owner=c.index_owner AND i.index_name=c.index_name AND c.column_name=?"
-                          " WHERE i.table_owner=? AND i.table_name=? AND i.ityp_owner='MDSYS' AND i.ityp_name='SPATIAL_INDEX'" ),
+                                                                                  " FROM all_indexes i"
+                                                                                  " JOIN all_ind_columns c ON i.owner=c.index_owner AND i.index_name=c.index_name AND c.column_name=?"
+                                                                                  " WHERE i.table_owner=? AND i.table_name=? AND i.ityp_owner='MDSYS' AND i.ityp_name='SPATIAL_INDEX'" ),
                           QVariantList() << geometryColumn << ownerName << tableName ) )
   {
     if ( qry.next() )
@@ -1151,12 +1165,7 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
       name = qry.value( 0 ).toString();
       if ( qry.value( 1 ).toString() != "VALID" )
       {
-        QgsMessageLog::logMessage( tr( "Invalid spatial index %1 on column %2.%3.%4 found - expect poor performance." )
-                                   .arg( name )
-                                   .arg( ownerName )
-                                   .arg( tableName )
-                                   .arg( geometryColumn ),
-                                   tr( "Oracle" ) );
+        QgsMessageLog::logMessage( tr( "Invalid spatial index %1 on column %2.%3.%4 found - expect poor performance." ).arg( name ).arg( ownerName ).arg( tableName ).arg( geometryColumn ), tr( "Oracle" ) );
         isValid = false;
       }
       else
@@ -1173,12 +1182,11 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
   else
   {
     const QString error { tr( "Probing for spatial index on column %1.%2.%3 failed [%4]" )
-                          .arg( ownerName )
-                          .arg( tableName )
-                          .arg( geometryColumn )
-                          .arg( qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( ownerName )
+                            .arg( tableName )
+                            .arg( geometryColumn )
+                            .arg( qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
 
     isValid = false;
   }
@@ -1193,24 +1201,22 @@ QString QgsOracleConn::createSpatialIndex( const QString &ownerName, const QStri
   int n = 0;
   const QString sql { QStringLiteral( "SELECT coalesce(substr(max(index_name),10),'0') FROM all_indexes WHERE index_name LIKE 'QGIS_IDX_%' ESCAPE '#' ORDER BY index_name" ) };
 
-  if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql, QVariantList() ) &&
-       qry.next() )
+  if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql, QVariantList() ) && qry.next() )
   {
     n = qry.value( 0 ).toInt() + 1;
   }
 
   const QString sql2 { QStringLiteral( "CREATE INDEX QGIS_IDX_%1 ON %2.%3(%4) INDEXTYPE IS MDSYS.SPATIAL_INDEX PARALLEL" )
-                       .arg( n, 10, 10, QChar( '0' ) )
-                       .arg( quotedIdentifier( ownerName ) )
-                       .arg( quotedIdentifier( tableName ) )
-                       .arg( quotedIdentifier( geometryColumn ) ) };
+                         .arg( n, 10, 10, QChar( '0' ) )
+                         .arg( quotedIdentifier( ownerName ) )
+                         .arg( quotedIdentifier( tableName ) )
+                         .arg( quotedIdentifier( geometryColumn ) ) };
   if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql2, QVariantList() ) )
   {
     const QString error { tr( "Creation spatial index failed.\nSQL: %1\nError: %2" )
-                          .arg( qry.lastQuery() )
-                          .arg( qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( qry.lastQuery() )
+                            .arg( qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return QString();
   }
 
@@ -1224,14 +1230,14 @@ QStringList QgsOracleConn::getPrimaryKeys( const QString &ownerName, const QStri
   QStringList result;
 
   if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name"
-                           " FROM all_cons_columns a"
-                           " JOIN all_constraints b ON a.constraint_name=b.constraint_name AND a.owner=b.owner"
-                           " WHERE b.constraint_type='P' AND b.owner=? AND b.table_name=?" ),
+                                                                                   " FROM all_cons_columns a"
+                                                                                   " JOIN all_constraints b ON a.constraint_name=b.constraint_name AND a.owner=b.owner"
+                                                                                   " WHERE b.constraint_type='P' AND b.owner=? AND b.table_name=?" ),
                            QVariantList() << ownerName << tableName ) )
   {
     const QString error { tr( "Unable to execute the query.\nThe error message from the database was:\n%1.\nSQL: %2" )
-                          .arg( qry.lastError().text() )
-                          .arg( qry.lastQuery() ) };
+                            .arg( qry.lastError().text() )
+                            .arg( qry.lastQuery() ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return result;
   }
