@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgspdalindexingtask.h"
+#include "moc_qgspdalindexingtask.cpp"
 
 #include <vector>
 #include <string>
@@ -28,11 +29,10 @@
 #include "qgsmessagelog.h"
 #include "qgis.h"
 
-QgsPdalIndexingTask::QgsPdalIndexingTask( const QString &file, const QString &outputPath, OutputFormat outputFormat, const QString &name )
+QgsPdalIndexingTask::QgsPdalIndexingTask( const QString &file, const QString &outputPath, const QString &name )
   : QgsTask( tr( "Indexing Point Cloud (%1)" ).arg( name ) )
   , mOutputPath( outputPath )
   , mFile( file )
-  , mOutputFormat( outputFormat )
 {
   mUntwineExecutableBinary = guessUntwineExecutableBinary();
 }
@@ -55,16 +55,7 @@ bool QgsPdalIndexingTask::run()
 
 void QgsPdalIndexingTask::cleanTemp()
 {
-  QDir tmpDir;
-  switch ( mOutputFormat )
-  {
-    case QgsPdalIndexingTask::OutputFormat::Ept:
-      tmpDir.setPath( mOutputPath + QDir::separator() + QStringLiteral( "tmp" ) );
-      break;
-    case QgsPdalIndexingTask::OutputFormat::Copc:
-      tmpDir.setPath( mOutputPath + QStringLiteral( "_tmp" ) );
-      break;
-  }
+  QDir tmpDir( mOutputPath + QStringLiteral( "_tmp" ) );
 
   if ( tmpDir.exists() )
   {
@@ -92,15 +83,12 @@ bool QgsPdalIndexingTask::runUntwine()
   // By default Untwine does not calculate stats for attributes, but they are very useful for us:
   // we can use them to set automatically set valid range for the data without having to scan the points again.
   options.push_back( { "stats", std::string() } );
-  if ( mOutputFormat == OutputFormat::Copc )
-  {
-    // By default Untwine will generate an ept dataset, we use single_file flag to generate COPC files
-    options.push_back( { "single_file", std::string() } );
-  }
+  // By default Untwine will generate an ept dataset, we use single_file flag to generate COPC files
+  options.push_back( { "single_file", std::string() } );
 
-  const std::vector<std::string> files = {mFile.toStdString()};
+  const std::vector<std::string> files = { mFile.toStdString() };
   untwineProcess.start( files, mOutputPath.toStdString(), options );
-  const int lastPercent = 0;
+  int lastPercent = 0;
   while ( true )
   {
     QThread::msleep( 100 );
@@ -115,6 +103,7 @@ bool QgsPdalIndexingTask::runUntwine()
       }
 #endif
       setProgress( percent );
+      lastPercent = percent;
     }
 
     if ( isCanceled() )
@@ -155,7 +144,7 @@ QString QgsPdalIndexingTask::guessUntwineExecutableBinary() const
   QString untwineExecutable = QProcessEnvironment::systemEnvironment().value( QStringLiteral( "QGIS_UNTWINE_EXECUTABLE" ) );
   if ( untwineExecutable.isEmpty() )
   {
-#if defined(Q_OS_WIN)
+#if defined( Q_OS_WIN )
     untwineExecutable = QgsApplication::libexecPath() + "untwine.exe";
 #else
     untwineExecutable = QgsApplication::libexecPath() + "untwine";
@@ -171,60 +160,17 @@ QString QgsPdalIndexingTask::outputPath() const
 
 bool QgsPdalIndexingTask::prepareOutputPath()
 {
-  switch ( mOutputFormat )
+  const QFileInfo fi( mOutputPath );
+  if ( fi.exists() )
   {
-    case OutputFormat::Ept:
-    {
-      const QFileInfo fi( mOutputPath + "/ept.json" );
-      if ( fi.exists() )
-      {
-        QgsMessageLog::logMessage( tr( "File %1 is already indexed" ).arg( mFile ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Info );
-        return true;
-      }
-      if ( QDir( mOutputPath ).exists() )
-      {
-        if ( !QDir( mOutputPath ).isEmpty() )
-        {
-          if ( QDir( mOutputPath + "/temp" ).exists() )
-          {
-            QgsMessageLog::logMessage( tr( "Another indexing process is running (or finished with crash) in directory %1" ).arg( mOutputPath ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Warning );
-            return false;
-          }
-          else
-          {
-            QgsMessageLog::logMessage( tr( "Folder %1 is non-empty, but there isn't ept.json present." ).arg( mOutputPath ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Critical );
-            return false;
-          }
-        }
-        else
-        {
-          // untwine expects that the output directory does not exist at all
-          if ( !QDir().rmdir( mOutputPath ) )
-          {
-            QgsMessageLog::logMessage( tr( "Failed to remove empty directory %1" ).arg( mOutputPath ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Critical );
-            return false;
-          }
-        }
-      }
-      break;
-    }
-    case OutputFormat::Copc:
-    {
-      const QFileInfo fi( mOutputPath );
-      if ( fi.exists() )
-      {
-        QgsMessageLog::logMessage( tr( "File %1 is already indexed" ).arg( mFile ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Info );
-        return true;
-      }
-      QString tmpDir = mOutputPath + QStringLiteral( "_tmp" );
-      if ( QDir( tmpDir ).exists() )
-      {
-        QgsMessageLog::logMessage( tr( "Another indexing process is running (or finished with crash) in directory %1" ).arg( mOutputPath ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Warning );
-        return false;
-      }
-      break;
-    }
+    QgsMessageLog::logMessage( tr( "File %1 is already indexed" ).arg( mFile ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Info );
+    return true;
+  }
+  QString tmpDir = mOutputPath + QStringLiteral( "_tmp" );
+  if ( QDir( tmpDir ).exists() )
+  {
+    QgsMessageLog::logMessage( tr( "Another indexing process is running (or finished with crash) in directory %1" ).arg( mOutputPath ), QObject::tr( "Point clouds" ), Qgis::MessageLevel::Warning );
+    return false;
   }
   return true;
 }
-
