@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgspostgresconnpool.h"
+#include "moc_qgspostgresconnpool.cpp"
 #include "qgspostgresconn.h"
 #include "qgslogger.h"
 
@@ -32,7 +33,8 @@ void QgsPostgresConnPool::cleanupInstance()
   sInstance = nullptr;
 }
 
-QgsPostgresConnPool::QgsPostgresConnPool() : QgsConnectionPool<QgsPostgresConn *, QgsPostgresConnPoolGroup>()
+QgsPostgresConnPool::QgsPostgresConnPool()
+  : QgsConnectionPool<QgsPostgresConn *, QgsPostgresConnPoolGroup>()
 {
   QgsDebugCall;
 }
@@ -41,4 +43,3 @@ QgsPostgresConnPool::~QgsPostgresConnPool()
 {
   QgsDebugCall;
 }
-
