@@ -28,7 +28,6 @@
 class QgsSpatialiteSourceSelectProvider : public QgsSourceSelectProvider
 {
   public:
-
     QString providerKey() const override { return QStringLiteral( "spatialite" ); }
     QString text() const override { return QObject::tr( "SpatiaLite" ); }
     int ordering() const override { return QgsSourceSelectProvider::OrderDatabaseProvider + 10; }
@@ -37,8 +36,12 @@ class QgsSpatialiteSourceSelectProvider : public QgsSourceSelectProvider
     {
       return new QgsSpatiaLiteSourceSelect( parent, fl, widgetMode );
     }
-};
 
+    QgsSourceSelectProvider::Capabilities capabilities() override
+    {
+      return QgsSourceSelectProvider::Capability::ConfigureFromUri;
+    }
+};
 
 
 QgsSpatiaLiteProviderGuiMetadata::QgsSpatiaLiteProviderGuiMetadata()
