@@ -32,7 +32,22 @@ void QgsFilterResponseDecorator::start()
   QgsServerFiltersMap::const_iterator filtersIterator;
   for ( filtersIterator = mFilters.constBegin(); filtersIterator != mFilters.constEnd(); ++filtersIterator )
   {
-    if ( ! filtersIterator.value()->onRequestReady() )
+    if ( !filtersIterator.value()->onRequestReady() )
+    {
+      // stop propagation
+      return;
+    }
+  }
+#endif
+}
+
+void QgsFilterResponseDecorator::ready()
+{
+#ifdef HAVE_SERVER_PYTHON_PLUGINS
+  QgsServerFiltersMap::const_iterator filtersIterator;
+  for ( filtersIterator = mFilters.constBegin(); filtersIterator != mFilters.constEnd(); ++filtersIterator )
+  {
+    if ( !filtersIterator.value()->onProjectReady() )
     {
       // stop propagation
       return;
@@ -47,7 +62,7 @@ void QgsFilterResponseDecorator::finish()
   QgsServerFiltersMap::const_iterator filtersIterator;
   for ( filtersIterator = mFilters.constBegin(); filtersIterator != mFilters.constEnd(); ++filtersIterator )
   {
-    if ( ! filtersIterator.value()->onResponseComplete() )
+    if ( !filtersIterator.value()->onResponseComplete() )
     {
       // stop propagation, 'finish' must be called on the wrapped
       // response
@@ -67,7 +82,7 @@ void QgsFilterResponseDecorator::flush()
 
   for ( filtersIterator = mFilters.constBegin(); filtersIterator != mFilters.constEnd(); ++filtersIterator )
   {
-    if ( ! filtersIterator.value()->onSendResponse() )
+    if ( !filtersIterator.value()->onSendResponse() )
     {
       // Stop propagation
       return;
@@ -76,5 +91,3 @@ void QgsFilterResponseDecorator::flush()
 #endif
   mResponse.flush();
 }
-
-
