@@ -22,34 +22,28 @@
 #ifndef QGSWFSDESCRIBEFEATURETYPE_H
 #define QGSWFSDESCRIBEFEATURETYPE_H
 
-
-#include <QDomDocument>
-#include <QDomElement>
-
 #include "qgsserverinterface.h"
 #include "qgswfsparameters.h"
 
+
 namespace QgsWfs
 {
 
   /**
-  * Returns the GML geometry type.
-  */
-  QString getGmlGeometryType( const QgsVectorLayer *layer, QgsWfsParameters::Format format );
-
-  void setSchemaLayer( QDomElement &parentElement, QDomDocument &doc, const QgsVectorLayer *layer, QgsWfsParameters::Format format );
+   * Helper for returning the field type and type name
+   */
+  void getFieldAttributes( const QgsField &field, QString &fieldName, QString &fieldType );
 
   /**
-   * Create get capabilities document
+   * Helper for returning typename list from the request
    */
-  QDomDocument createDescribeFeatureTypeDocument( QgsServerInterface *serverIface, const QgsProject *project, const QString &version,
-      const QgsServerRequest &request );
+  QStringList getRequestTypeNames( const QgsServerRequest &request, const QgsWfsParameters &wfsParams );
+
 
   /**
    * Output WFS  GetCapabilities response
    */
-  void writeDescribeFeatureType( QgsServerInterface *serverIface, const QgsProject *project, const QString &version,
-                                 const QgsServerRequest &request, QgsServerResponse &response );
+  void writeDescribeFeatureType( QgsServerInterface *serverIface, const QgsProject *project, const QString &version, const QgsServerRequest &request, QgsServerResponse &response );
 
 } // namespace QgsWfs
 
