@@ -47,19 +47,14 @@ namespace QgsWfs
     /**
      * Create get capabilities document
      */
-    QDomDocument createGetCapabilitiesDocument( QgsServerInterface *serverIface,
-        const QgsProject *project, const QString &version,
-        const QgsServerRequest &request );
+    QDomDocument createGetCapabilitiesDocument( QgsServerInterface *serverIface, const QgsProject *project, const QString &version, const QgsServerRequest &request );
 
     /**
      * Output WFS GetCapabilities response
      */
-    void writeGetCapabilities( QgsServerInterface *serverIface, const QgsProject *project,
-                               const QString &version, const QgsServerRequest &request,
-                               QgsServerResponse &response );
+    void writeGetCapabilities( QgsServerInterface *serverIface, const QgsProject *project, const QString &version, const QgsServerRequest &request, QgsServerResponse &response );
 
   } // namespace v1_0_0
 } // namespace QgsWfs
 
 #endif
-
