@@ -31,14 +31,12 @@ namespace QgsWms
    * \ingroup server
    * \class  QgsWms::QgsServiceException
    * \brief Exception class for WMS service exceptions.
-   * \since QGIS 3.0
    */
   class QgsServiceException : public QgsOgcServiceException
   {
       Q_GADGET
 
     public:
-
       /**
        * Exception codes as defined in OGC scpecifications for WMS 1.1.1 and
        * WMS 1.3.0. Some custom QGIS codes are defined too.
@@ -55,8 +53,8 @@ namespace QgsWms
         OGC_InvalidUpdateSequence,
         OGC_MissingDimensionValue,
         OGC_InvalidDimensionValue,
-        OGC_InvalidPoint, // new in WMS 1.3.0
-        OGC_InvalidCRS, // new in WMS 1.3.0
+        OGC_InvalidPoint,          // new in WMS 1.3.0
+        OGC_InvalidCRS,            // new in WMS 1.3.0
         OGC_OperationNotSupported, // new in WMS 1.3.0
         QGIS_MissingParameterValue,
         QGIS_InvalidParameterValue
@@ -70,8 +68,7 @@ namespace QgsWms
        * \param locator Locator attribute according to OGC specifications
        * \param responseCode HTTP error code
        */
-      QgsServiceException( const QString &code, const QString &message, const QString &locator = QString(),
-                           int responseCode = 200 )
+      QgsServiceException( const QString &code, const QString &message, const QString &locator = QString(), int responseCode = 200 )
         : QgsOgcServiceException( code, message, locator, responseCode, QStringLiteral( "1.3.0" ) )
       {}
 
@@ -187,12 +184,10 @@ namespace QgsWms
    * \ingroup server
    * \class  QgsWms::QgsSecurityException
    * \brief Exception thrown when data access violates access controls
-   * \since QGIS 3.0
    */
-  class QgsSecurityException: public QgsServiceException
+  class QgsSecurityException : public QgsServiceException
   {
     public:
-
       /**
        * Constructor for QgsSecurityException (HTTP error code 403 with
        * Security code name).
@@ -208,12 +203,10 @@ namespace QgsWms
    * \ingroup server
    * \class  QgsWms::QgsBadRequestException
    * \brief Exception thrown in case of malformed request
-   * \since QGIS 3.0
    */
-  class QgsBadRequestException: public QgsServiceException
+  class QgsBadRequestException : public QgsServiceException
   {
     public:
-
       /**
        * Constructor for QgsBadRequestException (HTTP error code 400).
        * \param code Error code
