@@ -33,12 +33,15 @@ class Dummy3DSymbol : public QgsAbstract3DSymbol
     void readXml( const QDomElement &, const QgsReadWriteContext & ) override {}
 
     static QgsAbstract3DSymbol *create() { return new Dummy3DSymbol(); }
-
 };
 
-class TestQgs3DSymbolRegistry : public QObject
+class TestQgs3DSymbolRegistry : public QgsTest
 {
     Q_OBJECT
+  public:
+    TestQgs3DSymbolRegistry()
+      : QgsTest( QStringLiteral( "3D Symbol Registry Tests" ), QStringLiteral( "3d" ) )
+    {}
 
   private slots:
     void initTestCase();
@@ -54,7 +57,6 @@ class TestQgs3DSymbolRegistry : public QObject
     void defaultSymbolForGeometryType();
 
   private:
-
 };
 
 void TestQgs3DSymbolRegistry::initTestCase()
@@ -70,12 +72,10 @@ void TestQgs3DSymbolRegistry::cleanupTestCase()
 
 void TestQgs3DSymbolRegistry::init()
 {
-
 }
 
 void TestQgs3DSymbolRegistry::cleanup()
 {
-
 }
 
 void TestQgs3DSymbolRegistry::metadata()
@@ -85,7 +85,7 @@ void TestQgs3DSymbolRegistry::metadata()
   QCOMPARE( metadata.visibleName(), QString( "display name" ) );
 
   //test creating symbol from metadata
-  const std::unique_ptr< QgsAbstract3DSymbol > symbol( metadata.create() );
+  const std::unique_ptr<QgsAbstract3DSymbol> symbol( metadata.create() );
   QVERIFY( symbol );
   Dummy3DSymbol *dummySymbol = dynamic_cast<Dummy3DSymbol *>( symbol.get() );
   QVERIFY( dummySymbol );
@@ -118,7 +118,7 @@ void TestQgs3DSymbolRegistry::addSymbol()
   QCOMPARE( registry->symbolTypes().length(), previousCount + 1 );
   //try adding again, should have no effect
   Qgs3DSymbolMetadata *dupe = new Qgs3DSymbolMetadata( QStringLiteral( "Dummy" ), QStringLiteral( "Dummy symbol" ), Dummy3DSymbol::create );
-  QVERIFY( ! registry->addSymbolType( dupe ) );
+  QVERIFY( !registry->addSymbolType( dupe ) );
   QCOMPARE( registry->symbolTypes().length(), previousCount + 1 );
   delete dupe;
 
@@ -145,7 +145,7 @@ void TestQgs3DSymbolRegistry::fetchTypes()
 void TestQgs3DSymbolRegistry::createSymbol()
 {
   Qgs3DSymbolRegistry *registry = QgsApplication::symbol3DRegistry();
-  std::unique_ptr< QgsAbstract3DSymbol > symbol( registry->createSymbol( QStringLiteral( "Dummy" ) ) );
+  std::unique_ptr<QgsAbstract3DSymbol> symbol( registry->createSymbol( QStringLiteral( "Dummy" ) ) );
 
   QVERIFY( symbol.get() );
   Dummy3DSymbol *dummySymbol = dynamic_cast<Dummy3DSymbol *>( symbol.get() );
@@ -159,13 +159,13 @@ void TestQgs3DSymbolRegistry::createSymbol()
 void TestQgs3DSymbolRegistry::defaultSymbolForGeometryType()
 {
   Qgs3DSymbolRegistry *registry = QgsApplication::symbol3DRegistry();
-  std::unique_ptr< QgsAbstract3DSymbol > symbol( registry->defaultSymbolForGeometryType( QgsWkbTypes::PointGeometry ) );
+  std::unique_ptr<QgsAbstract3DSymbol> symbol( registry->defaultSymbolForGeometryType( Qgis::GeometryType::Point ) );
   QCOMPARE( symbol->type(), QStringLiteral( "point" ) );
-  symbol.reset( registry->defaultSymbolForGeometryType( QgsWkbTypes::LineGeometry ) );
+  symbol.reset( registry->defaultSymbolForGeometryType( Qgis::GeometryType::Line ) );
   QCOMPARE( symbol->type(), QStringLiteral( "line" ) );
-  symbol.reset( registry->defaultSymbolForGeometryType( QgsWkbTypes::PolygonGeometry ) );
+  symbol.reset( registry->defaultSymbolForGeometryType( Qgis::GeometryType::Polygon ) );
   QCOMPARE( symbol->type(), QStringLiteral( "polygon" ) );
-  symbol.reset( registry->defaultSymbolForGeometryType( QgsWkbTypes::NullGeometry ) );
+  symbol.reset( registry->defaultSymbolForGeometryType( Qgis::GeometryType::Null ) );
   QVERIFY( !symbol );
 }
 
