@@ -41,8 +41,8 @@ class TestQgsAppLocatorFilters : public QObject
     Q_OBJECT
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
     void testCalculator();
     void testLayers();
     void testLayouts();
@@ -56,7 +56,7 @@ class TestQgsAppLocatorFilters : public QObject
   private:
     QgisApp *mQgisApp = nullptr;
 
-    QList< QgsLocatorResult > gatherResults( QgsLocatorFilter *filter, const QString &string, const QgsLocatorContext &context );
+    QList<QgsLocatorResult> gatherResults( QgsLocatorFilter *filter, const QString &string, const QgsLocatorContext &context );
 };
 
 //runs before all tests
@@ -79,9 +79,9 @@ void TestQgsAppLocatorFilters::testCalculator()
   QgsExpressionCalculatorLocatorFilter filter;
 
   // valid expression
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "1+2" ), QgsLocatorContext() );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "1+2" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
-  QCOMPARE( results.at( 0 ).userData.toInt(), 3 );
+  QCOMPARE( results.at( 0 ).userData().toInt(), 3 );
 
   // trigger result
   filter.triggerResult( results.at( 0 ) );
@@ -97,21 +97,21 @@ void TestQgsAppLocatorFilters::testLayers()
   QgsVectorLayer *l1 = new QgsVectorLayer( QStringLiteral( "Point" ), QStringLiteral( "aaaaa" ), QStringLiteral( "memory" ) );
   QgsVectorLayer *l2 = new QgsVectorLayer( QStringLiteral( "Point" ), QStringLiteral( "abc" ), QStringLiteral( "memory" ) );
   QgsVectorLayer *l3 = new QgsVectorLayer( QStringLiteral( "Point" ), QStringLiteral( "ccccc" ), QStringLiteral( "memory" ) );
-  QgsProject::instance()->addMapLayers( QList< QgsMapLayer *>() << l1 << l2 << l3 );
+  QgsProject::instance()->addMapLayers( QList<QgsMapLayer *>() << l1 << l2 << l3 );
 
   QgsLayerTreeLocatorFilter filter;
 
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "xxxxx" ), QgsLocatorContext() );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "xxxxx" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 0 );
 
   results = gatherResults( &filter, QStringLiteral( "aa" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
-  QCOMPARE( results.at( 0 ).userData.toString(), l1->id() );
+  QCOMPARE( results.at( 0 ).userData().toString(), l1->id() );
 
   results = gatherResults( &filter, QStringLiteral( "A" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 2 );
-  QCOMPARE( results.at( 0 ).userData.toString(), l1->id() );
-  QCOMPARE( results.at( 1 ).userData.toString(), l2->id() );
+  QCOMPARE( results.at( 0 ).userData().toString(), l1->id() );
+  QCOMPARE( results.at( 1 ).userData().toString(), l2->id() );
 
   results = gatherResults( &filter, QString(), QgsLocatorContext() );
   QCOMPARE( results.count(), 0 );
@@ -120,9 +120,9 @@ void TestQgsAppLocatorFilters::testLayers()
   context.usingPrefix = true;
   results = gatherResults( &filter, QString(), context );
   QCOMPARE( results.count(), 3 );
-  QCOMPARE( results.at( 0 ).userData.toString(), l1->id() );
-  QCOMPARE( results.at( 1 ).userData.toString(), l2->id() );
-  QCOMPARE( results.at( 2 ).userData.toString(), l3->id() );
+  QCOMPARE( results.at( 0 ).userData().toString(), l1->id() );
+  QCOMPARE( results.at( 1 ).userData().toString(), l2->id() );
+  QCOMPARE( results.at( 2 ).userData().toString(), l3->id() );
 }
 
 void TestQgsAppLocatorFilters::testLayouts()
@@ -139,17 +139,17 @@ void TestQgsAppLocatorFilters::testLayouts()
 
   QgsLayoutLocatorFilter filter;
 
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "xxxxx" ), QgsLocatorContext() );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "xxxxx" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 0 );
 
   results = gatherResults( &filter, QStringLiteral( "aa" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
-  QCOMPARE( results.at( 0 ).userData.toString(), pl1->name() );
+  QCOMPARE( results.at( 0 ).userData().toString(), pl1->name() );
 
   results = gatherResults( &filter, QStringLiteral( "A" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 2 );
-  QCOMPARE( results.at( 0 ).userData.toString(), pl1->name() );
-  QCOMPARE( results.at( 1 ).userData.toString(), pl2->name() );
+  QCOMPARE( results.at( 0 ).userData().toString(), pl1->name() );
+  QCOMPARE( results.at( 1 ).userData().toString(), pl2->name() );
 
   results = gatherResults( &filter, QString(), QgsLocatorContext() );
   QCOMPARE( results.count(), 0 );
@@ -158,9 +158,9 @@ void TestQgsAppLocatorFilters::testLayouts()
   context.usingPrefix = true;
   results = gatherResults( &filter, QString(), context );
   QCOMPARE( results.count(), 3 );
-  QCOMPARE( results.at( 0 ).userData.toString(), pl1->name() );
-  QCOMPARE( results.at( 1 ).userData.toString(), pl2->name() );
-  QCOMPARE( results.at( 2 ).userData.toString(), pl3->name() );
+  QCOMPARE( results.at( 0 ).userData().toString(), pl1->name() );
+  QCOMPARE( results.at( 1 ).userData().toString(), pl2->name() );
+  QCOMPARE( results.at( 2 ).userData().toString(), pl3->name() );
 }
 
 void TestQgsAppLocatorFilters::testSearchActiveLayer()
@@ -183,7 +183,7 @@ void TestQgsAppLocatorFilters::testSearchActiveLayer()
   QgsActiveLayerFeaturesLocatorFilter filter;
   const QgsLocatorContext context;
 
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "12345.6789" ), context );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "12345.6789" ), context );
   QCOMPARE( results.count(), 1 );
 
   results = gatherResults( &filter, QStringLiteral( "12345.67" ), context );
@@ -272,7 +272,7 @@ void TestQgsAppLocatorFilters::testSearchAllLayers()
   QgsVectorLayer *l1 = new QgsVectorLayer( layerDef, QStringLiteral( "Layer 1" ), QStringLiteral( "memory" ) );
   QgsVectorLayer *l2 = new QgsVectorLayer( layerDef, QStringLiteral( "Layer 2" ), QStringLiteral( "memory" ) );
 
-  QgsProject::instance()->addMapLayers( QList< QgsMapLayer *>() << l1 << l2 );
+  QgsProject::instance()->addMapLayers( QList<QgsMapLayer *>() << l1 << l2 );
 
   QgsFeature f1;
   f1.setAttributes( QVector<QVariant>() << 1001 << "A nice feature" << 6789 );
@@ -290,7 +290,7 @@ void TestQgsAppLocatorFilters::testSearchAllLayers()
   QgsAllLayersFeaturesLocatorFilter filter;
   const QgsLocatorContext context;
 
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "100" ), context );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "100" ), context );
 
   l1->setDisplayExpression( QStringLiteral( "\"my_text\" || ' is ' || \"my_number\"" ) );
   l2->setDisplayExpression( QStringLiteral( "\"my_text\" || ' is ' || \"my_number\"" ) );
@@ -311,7 +311,7 @@ void TestQgsAppLocatorFilters::testSearchAllLayersPrioritizeExactMatch()
   const QString layerDef = QStringLiteral( "Point?crs=epsg:4326&field=pk:integer&field=my_text:string&field=my_number:integer&key=pk" );
   QgsVectorLayer *l1 = new QgsVectorLayer( layerDef, QStringLiteral( "Layer 1" ), QStringLiteral( "memory" ) );
 
-  QgsProject::instance()->addMapLayers( QList< QgsMapLayer *>() << l1 );
+  QgsProject::instance()->addMapLayers( QList<QgsMapLayer *>() << l1 );
 
   QgsFeature f1;
   f1.setAttributes( QVector<QVariant>() << 100 << "A nice feature" << 100 );
@@ -331,7 +331,7 @@ void TestQgsAppLocatorFilters::testSearchAllLayersPrioritizeExactMatch()
 
   l1->setDisplayExpression( QStringLiteral( "\"my_number\"" ) );
 
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "1" ), context );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "1" ), context );
   QCOMPARE( results.count(), 2 );
   QCOMPARE( results.first().displayString, QStringLiteral( "1" ) );
   QCOMPARE( results.last().displayString, QStringLiteral( "100" ) );
@@ -346,8 +346,8 @@ QList<QgsLocatorResult> TestQgsAppLocatorFilters::gatherResults( QgsLocatorFilte
   filter->prepare( string, context );
   filter->fetchResults( string, context, &f );
 
-  QList< QgsLocatorResult > results;
-  for ( int i = 0; i < spy.count(); ++ i )
+  QList<QgsLocatorResult> results;
+  for ( int i = 0; i < spy.count(); ++i )
   {
     const QVariant v = spy.at( i ).at( 0 );
     const QgsLocatorResult result = v.value<QgsLocatorResult>();
@@ -361,72 +361,72 @@ void TestQgsAppLocatorFilters::testGoto()
   QgsGotoLocatorFilter filter;
 
   // simple goto
-  QList< QgsLocatorResult > results = gatherResults( &filter, QStringLiteral( "4 5" ), QgsLocatorContext() );
+  QList<QgsLocatorResult> results = gatherResults( &filter, QStringLiteral( "4 5" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 2 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 4 5 (Map CRS, )" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 4, 5 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 4, 5 ) );
   QCOMPARE( results.at( 1 ).displayString, QObject::tr( "Go to 4°N 5°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 1 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 5, 4 ) );
+  QCOMPARE( results.at( 1 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 5, 4 ) );
 
   // locale-specific goto
   results = gatherResults( &filter, QStringLiteral( "1,234.56 789.012" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 1,234.56 789.012 (Map CRS, )" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1234.56, 789.012 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1234.56, 789.012 ) );
 
   // decimal degree with suffixes
   results = gatherResults( &filter, QStringLiteral( "12.345N, 67.890W" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 12.345°N -67.89°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( -67.890, 12.345 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( -67.890, 12.345 ) );
 
   results = gatherResults( &filter, QStringLiteral( "12.345 e, 67.890 s" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to -67.89°N 12.345°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 12.345, -67.890 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 12.345, -67.890 ) );
 
   // degree/minuste/second coordinates goto
   // easting northing
   results = gatherResults( &filter, QStringLiteral( "40deg 1' 0\" E 11deg  55' 0\" S" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to -11.91666667°N 40.01666667°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 40.0166666667, -11.9166666667 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 40.0166666667, -11.9166666667 ) );
 
   // northing easting
   results = gatherResults( &filter, QStringLiteral( "14°49′48″N 01°48′45″E" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 14.83°N 1.8125°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1.8125, 14.83 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1.8125, 14.83 ) );
 
   // northing, esting (comma separated)
   results = gatherResults( &filter, QStringLiteral( "14°49′48″N, 01°48′45″E" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 14.83°N 1.8125°E (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1.8125, 14.83 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 1.8125, 14.83 ) );
 
   // OSM/Leaflet/OpenLayers
   results = gatherResults( &filter, QStringLiteral( "https://www.openstreetmap.org/#map=15/44.5546/6.4936" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 44.5546°N 6.4936°E at scale 1:22569 (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 6.4936, 44.5546 ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "scale" )].toDouble(), 22569.0 );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 6.4936, 44.5546 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "scale" )].toDouble(), 22569.0 );
 
   // Google Maps
   results = gatherResults( &filter, QStringLiteral( "https://www.google.com/maps/@44.5546,6.4936,15.25z" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 44.5546°N 6.4936°E at scale 1:22569 (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 6.4936, 44.5546 ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "scale" )].toDouble(), 22569.0 );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 6.4936, 44.5546 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "scale" )].toDouble(), 22569.0 );
 
   results = gatherResults( &filter, QStringLiteral( "https://www.google.com/maps/@7.8750,81.0149,574195m/data=!3m1!1e3" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 81.0149, 7.8750 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 81.0149, 7.8750 ) );
 
   results = gatherResults( &filter, QStringLiteral( "https://www.google.com/maps/@27.7132,85.3288,3a,75y,278.89h,90t/data=!3m8!1e1!3m6!1sAF1QipMrXuXozGc9x9bxx5uPl_3ys4H-rNVqMLr6EYLA!2e10!3e11!6shttps:%2F%2Flh5.googleusercontent.com%2Fp%2FAF1QipMrXuXozGc9x9bxx5uPl_3ys4H-rNVqMLr6EYLA%3Dw203-h100-k-no-pi2.869903-ya293.58762-ro-1.9255565-fo100!7i3840!8i1920" ), QgsLocatorContext() );
   QCOMPARE( results.count(), 1 );
   QCOMPARE( results.at( 0 ).displayString, QObject::tr( "Go to 27.7132°N 85.3288°E at scale 1:282 (EPSG:4326 - WGS 84)" ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 85.3288, 27.7132 ) );
-  QCOMPARE( results.at( 0 ).userData.toMap()[QStringLiteral( "scale" )].toDouble(), 282.0 );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "point" )].value<QgsPointXY>(), QgsPointXY( 85.3288, 27.7132 ) );
+  QCOMPARE( results.at( 0 ).userData().toMap()[QStringLiteral( "scale" )].toDouble(), 282.0 );
 }
 
 QGSTEST_MAIN( TestQgsAppLocatorFilters )
