@@ -20,20 +20,21 @@
 
 #include "qgsfields.h"
 
-class TestQgsFields: public QObject
+class TestQgsFields : public QObject
 {
     Q_OBJECT
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init();// will be called before each testfunction is executed.
-    void cleanup();// will be called after every testfunction.
-    void create();//test creating a data defined container
-    void copy();// test cpy destruction (double delete)
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init();            // will be called before each testfunction is executed.
+    void cleanup();         // will be called after every testfunction.
+    void create();          //test creating a data defined container
+    void copy();            // test cpy destruction (double delete)
     void assignment();
-    void equality(); //test equality operators
+    void equality();  //test equality operators
     void asVariant(); //test conversion to and from a QVariant
+    void construct();
     void clear();
     void exists();
     void count();
@@ -54,28 +55,26 @@ class TestQgsFields: public QObject
     void qforeach();
     void iterator();
     void constIterator();
+    void appendList();
+    void appendQgsFields();
 
   private:
 };
 
 void TestQgsFields::initTestCase()
 {
-
 }
 
 void TestQgsFields::cleanupTestCase()
 {
-
 }
 
 void TestQgsFields::init()
 {
-
 }
 
 void TestQgsFields::cleanup()
 {
-
 }
 
 void TestQgsFields::create()
@@ -164,6 +163,29 @@ void TestQgsFields::asVariant()
   QCOMPARE( fromVar, original );
 }
 
+void TestQgsFields::construct()
+{
+  // construct using a list of fields
+  QgsFields fields(
+    QList<QgsField> {
+      QgsField( QStringLiteral( "field1" ), QMetaType::Type::QString ),
+      QgsField( QStringLiteral( "field2" ), QMetaType::Type::Int ),
+      QgsField( QStringLiteral( "field3" ), QMetaType::Type::Double ),
+    }
+  );
+
+  QCOMPARE( fields.size(), 3 );
+  QCOMPARE( fields.at( 0 ).name(), QStringLiteral( "field1" ) );
+  QCOMPARE( fields.at( 0 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field1" ) ), 0 );
+  QCOMPARE( fields.at( 1 ).name(), QStringLiteral( "field2" ) );
+  QCOMPARE( fields.at( 1 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field2" ) ), 1 );
+  QCOMPARE( fields.at( 2 ).name(), QStringLiteral( "field3" ) );
+  QCOMPARE( fields.at( 2 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field3" ) ), 2 );
+}
+
 void TestQgsFields::clear()
 {
   QgsFields original;
@@ -267,7 +289,7 @@ void TestQgsFields::extend()
 
   QgsFields source;
   const QgsField field3( QStringLiteral( "testfield3" ) );
-  source.append( field3, QgsFields::OriginJoin, 5 );
+  source.append( field3, Qgis::FieldOrigin::Join, 5 );
   const QgsField field4( QStringLiteral( "testfield4" ) );
   source.append( field4 );
 
@@ -314,34 +336,34 @@ void TestQgsFields::fieldOrigin()
 {
   QgsFields fields;
   const QgsField field( QStringLiteral( "testfield" ) );
-  fields.append( field, QgsFields::OriginJoin );
+  fields.append( field, Qgis::FieldOrigin::Join );
   const QgsField field2( QStringLiteral( "testfield2" ) );
-  fields.append( field2, QgsFields::OriginExpression );
+  fields.append( field2, Qgis::FieldOrigin::Expression );
 
-  QCOMPARE( fields.fieldOrigin( 0 ), QgsFields::OriginJoin );
-  QCOMPARE( fields.fieldOrigin( 1 ), QgsFields::OriginExpression );
-  QCOMPARE( fields.fieldOrigin( 2 ), QgsFields::OriginUnknown );
+  QCOMPARE( fields.fieldOrigin( 0 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.fieldOrigin( 1 ), Qgis::FieldOrigin::Expression );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Unknown );
 }
 
 void TestQgsFields::fieldOriginIndex()
 {
   QgsFields fields;
   const QgsField field( QStringLiteral( "testfield" ) );
-  fields.append( field, QgsFields::OriginProvider, 5 );
+  fields.append( field, Qgis::FieldOrigin::Provider, 5 );
   QCOMPARE( fields.fieldOriginIndex( 0 ), 5 );
 
   const QgsField field2( QStringLiteral( "testfield2" ) );
-  fields.append( field2, QgsFields::OriginProvider, 10 );
+  fields.append( field2, Qgis::FieldOrigin::Provider, 10 );
   QCOMPARE( fields.fieldOriginIndex( 1 ), 10 );
 
   const QgsField field3( QStringLiteral( "testfield3" ) );
   //field origin index not specified with OriginProvider, should be automatic
-  fields.append( field3, QgsFields::OriginProvider );
+  fields.append( field3, Qgis::FieldOrigin::Provider );
   QCOMPARE( fields.fieldOriginIndex( 2 ), 2 );
 
   const QgsField field4( QStringLiteral( "testfield4" ) );
   //field origin index not specified with other than OriginProvider, should remain -1
-  fields.append( field4, QgsFields::OriginEdit );
+  fields.append( field4, Qgis::FieldOrigin::Edit );
   QCOMPARE( fields.fieldOriginIndex( 3 ), -1 );
 }
 
@@ -374,9 +396,9 @@ void TestQgsFields::indexFromName()
   QCOMPARE( fields.lookupField( QString( "teStFiEld2" ) ), 1 );
 
   //test that fieldNameIndex prefers exact case matches over case insensitive matches
-  const QgsField sameNameDifferentCase( QStringLiteral( "teStFielD" ) );  //#spellok
+  const QgsField sameNameDifferentCase( QStringLiteral( "teStFielD" ) ); //#spellok
   fields.append( sameNameDifferentCase );
-  QCOMPARE( fields.lookupField( QString( "teStFielD" ) ), 4 );  //#spellok
+  QCOMPARE( fields.lookupField( QString( "teStFielD" ) ), 4 ); //#spellok
 
   //test that the alias is only matched with fieldNameIndex
   QCOMPARE( fields.indexFromName( "testfieldAlias" ), -1 );
@@ -437,7 +459,7 @@ void TestQgsFields::appendExpressionField()
   const QgsField exprField( QStringLiteral( "expression" ) );
   QVERIFY( fields.appendExpressionField( exprField, 5 ) );
   QCOMPARE( fields.count(), 3 );
-  QCOMPARE( fields.fieldOrigin( 2 ), QgsFields::OriginExpression );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Expression );
   QCOMPARE( fields.fieldOriginIndex( 2 ), 5 );
 }
 
@@ -445,7 +467,7 @@ void TestQgsFields::dataStream()
 {
   QgsField original1;
   original1.setName( QStringLiteral( "name" ) );
-  original1.setType( QVariant::Int );
+  original1.setType( QMetaType::Type::Int );
   original1.setLength( 5 );
   original1.setPrecision( 2 );
   original1.setTypeName( QStringLiteral( "typename1" ) );
@@ -453,7 +475,7 @@ void TestQgsFields::dataStream()
 
   QgsField original2;
   original2.setName( QStringLiteral( "next name" ) );
-  original2.setType( QVariant::Double );
+  original2.setType( QMetaType::Type::Double );
   original2.setLength( 15 );
   original2.setPrecision( 3 );
   original2.setTypeName( QStringLiteral( "double" ) );
@@ -473,7 +495,7 @@ void TestQgsFields::dataStream()
 
   QCOMPARE( resultFields, originalFields );
   QCOMPARE( resultFields.field( 0 ).typeName(), originalFields.field( 0 ).typeName() ); //typename is NOT required for equality
-  QCOMPARE( resultFields.field( 0 ).comment(), originalFields.field( 0 ).comment() ); //comment is NOT required for equality
+  QCOMPARE( resultFields.field( 0 ).comment(), originalFields.field( 0 ).comment() );   //comment is NOT required for equality
   QCOMPARE( resultFields.field( 1 ).typeName(), originalFields.field( 1 ).typeName() );
   QCOMPARE( resultFields.field( 1 ).comment(), originalFields.field( 1 ).comment() );
 }
@@ -482,27 +504,27 @@ void TestQgsFields::field()
 {
   QgsField original;
   original.setName( QStringLiteral( "name" ) );
-  original.setType( QVariant::Int );
+  original.setType( QMetaType::Type::Int );
   original.setLength( 5 );
   original.setPrecision( 2 );
 
   //test constructors for QgsFields::Field
-  const QgsFields::Field fieldConstructor1( original, QgsFields::OriginJoin, 5 );
+  const QgsFields::Field fieldConstructor1( original, Qgis::FieldOrigin::Join, 5 );
   QCOMPARE( fieldConstructor1.field, original );
-  QCOMPARE( fieldConstructor1.origin, QgsFields::OriginJoin );
+  QCOMPARE( fieldConstructor1.origin, Qgis::FieldOrigin::Join );
   QCOMPARE( fieldConstructor1.originIndex, 5 );
 
   const QgsFields::Field fieldConstructor2;
-  QCOMPARE( fieldConstructor2.origin, QgsFields::OriginUnknown );
+  QCOMPARE( fieldConstructor2.origin, Qgis::FieldOrigin::Unknown );
   QCOMPARE( fieldConstructor2.originIndex, -1 );
 
   //test equality operators
-  const QgsFields::Field field1( original, QgsFields::OriginJoin, 5 );
-  const QgsFields::Field field2( original, QgsFields::OriginJoin, 5 );
+  const QgsFields::Field field1( original, Qgis::FieldOrigin::Join, 5 );
+  const QgsFields::Field field2( original, Qgis::FieldOrigin::Join, 5 );
   QVERIFY( field1 == field2 );
-  const QgsFields::Field field3( original, QgsFields::OriginEdit, 5 );
+  const QgsFields::Field field3( original, Qgis::FieldOrigin::Edit, 5 );
   QVERIFY( field1 != field3 );
-  const QgsFields::Field field4( original, QgsFields::OriginJoin, 6 );
+  const QgsFields::Field field4( original, Qgis::FieldOrigin::Join, 6 );
   QVERIFY( field1 != field4 );
 }
 
@@ -569,7 +591,7 @@ void TestQgsFields::constIterator()
 
   //test with empty fields
   QCOMPARE( fields.constBegin(), fields.constEnd() );
-  QCOMPARE( const_cast< const QgsFields * >( &fields )->begin(), const_cast< const QgsFields * >( &fields )->end() );
+  QCOMPARE( const_cast<const QgsFields *>( &fields )->begin(), const_cast<const QgsFields *>( &fields )->end() );
   for ( const QgsField &f : fields )
   {
     Q_UNUSED( f );
@@ -623,5 +645,149 @@ void TestQgsFields::constIterator()
   QCOMPARE( it3 - it, 1 );
 }
 
+void TestQgsFields::appendList()
+{
+  // test appending a list of fields
+  QgsFields fields;
+
+  QVERIFY( fields.append(
+    QList<QgsField> {
+      QgsField( QStringLiteral( "field1" ), QMetaType::Type::QString ),
+      QgsField( QStringLiteral( "field2" ), QMetaType::Type::Int ),
+      QgsField( QStringLiteral( "field3" ), QMetaType::Type::Double ),
+    }
+  ) );
+
+  QCOMPARE( fields.size(), 3 );
+  QCOMPARE( fields.at( 0 ).name(), QStringLiteral( "field1" ) );
+  QCOMPARE( fields.at( 0 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 0 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field1" ) ), 0 );
+  QCOMPARE( fields.at( 1 ).name(), QStringLiteral( "field2" ) );
+  QCOMPARE( fields.at( 1 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 1 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field2" ) ), 1 );
+  QCOMPARE( fields.at( 2 ).name(), QStringLiteral( "field3" ) );
+  QCOMPARE( fields.at( 2 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field3" ) ), 2 );
+
+  // should be rejected, duplicate field name
+  QVERIFY( !fields.append(
+    QList<QgsField> {
+      QgsField( QStringLiteral( "field1" ), QMetaType::Type::QString )
+    }
+  ) );
+
+  QCOMPARE( fields.size(), 3 );
+
+  QVERIFY( fields.append(
+    QList<QgsField> {
+      QgsField( QStringLiteral( "field4" ), QMetaType::Type::QString ),
+      QgsField( QStringLiteral( "field5" ), QMetaType::Type::Int ),
+      QgsField( QStringLiteral( "field6" ), QMetaType::Type::Double ),
+    },
+    Qgis::FieldOrigin::Join
+  ) );
+
+  QCOMPARE( fields.size(), 6 );
+  QCOMPARE( fields.at( 0 ).name(), QStringLiteral( "field1" ) );
+  QCOMPARE( fields.at( 0 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 0 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field1" ) ), 0 );
+  QCOMPARE( fields.at( 1 ).name(), QStringLiteral( "field2" ) );
+  QCOMPARE( fields.at( 1 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 1 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field2" ) ), 1 );
+  QCOMPARE( fields.at( 2 ).name(), QStringLiteral( "field3" ) );
+  QCOMPARE( fields.at( 2 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field3" ) ), 2 );
+  QCOMPARE( fields.at( 3 ).name(), QStringLiteral( "field4" ) );
+  QCOMPARE( fields.at( 3 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 3 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field4" ) ), 3 );
+  QCOMPARE( fields.at( 4 ).name(), QStringLiteral( "field5" ) );
+  QCOMPARE( fields.at( 4 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 4 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field5" ) ), 4 );
+  QCOMPARE( fields.at( 5 ).name(), QStringLiteral( "field6" ) );
+  QCOMPARE( fields.at( 5 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 5 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field6" ) ), 5 );
+}
+
+void TestQgsFields::appendQgsFields()
+{
+  // test appending fields from QgsFields
+  QgsFields fields;
+
+  QgsFields fields2;
+  fields2.append( QgsField( QStringLiteral( "field1" ), QMetaType::Type::QString ), Qgis::FieldOrigin::Edit, 2 );
+  fields2.append( QgsField( QStringLiteral( "field2" ), QMetaType::Type::Int ), Qgis::FieldOrigin::Join, 4 );
+  fields2.append( QgsField( QStringLiteral( "field3" ), QMetaType::Type::Double ), Qgis::FieldOrigin::Provider, 6 );
+
+  QVERIFY( fields.append( fields2 ) );
+  QCOMPARE( fields.size(), 3 );
+  QCOMPARE( fields.at( 0 ).name(), QStringLiteral( "field1" ) );
+  QCOMPARE( fields.at( 0 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 0 ), Qgis::FieldOrigin::Edit );
+  QCOMPARE( fields.fieldOriginIndex( 0 ), 2 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field1" ) ), 0 );
+  QCOMPARE( fields.at( 1 ).name(), QStringLiteral( "field2" ) );
+  QCOMPARE( fields.at( 1 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 1 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.fieldOriginIndex( 1 ), 4 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field2" ) ), 1 );
+  QCOMPARE( fields.at( 2 ).name(), QStringLiteral( "field3" ) );
+  QCOMPARE( fields.at( 2 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.fieldOriginIndex( 2 ), 6 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field3" ) ), 2 );
+
+  // should be rejected, duplicate field name
+  QVERIFY( !fields.append( fields2 ) );
+  QCOMPARE( fields.size(), 3 );
+
+  QgsFields fields3;
+  fields3.append( QgsField( QStringLiteral( "field4" ), QMetaType::Type::QString ), Qgis::FieldOrigin::Expression, 3 );
+  fields3.append( QgsField( QStringLiteral( "field5" ), QMetaType::Type::Int ), Qgis::FieldOrigin::Join, 5 );
+  fields3.append( QgsField( QStringLiteral( "field6" ), QMetaType::Type::Double ), Qgis::FieldOrigin::Provider, 7 );
+
+  QVERIFY( fields.append( fields3 ) );
+
+  QCOMPARE( fields.size(), 6 );
+  QCOMPARE( fields.at( 0 ).name(), QStringLiteral( "field1" ) );
+  QCOMPARE( fields.at( 0 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 0 ), Qgis::FieldOrigin::Edit );
+  QCOMPARE( fields.fieldOriginIndex( 0 ), 2 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field1" ) ), 0 );
+  QCOMPARE( fields.at( 1 ).name(), QStringLiteral( "field2" ) );
+  QCOMPARE( fields.at( 1 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 1 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.fieldOriginIndex( 1 ), 4 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field2" ) ), 1 );
+  QCOMPARE( fields.at( 2 ).name(), QStringLiteral( "field3" ) );
+  QCOMPARE( fields.at( 2 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 2 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.fieldOriginIndex( 2 ), 6 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field3" ) ), 2 );
+  QCOMPARE( fields.at( 3 ).name(), QStringLiteral( "field4" ) );
+  QCOMPARE( fields.at( 3 ).type(), QMetaType::Type::QString );
+  QCOMPARE( fields.fieldOrigin( 3 ), Qgis::FieldOrigin::Expression );
+  QCOMPARE( fields.fieldOriginIndex( 3 ), 3 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field4" ) ), 3 );
+  QCOMPARE( fields.at( 4 ).name(), QStringLiteral( "field5" ) );
+  QCOMPARE( fields.at( 4 ).type(), QMetaType::Type::Int );
+  QCOMPARE( fields.fieldOrigin( 4 ), Qgis::FieldOrigin::Join );
+  QCOMPARE( fields.fieldOriginIndex( 4 ), 5 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field5" ) ), 4 );
+  QCOMPARE( fields.at( 5 ).name(), QStringLiteral( "field6" ) );
+  QCOMPARE( fields.at( 5 ).type(), QMetaType::Type::Double );
+  QCOMPARE( fields.fieldOrigin( 5 ), Qgis::FieldOrigin::Provider );
+  QCOMPARE( fields.fieldOriginIndex( 5 ), 7 );
+  QCOMPARE( fields.indexFromName( QStringLiteral( "field6" ) ), 5 );
+}
+
 QGSTEST_MAIN( TestQgsFields )
 #include "testqgsfields.moc"
