@@ -34,19 +34,20 @@ class TestQgsLayoutHtml : public QgsTest
     Q_OBJECT
 
   public:
-    TestQgsLayoutHtml() : QgsTest( QStringLiteral( "Layout HTML Tests" ), QStringLiteral( "composer_html" ) ) {}
+    TestQgsLayoutHtml()
+      : QgsTest( QStringLiteral( "Layout HTML Tests" ), QStringLiteral( "composer_html" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void sourceMode(); //test if rendering manual HTML works
-    void userStylesheets(); //test if user stylesheets work
-    void evalExpressions(); //test if rendering with expressions works
-    void evalExpressionsOff(); //test if rendering with expressions disabled works
-    void table(); //test if rendering a HTML url works
-    void tableMultiFrame(); //tests multiframe capabilities of composer html
+    void initTestCase();             // will be called before the first testfunction is executed.
+    void cleanupTestCase();          // will be called after the last testfunction was executed.
+    void sourceMode();               //test if rendering manual HTML works
+    void userStylesheets();          //test if user stylesheets work
+    void evalExpressions();          //test if rendering with expressions works
+    void evalExpressionsOff();       //test if rendering with expressions disabled works
+    void table();                    //test if rendering a HTML url works
+    void tableMultiFrame();          //tests multiframe capabilities of composer html
     void htmlMultiFrameSmartBreak(); //tests smart page breaks in html multi frame
-    void javascriptSetFeature(); //test that JavaScript setFeature() function is correctly called
+    void javascriptSetFeature();     //test that JavaScript setFeature() function is correctly called
 
   private:
     QFont mTestFont;
@@ -79,7 +80,7 @@ void TestQgsLayoutHtml::sourceMode()
   htmlItem->setHtml( QStringLiteral( "<body style=\"margin: 10px;\"><div style=\"width: 100px; height: 50px; background-color: red;\"></div></body>" ) );
   htmlItem->loadHtml();
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_manual" ), &l, 0, 100 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_manual" ), &l, 0, 100 );
 }
 
 void TestQgsLayoutHtml::userStylesheets()
@@ -99,7 +100,7 @@ void TestQgsLayoutHtml::userStylesheets()
   //setting user stylesheet enabled automatically loads html
   htmlItem->setUserStylesheetEnabled( true );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_userstylesheet" ), &l, 0, 100 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_userstylesheet" ), &l, 0, 100 );
 }
 
 void TestQgsLayoutHtml::evalExpressions()
@@ -117,7 +118,7 @@ void TestQgsLayoutHtml::evalExpressions()
 
   htmlItem->loadHtml();
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_expressions_enabled" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_expressions_enabled" ), &l );
 }
 
 void TestQgsLayoutHtml::evalExpressionsOff()
@@ -126,14 +127,15 @@ void TestQgsLayoutHtml::evalExpressionsOff()
   l.initializeDefaults();
   QgsLayoutItemHtml *htmlItem = new QgsLayoutItemHtml( &l );
   QgsLayoutFrame *htmlFrame = new QgsLayoutFrame( &l, htmlItem );
-  htmlFrame->attemptSetSceneRect( QRectF( 0, 0, 100, 200 ) );  htmlFrame->setFrameEnabled( true );
+  htmlFrame->attemptSetSceneRect( QRectF( 0, 0, 100, 200 ) );
+  htmlFrame->setFrameEnabled( true );
   htmlItem->addFrame( htmlFrame );
   htmlItem->setContentMode( QgsLayoutItemHtml::ManualHtml );
   htmlItem->setEvaluateExpressions( false );
   htmlItem->setHtml( QStringLiteral( "<body style=\"margin: 10px;\"><div style=\"width: [% 10 * 10 %]px; height: [% 30 + 20 %]px; background-color: [% 'yel' || 'low' %];\"></div></body>" ) );
   htmlItem->loadHtml();
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_expressions_disabled" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_expressions_disabled" ), &l );
 }
 
 void TestQgsLayoutHtml::table()
@@ -142,11 +144,12 @@ void TestQgsLayoutHtml::table()
   l.initializeDefaults();
   QgsLayoutItemHtml *htmlItem = new QgsLayoutItemHtml( &l );
   QgsLayoutFrame *htmlFrame = new QgsLayoutFrame( &l, htmlItem );
-  htmlFrame->attemptSetSceneRect( QRectF( 0, 0, 100, 200 ) );  htmlFrame->setFrameEnabled( true );
+  htmlFrame->attemptSetSceneRect( QRectF( 0, 0, 100, 200 ) );
+  htmlFrame->setFrameEnabled( true );
   htmlItem->addFrame( htmlFrame );
   htmlItem->setUrl( QUrl( QStringLiteral( "file:///%1/test_html.html" ).arg( TEST_DATA_DIR ) ) );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_table" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_table" ), &l );
 }
 
 void TestQgsLayoutHtml::tableMultiFrame()
@@ -163,10 +166,10 @@ void TestQgsLayoutHtml::tableMultiFrame()
   //page1
   htmlItem->setUrl( QUrl( QStringLiteral( "file:///%1/test_html.html" ).arg( TEST_DATA_DIR ) ) );
   htmlItem->frame( 0 )->setFrameEnabled( true );
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_multiframe1" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_multiframe1" ), &l );
 
   //page2
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_multiframe2" ), &l, 1 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_multiframe2" ), &l, 1 );
 }
 
 void TestQgsLayoutHtml::htmlMultiFrameSmartBreak()
@@ -183,10 +186,10 @@ void TestQgsLayoutHtml::htmlMultiFrameSmartBreak()
   //page1
   htmlItem->setUrl( QUrl( QStringLiteral( "file:///%1/test_html.html" ).arg( TEST_DATA_DIR ) ) );
   htmlItem->frame( 0 )->setFrameEnabled( true );
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_smartbreaks1" ), &l, 0, 200 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_smartbreaks1" ), &l, 0, 200 );
 
   //page2
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_smartbreaks2" ), &l, 1, 200 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_smartbreaks2" ), &l, 1, 200 );
 }
 
 void TestQgsLayoutHtml::javascriptSetFeature()
@@ -200,7 +203,7 @@ void TestQgsLayoutHtml::javascriptSetFeature()
   QgsVectorDataProvider *pr = parentLayer->dataProvider();
   QgsFeature pf1;
   pf1.setFields( parentLayer->fields() );
-  pf1.setAttributes( QgsAttributes() << "test1" << 67 <<  123 );
+  pf1.setAttributes( QgsAttributes() << "test1" << 67 << 123 );
   QgsFeature pf2;
   pf2.setFields( parentLayer->fields() );
   pf2.setAttributes( QgsAttributes() << "test2" << 68 << 124 );
@@ -214,11 +217,11 @@ void TestQgsLayoutHtml::javascriptSetFeature()
   f1.setAttributes( QgsAttributes() << "foo" << 123 << 321 );
   QgsFeature f2;
   f2.setFields( childLayer->fields() );
-  f2.setAttributes( QgsAttributes() << "bar" <<  123 <<  654 );
+  f2.setAttributes( QgsAttributes() << "bar" << 123 << 654 );
   QgsFeature f3;
   f3.setFields( childLayer->fields() );
-  f3.setAttributes( QgsAttributes() << "foobar" << 124 <<  554 );
-  QVERIFY( pr->addFeatures( QgsFeatureList() << f1 <<  f2 <<  f3 ) );
+  f3.setAttributes( QgsAttributes() << "foobar" << 124 << 554 );
+  QVERIFY( pr->addFeatures( QgsFeatureList() << f1 << f2 << f3 ) );
 
   QgsProject::instance()->addMapLayers( QList<QgsMapLayer *>() << childLayer << parentLayer );
 
@@ -257,7 +260,7 @@ void TestQgsLayoutHtml::javascriptSetFeature()
 
   htmlItem->loadHtml();
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerhtml_setfeature" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerhtml_setfeature" ), &l );
 
   QgsProject::instance()->removeMapLayers( QList<QgsMapLayer *>() << childLayer << parentLayer );
 }
