@@ -23,20 +23,22 @@
 #include "qgsfillsymbollayer.h"
 #include "qgslinesymbollayer.h"
 #include "qgsmarkersymbollayer.h"
-#include "qgsmultirenderchecker.h"
 #include "qgslayoutpagecollection.h"
 #include <QObject>
 #include "qgstest.h"
 #include "qgsfillsymbol.h"
+#include "qgslayoutrendercontext.h"
 
 class TestQgsLayoutPage : public QgsTest
 {
     Q_OBJECT
 
   public:
-    TestQgsLayoutPage() : QgsTest( QStringLiteral( "Layout Page Tests" ) ) {}
+    TestQgsLayoutPage()
+      : QgsTest( QStringLiteral( "Layout Page Tests" ), QStringLiteral( "composer_paper" ) ) {}
 
   private slots:
+    void cleanupTestCase();
 
     void itemType();
     void pageSize();
@@ -44,34 +46,38 @@ class TestQgsLayoutPage : public QgsTest
     void grid();
     void defaultPaper();
     void transparentPaper(); //test totally transparent paper style
-    void borderedPaper(); //test page with border
-    void markerLinePaper(); //test page with marker line borde
+    void borderedPaper();    //test page with border
+    void markerLinePaper();  //test page with marker line borde
 
     void hiddenPages(); //test hidden page boundaries
 
     void pageLayout(); //test page layout
-
 };
 
+void TestQgsLayoutPage::cleanupTestCase()
+{
+  QgsApplication::exitQgis();
+}
+
 void TestQgsLayoutPage::itemType()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  QCOMPARE( page->type(), static_cast< int >( QgsLayoutItemRegistry::LayoutPage ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  QCOMPARE( page->type(), static_cast<int>( QgsLayoutItemRegistry::LayoutPage ) );
 }
 
 void TestQgsLayoutPage::pageSize()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 270, 297, QgsUnitTypes::LayoutMeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 270, 297, Qgis::LayoutUnit::Meters ) );
   QCOMPARE( page->pageSize().width(), 270.0 );
   QCOMPARE( page->pageSize().height(), 297.0 );
-  QCOMPARE( page->pageSize().units(), QgsUnitTypes::LayoutMeters );
+  QCOMPARE( page->pageSize().units(), Qgis::LayoutUnit::Meters );
   QCOMPARE( page->orientation(), QgsLayoutItemPage::Portrait );
-  page->setPageSize( QgsLayoutSize( 297, 270, QgsUnitTypes::LayoutMeters ) );
+  page->setPageSize( QgsLayoutSize( 297, 270, Qgis::LayoutUnit::Meters ) );
   QCOMPARE( page->orientation(), QgsLayoutItemPage::Landscape );
 
   // from registry
@@ -79,21 +85,20 @@ void TestQgsLayoutPage::pageSize()
   // should be unchanged
   QCOMPARE( page->pageSize().width(), 297.0 );
   QCOMPARE( page->pageSize().height(), 270.0 );
-  QCOMPARE( page->pageSize().units(), QgsUnitTypes::LayoutMeters );
+  QCOMPARE( page->pageSize().units(), Qgis::LayoutUnit::Meters );
 
   // good size
   QVERIFY( page->setPageSize( "A5" ) );
   QCOMPARE( page->pageSize().width(), 148.0 );
   QCOMPARE( page->pageSize().height(), 210.0 );
-  QCOMPARE( page->pageSize().units(), QgsUnitTypes::LayoutMillimeters );
+  QCOMPARE( page->pageSize().units(), Qgis::LayoutUnit::Millimeters );
   QCOMPARE( page->orientation(), QgsLayoutItemPage::Portrait );
 
   QVERIFY( page->setPageSize( "A5", QgsLayoutItemPage::Landscape ) );
   QCOMPARE( page->pageSize().width(), 210.0 );
   QCOMPARE( page->pageSize().height(), 148.0 );
-  QCOMPARE( page->pageSize().units(), QgsUnitTypes::LayoutMillimeters );
+  QCOMPARE( page->pageSize().units(), Qgis::LayoutUnit::Millimeters );
   QCOMPARE( page->orientation(), QgsLayoutItemPage::Landscape );
-
 }
 
 void TestQgsLayoutPage::decodePageOrientation()
@@ -115,7 +120,7 @@ void TestQgsLayoutPage::grid()
   // test that grid follows page around
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
 
   // should have a grid
   QVERIFY( page->mGrid.get() );
@@ -140,92 +145,83 @@ void TestQgsLayoutPage::grid()
   QCOMPARE( page->mGrid->rect().height(), 250.0 );
   QCOMPARE( page->mGrid->pos().x(), 0.0 );
   QCOMPARE( page->mGrid->pos().y(), 0.0 );
-
 }
 
 void TestQgsLayoutPage::defaultPaper()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
   l.pageCollection()->addPage( page.release() );
 
-  QgsLayoutChecker checker( QStringLiteral( "composerpaper_default" ), &l );
-  checker.setControlPathPrefix( QStringLiteral( "composer_paper" ) );
-  QVERIFY( checker.testLayout( mReport ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerpaper_default" ), &l );
 }
 
 void TestQgsLayoutPage::transparentPaper()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
   l.pageCollection()->addPage( page.release() );
 
   QgsSimpleFillSymbolLayer *simpleFill = new QgsSimpleFillSymbolLayer();
-  std::unique_ptr< QgsFillSymbol > fillSymbol( new QgsFillSymbol() );
+  std::unique_ptr<QgsFillSymbol> fillSymbol( new QgsFillSymbol() );
   fillSymbol->changeSymbolLayer( 0, simpleFill );
   simpleFill->setColor( Qt::transparent );
   simpleFill->setStrokeColor( Qt::transparent );
   l.pageCollection()->setPageStyleSymbol( fillSymbol.get() );
 
-  QgsLayoutChecker checker( QStringLiteral( "composerpaper_transparent" ), &l );
-  checker.setControlPathPrefix( QStringLiteral( "composer_paper" ) );
-  QVERIFY( checker.testLayout( mReport ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerpaper_transparent" ), &l );
 }
 
 void TestQgsLayoutPage::borderedPaper()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
   l.pageCollection()->addPage( page.release() );
 
   QgsSimpleFillSymbolLayer *simpleFill = new QgsSimpleFillSymbolLayer();
-  std::unique_ptr< QgsFillSymbol > fillSymbol = std::make_unique< QgsFillSymbol >();
+  std::unique_ptr<QgsFillSymbol> fillSymbol = std::make_unique<QgsFillSymbol>();
   fillSymbol->changeSymbolLayer( 0, simpleFill );
   simpleFill->setColor( Qt::white );
   simpleFill->setStrokeColor( Qt::black );
   simpleFill->setStrokeWidth( 6 );
   l.pageCollection()->setPageStyleSymbol( fillSymbol.get() );
 
-  QgsLayoutChecker checker( QStringLiteral( "composerpaper_bordered" ), &l );
-  checker.setControlPathPrefix( QStringLiteral( "composer_paper" ) );
-  QVERIFY( checker.testLayout( mReport ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerpaper_bordered" ), &l );
 }
 
 void TestQgsLayoutPage::markerLinePaper()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
   l.pageCollection()->addPage( page.release() );
 
   QgsMarkerLineSymbolLayer *markerLine = new QgsMarkerLineSymbolLayer();
-  static_cast< QgsSimpleMarkerSymbolLayer * >( markerLine->subSymbol()->symbolLayer( 0 ) )->setStrokeColor( Qt::black );
-  std::unique_ptr< QgsFillSymbol > markerLineSymbol = std::make_unique< QgsFillSymbol >();
+  static_cast<QgsSimpleMarkerSymbolLayer *>( markerLine->subSymbol()->symbolLayer( 0 ) )->setStrokeColor( Qt::black );
+  std::unique_ptr<QgsFillSymbol> markerLineSymbol = std::make_unique<QgsFillSymbol>();
   markerLineSymbol->changeSymbolLayer( 0, markerLine );
   l.pageCollection()->setPageStyleSymbol( markerLineSymbol.get() );
 
-  QgsLayoutChecker checker( QStringLiteral( "composerpaper_markerborder" ), &l );
-  checker.setControlPathPrefix( QStringLiteral( "composer_paper" ) );
-  QVERIFY( checker.testLayout( mReport, 0, 0 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerpaper_markerborder" ), &l );
 }
 
 void TestQgsLayoutPage::hiddenPages()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page( new QgsLayoutItemPage( &l ) );
-  page->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page( new QgsLayoutItemPage( &l ) );
+  page->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
   l.pageCollection()->addPage( page.release() );
 
   QgsSimpleFillSymbolLayer *simpleFill = new QgsSimpleFillSymbolLayer();
-  std::unique_ptr< QgsFillSymbol > fillSymbol = std::make_unique< QgsFillSymbol >();
+  std::unique_ptr<QgsFillSymbol> fillSymbol = std::make_unique<QgsFillSymbol>();
   fillSymbol->changeSymbolLayer( 0, simpleFill );
   simpleFill->setColor( Qt::blue );
   simpleFill->setStrokeColor( Qt::transparent );
@@ -233,19 +229,15 @@ void TestQgsLayoutPage::hiddenPages()
 
   l.renderContext().setPagesVisible( false );
 
-  QgsLayoutChecker checker( QStringLiteral( "composerpaper_hidden" ), &l );
-  checker.setControlPathPrefix( QStringLiteral( "composer_paper" ) );
-  const bool result = checker.testLayout( mReport );
-  QVERIFY( result );
-
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerpaper_hidden" ), &l );
 }
 
 void TestQgsLayoutPage::pageLayout()
 {
   QgsProject p;
   QgsLayout l( &p );
-  std::unique_ptr< QgsLayoutItemPage > page1( new QgsLayoutItemPage( &l ) );
-  page1->setPageSize( QgsLayoutSize( 297, 210, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page1( new QgsLayoutItemPage( &l ) );
+  page1->setPageSize( QgsLayoutSize( 297, 210, Qgis::LayoutUnit::Millimeters ) );
 
   const QPageLayout layout1 = page1->pageLayout();
 
@@ -254,8 +246,8 @@ void TestQgsLayoutPage::pageLayout()
   QCOMPARE( layout1.pageSize().size( QPageSize::Millimeter ).width(), 210 );
   QCOMPARE( layout1.pageSize().size( QPageSize::Millimeter ).height(), 297 );
 
-  std::unique_ptr< QgsLayoutItemPage > page2( new QgsLayoutItemPage( &l ) );
-  page2->setPageSize( QgsLayoutSize( 210, 297, QgsUnitTypes::LayoutMillimeters ) );
+  std::unique_ptr<QgsLayoutItemPage> page2( new QgsLayoutItemPage( &l ) );
+  page2->setPageSize( QgsLayoutSize( 210, 297, Qgis::LayoutUnit::Millimeters ) );
 
   const QPageLayout layout2 = page2->pageLayout();
 
