@@ -46,41 +46,42 @@ class TestQgsLayoutTable : public QgsTest
     Q_OBJECT
 
   public:
-    TestQgsLayoutTable() : QgsTest( QStringLiteral( "Layout Table Tests" ), QStringLiteral( "composer_table" ) ) {}
+    TestQgsLayoutTable()
+      : QgsTest( QStringLiteral( "Layout Table Tests" ), QStringLiteral( "composer_table" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init();// will be called before each testfunction is executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init();            // will be called before each testfunction is executed.
 
-    void attributeTableHeadings(); //test retrieving attribute table headers
-    void attributeTableRows(); //test retrieving attribute table rows
-    void attributeTableFormattedRows(); //test retrieving attribute formatted table rows
-    void attributeTableRowsLocalized(); //test retrieving attribute table rows with locale
+    void attributeTableHeadings();       //test retrieving attribute table headers
+    void attributeTableRows();           //test retrieving attribute table rows
+    void attributeTableFormattedRows();  //test retrieving attribute formatted table rows
+    void attributeTableRowsLocalized();  //test retrieving attribute table rows with locale
     void attributeTableFilterFeatures(); //test filtering attribute table rows
-    void attributeTableSetAttributes(); //test subset of attributes in table
-    void attributeTableVisibleOnly(); //test displaying only visible attributes
+    void attributeTableSetAttributes();  //test subset of attributes in table
+    void attributeTableVisibleOnly();    //test displaying only visible attributes
     void attributeTableInsideAtlasOnly();
     void attributeTableRender(); //test rendering attribute table
-    void manualColumnWidth(); //test setting manual column widths
-    void attributeTableEmpty(); //test empty modes for attribute table
-    void showEmptyRows(); //test showing empty rows
+    void manualColumnWidth();    //test setting manual column widths
+    void attributeTableEmpty();  //test empty modes for attribute table
+    void showEmptyRows();        //test showing empty rows
     void attributeTableExtend();
     void attributeTableRepeat();
     void attributeTableAtlasSource(); //test attribute table in atlas feature mode
     void attributeTableRestoreAtlasSource();
-    void attributeTableRelationSource(); //test attribute table in relation mode
-    void contentsContainsRow(); //test the contentsContainsRow function
-    void removeDuplicates(); //test removing duplicate rows
-    void multiLineText(); //test rendering a table with multiline text
-    void horizontalGrid(); //test rendering a table with horizontal-only grid
-    void verticalGrid(); //test rendering a table with vertical-only grid
-    void align(); //test alignment of table cells
-    void wrapChar(); //test setting wrap character
-    void autoWrap(); //test auto word wrap
-    void cellStyles(); //test cell styles
-    void cellStylesRender(); //test rendering cell styles
-    void conditionalFormatting(); //test rendering with conditional formatting
+    void attributeTableRelationSource();            //test attribute table in relation mode
+    void contentsContainsRow();                     //test the contentsContainsRow function
+    void removeDuplicates();                        //test removing duplicate rows
+    void multiLineText();                           //test rendering a table with multiline text
+    void horizontalGrid();                          //test rendering a table with horizontal-only grid
+    void verticalGrid();                            //test rendering a table with vertical-only grid
+    void align();                                   //test alignment of table cells
+    void wrapChar();                                //test setting wrap character
+    void autoWrap();                                //test auto word wrap
+    void cellStyles();                              //test cell styles
+    void cellStylesRender();                        //test rendering cell styles
+    void conditionalFormatting();                   //test rendering with conditional formatting
     void conditionalFormattingWithTextFormatting(); //test rendering with conditional formatting with text formatting
     void dataDefinedSource();
     void wrappedText();
@@ -104,9 +105,7 @@ void TestQgsLayoutTable::initTestCase()
 
   //create maplayers from testdata and add to layer registry
   const QFileInfo vectorFileInfo( QStringLiteral( TEST_DATA_DIR ) + "/points.shp" );
-  mVectorLayer = new QgsVectorLayer( vectorFileInfo.filePath(),
-                                     vectorFileInfo.completeBaseName(),
-                                     QStringLiteral( "ogr" ) );
+  mVectorLayer = new QgsVectorLayer( vectorFileInfo.filePath(), vectorFileInfo.completeBaseName(), QStringLiteral( "ogr" ) );
   QgsProject::instance()->addMapLayer( mVectorLayer );
 
   QgsFontUtils::loadStandardTestFonts( QStringList() << QStringLiteral( "Bold" ) );
@@ -222,26 +221,26 @@ void TestQgsLayoutTable::attributeTableFormattedRows()
   QgsVectorLayer vl { QStringLiteral( "Point?field=int:int" ), QStringLiteral( "test" ), QStringLiteral( "memory" ) };
   QVariantList valueConfig;
   QVariantMap config;
-  config[ QStringLiteral( "one" ) ] = QStringLiteral( "1" );
-  config[ QStringLiteral( "two" ) ] = QStringLiteral( "2" );
+  config[QStringLiteral( "one" )] = QStringLiteral( "1" );
+  config[QStringLiteral( "two" )] = QStringLiteral( "2" );
   valueConfig.append( config );
   QVariantMap editorConfig;
   editorConfig.insert( QStringLiteral( "map" ), valueConfig );
   vl.setEditorWidgetSetup( 0, QgsEditorWidgetSetup( QStringLiteral( "ValueMap" ), editorConfig ) );
-  QgsFeature f { vl.fields( ) };
+  QgsFeature f { vl.fields() };
   f.setGeometry( QgsGeometry::fromWkt( QStringLiteral( "point(9 45)" ) ) );
   f.setAttribute( QStringLiteral( "int" ), 2 );
-  QgsFeature f2 { vl.fields( ) };
+  QgsFeature f2 { vl.fields() };
   f2.setGeometry( QgsGeometry::fromWkt( QStringLiteral( "point(10 46)" ) ) );
   f2.setAttribute( QStringLiteral( "int" ), 1 );
   vl.dataProvider()->addFeatures( QgsFeatureList() << f << f2 );
 
   QVector<QStringList> expectedRows;
   QStringList row;
-  row <<  QStringLiteral( "two" );
+  row << QStringLiteral( "two" );
   expectedRows.append( row );
   QStringList row2;
-  row2 <<  QStringLiteral( "one" );
+  row2 << QStringLiteral( "one" );
   expectedRows.append( row2 );
 
   QgsLayout l( QgsProject::instance() );
@@ -251,7 +250,6 @@ void TestQgsLayoutTable::attributeTableFormattedRows()
 
   //retrieve rows and check
   compareTable( table, expectedRows );
-
 }
 
 void TestQgsLayoutTable::attributeTableRowsLocalized()
@@ -259,7 +257,7 @@ void TestQgsLayoutTable::attributeTableRowsLocalized()
   //test retrieving attribute table rows
 
   QgsVectorLayer vl { QStringLiteral( "Point?field=int:int&field=double:double&" ), QStringLiteral( "test" ), QStringLiteral( "memory" ) };
-  QgsFeature f { vl.fields( ) };
+  QgsFeature f { vl.fields() };
   f.setGeometry( QgsGeometry::fromWkt( QStringLiteral( "point(9 45)" ) ) );
   f.setAttribute( QStringLiteral( "int" ), 12346 );
   f.setAttribute( QStringLiteral( "double" ), 123456.801 );
@@ -267,7 +265,7 @@ void TestQgsLayoutTable::attributeTableRowsLocalized()
 
   QVector<QStringList> expectedRows;
   QStringList row;
-  row <<  QStringLiteral( "12,346" ) << QStringLiteral( "123,456.801" );
+  row << QStringLiteral( "12,346" ) << QStringLiteral( "123,456.801" );
   expectedRows.append( row );
 
   QgsLayout l( QgsProject::instance() );
@@ -281,13 +279,12 @@ void TestQgsLayoutTable::attributeTableRowsLocalized()
 
   expectedRows.clear();
   row.clear();
-  row <<  QStringLiteral( "12.346" ) << QStringLiteral( "123.456,801" );
+  row << QStringLiteral( "12.346" ) << QStringLiteral( "123.456,801" );
   expectedRows.append( row );
   QLocale::setDefault( QLocale::Italian );
   compareTable( table, expectedRows );
 
   QLocale::setDefault( QLocale::English );
-
 }
 
 
@@ -451,7 +448,7 @@ void TestQgsLayoutTable::attributeTableInsideAtlasOnly()
   compareTable( table, expectedRows, false );
 
   //setup atlas
-  std::unique_ptr< QgsVectorLayer > atlasLayer = std::make_unique< QgsVectorLayer >( QStringLiteral( "Polygon?crs=EPSG:3857" ), QStringLiteral( "atlas" ), QStringLiteral( "memory" ) );
+  std::unique_ptr<QgsVectorLayer> atlasLayer = std::make_unique<QgsVectorLayer>( QStringLiteral( "Polygon?crs=EPSG:3857" ), QStringLiteral( "atlas" ), QStringLiteral( "memory" ) );
   QVERIFY( atlasLayer->isValid() );
   const QgsGeometry atlasGeom( QgsGeometry::fromWkt( QStringLiteral( "Polygon ((-8863916.31126776337623596 4621257.48816855065524578, -9664269.45078738406300545 5097056.938785120844841, -10049249.44194872118532658 3765399.75924854446202517, -8985488.94005555473268032 3458599.17133777122944593, -8863916.31126776337623596 4621257.48816855065524578))" ) ) );
   QgsFeature f;
@@ -511,7 +508,7 @@ void TestQgsLayoutTable::attributeTableRender()
   table->setBackgroundColor( Qt::yellow );
 
   table->setMaximumNumberOfFeatures( 20 );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_render" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_render" ), &l );
 }
 
 void TestQgsLayoutTable::manualColumnWidth()
@@ -536,7 +533,7 @@ void TestQgsLayoutTable::manualColumnWidth()
 
   table->setMaximumNumberOfFeatures( 20 );
   table->columns()[0].setWidth( 5 );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_columnwidth" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_columnwidth" ), &l );
 }
 
 void TestQgsLayoutTable::attributeTableEmpty()
@@ -565,14 +562,14 @@ void TestQgsLayoutTable::attributeTableEmpty()
   table->setFilterFeatures( true );
 
   table->setEmptyTableBehavior( QgsLayoutTable::HeadersOnly );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_headersonly" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_headersonly" ), &l );
 
   table->setEmptyTableBehavior( QgsLayoutTable::HideTable );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_hidetable" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_hidetable" ), &l );
 
   table->setEmptyTableBehavior( QgsLayoutTable::ShowMessage );
   table->setEmptyTableMessage( QStringLiteral( "no rows" ) );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_showmessage" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_showmessage" ), &l );
 }
 
 void TestQgsLayoutTable::showEmptyRows()
@@ -597,7 +594,7 @@ void TestQgsLayoutTable::showEmptyRows()
 
   table->setMaximumNumberOfFeatures( 3 );
   table->setShowEmptyRows( true );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_drawempty" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_drawempty" ), &l );
 }
 
 void TestQgsLayoutTable::attributeTableExtend()
@@ -688,9 +685,7 @@ void TestQgsLayoutTable::attributeTableAtlasSource()
   //setup atlas
   QgsVectorLayer *vectorLayer = nullptr;
   const QFileInfo vectorFileInfo( QStringLiteral( TEST_DATA_DIR ) + "/points.shp" );
-  vectorLayer = new QgsVectorLayer( vectorFileInfo.filePath(),
-                                    vectorFileInfo.completeBaseName(),
-                                    QStringLiteral( "ogr" ) );
+  vectorLayer = new QgsVectorLayer( vectorFileInfo.filePath(), vectorFileInfo.completeBaseName(), QStringLiteral( "ogr" ) );
   QgsProject::instance()->addMapLayer( vectorLayer );
   l.reportContext().setLayer( vectorLayer );
 
@@ -739,7 +734,6 @@ void TestQgsLayoutTable::attributeTableAtlasSource()
   //try for a crash when removing current atlas layer
   QgsProject::instance()->removeMapLayer( vectorLayer->id() );
   table->refreshAttributes();
-
 }
 
 void TestQgsLayoutTable::attributeTableRestoreAtlasSource()
@@ -748,8 +742,8 @@ void TestQgsLayoutTable::attributeTableRestoreAtlasSource()
   QgsProject p;
   p.read( projectPath );
 
-  QgsPrintLayout *l = dynamic_cast< QgsPrintLayout *>( p.layoutManager()->layouts().at( 0 ) );
-  QgsLayoutItemAttributeTable *table = qobject_cast< QgsLayoutItemAttributeTable * >( l->multiFrames().at( 0 ) );
+  QgsPrintLayout *l = dynamic_cast<QgsPrintLayout *>( p.layoutManager()->layouts().at( 0 ) );
+  QgsLayoutItemAttributeTable *table = qobject_cast<QgsLayoutItemAttributeTable *>( l->multiFrames().at( 0 ) );
   QCOMPARE( table->source(), QgsLayoutItemAttributeTable::AtlasFeature );
   QVERIFY( l->atlas()->coverageLayer() );
   QVERIFY( l->atlas()->coverageLayer()->isValid() );
@@ -781,9 +775,7 @@ void TestQgsLayoutTable::attributeTableRelationSource()
   table->setBackgroundColor( Qt::yellow );
 
   const QFileInfo vectorFileInfo( QStringLiteral( TEST_DATA_DIR ) + "/points_relations.shp" );
-  QgsVectorLayer *atlasLayer = new QgsVectorLayer( vectorFileInfo.filePath(),
-      vectorFileInfo.completeBaseName(),
-      QStringLiteral( "ogr" ) );
+  QgsVectorLayer *atlasLayer = new QgsVectorLayer( vectorFileInfo.filePath(), vectorFileInfo.completeBaseName(), QStringLiteral( "ogr" ) );
 
   QgsProject::instance()->addMapLayer( atlasLayer );
 
@@ -981,7 +973,7 @@ void TestQgsLayoutTable::multiLineText()
 
   table->setMaximumNumberOfFeatures( 20 );
   table->setVectorLayer( multiLineLayer );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_multiline" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_multiline" ), &l );
 
   delete multiLineLayer;
 }
@@ -1035,7 +1027,7 @@ void TestQgsLayoutTable::horizontalGrid()
   table->setHorizontalGrid( true );
   table->setVerticalGrid( false );
   table->setVectorLayer( multiLineLayer );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_horizontalgrid" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_horizontalgrid" ), &l );
 
   delete multiLineLayer;
 }
@@ -1089,7 +1081,7 @@ void TestQgsLayoutTable::verticalGrid()
   table->setHorizontalGrid( false );
   table->setVerticalGrid( true );
   table->setVectorLayer( multiLineLayer );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_verticalgrid" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_verticalgrid" ), &l );
 
   delete multiLineLayer;
 }
@@ -1111,10 +1103,10 @@ void TestQgsLayoutTable::testDataDefinedTextFormatForCell()
   QgsTextFormat textFormat = QgsTextFormat::fromQFont( QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) ) );
   table->setHeaderTextFormat( textFormat );
 
-  textFormat.dataDefinedProperties().setProperty( QgsPalLayerSettings::Size, QgsProperty::fromExpression( QStringLiteral( "if(@column_number = 1,35,15)" ) ) );
+  textFormat.dataDefinedProperties().setProperty( QgsPalLayerSettings::Property::Size, QgsProperty::fromExpression( QStringLiteral( "if(@column_number = 1,35,15)" ) ) );
   table->setContentTextFormat( textFormat );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_datadefinedtextformat" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_datadefinedtextformat" ), &l );
 }
 
 void TestQgsLayoutTable::testIntegerNullCell()
@@ -1130,22 +1122,21 @@ void TestQgsLayoutTable::testIntegerNullCell()
   l.addLayoutItem( frame );
   table->addFrame( frame );
 
-  std::unique_ptr<QgsVectorLayer> layer = std::make_unique< QgsVectorLayer> ( QStringLiteral( "Point?field=intf:integer" ), QStringLiteral( "point" ), QStringLiteral( "memory" ) );
+  std::unique_ptr<QgsVectorLayer> layer = std::make_unique<QgsVectorLayer>( QStringLiteral( "Point?field=intf:integer" ), QStringLiteral( "point" ), QStringLiteral( "memory" ) );
   QVERIFY( layer->isValid() );
   QgsFeature f1( layer->dataProvider()->fields(), 1 );
   f1.setAttribute( QStringLiteral( "intf" ), 1 );
   QgsFeature f2( layer->dataProvider()->fields(), 2 );
   f2.setAttribute( QStringLiteral( "intf" ), 2 );
   QgsFeature f3( layer->dataProvider()->fields(), 3 );
-  f3.setAttribute( QStringLiteral( "intf" ), QVariant( QVariant::Int ) );
+  f3.setAttribute( QStringLiteral( "intf" ), QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) );
   layer->dataProvider()->addFeatures( QgsFeatureList() << f1 << f2 << f3 );
 
   table->setVectorLayer( layer.get() );
   table->setContentTextFormat( QgsTextFormat::fromQFont( QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) ) ) );
   table->setHeaderTextFormat( QgsTextFormat::fromQFont( QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) ) ) );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_integernullcell" ), &l ) );
-
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_integernullcell" ), &l );
 }
 
 void TestQgsLayoutTable::align()
@@ -1199,7 +1190,7 @@ void TestQgsLayoutTable::align()
   table->columns()[1].setVAlignment( Qt::AlignVCenter );
   table->columns()[2].setHAlignment( Qt::AlignRight );
   table->columns()[2].setVAlignment( Qt::AlignBottom );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_align" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_align" ), &l );
 
   delete multiLineLayer;
 }
@@ -1216,7 +1207,7 @@ void TestQgsLayoutTable::wrapChar()
   table->setHeaderTextFormat( QgsTextFormat::fromQFont( QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) ) ) );
   table->setBackgroundColor( Qt::yellow );
 
-  std::unique_ptr< QgsVectorLayer > multiLineLayer = std::make_unique< QgsVectorLayer >( QStringLiteral( "Point?field=col1:string&field=col2:string&field=col3:string" ), QStringLiteral( "multiline" ), QStringLiteral( "memory" ) );
+  std::unique_ptr<QgsVectorLayer> multiLineLayer = std::make_unique<QgsVectorLayer>( QStringLiteral( "Point?field=col1:string&field=col2:string&field=col3:string" ), QStringLiteral( "multiline" ), QStringLiteral( "memory" ) );
   QVERIFY( multiLineLayer->isValid() );
   QgsFeature f1( multiLineLayer->dataProvider()->fields(), 1 );
   f1.setAttribute( QStringLiteral( "col1" ), "multiline\nstring" );
@@ -1257,7 +1248,7 @@ void TestQgsLayoutTable::autoWrap()
   table->setHeaderTextFormat( QgsTextFormat::fromQFont( QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) ) ) );
   table->setBackgroundColor( Qt::yellow );
 
-  std::unique_ptr< QgsVectorLayer > multiLineLayer = std::make_unique< QgsVectorLayer >( QStringLiteral( "Point?field=col1:string&field=col2:string&field=col3:string" ), QStringLiteral( "multiline" ), QStringLiteral( "memory" ) );
+  std::unique_ptr<QgsVectorLayer> multiLineLayer = std::make_unique<QgsVectorLayer>( QStringLiteral( "Point?field=col1:string&field=col2:string&field=col3:string" ), QStringLiteral( "multiline" ), QStringLiteral( "memory" ) );
   QVERIFY( multiLineLayer->isValid() );
   QgsFeature f1( multiLineLayer->dataProvider()->fields(), 1 );
   f1.setAttribute( QStringLiteral( "col1" ), "long multiline\nstring" );
@@ -1285,7 +1276,7 @@ void TestQgsLayoutTable::autoWrap()
 
   table->columns()[0].setWidth( 25 );
   table->columns()[1].setWidth( 25 );
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_autowrap" ), &l ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_autowrap" ), &l );
 }
 
 void TestQgsLayoutTable::cellStyles()
@@ -1314,9 +1305,9 @@ void TestQgsLayoutTable::cellStyles()
 
   //write to xml
   QDomImplementation DomImplementation;
-  const QDomDocumentType documentType =
-    DomImplementation.createDocumentType(
-      QStringLiteral( "qgis" ), QStringLiteral( "http://mrcc.com/qgis.dtd" ), QStringLiteral( "SYSTEM" ) );
+  const QDomDocumentType documentType = DomImplementation.createDocumentType(
+    QStringLiteral( "qgis" ), QStringLiteral( "http://mrcc.com/qgis.dtd" ), QStringLiteral( "SYSTEM" )
+  );
   QDomDocument doc( documentType );
 
   //test writing with no node
@@ -1532,7 +1523,7 @@ void TestQgsLayoutTable::cellStylesRender()
   style.cellBackgroundColor = QColor( 50, 200, 200, 200 );
   table->setCellStyle( QgsLayoutTable::LastRow, style );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_cellstyle" ), &l, 0, 0, QSize(), 10 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_cellstyle" ), &l, 0, 0, QSize(), 10 );
 }
 
 void TestQgsLayoutTable::conditionalFormatting()
@@ -1570,7 +1561,7 @@ void TestQgsLayoutTable::conditionalFormatting()
   style2.setRule( QStringLiteral( "@value > 5" ) );
   style2.setTextColor( QColor( 255, 0, 0 ) );
   style2.setBackgroundColor( QColor( 0, 0, 255 ) );
-  mVectorLayer->conditionalStyles()->setFieldStyles( QStringLiteral( "Staff" ), QList< QgsConditionalStyle >() << style2 );
+  mVectorLayer->conditionalStyles()->setFieldStyles( QStringLiteral( "Staff" ), QList<QgsConditionalStyle>() << style2 );
 
   table->setUseConditionalStyling( true );
 
@@ -1591,7 +1582,7 @@ void TestQgsLayoutTable::conditionalFormatting()
   style.cellBackgroundColor = QColor( 50, 200, 200, 200 );
   table->setCellStyle( QgsLayoutTable::LastRow, style );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_conditionalstyles" ), &l, 0, 0, QSize(), 10 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_conditionalstyles" ), &l, 0, 0, QSize(), 10 );
 }
 
 void TestQgsLayoutTable::conditionalFormattingWithTextFormatting()
@@ -1637,7 +1628,7 @@ void TestQgsLayoutTable::conditionalFormattingWithTextFormatting()
   QFont conditionalFont2 = QgsFontUtils::getStandardTestFont( QStringLiteral( "Bold" ) );
   conditionalFont2.setUnderline( true );
   style2.setFont( conditionalFont2 );
-  mVectorLayer->conditionalStyles()->setFieldStyles( QStringLiteral( "Staff" ), QList< QgsConditionalStyle >() << style2 );
+  mVectorLayer->conditionalStyles()->setFieldStyles( QStringLiteral( "Staff" ), QList<QgsConditionalStyle>() << style2 );
 
   table->setUseConditionalStyling( true );
 
@@ -1658,7 +1649,7 @@ void TestQgsLayoutTable::conditionalFormattingWithTextFormatting()
   style.cellBackgroundColor = QColor( 50, 200, 200, 200 );
   table->setCellStyle( QgsLayoutTable::LastRow, style );
 
-  QVERIFY( layoutCheck( QStringLiteral( "composerattributetable_conditionalstyles_text" ), &l, 0, 0, QSize(), 10 ) );
+  QGSVERIFYLAYOUTCHECK( QStringLiteral( "composerattributetable_conditionalstyles_text" ), &l, 0, 0, QSize(), 10 );
 }
 
 void TestQgsLayoutTable::dataDefinedSource()
@@ -1696,25 +1687,25 @@ void TestQgsLayoutTable::dataDefinedSource()
   table->setVectorLayer( layer1 );
   table->setMaximumNumberOfFeatures( 50 );
   QCOMPARE( table->contents().length(), 1 );
-  QCOMPARE( table->contents().at( 0 ), QVector< QVariant >() << 1 << 2 << 3 );
+  QCOMPARE( table->contents().at( 0 ), QVector<QVariant>() << 1 << 2 << 3 );
 
   // data defined table name, by layer id
-  table->dataDefinedProperties().setProperty( QgsLayoutObject::AttributeTableSourceLayer, layer1->id() );
+  table->dataDefinedProperties().setProperty( QgsLayoutObject::DataDefinedProperty::AttributeTableSourceLayer, layer1->id() );
   table->refresh();
   QCOMPARE( table->contents().length(), 1 );
-  QCOMPARE( table->contents().at( 0 ), QVector< QVariant >() << 1 << 2 << 3 );
+  QCOMPARE( table->contents().at( 0 ), QVector<QVariant>() << 1 << 2 << 3 );
 
   // by layer name
-  table->dataDefinedProperties().setProperty( QgsLayoutObject::AttributeTableSourceLayer, QStringLiteral( "l2" ) );
+  table->dataDefinedProperties().setProperty( QgsLayoutObject::DataDefinedProperty::AttributeTableSourceLayer, QStringLiteral( "l2" ) );
   table->refresh();
   QCOMPARE( table->contents().length(), 1 );
-  QCOMPARE( table->contents().at( 0 ), QVector< QVariant >() << 11 << 12 << 13 );
+  QCOMPARE( table->contents().at( 0 ), QVector<QVariant>() << 11 << 12 << 13 );
 
   // by layer name (case insensitive)
-  table->dataDefinedProperties().setProperty( QgsLayoutObject::AttributeTableSourceLayer, QStringLiteral( "L3" ) );
+  table->dataDefinedProperties().setProperty( QgsLayoutObject::DataDefinedProperty::AttributeTableSourceLayer, QStringLiteral( "L3" ) );
   table->refresh();
   QCOMPARE( table->contents().length(), 1 );
-  QCOMPARE( table->contents().at( 0 ), QVector< QVariant >() << 21 << QVariant() << 23 );
+  QCOMPARE( table->contents().at( 0 ), QVector<QVariant>() << 21 << QVariant() << 23 );
 
   // delete current data defined layer match
   p.removeMapLayer( layer3->id() );
@@ -1722,7 +1713,7 @@ void TestQgsLayoutTable::dataDefinedSource()
   // expect table to return to preset layer
   table->refreshAttributes();
   QCOMPARE( table->contents().length(), 1 );
-  QCOMPARE( table->contents().at( 0 ), QVector< QVariant >() << 1 << 2 << 3 );
+  QCOMPARE( table->contents().at( 0 ), QVector<QVariant>() << 1 << 2 << 3 );
 }
 
 void TestQgsLayoutTable::wrappedText()
@@ -1749,7 +1740,7 @@ void TestQgsLayoutTable::testBaseSort()
   QgsLayoutTableColumn col;
   col.setAttribute( table->columns()[2].attribute() );
   col.setSortOrder( Qt::DescendingOrder );
-  table->sortColumns() = {col};
+  table->sortColumns() = { col };
   table->refresh();
 
   QVector<QStringList> expectedRows;
@@ -1774,7 +1765,7 @@ void TestQgsLayoutTable::testExpressionSort()
   col.setAttribute( "Heading * -1" );
   col.setHeading( "exp" );
   col.setSortOrder( Qt::AscendingOrder );
-  table->sortColumns() = {col};
+  table->sortColumns() = { col };
   table->columns()[0] = col;
   table->refresh();
 
@@ -1796,7 +1787,7 @@ void TestQgsLayoutTable::testScopeForCell()
   table->setVectorLayer( mVectorLayer );
   table->refresh();
 
-  std::unique_ptr< QgsExpressionContextScope > scope( table->scopeForCell( 0, 0 ) );
+  std::unique_ptr<QgsExpressionContextScope> scope( table->scopeForCell( 0, 0 ) );
 
   // variable values for row/col should start at 1, not 0!
   QCOMPARE( scope->variable( QStringLiteral( "row_number" ) ).toInt(), 1 );
