@@ -26,6 +26,7 @@
 #include <memory>
 
 #include <QLineEdit>
+#include <QSignalSpy>
 
 class QgsFilterLineEdit;
 
@@ -36,10 +37,10 @@ class TestQgsFeatureListComboBox : public QObject
     TestQgsFeatureListComboBox() = default;
 
   private slots:
-    void initTestCase(); // will be called before the first testfunction is executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
     void cleanupTestCase(); // will be called after the last testfunction was executed.
-    void init(); // will be called before each testfunction is executed.
-    void cleanup(); // will be called after every testfunction.
+    void init();            // will be called before each testfunction is executed.
+    void cleanup();         // will be called after every testfunction.
 
     void testSetGetLayer();
     void testSetGetForeignKey();
@@ -49,9 +50,9 @@ class TestQgsFeatureListComboBox : public QObject
     void testValuesAndSelection_data();
     void nullRepresentation();
     void testNotExistingYetFeature();
+    void testFeatureFurtherThanFetchLimit();
 
   private:
-
     std::unique_ptr<QgsVectorLayer> mLayer;
 
     friend class QgsFeatureListComboBox;
@@ -66,7 +67,6 @@ void TestQgsFeatureListComboBox::initTestCase()
   QCoreApplication::setOrganizationName( QStringLiteral( "QGIS" ) );
   QCoreApplication::setOrganizationDomain( QStringLiteral( "qgis.org" ) );
   QCoreApplication::setApplicationName( QStringLiteral( "QGIS-TEST-FEATURELIST-COMBOBOX" ) );
-
 }
 
 void TestQgsFeatureListComboBox::cleanupTestCase()
@@ -78,6 +78,7 @@ void TestQgsFeatureListComboBox::init()
 {
   // create layer
   mLayer.reset( new QgsVectorLayer( QStringLiteral( "LineString?field=pk:int&field=material:string&field=diameter:int&field=raccord:string" ), QStringLiteral( "vl2" ), QStringLiteral( "memory" ) ) );
+  mLayer->setDisplayExpression( QStringLiteral( "pk" ) );
 
   // add features
   mLayer->startEditing();
@@ -103,6 +104,18 @@ void TestQgsFeatureListComboBox::init()
   ft3.setAttribute( QStringLiteral( "raccord" ), "collar" );
   mLayer->addFeature( ft3 );
 
+  QgsFeatureList flist;
+  for ( int i = 13; i < 40; i++ )
+  {
+    QgsFeature f( mLayer->fields() );
+    f.setAttribute( QStringLiteral( "pk" ), i );
+    f.setAttribute( QStringLiteral( "material" ), QStringLiteral( "material_%1" ).arg( i ) );
+    f.setAttribute( QStringLiteral( "diameter" ), i );
+    f.setAttribute( QStringLiteral( "raccord" ), QStringLiteral( "raccord_%1" ).arg( i ) );
+    flist << f;
+  }
+  mLayer->addFeatures( flist );
+
   mLayer->commitChanges();
 }
 
@@ -121,27 +134,23 @@ void TestQgsFeatureListComboBox::testSetGetLayer()
 
 void TestQgsFeatureListComboBox::testSetGetForeignKey()
 {
-  std::unique_ptr<QgsFeatureListComboBox> cb( new QgsFeatureListComboBox() );
-
-  QgsFeatureFilterModel *model = qobject_cast<QgsFeatureFilterModel *>( cb->model() );
-  QEventLoop loop;
-  connect( model, &QgsFeatureFilterModel::filterJobCompleted, &loop, &QEventLoop::quit );
+  QgsFeatureListComboBox cb;
 
   Q_NOWARN_DEPRECATED_PUSH
-  QVERIFY( cb->identifierValue().isNull() );
+  QVERIFY( cb.identifierValue().isNull() );
 
-  cb->setSourceLayer( mLayer.get() );
-  cb->setDisplayExpression( "\"material\"" );
-  cb->lineEdit()->setText( "ro" );
-  emit cb->lineEdit()->textChanged( "ro" );
-  QVERIFY( cb->identifierValue().isNull() );
+  cb.setSourceLayer( mLayer.get() );
+  cb.setDisplayExpression( "\"material\"" );
+  cb.setIdentifierField( "material" );
 
-  loop.exec();
+  QSignalSpy spy( &cb, &QgsFeatureListComboBox::identifierValueChanged );
+  QTest::keyClicks( cb.lineEdit(), "ro" );
+  QTest::keyClick( cb.lineEdit(), Qt::Key_Enter );
 
-  QVERIFY( cb->identifierValue().isNull() );
+  spy.wait();
+
+  QCOMPARE( cb.identifierValue().toString(), QStringLiteral( "iron" ) );
 
-  cb->setIdentifierValue( 20 );
-  QCOMPARE( cb->identifierValue(), QVariant( 20 ) );
   Q_NOWARN_DEPRECATED_POP
 }
 
@@ -163,14 +172,14 @@ void TestQgsFeatureListComboBox::testMultipleForeignKeys()
 
   cb->setIdentifierValuesToNull();
   QCOMPARE( cb->identifierValues().count(), 3 );
-  QCOMPARE( cb->identifierValues(), QVariantList() << QVariant( QVariant::Int ) << QVariant( QVariant::Int ) << QVariant( QVariant::Int ) );
+  QCOMPARE( cb->identifierValues(), QVariantList() << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) );
 
   cb->setIdentifierValues( QVariantList() << "silver" << 888 << "fish" );
   QCOMPARE( cb->identifierValues(), QVariantList() << "silver" << 888 << "fish" );
 
   cb->setIdentifierValuesToNull();
   QCOMPARE( cb->identifierValues().count(), 3 );
-  QCOMPARE( cb->identifierValues(), QVariantList() << QVariant( QVariant::Int ) << QVariant( QVariant::Int ) << QVariant( QVariant::Int ) );
+  QCOMPARE( cb->identifierValues(), QVariantList() << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) );
 
   cb->setIdentifierFields( QStringList() << "material" << "raccord" );
   cb->setDisplayExpression( "\"material\" || ' ' || \"raccord\"" );
@@ -182,7 +191,7 @@ void TestQgsFeatureListComboBox::testMultipleForeignKeys()
 
   cb->setIdentifierValuesToNull();
   QCOMPARE( cb->identifierValues().count(), 2 );
-  QCOMPARE( cb->identifierValues(), QVariantList() << QVariant( QVariant::Int ) << QVariant( QVariant::Int ) );
+  QCOMPARE( cb->identifierValues(), QVariantList() << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) << QgsVariantUtils::createNullVariant( QMetaType::Type::Int ) );
 }
 
 void TestQgsFeatureListComboBox::testAllowNull()
@@ -203,20 +212,18 @@ void TestQgsFeatureListComboBox::testValuesAndSelection()
 {
   QFETCH( bool, allowNull );
 
-
   QgsApplication::setNullRepresentation( QStringLiteral( "nope" ) );
   std::unique_ptr<QgsFeatureListComboBox> cb( new QgsFeatureListComboBox() );
 
-  QgsFeatureFilterModel *model = qobject_cast<QgsFeatureFilterModel *>( cb->model() );
-  QEventLoop loop;
-  connect( model, &QgsFeatureFilterModel::filterJobCompleted, &loop, &QEventLoop::quit );
+  QSignalSpy spy( cb.get(), &QgsFeatureListComboBox::identifierValueChanged );
 
   cb->setSourceLayer( mLayer.get() );
-  cb->setDisplayExpression( QStringLiteral( "\"raccord\"" ) );
   cb->setAllowNull( allowNull );
+  cb->setIdentifierFields( { QStringLiteral( "raccord" ) } );
+  cb->setDisplayExpression( QStringLiteral( "\"raccord\"" ) );
 
   //check if everything is fine:
-  loop.exec();
+  spy.wait();
   QCOMPARE( cb->currentIndex(), allowNull ? cb->nullIndex() : 0 );
   QCOMPARE( cb->currentText(), allowNull ? QStringLiteral( "nope" ) : QStringLiteral( "brides" ) );
 
@@ -225,18 +232,18 @@ void TestQgsFeatureListComboBox::testValuesAndSelection()
   QCOMPARE( cb->currentIndex(), allowNull ? cb->nullIndex() : 0 );
   QCOMPARE( cb->currentText(), allowNull ? QStringLiteral( "nope" ) : QString() );
   QCOMPARE( cb->lineEdit()->selectedText(), allowNull ? QStringLiteral( "nope" ) : QString() );
-  QVERIFY( ! cb->mLineEdit->mClearAction );
+  QVERIFY( !cb->mLineEdit->mClearAction );
 
   //check if text is selected after receiving focus
   cb->setFocus();
   QCOMPARE( cb->currentIndex(), allowNull ? cb->nullIndex() : 0 );
   QCOMPARE( cb->currentText(), allowNull ? QStringLiteral( "nope" ) : QString() );
   QCOMPARE( cb->lineEdit()->selectedText(), allowNull ? QStringLiteral( "nope" ) : QString() );
-  QVERIFY( ! cb->mLineEdit->mClearAction );
+  QVERIFY( !cb->mLineEdit->mClearAction );
 
   //check with another entry, clear button needs to be there then:
   QTest::keyClicks( cb.get(), QStringLiteral( "sleeve" ) );
-  loop.exec();
+  spy.wait();
   QCOMPARE( cb->currentText(), QStringLiteral( "sleeve" ) );
   QVERIFY( cb->mLineEdit->mClearAction );
 }
@@ -282,5 +289,27 @@ void TestQgsFeatureListComboBox::testNotExistingYetFeature()
   QCOMPARE( cb->currentText(), QStringLiteral( "(42)" ) );
 }
 
+void TestQgsFeatureListComboBox::testFeatureFurtherThanFetchLimit()
+{
+  const int fetchLimit = 20;
+  QVERIFY( fetchLimit < mLayer->featureCount() );
+  std::unique_ptr<QgsFeatureListComboBox> cb( new QgsFeatureListComboBox() );
+  QgsFeatureFilterModel *model = qobject_cast<QgsFeatureFilterModel *>( cb->model() );
+  QSignalSpy spy( cb.get(), &QgsFeatureListComboBox::identifierValueChanged );
+  model->setFetchLimit( 20 );
+  model->setAllowNull( false );
+  cb->setSourceLayer( mLayer.get() );
+  cb->setIdentifierFields( { QStringLiteral( "pk" ) } );
+  spy.wait();
+  QCOMPARE( model->mEntries.count(), 20 );
+  for ( int i = 0; i < 20; i++ )
+    QCOMPARE( model->mEntries.at( i ).identifierFields.at( 0 ).toInt(), i + 10 );
+  cb->setIdentifierValues( { 33 } );
+  spy.wait();
+  QCOMPARE( cb->lineEdit()->text(), QStringLiteral( "33" ) );
+  QCOMPARE( model->mEntries.count(), 21 );
+  QCOMPARE( model->mEntries.at( 0 ).identifierFields.at( 0 ).toInt(), 33 );
+}
+
 QGSTEST_MAIN( TestQgsFeatureListComboBox )
 #include "testqgsfeaturelistcombobox.moc"
