@@ -22,22 +22,22 @@
 #include <qgspostgresconn.h>
 #include <qgsfields.h>
 
-class TestQgsPostgresProvider: public QObject
+class TestQgsPostgresProvider : public QObject
 {
     Q_OBJECT
 
   private:
-
 #ifdef ENABLE_PGTEST
     QgsPostgresConn *_connection;
 
 
     QgsPostgresConn *getConnection()
     {
-      if ( ! _connection )
+      if ( !_connection )
       {
         const char *connstring = getenv( "QGIS_PGTEST_DB" );
-        if ( !connstring ) connstring = "service=qgis_test";
+        if ( !connstring )
+          connstring = "service=qgis_test";
         _connection = QgsPostgresConn::connectDb( connstring, true );
       }
       return _connection;
@@ -55,7 +55,8 @@ class TestQgsPostgresProvider: public QObject
     void cleanupTestCase() // will be called after the last testfunction was executed.
     {
 #ifdef ENABLE_PGTEST
-      if ( this->_connection ) this->_connection->unref();
+      if ( this->_connection )
+        this->_connection->unref();
 #endif
     }
 
@@ -79,11 +80,10 @@ class TestQgsPostgresProvider: public QObject
 };
 
 
-
 void TestQgsPostgresProvider::decodeHstore()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "\"1\"=>\"2\", \"a\"=>\"b, \\\"c'\", \"backslash\"=>\"\\\\\"" ), QStringLiteral( "hstore" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Map );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "\"1\"=>\"2\", \"a\"=>\"b, \\\"c'\", \"backslash\"=>\"\\\\\"" ), QStringLiteral( "hstore" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantMap );
 
   QVariantMap expected;
   expected[QStringLiteral( "1" )] = "2";
@@ -95,8 +95,8 @@ void TestQgsPostgresProvider::decodeHstore()
 
 void TestQgsPostgresProvider::decodeHstoreNoQuote()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "1=>2, a=>b c" ), QStringLiteral( "hstore" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Map );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "1=>2, a=>b c" ), QStringLiteral( "hstore" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantMap );
 
   QVariantMap expected;
   expected[QStringLiteral( "1" )] = "2";
@@ -107,8 +107,8 @@ void TestQgsPostgresProvider::decodeHstoreNoQuote()
 
 void TestQgsPostgresProvider::decodeArray2StringList()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::StringList, QVariant::String, QStringLiteral( "{\"1\",\"2\", \"a\\\\1\" , \"\\\\\",\"b, \\\"c'\"}" ), QStringLiteral( "hstore" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::StringList );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QStringList, QMetaType::Type::QString, QStringLiteral( "{\"1\",\"2\", \"a\\\\1\" , \"\\\\\",\"b, \\\"c'\"}" ), QStringLiteral( "hstore" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QStringList );
 
   QStringList expected;
   expected << QStringLiteral( "1" ) << QStringLiteral( "2" ) << QStringLiteral( "a\\1" ) << QStringLiteral( "\\" ) << QStringLiteral( "b, \"c'" );
@@ -118,8 +118,8 @@ void TestQgsPostgresProvider::decodeArray2StringList()
 
 void TestQgsPostgresProvider::decodeArray2StringListNoQuote()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::StringList, QVariant::String, QStringLiteral( "{1,2, a ,b, c}" ), QStringLiteral( "hstore" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::StringList );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QStringList, QMetaType::Type::QString, QStringLiteral( "{1,2, a ,b, c}" ), QStringLiteral( "hstore" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QStringList );
 
   QStringList expected;
   expected << QStringLiteral( "1" ) << QStringLiteral( "2" ) << QStringLiteral( "a" ) << QStringLiteral( "b" ) << QStringLiteral( "c" );
@@ -129,8 +129,8 @@ void TestQgsPostgresProvider::decodeArray2StringListNoQuote()
 
 void TestQgsPostgresProvider::decodeArray2IntList()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::StringList, QVariant::String, QStringLiteral( "{1, 2, 3,-5,10}" ), QStringLiteral( "hstore" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::StringList );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QStringList, QMetaType::Type::QString, QStringLiteral( "{1, 2, 3,-5,10}" ), QStringLiteral( "hstore" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QStringList );
 
   QVariantList expected;
   expected << QVariant( 1 ) << QVariant( 2 ) << QVariant( 3 ) << QVariant( -5 ) << QVariant( 10 );
@@ -140,8 +140,8 @@ void TestQgsPostgresProvider::decodeArray2IntList()
 
 void TestQgsPostgresProvider::decode2DimensionArray()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::StringList, QVariant::String, QStringLiteral( "{{foo,\"escape bracket \\}\"},{\"escape bracket and backslash \\\\\\}\",\"hello bar\"}}" ), QStringLiteral( "_text" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::StringList );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QStringList, QMetaType::Type::QString, QStringLiteral( "{{foo,\"escape bracket \\}\"},{\"escape bracket and backslash \\\\\\}\",\"hello bar\"}}" ), QStringLiteral( "_text" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QStringList );
 
   QVariantList expected;
   expected << QVariant( "{foo,\"escape bracket \\}\"}" ) << QVariant( "{\"escape bracket and backslash \\\\\\}\",\"hello bar\"}" );
@@ -151,8 +151,8 @@ void TestQgsPostgresProvider::decode2DimensionArray()
 
 void TestQgsPostgresProvider::decode3DimensionArray()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::StringList, QVariant::String, QStringLiteral( "{{{0,1},{1,2}},{{3,4},{5,6}}}" ), QStringLiteral( "_integer" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::StringList );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QStringList, QMetaType::Type::QString, QStringLiteral( "{{{0,1},{1,2}},{{3,4},{5,6}}}" ), QStringLiteral( "_integer" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QStringList );
 
   QVariantList expected;
   expected << QVariant( "{{0,1},{1,2}}" ) << QVariant( "{{3,4},{5,6}}" );
@@ -162,8 +162,8 @@ void TestQgsPostgresProvider::decode3DimensionArray()
 
 void TestQgsPostgresProvider::decodeJsonList()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "[1,2,3]" ), QStringLiteral( "json" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::List );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "[1,2,3]" ), QStringLiteral( "json" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantList );
 
   QVariantList expected;
   expected.append( 1 );
@@ -175,8 +175,8 @@ void TestQgsPostgresProvider::decodeJsonList()
 
 void TestQgsPostgresProvider::decodeJsonbList()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "[1,2,3]" ), QStringLiteral( "jsonb" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::List );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "[1,2,3]" ), QStringLiteral( "jsonb" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantList );
 
   QVariantList expected;
   expected.append( 1 );
@@ -188,8 +188,8 @@ void TestQgsPostgresProvider::decodeJsonbList()
 
 void TestQgsPostgresProvider::decodeJsonMap()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "{\"a\":1,\"b\":2}" ), QStringLiteral( "json" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Map );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "{\"a\":1,\"b\":2}" ), QStringLiteral( "json" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantMap );
 
   QVariantMap expected;
   expected[QStringLiteral( "a" )] = "1";
@@ -200,8 +200,8 @@ void TestQgsPostgresProvider::decodeJsonMap()
 
 void TestQgsPostgresProvider::decodeJsonbMap()
 {
-  const QVariant decoded = QgsPostgresProvider::convertValue( QVariant::Map, QVariant::String, QStringLiteral( "{\"a\":1,\"b\":2}" ), QStringLiteral( "jsonb" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Map );
+  const QVariant decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QVariantMap, QMetaType::Type::QString, QStringLiteral( "{\"a\":1,\"b\":2}" ), QStringLiteral( "jsonb" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QVariantMap );
 
   QVariantMap expected;
   expected[QStringLiteral( "a" )] = "1";
@@ -212,24 +212,22 @@ void TestQgsPostgresProvider::decodeJsonbMap()
 
 void TestQgsPostgresProvider::testDecodeDateTimes()
 {
-
   QVariant decoded;
 
-  decoded = QgsPostgresProvider::convertValue( QVariant::DateTime, QVariant::Invalid, QStringLiteral( "2020-06-08 18:30:35.496438+02" ), QStringLiteral( "timestamptz" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::DateTime );
+  decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QDateTime, QMetaType::Type::UnknownType, QStringLiteral( "2020-06-08 18:30:35.496438+02" ), QStringLiteral( "timestamptz" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QDateTime );
 
-  decoded = QgsPostgresProvider::convertValue( QVariant::Time, QVariant::Invalid, QStringLiteral( "18:29:27.569401+02" ), QStringLiteral( "timetz" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Time );
+  decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QTime, QMetaType::Type::UnknownType, QStringLiteral( "18:29:27.569401+02" ), QStringLiteral( "timetz" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QTime );
 
-  decoded = QgsPostgresProvider::convertValue( QVariant::Date, QVariant::Invalid, QStringLiteral( "2020-06-08" ), QStringLiteral( "date" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Date );
+  decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QDate, QMetaType::Type::UnknownType, QStringLiteral( "2020-06-08" ), QStringLiteral( "date" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QDate );
 
-  decoded = QgsPostgresProvider::convertValue( QVariant::DateTime, QVariant::Invalid, QStringLiteral( "2020-06-08 18:30:35.496438" ), QStringLiteral( "timestamp" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::DateTime );
-
-  decoded = QgsPostgresProvider::convertValue( QVariant::Time, QVariant::Invalid, QStringLiteral( "18:29:27.569401" ), QStringLiteral( "time" ), nullptr );
-  QCOMPARE( decoded.type(), QVariant::Time );
+  decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QDateTime, QMetaType::Type::UnknownType, QStringLiteral( "2020-06-08 18:30:35.496438" ), QStringLiteral( "timestamp" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QDateTime );
 
+  decoded = QgsPostgresProvider::convertValue( QMetaType::Type::QTime, QMetaType::Type::UnknownType, QStringLiteral( "18:29:27.569401" ), QStringLiteral( "time" ), nullptr );
+  QCOMPARE( static_cast<QMetaType::Type>( decoded.userType() ), QMetaType::Type::QTime );
 }
 
 void TestQgsPostgresProvider::testQuotedValueBigInt()
@@ -238,13 +236,13 @@ void TestQgsPostgresProvider::testQuotedValueBigInt()
   QList<int> pkAttrs;
   QVariantList vlst;
 
-  const std::shared_ptr< QgsPostgresSharedData > sdata( new QgsPostgresSharedData() );
+  const std::shared_ptr<QgsPostgresSharedData> sdata( new QgsPostgresSharedData() );
 
   QgsField f0, f1, f2, f3;
 
   // 4 byte integer
   f0.setName( "fld_integer" );
-  f0.setType( QVariant::Int );
+  f0.setType( QMetaType::Type::Int );
   f0.setTypeName( "int4" );
 
   fields.append( f0 );
@@ -258,7 +256,7 @@ void TestQgsPostgresProvider::testQuotedValueBigInt()
 
   // 8 byte integer
   f1.setName( "fld_bigint" );
-  f1.setType( QVariant::LongLong );
+  f1.setType( QMetaType::Type::LongLong );
   f1.setTypeName( "int8" );
 
   fields.clear();
@@ -276,7 +274,7 @@ void TestQgsPostgresProvider::testQuotedValueBigInt()
 
   // double
   f2.setName( "fld_double" );
-  f2.setType( QVariant::Double );
+  f2.setType( QMetaType::Type::Double );
   f2.setTypeName( "float8" );
 
   fields.clear();
@@ -294,7 +292,7 @@ void TestQgsPostgresProvider::testQuotedValueBigInt()
 
   // text
   f3.setName( "fld_text" );
-  f3.setType( QVariant::String );
+  f3.setType( QMetaType::Type::QString );
   f3.setTypeName( "text" );
 
   fields.clear();
@@ -340,44 +338,44 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   QgsFields fields;
   QList<int> pkAttrs;
 
-  const std::shared_ptr< QgsPostgresSharedData > sdata( new QgsPostgresSharedData() );
+  const std::shared_ptr<QgsPostgresSharedData> sdata( new QgsPostgresSharedData() );
 
   QgsField f0, f1, f2, f3;
 
   // need regular expression to check IN/OR because QgsFeatureIds is a set and ids could come
   // in various order
 
-#define CHECK_IN_CLAUSE(whereClause,expectedValues)                     \
-  {                                                                     \
-    QRegularExpression inRe("\\\"fld\\\" IN \\(([^,]*),([^,]*)\\)");    \
-    QVERIFY(inRe.isValid());                                            \
-    QRegularExpressionMatch match = inRe.match( whereClause );          \
-    QVERIFY( match.hasMatch() );                                        \
-    QStringList values;                                                 \
-    values << match.captured(1);                                        \
-    values << match.captured(2);                                        \
-    std::sort( values.begin(), values.end() );                          \
-    QCOMPARE( values, expectedValues );                                 \
+#define CHECK_IN_CLAUSE( whereClause, expectedValues )                 \
+  {                                                                    \
+    QRegularExpression inRe( "\\\"fld\\\" IN \\(([^,]*),([^,]*)\\)" ); \
+    QVERIFY( inRe.isValid() );                                         \
+    QRegularExpressionMatch match = inRe.match( whereClause );         \
+    QVERIFY( match.hasMatch() );                                       \
+    QStringList values;                                                \
+    values << match.captured( 1 );                                     \
+    values << match.captured( 2 );                                     \
+    std::sort( values.begin(), values.end() );                         \
+    QCOMPARE( values, expectedValues );                                \
   }
 
   // QRegularExpression inOr("\\(\\\"fld\\\"=([^,]*) OR \\\"fld\\\"=([^,]*)\\)");
 
-#define CHECK_OR_CLAUSE(whereClause,expectedValues)                     \
-  {                                                                     \
-    QRegularExpression inOr("\\((.*) OR (.*)\\)");                      \
-    QVERIFY(inOr.isValid());                                            \
-    QRegularExpressionMatch match = inOr.match( whereClause );          \
-    QVERIFY( match.hasMatch() );                                        \
-    QStringList values;                                                 \
-    values << match.captured(1);                                        \
-    values << match.captured(2);                                        \
-    std::sort( values.begin(), values.end() );                          \
-    QCOMPARE( values, expectedValues );                                 \
+#define CHECK_OR_CLAUSE( whereClause, expectedValues )         \
+  {                                                            \
+    QRegularExpression inOr( "\\((.*) OR (.*)\\)" );           \
+    QVERIFY( inOr.isValid() );                                 \
+    QRegularExpressionMatch match = inOr.match( whereClause ); \
+    QVERIFY( match.hasMatch() );                               \
+    QStringList values;                                        \
+    values << match.captured( 1 );                             \
+    values << match.captured( 2 );                             \
+    std::sort( values.begin(), values.end() );                 \
+    QCOMPARE( values, expectedValues );                        \
   }
 
   // 4 byte integer -> IN clause
   f0.setName( "fld" );
-  f0.setType( QVariant::Int );
+  f0.setType( QMetaType::Type::Int );
   f0.setTypeName( "int4" );
 
   // for positive integers, fid  == the value, there is no map.
@@ -387,12 +385,11 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   sdata->insertFid( 42, QVariantList() << 42 );
   sdata->insertFid( 43, QVariantList() << 43 );
 
-  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 42 << 43, fields, NULL, QgsPostgresPrimaryKeyType::PktInt, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ),
-                   QStringList() << "42" << "43" );
+  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 42 << 43, fields, NULL, QgsPostgresPrimaryKeyType::PktInt, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ), QStringList() << "42" << "43" );
 
   // 8 byte integer -> IN clause
   f1.setName( "fld" );
-  f1.setType( QVariant::LongLong );
+  f1.setType( QMetaType::Type::LongLong );
   f1.setTypeName( "int8" );
 
   fields.clear();
@@ -405,12 +402,11 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   sdata->insertFid( 1LL, QVariantList() << -9223372036854775800LL ); // way outside int4 range
   sdata->insertFid( 2LL, QVariantList() << -9223372036854775801LL );
 
-  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktInt64, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ),
-                   QStringList() << "-9223372036854775800" << "-9223372036854775801" );
+  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktInt64, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ), QStringList() << "-9223372036854775800" << "-9223372036854775801" );
 
   // double -> OR clause
   f2.setName( "fld" );
-  f2.setType( QVariant::Double );
+  f2.setType( QMetaType::Type::Double );
   f2.setTypeName( "float8" );
 
   fields.clear();
@@ -423,12 +419,11 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   sdata->insertFid( 1LL, QVariantList() << 3.141592741 );
   sdata->insertFid( 2LL, QVariantList() << 6.141592741 );
 
-  CHECK_OR_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ),
-                   QStringList() << "\"fld\"='3.141592741'" << "\"fld\"='6.141592741'" );
+  CHECK_OR_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ), QStringList() << "\"fld\"='3.141592741'" << "\"fld\"='6.141592741'" );
 
   // text -> IN clause
   f3.setName( "fld" );
-  f3.setType( QVariant::String );
+  f3.setType( QMetaType::Type::QString );
   f3.setTypeName( "text" );
 
   fields.clear();
@@ -441,8 +436,7 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   sdata->insertFid( 1LL, QVariantList() << QString( "QGIS 'Rocks'!" ) );
   sdata->insertFid( 2LL, QVariantList() << QString( "PostGIS too!" ) );
 
-  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ),
-                   QStringList() << "'PostGIS too!'" << "'QGIS ''Rocks''!'" );
+  CHECK_IN_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ), QStringList() << "'PostGIS too!'" << "'QGIS ''Rocks''!'" );
 
   // Composite text + int -> OR clause
   f0.setName( "fld_int" );
@@ -458,9 +452,8 @@ void TestQgsPostgresProvider::testWhereClauseFids()
   sdata->insertFid( 1LL, QVariantList() << 42 << QString( "QGIS 'Rocks'!" ) );
   sdata->insertFid( 2LL, QVariantList() << 43 << QString( "PostGIS too!" ) );
 
-  CHECK_OR_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ),
-                   QStringList() << "\"fld_int\"=42 AND \"fld\"::text='QGIS ''Rocks''!'"
-                   << "\"fld_int\"=43 AND \"fld\"::text='PostGIS too!'" );
+  CHECK_OR_CLAUSE( QgsPostgresUtils::whereClause( QgsFeatureIds() << 1LL << 2LL, fields, NULL, QgsPostgresPrimaryKeyType::PktFidMap, pkAttrs, std::shared_ptr<QgsPostgresSharedData>( sdata ) ), QStringList() << "\"fld_int\"=42 AND \"fld\"::text='QGIS ''Rocks''!'"
+                                                                                                                                                                                                               << "\"fld_int\"=43 AND \"fld\"::text='PostGIS too!'" );
 }
 
 #ifdef ENABLE_PGTEST
@@ -474,7 +467,7 @@ void TestQgsPostgresProvider::testEwktInOut()
   QString ewkt_obtained;
 
   g = QgsPostgresProvider::fromEwkt( "SRID=4326;LINESTRING(0 0,-5 2)", conn );
-  QVERIFY( ! g.isNull() );
+  QVERIFY( !g.isNull() );
   QCOMPARE( g.crs().authid(), "EPSG:4326" );
   ewkt_obtained = QgsPostgresProvider::toEwkt( g, conn );
   QCOMPARE( ewkt_obtained, "SRID=4326;LineString (0 0, -5 2)" );
@@ -482,11 +475,10 @@ void TestQgsPostgresProvider::testEwktInOut()
   // Test for srid-less geometry
   // See https://github.com/qgis/QGIS/issues/49380#issuecomment-1282913470
   g = QgsPostgresProvider::fromEwkt( "POINT(0 0)", conn );
-  QVERIFY( ! g.isNull() );
+  QVERIFY( !g.isNull() );
   ewkt_obtained = QgsPostgresProvider::toEwkt( g, conn );
-  QVERIFY( ! g.crs().isValid() ); // is unknown
+  QVERIFY( !g.crs().isValid() ); // is unknown
   QCOMPARE( ewkt_obtained, QString( "SRID=0;Point (0 0)" ) );
-
 }
 #endif // ENABLE_PGTEST
 
