@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '28/3/2022'
-__copyright__ = 'Copyright 2022, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nyall Dawson"
+__date__ = "28/3/2022"
+__copyright__ = "Copyright 2022, The QGIS Project"
+
 from qgis.PyQt.QtCore import QDir, QSizeF, Qt
 from qgis.PyQt.QtGui import QColor, QImage, QPainter
 from qgis.PyQt.QtXml import QDomDocument
@@ -22,11 +22,10 @@ from qgis.core import (
     QgsPalLayerSettings,
     QgsProperty,
     QgsReadWriteContext,
-    QgsRenderChecker,
     QgsRenderContext,
     QgsSymbolLayer,
     QgsTextFormat,
-    Qgis
+    Qgis,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -38,32 +37,46 @@ class TestQgsPlot(QgisTestCase):
 
     @classmethod
     def control_path_prefix(cls):
-        return 'plot'
+        return "plot"
 
     def testPlot(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -73,7 +86,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -88,8 +101,8 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -98,38 +111,52 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_base', 'plot_2d_base', im)
+        assert self.image_check("plot_2d_base", "plot_2d_base", im)
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 64.8, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testPlotSuffixAll(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -139,7 +166,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -154,13 +181,13 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        plot.xAxis().setLabelSuffix('x')
+        plot.xAxis().setLabelSuffix("x")
         plot.xAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.EveryLabel)
-        plot.yAxis().setLabelSuffix('y')
+        plot.yAxis().setLabelSuffix("y")
         plot.yAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.EveryLabel)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -169,38 +196,54 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_base_suffix_all', 'plot_2d_base_suffix_all', im)
+        assert self.image_check(
+            "plot_2d_base_suffix_all", "plot_2d_base_suffix_all", im
+        )
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 80.46, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testPlotSuffixFirst(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -210,7 +253,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -225,13 +268,13 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        plot.xAxis().setLabelSuffix('x')
+        plot.xAxis().setLabelSuffix("x")
         plot.xAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.FirstLabel)
-        plot.yAxis().setLabelSuffix('y')
+        plot.yAxis().setLabelSuffix("y")
         plot.yAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.FirstLabel)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -240,38 +283,54 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_base_suffix_first', 'plot_2d_base_suffix_first', im)
+        assert self.image_check(
+            "plot_2d_base_suffix_first", "plot_2d_base_suffix_first", im
+        )
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 64.82, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testPlotSuffixLast(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -281,7 +340,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -296,13 +355,13 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        plot.xAxis().setLabelSuffix('x')
+        plot.xAxis().setLabelSuffix("x")
         plot.xAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.LastLabel)
-        plot.yAxis().setLabelSuffix('y')
+        plot.yAxis().setLabelSuffix("y")
         plot.yAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.LastLabel)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -311,38 +370,54 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_base_suffix_last', 'plot_2d_base_suffix_last', im)
+        assert self.image_check(
+            "plot_2d_base_suffix_last", "plot_2d_base_suffix_last", im
+        )
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 80.46, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testPlotSuffixFirstAndLast(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -352,7 +427,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -367,13 +442,17 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        plot.xAxis().setLabelSuffix('x')
-        plot.xAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels)
-        plot.yAxis().setLabelSuffix('y')
-        plot.yAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels)
+        plot.xAxis().setLabelSuffix("x")
+        plot.xAxis().setLabelSuffixPlacement(
+            Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels
+        )
+        plot.yAxis().setLabelSuffix("y")
+        plot.yAxis().setLabelSuffixPlacement(
+            Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels
+        )
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -382,42 +461,60 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_base_suffix_first_and_last', 'plot_2d_base_suffix_first_and_last', im)
+        assert self.image_check(
+            "plot_2d_base_suffix_first_and_last",
+            "plot_2d_base_suffix_first_and_last",
+            im,
+        )
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 80.46, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testPlotIntervals(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         plot.xAxis().setTextFormat(x_axis_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         plot.yAxis().setTextFormat(y_axis_format)
 
@@ -436,8 +533,8 @@ class TestQgsPlot(QgisTestCase):
         plot.xAxis().setLabelInterval(5)
         plot.yAxis().setLabelInterval(70)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -446,43 +543,87 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_intervals', 'plot_2d_intervals', im)
+        assert self.image_check("plot_2d_intervals", "plot_2d_intervals", im)
 
     def testPlotDataDefinedProperties(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#ffffff', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#ffffff", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#000000', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#000000",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1, 'capstyle': 'flat'})
-        sym3[0].setDataDefinedProperty(QgsSymbolLayer.PropertyStrokeWidth, QgsProperty.fromExpression('case when @plot_axis_value = 10 then 3 else 1 end'))
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1, "capstyle": "flat"}
+        )
+        sym3[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyStrokeWidth,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value = 10 then 3 else 1 end"
+            ),
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5, 'capstyle': 'flat'})
-        sym4[0].setDataDefinedProperty(QgsSymbolLayer.PropertyStrokeWidth, QgsProperty.fromExpression('case when @plot_axis_value = 6 then 3 else 0.5 end'))
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5, "capstyle": "flat"}
+        )
+        sym4[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyStrokeWidth,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value = 6 then 3 else 0.5 end"
+            ),
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1, 'capstyle': 'flat'})
-        sym3[0].setDataDefinedProperty(QgsSymbolLayer.PropertyStrokeWidth, QgsProperty.fromExpression('case when @plot_axis_value = 5 then 3 else 0.5 end'))
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1, "capstyle": "flat"}
+        )
+        sym3[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyStrokeWidth,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value = 5 then 3 else 0.5 end"
+            ),
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5, 'capstyle': 'flat'})
-        sym4[0].setDataDefinedProperty(QgsSymbolLayer.PropertyStrokeWidth, QgsProperty.fromExpression('case when @plot_axis_value = 9 then 3 else 0.5 end'))
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5, "capstyle": "flat"}
+        )
+        sym4[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.PropertyStrokeWidth,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value = 9 then 3 else 0.5 end"
+            ),
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
-        x_axis_format.dataDefinedProperties().setProperty(QgsPalLayerSettings.Color, QgsProperty.fromExpression('case when @plot_axis_value %3 = 0 then \'#ff0000\' else \'#000000\' end'))
+        x_axis_format.dataDefinedProperties().setProperty(
+            QgsPalLayerSettings.Property.Color,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value %3 = 0 then '#ff0000' else '#000000' end"
+            ),
+        )
         plot.xAxis().setTextFormat(x_axis_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
-        y_axis_format.dataDefinedProperties().setProperty(QgsPalLayerSettings.Color, QgsProperty.fromExpression('case when @plot_axis_value %4 = 0 then \'#0000ff\' else \'#000000\' end'))
+        y_axis_format.dataDefinedProperties().setProperty(
+            QgsPalLayerSettings.Property.Color,
+            QgsProperty.fromExpression(
+                "case when @plot_axis_value %4 = 0 then '#0000ff' else '#000000' end"
+            ),
+        )
         plot.yAxis().setTextFormat(y_axis_format)
 
         plot.setXMinimum(3)
@@ -491,8 +632,8 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -501,23 +642,23 @@ class TestQgsPlot(QgisTestCase):
         plot.render(rc)
         painter.end()
 
-        assert self.image_check('plot_2d_data_defined', 'plot_2d_data_defined', im)
+        assert self.image_check("plot_2d_data_defined", "plot_2d_data_defined", im)
 
         plot_rect = plot.interiorPlotArea(rc)
         self.assertAlmostEqual(plot_rect.left(), 44.71, 0)
         self.assertAlmostEqual(plot_rect.right(), 592.44, 0)
         self.assertAlmostEqual(plot_rect.top(), 7.559, 0)
-        self.assertAlmostEqual(plot_rect.bottom(), 465.55, 0)
+        self.assertAlmostEqual(plot_rect.bottom(), 465.55, delta=1)
 
     def testOptimiseIntervals(self):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         plot.xAxis().setTextFormat(x_axis_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         plot.yAxis().setTextFormat(y_axis_format)
 
@@ -526,8 +667,8 @@ class TestQgsPlot(QgisTestCase):
         plot.setYMinimum(2)
         plot.setYMaximum(12)
 
-        im = QImage(600, 500, QImage.Format_ARGB32)
-        im.fill(Qt.white)
+        im = QImage(600, 500, QImage.Format.Format_ARGB32)
+        im.fill(Qt.GlobalColor.white)
         im.setDotsPerMeterX(int(96 / 25.4 * 1000))
         im.setDotsPerMeterY(int(96 / 25.4 * 1000))
 
@@ -594,26 +735,40 @@ class TestQgsPlot(QgisTestCase):
         plot = Qgs2DPlot()
         plot.setSize(QSizeF(600, 500))
 
-        sym1 = QgsFillSymbol.createSimple({'color': '#fdbf6f', 'outline_style': 'no'})
+        sym1 = QgsFillSymbol.createSimple({"color": "#fdbf6f", "outline_style": "no"})
         plot.setChartBackgroundSymbol(sym1)
 
         sym2 = QgsFillSymbol.createSimple(
-            {'outline_color': '#0000ff', 'style': 'no', 'outline_style': 'solid', 'outline_width': 1})
+            {
+                "outline_color": "#0000ff",
+                "style": "no",
+                "outline_style": "solid",
+                "outline_width": 1,
+            }
+        )
         plot.setChartBorderSymbol(sym2)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#00ffff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#00ffff", "outline_width": 1}
+        )
         plot.xAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff00ff', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff00ff", "outline_width": 0.5}
+        )
         plot.xAxis().setGridMinorSymbol(sym4)
 
-        sym3 = QgsLineSymbol.createSimple({'outline_color': '#0066ff', 'outline_width': 1})
+        sym3 = QgsLineSymbol.createSimple(
+            {"outline_color": "#0066ff", "outline_width": 1}
+        )
         plot.yAxis().setGridMajorSymbol(sym3)
 
-        sym4 = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym4 = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         plot.yAxis().setGridMinorSymbol(sym4)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 16)
+        font = QgsFontUtils.getStandardTestFont("Bold", 16)
         x_axis_format = QgsTextFormat.fromQFont(font)
         x_axis_format.setColor(QColor(255, 0, 0))
         plot.xAxis().setTextFormat(x_axis_format)
@@ -623,7 +778,7 @@ class TestQgsPlot(QgisTestCase):
         x_axis_number_format.setShowTrailingZeros(True)
         plot.xAxis().setNumericFormat(x_axis_number_format)
 
-        font = QgsFontUtils.getStandardTestFont('Bold', 18)
+        font = QgsFontUtils.getStandardTestFont("Bold", 18)
         y_axis_format = QgsTextFormat.fromQFont(font)
         y_axis_format.setColor(QColor(0, 255, 0))
         plot.yAxis().setTextFormat(y_axis_format)
@@ -646,15 +801,15 @@ class TestQgsPlot(QgisTestCase):
         plot.xAxis().setLabelInterval(32)
         plot.yAxis().setLabelInterval(23)
 
-        plot.xAxis().setLabelSuffix('km')
-        plot.xAxis().setLabelSuffixPlacement(
-            Qgis.PlotAxisSuffixPlacement.LastLabel)
-        plot.yAxis().setLabelSuffix('m')
+        plot.xAxis().setLabelSuffix("km")
+        plot.xAxis().setLabelSuffixPlacement(Qgis.PlotAxisSuffixPlacement.LastLabel)
+        plot.yAxis().setLabelSuffix("m")
         plot.yAxis().setLabelSuffixPlacement(
-            Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels)
+            Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels
+        )
 
         doc = QDomDocument()
-        elem = doc.createElement('test')
+        elem = doc.createElement("test")
         plot.writeXml(elem, doc, QgsReadWriteContext())
 
         res = Qgs2DPlot()
@@ -676,24 +831,27 @@ class TestQgsPlot(QgisTestCase):
         self.assertEqual(res.xAxis().numericFormat().numberDecimalPlaces(), 1)
         self.assertTrue(res.yAxis().numericFormat().showPlusSign())
 
-        self.assertEqual(res.xAxis().textFormat().color().name(), '#ff0000')
-        self.assertEqual(res.yAxis().textFormat().color().name(), '#00ff00')
+        self.assertEqual(res.xAxis().textFormat().color().name(), "#ff0000")
+        self.assertEqual(res.yAxis().textFormat().color().name(), "#00ff00")
 
-        self.assertEqual(res.chartBackgroundSymbol().color().name(), '#fdbf6f')
-        self.assertEqual(res.chartBorderSymbol().color().name(), '#0000ff')
+        self.assertEqual(res.chartBackgroundSymbol().color().name(), "#fdbf6f")
+        self.assertEqual(res.chartBorderSymbol().color().name(), "#0000ff")
 
-        self.assertEqual(res.xAxis().gridMinorSymbol().color().name(), '#ff00ff')
-        self.assertEqual(res.xAxis().gridMajorSymbol().color().name(), '#00ffff')
-        self.assertEqual(res.yAxis().gridMinorSymbol().color().name(), '#ff4433')
-        self.assertEqual(res.yAxis().gridMajorSymbol().color().name(), '#0066ff')
+        self.assertEqual(res.xAxis().gridMinorSymbol().color().name(), "#ff00ff")
+        self.assertEqual(res.xAxis().gridMajorSymbol().color().name(), "#00ffff")
+        self.assertEqual(res.yAxis().gridMinorSymbol().color().name(), "#ff4433")
+        self.assertEqual(res.yAxis().gridMajorSymbol().color().name(), "#0066ff")
 
-        self.assertEqual(res.xAxis().labelSuffix(), 'km')
-        self.assertEqual(res.xAxis().labelSuffixPlacement(),
-                         Qgis.PlotAxisSuffixPlacement.LastLabel)
-        self.assertEqual(res.yAxis().labelSuffix(), 'm')
-        self.assertEqual(res.yAxis().labelSuffixPlacement(),
-                         Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels)
+        self.assertEqual(res.xAxis().labelSuffix(), "km")
+        self.assertEqual(
+            res.xAxis().labelSuffixPlacement(), Qgis.PlotAxisSuffixPlacement.LastLabel
+        )
+        self.assertEqual(res.yAxis().labelSuffix(), "m")
+        self.assertEqual(
+            res.yAxis().labelSuffixPlacement(),
+            Qgis.PlotAxisSuffixPlacement.FirstAndLastLabels,
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
