@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Denis Rouzaud'
-__date__ = '26/11/2021'
-__copyright__ = 'Copyright 2015, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Denis Rouzaud"
+__date__ = "26/11/2021"
+__copyright__ = "Copyright 2015, The QGIS Project"
+
 from qgis.PyQt import sip
 from qgis.core import (
     Qgis,
@@ -26,7 +26,7 @@ start_app()
 
 class MySuperMarkerMetadata(QgsSymbolLayerAbstractMetadata):
     def __init__(self):
-        super().__init__('MySuperMarker', 'My Super Marker', Qgis.SymbolType.Marker)
+        super().__init__("MySuperMarker", "My Super Marker", Qgis.SymbolType.Marker)
 
     def createSymbolLayer(self, map: dict) -> QgsSymbolLayer:
         return QgsSimpleMarkerSymbolLayer()
@@ -56,7 +56,9 @@ class TestQgsSymbolLayerRegistry(QgisTestCase):
         # layer already added
         self.assertFalse(self.registry.addSymbolLayerType(metadata))
         # check there is one more layer
-        self.assertEqual(len(self.registry.symbolLayersForType(Qgis.SymbolType.Marker)), n + 1)
+        self.assertEqual(
+            len(self.registry.symbolLayersForType(Qgis.SymbolType.Marker)), n + 1
+        )
         # remove layer
         self.assertTrue(self.registry.removeSymbolLayerType(metadata))
         # check layer has been deleted
@@ -73,9 +75,12 @@ class TestQgsSymbolLayerRegistry(QgisTestCase):
         metadata = MySuperMarkerMetadata()
         self.assertTrue(self.registry.addSymbolLayerType(metadata))
         del metadata
-        self.assertIn(MySuperMarkerMetadata().name(), self.registry.symbolLayersForType(Qgis.SymbolType.Marker))
+        self.assertIn(
+            MySuperMarkerMetadata().name(),
+            self.registry.symbolLayersForType(Qgis.SymbolType.Marker),
+        )
         self.assertTrue(self.registry.removeSymbolLayerType(MySuperMarkerMetadata()))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
