@@ -8,14 +8,14 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Loïc Bartoletti'
-__date__ = '18/10/2022'
-__copyright__ = 'Copyright 2022, The QGIS Project'
+
+__author__ = "Loïc Bartoletti"
+__date__ = "18/10/2022"
+__copyright__ = "Copyright 2022, The QGIS Project"
 
 import os
 import tempfile
 
-import qgis  # NOQA
 from qgis.PyQt.QtCore import (
     QVariant,
 )
@@ -36,7 +36,7 @@ from qgis.core import (
     QgsWkbTypes,
     QgsDefaultValue,
     QgsVectorLayerUtils,
-    QgsUnsetAttributeValue
+    QgsUnsetAttributeValue,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -45,8 +45,7 @@ start_app()
 
 
 def createEmptyLayer(geomType):
-    layer = QgsVectorLayer(geomType,
-                           geomType.lower(), "memory")
+    layer = QgsVectorLayer(geomType, geomType.lower(), "memory")
     assert layer.isValid()
     return layer
 
@@ -68,18 +67,26 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f = QgsFeature(layer.fields(), 1)
-        f.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         assert pr.addFeatures([f])
         self.assertEqual(layer.featureCount(), 1)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRing([QgsPointXY(1, 1), QgsPointXY(1, 2), QgsPointXY(2, 2), QgsPointXY(2, 1), QgsPointXY(1, 1)])
+        result = vle.addRing(
+            [
+                QgsPointXY(1, 1),
+                QgsPointXY(1, 2),
+                QgsPointXY(2, 2),
+                QgsPointXY(2, 1),
+                QgsPointXY(1, 1),
+            ]
+        )
         self.assertEqual(Qgis.GeometryOperationResult.Success, result[0])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(1 1, 1 2, 2 2, 2 1, 1 1))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(1 1, 1 2, 2 2, 2 1, 1 1))",
         )
 
     def testAddRingOutside(self):
@@ -89,18 +96,28 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f = QgsFeature(layer.fields(), 1)
-        f.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         assert pr.addFeatures([f])
         self.assertEqual(layer.featureCount(), 1)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRing([QgsPointXY(-1, -1), QgsPointXY(-1, -2), QgsPointXY(-2, -2), QgsPointXY(-2, -1), QgsPointXY(-1, -1)])
-        self.assertEqual(Qgis.GeometryOperationResult.AddRingNotInExistingFeature, result[0])
+        result = vle.addRing(
+            [
+                QgsPointXY(-1, -1),
+                QgsPointXY(-1, -2),
+                QgsPointXY(-2, -2),
+                QgsPointXY(-2, -1),
+                QgsPointXY(-1, -1),
+            ]
+        )
+        self.assertEqual(
+            Qgis.GeometryOperationResult.AddRingNotInExistingFeature, result[0]
+        )
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))",
         )
 
     def testAddRingOverlappedFeatures(self):
@@ -111,25 +128,32 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRing([QgsPointXY(3, 3), QgsPointXY(3, 4), QgsPointXY(4, 4), QgsPointXY(4, 3), QgsPointXY(3, 3)])
-        self.assertEqual(Qgis.GeometryOperationResult.Success,
-                         result[0])
+        result = vle.addRing(
+            [
+                QgsPointXY(3, 3),
+                QgsPointXY(3, 4),
+                QgsPointXY(4, 4),
+                QgsPointXY(4, 3),
+                QgsPointXY(3, 3),
+            ]
+        )
+        self.assertEqual(Qgis.GeometryOperationResult.Success, result[0])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
         )
 
     def testAddRingV2NotEditable(self):
@@ -140,26 +164,36 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
         layer.commitChanges()
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRingV2(QgsLineString([QgsPoint(3, 3), QgsPoint(3, 4), QgsPoint(4, 4), QgsPoint(4, 3), QgsPoint(3, 3)]))
+        result = vle.addRingV2(
+            QgsLineString(
+                [
+                    QgsPoint(3, 3),
+                    QgsPoint(3, 4),
+                    QgsPoint(4, 4),
+                    QgsPoint(4, 3),
+                    QgsPoint(3, 3),
+                ]
+            )
+        )
         self.assertEqual(Qgis.GeometryOperationResult.LayerNotEditable, result[0])
         self.assertEqual([], result[1])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
         )
 
     def testAddRingV2NotClosedRing(self):
@@ -170,25 +204,29 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRingV2(QgsLineString([QgsPoint(3, 3), QgsPoint(3, 4), QgsPoint(4, 4), QgsPoint(4, 3)]))
+        result = vle.addRingV2(
+            QgsLineString(
+                [QgsPoint(3, 3), QgsPoint(3, 4), QgsPoint(4, 4), QgsPoint(4, 3)]
+            )
+        )
         self.assertEqual(Qgis.GeometryOperationResult.AddRingNotClosed, result[0])
         self.assertEqual([], result[1])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
         )
 
     def testAddRingV2Outside(self):
@@ -199,28 +237,37 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRingV2(QgsLineString([QgsPoint(8, 8), QgsPoint(8, 9), QgsPoint(9, 9), QgsPoint(9, 8), QgsPoint(8, 8)]))
+        result = vle.addRingV2(
+            QgsLineString(
+                [
+                    QgsPoint(8, 8),
+                    QgsPoint(8, 9),
+                    QgsPoint(9, 9),
+                    QgsPoint(9, 8),
+                    QgsPoint(8, 8),
+                ]
+            )
+        )
         self.assertEqual(
-            Qgis.GeometryOperationResult.AddRingNotInExistingFeature,
-            result[0]
+            Qgis.GeometryOperationResult.AddRingNotInExistingFeature, result[0]
         )
         self.assertEqual([], result[1])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
         )
 
     def testAddRingV2(self):
@@ -230,25 +277,35 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRingV2(QgsLineString([QgsPoint(3, 3), QgsPoint(3, 4), QgsPoint(4, 4), QgsPoint(4, 3), QgsPoint(3, 3)]))
+        result = vle.addRingV2(
+            QgsLineString(
+                [
+                    QgsPoint(3, 3),
+                    QgsPoint(3, 4),
+                    QgsPoint(4, 4),
+                    QgsPoint(4, 3),
+                    QgsPoint(3, 3),
+                ]
+            )
+        )
         self.assertEqual(Qgis.GeometryOperationResult.Success, result[0])
         self.assertEqual({2, 1}, set(result[1]))
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2),(3 3, 3 4, 4 4, 4 3, 3 3))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2),(3 3, 3 4, 4 4, 4 3, 3 3))",
         )
 
     def testAddRingV2SelectedFeatures(self):
@@ -259,25 +316,77 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
         f2 = QgsFeature(layer.fields(), 1)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))'))
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
         assert pr.addFeatures([f1, f2])
         self.assertEqual(layer.featureCount(), 2)
 
         vle = QgsVectorLayerEditUtils(layer)
-        result = vle.addRingV2(QgsLineString([QgsPoint(3, 3), QgsPoint(3, 4), QgsPoint(4, 4), QgsPoint(4, 3), QgsPoint(3, 3)]), [1])
+        result = vle.addRingV2(
+            QgsLineString(
+                [
+                    QgsPoint(3, 3),
+                    QgsPoint(3, 4),
+                    QgsPoint(4, 4),
+                    QgsPoint(4, 3),
+                    QgsPoint(3, 3),
+                ]
+            ),
+            [1],
+        )
         self.assertEqual(Qgis.GeometryOperationResult.Success, result[0])
         self.assertEqual([1], result[1])
         layer.commitChanges()
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))"
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(3 3, 3 4, 4 4, 4 3, 3 3))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))"
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
+        )
+
+    def testAddRingV2AtLeastOne(self):
+        # test adding ring on multi features
+        # Succeed if the ring can be added at least to 1 feature
+        layer = createEmptyPolygonLayer()
+        self.assertTrue(layer.startEditing())
+
+        pr = layer.dataProvider()
+        f1 = QgsFeature(layer.fields(), 1)
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
+        f2 = QgsFeature(layer.fields(), 1)
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((2 2, 6 2, 6 6, 2 6, 2 2))"))
+        assert pr.addFeatures([f1, f2])
+        self.assertEqual(layer.featureCount(), 2)
+
+        vle = QgsVectorLayerEditUtils(layer)
+        result = vle.addRingV2(
+            QgsLineString(
+                [
+                    QgsPoint(0.5, 3),
+                    QgsPoint(1.5, 3),
+                    QgsPoint(1.5, 1.5),
+                    QgsPoint(3, 1.5),
+                    QgsPoint(3, 0.5),
+                    QgsPoint(0.5, 0.5),
+                    QgsPoint(0.5, 3),
+                ]
+            )
+        )
+        self.assertEqual(Qgis.GeometryOperationResult.Success, result[0])
+        self.assertEqual({1}, set(result[1]))
+        layer.commitChanges()
+
+        self.assertEqual(
+            layer.getFeature(1).geometry().asWkt(),
+            "Polygon ((0 0, 5 0, 5 5, 0 5, 0 0),(0.5 3, 1.5 3, 1.5 1.5, 3 1.5, 3 0.5, 0.5 0.5, 0.5 3))",
+        )
+        self.assertEqual(
+            layer.getFeature(2).geometry().asWkt(),
+            "Polygon ((2 2, 6 2, 6 6, 2 6, 2 2))",
         )
 
     def testMoveVertex(self):
@@ -287,7 +396,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('Point(0 0)'))
+        f1.setGeometry(QgsGeometry.fromWkt("Point(0 0)"))
         self.assertTrue(pr.addFeatures([f1]))
         self.assertEqual(layer.featureCount(), 1)
 
@@ -314,7 +423,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('PointZ(0 0 0)'))
+        f1.setGeometry(QgsGeometry.fromWkt("PointZ(0 0 0)"))
         self.assertTrue(pr.addFeatures([f1]))
         self.assertEqual(layer.featureCount(), 1)
 
@@ -338,7 +447,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         # Add a non-Z point and check that Z get added on move
         f2 = QgsFeature(layer.fields(), 2)
-        f2.setGeometry(QgsGeometry.fromWkt('Point(0 0)'))
+        f2.setGeometry(QgsGeometry.fromWkt("Point(0 0)"))
         self.assertTrue(pr.addFeatures([f2]))
         self.assertEqual(layer.featureCount(), 2)
 
@@ -358,7 +467,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('PointM(0 0 0)'))
+        f1.setGeometry(QgsGeometry.fromWkt("PointM(0 0 0)"))
         self.assertTrue(pr.addFeatures([f1]))
         self.assertEqual(layer.featureCount(), 1)
 
@@ -375,7 +484,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         # Add a non-M point and check that M get added on move
         f2 = QgsFeature(layer.fields(), 2)
-        f2.setGeometry(QgsGeometry.fromWkt('Point(0 0)'))
+        f2.setGeometry(QgsGeometry.fromWkt("Point(0 0)"))
         self.assertTrue(pr.addFeatures([f2]))
         self.assertEqual(layer.featureCount(), 2)
 
@@ -397,7 +506,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         pr = layer.dataProvider()
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('PointZM(0 0 0 0)'))
+        f1.setGeometry(QgsGeometry.fromWkt("PointZM(0 0 0 0)"))
         self.assertTrue(pr.addFeatures([f1]))
         self.assertEqual(layer.featureCount(), 1)
 
@@ -415,7 +524,7 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         # Add a non-ZM point and check that Z and M get added on move
         f2 = QgsFeature(layer.fields(), 2)
-        f2.setGeometry(QgsGeometry.fromWkt('Point(0 0)'))
+        f2.setGeometry(QgsGeometry.fromWkt("Point(0 0)"))
         self.assertTrue(pr.addFeatures([f2]))
         self.assertEqual(layer.featureCount(), 2)
 
@@ -442,15 +551,27 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         # Each feature is composed of two squares side by side
         # Each feature is on a separate row to form a 3*2 grid
         f = QgsFeature(layer.fields(), 1)
-        f.setGeometry(QgsGeometry.fromWkt('MULTIPOLYGON(((0 0, 4 0, 4 4, 0 4, 0 0)), ((6 0, 10 0, 10 4, 6 4, 6 0)))'))
+        f.setGeometry(
+            QgsGeometry.fromWkt(
+                "MULTIPOLYGON(((0 0, 4 0, 4 4, 0 4, 0 0)), ((6 0, 10 0, 10 4, 6 4, 6 0)))"
+            )
+        )
         assert pr.addFeatures([f])
 
         f = QgsFeature(layer.fields(), 2)
-        f.setGeometry(QgsGeometry.fromWkt('MULTIPOLYGON(((0 6, 4 6, 4 10, 0 10, 0 6)), ((6 6, 10 6, 10 10, 6 10, 6 6)))'))
+        f.setGeometry(
+            QgsGeometry.fromWkt(
+                "MULTIPOLYGON(((0 6, 4 6, 4 10, 0 10, 0 6)), ((6 6, 10 6, 10 10, 6 10, 6 6)))"
+            )
+        )
         assert pr.addFeatures([f])
 
         f = QgsFeature(layer.fields(), 3)
-        f.setGeometry(QgsGeometry.fromWkt('MULTIPOLYGON(((0 12, 4 12, 4 16, 0 16, 0 12)), ((6 12, 10 12, 10 16, 6 16, 6 12)))'))
+        f.setGeometry(
+            QgsGeometry.fromWkt(
+                "MULTIPOLYGON(((0 12, 4 12, 4 16, 0 16, 0 12)), ((6 12, 10 12, 10 16, 6 16, 6 12)))"
+            )
+        )
         assert pr.addFeatures([f])
 
         self.assertEqual(layer.featureCount(), 3)
@@ -471,33 +592,33 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
 
         self.assertEqual(
             layer.getFeature(1).geometry().asWkt(),
-            'MultiPolygon (((2 0, 2 2, 4 2, 4 0, 2 0)),((2 2, 2 0, 0 0, 0 2, 2 2)),((2 2, 2 4, 4 4, 4 2, 2 2)),((2 4, 2 2, 0 2, 0 4, 2 4)),((6 2, 10 2, 10 0, 6 0, 6 2)),((10 2, 6 2, 6 4, 10 4, 10 2)))'
+            "MultiPolygon (((2 0, 2 2, 4 2, 4 0, 2 0)),((2 2, 2 0, 0 0, 0 2, 2 2)),((2 2, 2 4, 4 4, 4 2, 2 2)),((2 4, 2 2, 0 2, 0 4, 2 4)),((6 2, 10 2, 10 0, 6 0, 6 2)),((10 2, 6 2, 6 4, 10 4, 10 2)))",
         )
         self.assertEqual(
             layer.getFeature(2).geometry().asWkt(),
-            'MultiPolygon (((2 6, 2 10, 4 10, 4 6, 2 6)),((2 10, 2 6, 0 6, 0 10, 2 10)),((6 6, 10 6, 10 10, 6 10, 6 6)))'
+            "MultiPolygon (((2 6, 2 10, 4 10, 4 6, 2 6)),((2 10, 2 6, 0 6, 0 10, 2 10)),((6 6, 10 6, 10 10, 6 10, 6 6)))",
         )
 
         self.assertEqual(
             layer.getFeature(3).geometry().asWkt(),
-            'MultiPolygon (((2 12, 2 16, 4 16, 4 12, 2 12)),((2 16, 2 12, 0 12, 0 16, 2 16)),((6 12, 10 12, 10 16, 6 16, 6 12)))'
+            "MultiPolygon (((2 12, 2 16, 4 16, 4 12, 2 12)),((2 16, 2 12, 0 12, 0 16, 2 16)),((6 12, 10 12, 10 16, 6 16, 6 12)))",
         )
 
     def testMergeFeatures(self):
         layer = createEmptyPolygonLayer()
         self.assertTrue(layer.startEditing())
-        layer.addAttribute(QgsField('name', QVariant.String))
+        layer.addAttribute(QgsField("name", QVariant.String))
         pr = layer.dataProvider()
 
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
-        f1.setAttribute('name', 'uno')
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
+        f1.setAttribute("name", "uno")
         assert pr.addFeatures([f1])
         self.assertEqual(layer.featureCount(), 1)
 
         f2 = QgsFeature(layer.fields(), 2)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((3 3, 8 3, 8 8, 3 8, 3 3))'))
-        f2.setAttribute('name', 'due')
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((3 3, 8 3, 8 8, 3 8, 3 3))"))
+        f2.setAttribute("name", "due")
         assert pr.addFeatures([f2])
         self.assertEqual(layer.featureCount(), 2)
 
@@ -508,7 +629,9 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         self.assertFalse(unionGeom.isNull())
 
         vle = QgsVectorLayerEditUtils(layer)
-        success, errorMessage = vle.mergeFeatures(f1.id(), featureIds, ['tre'], unionGeom)
+        success, errorMessage = vle.mergeFeatures(
+            f1.id(), featureIds, ["tre"], unionGeom
+        )
         self.assertFalse(errorMessage)
         self.assertTrue(success)
 
@@ -518,39 +641,42 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         mergedFeature = next(layer.getFeatures())
         self.assertEqual(
             mergedFeature.geometry().asWkt(),
-            "Polygon ((5 0, 0 0, 0 5, 3 5, 3 8, 8 8, 8 3, 5 3, 5 0))"
+            "Polygon ((5 0, 0 0, 0 5, 3 5, 3 8, 8 8, 8 3, 5 3, 5 0))",
         )
-        self.assertEqual(mergedFeature.attribute('name'), 'tre')
+        self.assertEqual(mergedFeature.attribute("name"), "tre")
 
     def testMergeFeaturesIntoExisting(self):
-        tempgpkg = os.path.join(tempfile.mkdtemp(), 'testMergeFeaturesIntoExisting.gpkg')
+        tempgpkg = os.path.join(
+            tempfile.mkdtemp(), "testMergeFeaturesIntoExisting.gpkg"
+        )
         fields = QgsFields()
-        fields.append(QgsField('name', QVariant.String))
+        fields.append(QgsField("name", QVariant.String))
 
-        crs = QgsCoordinateReferenceSystem('epsg:4326')
+        crs = QgsCoordinateReferenceSystem("epsg:4326")
         options = QgsVectorFileWriter.SaveVectorOptions()
         options.driverName = "GPKG"
         QgsVectorFileWriter.create(
             fileName=tempgpkg,
             fields=fields,
-            geometryType=QgsWkbTypes.Polygon,
+            geometryType=QgsWkbTypes.Type.Polygon,
             srs=crs,
             transformContext=QgsCoordinateTransformContext(),
-            options=options)
+            options=options,
+        )
 
-        layer = QgsVectorLayer(tempgpkg, 'my_layer', 'ogr')
+        layer = QgsVectorLayer(tempgpkg, "my_layer", "ogr")
         self.assertTrue(layer.startEditing())
         pr = layer.dataProvider()
 
         f1 = QgsFeature(layer.fields(), 1)
-        f1.setGeometry(QgsGeometry.fromWkt('POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))'))
-        f1.setAttribute('name', 'uno')
+        f1.setGeometry(QgsGeometry.fromWkt("POLYGON((0 0, 5 0, 5 5, 0 5, 0 0))"))
+        f1.setAttribute("name", "uno")
         assert pr.addFeatures([f1])
         self.assertEqual(layer.featureCount(), 1)
 
         f2 = QgsFeature(layer.fields(), 2)
-        f2.setGeometry(QgsGeometry.fromWkt('POLYGON((3 3, 8 3, 8 8, 3 8, 3 3))'))
-        f2.setAttribute('name', 'due')
+        f2.setGeometry(QgsGeometry.fromWkt("POLYGON((3 3, 8 3, 8 8, 3 8, 3 3))"))
+        f2.setAttribute("name", "due")
         assert pr.addFeatures([f2])
         self.assertEqual(layer.featureCount(), 2)
 
@@ -561,7 +687,9 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         self.assertFalse(unionGeom.isNull())
 
         vle = QgsVectorLayerEditUtils(layer)
-        success, errorMessage = vle.mergeFeatures(f2.id(), featureIds, [2, 'tre'], unionGeom)
+        success, errorMessage = vle.mergeFeatures(
+            f2.id(), featureIds, [2, "tre"], unionGeom
+        )
         self.assertFalse(errorMessage)
         self.assertTrue(success)
 
@@ -571,42 +699,36 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         mergedFeature = layer.getFeature(2)
         self.assertEqual(
             mergedFeature.geometry().asWkt(),
-            "Polygon ((5 0, 0 0, 0 5, 3 5, 3 8, 8 8, 8 3, 5 3, 5 0))"
+            "Polygon ((5 0, 0 0, 0 5, 3 5, 3 8, 8 8, 8 3, 5 3, 5 0))",
         )
-        self.assertEqual(mergedFeature.attribute('name'), 'tre')
+        self.assertEqual(mergedFeature.attribute("name"), "tre")
 
     def test_split_policy_lines(self):
-        temp_layer = QgsVectorLayer("LineString?crs=epsg:3111&field=pk:int&field=field_default:real&field=field_dupe:real&field=field_unset:real&field=field_ratio:real&field=apply_default:real",
-                                    "vl", "memory")
+        temp_layer = QgsVectorLayer(
+            "LineString?crs=epsg:3111&field=pk:int&field=field_default:real&field=field_dupe:real&field=field_unset:real&field=field_ratio:real&field=apply_default:real",
+            "vl",
+            "memory",
+        )
         self.assertTrue(temp_layer.isValid())
 
-        temp_layer.setDefaultValueDefinition(1,
-                                             QgsDefaultValue('301'))
-        temp_layer.setDefaultValueDefinition(2,
-                                             QgsDefaultValue('302'))
-        temp_layer.setDefaultValueDefinition(3,
-                                             QgsDefaultValue('303'))
-        temp_layer.setDefaultValueDefinition(4,
-                                             QgsDefaultValue('304'))
-        temp_layer.setDefaultValueDefinition(5,
-                                             QgsDefaultValue('305', True))
+        temp_layer.setDefaultValueDefinition(1, QgsDefaultValue("301"))
+        temp_layer.setDefaultValueDefinition(2, QgsDefaultValue("302"))
+        temp_layer.setDefaultValueDefinition(3, QgsDefaultValue("303"))
+        temp_layer.setDefaultValueDefinition(4, QgsDefaultValue("304"))
+        temp_layer.setDefaultValueDefinition(5, QgsDefaultValue("305", True))
 
-        temp_layer.setFieldSplitPolicy(1,
-                                       Qgis.FieldDomainSplitPolicy.DefaultValue)
-        temp_layer.setFieldSplitPolicy(2,
-                                       Qgis.FieldDomainSplitPolicy.Duplicate)
-        temp_layer.setFieldSplitPolicy(3,
-                                       Qgis.FieldDomainSplitPolicy.UnsetField)
-        temp_layer.setFieldSplitPolicy(4,
-                                       Qgis.FieldDomainSplitPolicy.GeometryRatio)
+        temp_layer.setFieldSplitPolicy(1, Qgis.FieldDomainSplitPolicy.DefaultValue)
+        temp_layer.setFieldSplitPolicy(2, Qgis.FieldDomainSplitPolicy.Duplicate)
+        temp_layer.setFieldSplitPolicy(3, Qgis.FieldDomainSplitPolicy.UnsetField)
+        temp_layer.setFieldSplitPolicy(4, Qgis.FieldDomainSplitPolicy.GeometryRatio)
         # this will be ignored -- the apply on update default will override it
-        temp_layer.setFieldSplitPolicy(5,
-                                       Qgis.FieldDomainSplitPolicy.GeometryRatio)
+        temp_layer.setFieldSplitPolicy(5, Qgis.FieldDomainSplitPolicy.GeometryRatio)
 
         temp_layer.startEditing()
 
-        feature = QgsVectorLayerUtils.createFeature(temp_layer,
-                                                    QgsGeometry.fromWkt('LineString( 0 0, 10 0)'))
+        feature = QgsVectorLayerUtils.createFeature(
+            temp_layer, QgsGeometry.fromWkt("LineString( 0 0, 10 0)")
+        )
         feature[1] = 3301
         feature[5] = 3305
         self.assertTrue(temp_layer.addFeature(feature))
@@ -614,75 +736,91 @@ class TestQgsVectorLayerEditUtils(QgisTestCase):
         temp_layer.commitChanges()
 
         original_feature = next(temp_layer.getFeatures())
-        self.assertEqual(original_feature.attributes(),
-                         [None, 3301.0, 302.0, 303.0, 304.0, 3305.0])
+        self.assertEqual(
+            original_feature.attributes(), [None, 3301.0, 302.0, 303.0, 304.0, 3305.0]
+        )
 
         temp_layer.startEditing()
 
-        split_curve = QgsGeometry.fromWkt('LineString (0.3 0.2, 0.27 -0.2, 0.86 -0.24, 0.88 0.22)')
+        split_curve = QgsGeometry.fromWkt(
+            "LineString (0.3 0.2, 0.27 -0.2, 0.86 -0.24, 0.88 0.22)"
+        )
         temp_layer.splitFeatures(split_curve.constGet(), preserveCircular=False)
 
         features = list(temp_layer.getFeatures())
         attributes = [f.attributes() for f in features]
-        self.assertCountEqual(attributes,
-                              [[None, 3301.0, 302.0, 303.0, 8.664000000000001, 305.0],
-                               [None, 301, 302.0, QgsUnsetAttributeValue(), 17.797217391304347, 305.0],
-                               [None, 301, 302.0, QgsUnsetAttributeValue(), 277.53878260869567, 305.0]
-                               ])
+        self.assertCountEqual(
+            attributes,
+            [
+                [None, 3301.0, 302.0, 303.0, 277.53878260869567, 305.0],
+                [None, 301, 302.0, QgsUnsetAttributeValue(), 8.664000000000001, 305.0],
+                [None, 301, 302.0, QgsUnsetAttributeValue(), 17.797217391304347, 305.0],
+            ],
+        )
 
         temp_layer.rollBack()
 
     def test_split_policy_polygon(self):
-        temp_layer = QgsVectorLayer("Polygon?crs=epsg:3111&field=pk:int&field=field_default:real&field=field_dupe:real&field=field_unset:real&field=field_ratio:real",
-                                    "vl", "memory")
+        temp_layer = QgsVectorLayer(
+            "Polygon?crs=epsg:3111&field=pk:int&field=field_default:real&field=field_dupe:real&field=field_unset:real&field=field_ratio:real",
+            "vl",
+            "memory",
+        )
         self.assertTrue(temp_layer.isValid())
 
-        temp_layer.setDefaultValueDefinition(1,
-                                             QgsDefaultValue('301'))
-        temp_layer.setDefaultValueDefinition(2,
-                                             QgsDefaultValue('302'))
-        temp_layer.setDefaultValueDefinition(3,
-                                             QgsDefaultValue('303'))
-        temp_layer.setDefaultValueDefinition(4,
-                                             QgsDefaultValue('304'))
+        temp_layer.setDefaultValueDefinition(1, QgsDefaultValue("301"))
+        temp_layer.setDefaultValueDefinition(2, QgsDefaultValue("302"))
+        temp_layer.setDefaultValueDefinition(3, QgsDefaultValue("303"))
+        temp_layer.setDefaultValueDefinition(4, QgsDefaultValue("304"))
 
-        temp_layer.setFieldSplitPolicy(1,
-                                       Qgis.FieldDomainSplitPolicy.DefaultValue)
-        temp_layer.setFieldSplitPolicy(2,
-                                       Qgis.FieldDomainSplitPolicy.Duplicate)
-        temp_layer.setFieldSplitPolicy(3,
-                                       Qgis.FieldDomainSplitPolicy.UnsetField)
-        temp_layer.setFieldSplitPolicy(4,
-                                       Qgis.FieldDomainSplitPolicy.GeometryRatio)
+        temp_layer.setFieldSplitPolicy(1, Qgis.FieldDomainSplitPolicy.DefaultValue)
+        temp_layer.setFieldSplitPolicy(2, Qgis.FieldDomainSplitPolicy.Duplicate)
+        temp_layer.setFieldSplitPolicy(3, Qgis.FieldDomainSplitPolicy.UnsetField)
+        temp_layer.setFieldSplitPolicy(4, Qgis.FieldDomainSplitPolicy.GeometryRatio)
 
         temp_layer.startEditing()
 
-        feature = QgsVectorLayerUtils.createFeature(temp_layer,
-                                                    QgsGeometry.fromWkt('Polygon(( 0 0, 10 0, 10 10, 0 10, 0 0))'))
+        feature = QgsVectorLayerUtils.createFeature(
+            temp_layer, QgsGeometry.fromWkt("Polygon(( 0 0, 10 0, 10 10, 0 10, 0 0))")
+        )
         feature[1] = 3301
         self.assertTrue(temp_layer.addFeature(feature))
 
         temp_layer.commitChanges()
 
         original_feature = next(temp_layer.getFeatures())
-        self.assertEqual(original_feature.attributes(),
-                         [None, 3301.0, 302.0, 303.0, 304.0])
+        self.assertEqual(
+            original_feature.attributes(), [None, 3301.0, 302.0, 303.0, 304.0]
+        )
 
         temp_layer.startEditing()
 
-        split_curve = QgsGeometry.fromWkt('LineString (-2.7 4.3, 5.5 11.8, 5.28 -5.57)')
+        split_curve = QgsGeometry.fromWkt("LineString (-2.7 4.3, 5.5 11.8, 5.28 -5.57)")
         temp_layer.splitFeatures(split_curve.constGet(), preserveCircular=False)
 
+        def round_attributes(_attributes, places):
+            res = []
+            for a in _attributes:
+                if isinstance(a, float):
+                    res.append(round(a, places))
+                else:
+                    res.append(a)
+
+            return res
+
         features = list(temp_layer.getFeatures())
-        attributes = [f.attributes() for f in features]
-        self.assertCountEqual(attributes,
-                              [[None, 3301.0, 302.0, 303.0, 147.23845863746018],
-                               [None, 301, 302.0, QgsUnsetAttributeValue(), 17.343326048780483],
-                               [None, 301, 302.0, QgsUnsetAttributeValue(), 139.41821531375936]
-                               ])
+        attributes = [round_attributes(f.attributes(), 4) for f in features]
+        self.assertCountEqual(
+            attributes,
+            [
+                [None, 3301.0, 302.0, 303.0, 147.2385],
+                [None, 301, 302.0, QgsUnsetAttributeValue(), 17.3433],
+                [None, 301, 302.0, QgsUnsetAttributeValue(), 139.4182],
+            ],
+        )
 
         temp_layer.rollBack()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
