@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '09/11/2020'
-__copyright__ = 'Copyright 2020, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nyall Dawson"
+__date__ = "09/11/2020"
+__copyright__ = "Copyright 2020, The QGIS Project"
+
 from qgis.PyQt.QtXml import QDomDocument
 from qgis.core import (
     Qgis,
@@ -68,35 +68,56 @@ class TestQgsVectorLayerElevationProperties(QgisTestCase):
         self.assertEqual(props.binding(), Qgis.AltitudeBinding.Vertex)
         self.assertFalse(props.respectLayerSymbology())
         self.assertEqual(props.type(), Qgis.VectorProfileType.ContinuousSurface)
-        self.assertEqual(props.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow)
+        self.assertEqual(
+            props.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow
+        )
         self.assertTrue(props.showMarkerSymbolInSurfacePlots())
         self.assertEqual(props.elevationLimit(), 909)
 
-        props.dataDefinedProperties().setProperty(QgsMapLayerElevationProperties.ExtrusionHeight, QgsProperty.fromExpression('1*5'))
-        self.assertEqual(props.dataDefinedProperties().property(QgsMapLayerElevationProperties.ExtrusionHeight).asExpression(), '1*5')
+        props.dataDefinedProperties().setProperty(
+            QgsMapLayerElevationProperties.Property.ExtrusionHeight,
+            QgsProperty.fromExpression("1*5"),
+        )
+        self.assertEqual(
+            props.dataDefinedProperties()
+            .property(QgsMapLayerElevationProperties.Property.ExtrusionHeight)
+            .asExpression(),
+            "1*5",
+        )
         properties = QgsPropertyCollection()
-        properties.setProperty(QgsMapLayerElevationProperties.ZOffset, QgsProperty.fromExpression('9'))
+        properties.setProperty(
+            QgsMapLayerElevationProperties.Property.ZOffset,
+            QgsProperty.fromExpression("9"),
+        )
         props.setDataDefinedProperties(properties)
         self.assertFalse(
-            props.dataDefinedProperties().isActive(QgsMapLayerElevationProperties.ExtrusionHeight))
+            props.dataDefinedProperties().isActive(
+                QgsMapLayerElevationProperties.Property.ExtrusionHeight
+            )
+        )
         self.assertEqual(
-            props.dataDefinedProperties().property(QgsMapLayerElevationProperties.ZOffset).asExpression(),
-            '9')
+            props.dataDefinedProperties()
+            .property(QgsMapLayerElevationProperties.Property.ZOffset)
+            .asExpression(),
+            "9",
+        )
 
-        sym = QgsLineSymbol.createSimple({'outline_color': '#ff4433', 'outline_width': 0.5})
+        sym = QgsLineSymbol.createSimple(
+            {"outline_color": "#ff4433", "outline_width": 0.5}
+        )
         props.setProfileLineSymbol(sym)
-        self.assertEqual(props.profileLineSymbol().color().name(), '#ff4433')
+        self.assertEqual(props.profileLineSymbol().color().name(), "#ff4433")
 
-        sym = QgsFillSymbol.createSimple({'color': '#ff4455', 'outline_width': 0.5})
+        sym = QgsFillSymbol.createSimple({"color": "#ff4455", "outline_width": 0.5})
         props.setProfileFillSymbol(sym)
-        self.assertEqual(props.profileFillSymbol().color().name(), '#ff4455')
+        self.assertEqual(props.profileFillSymbol().color().name(), "#ff4455")
 
-        sym = QgsMarkerSymbol.createSimple({'color': '#ff1122', 'outline_width': 0.5})
+        sym = QgsMarkerSymbol.createSimple({"color": "#ff1122", "outline_width": 0.5})
         props.setProfileMarkerSymbol(sym)
-        self.assertEqual(props.profileMarkerSymbol().color().name(), '#ff1122')
+        self.assertEqual(props.profileMarkerSymbol().color().name(), "#ff1122")
 
         doc = QDomDocument("testdoc")
-        elem = doc.createElement('test')
+        elem = doc.createElement("test")
         props.writeXml(elem, doc, QgsReadWriteContext())
 
         props2 = QgsVectorLayerElevationProperties(None)
@@ -109,17 +130,22 @@ class TestQgsVectorLayerElevationProperties(QgisTestCase):
         self.assertTrue(props2.extrusionEnabled())
         self.assertFalse(props2.respectLayerSymbology())
         self.assertEqual(props2.type(), Qgis.VectorProfileType.ContinuousSurface)
-        self.assertEqual(props2.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow)
+        self.assertEqual(
+            props2.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow
+        )
         self.assertTrue(props2.showMarkerSymbolInSurfacePlots())
         self.assertEqual(props2.elevationLimit(), 909)
 
-        self.assertEqual(props2.profileLineSymbol().color().name(), '#ff4433')
-        self.assertEqual(props2.profileFillSymbol().color().name(), '#ff4455')
-        self.assertEqual(props2.profileMarkerSymbol().color().name(), '#ff1122')
+        self.assertEqual(props2.profileLineSymbol().color().name(), "#ff4433")
+        self.assertEqual(props2.profileFillSymbol().color().name(), "#ff4455")
+        self.assertEqual(props2.profileMarkerSymbol().color().name(), "#ff1122")
 
         self.assertEqual(
-            props2.dataDefinedProperties().property(QgsMapLayerElevationProperties.ZOffset).asExpression(),
-            '9')
+            props2.dataDefinedProperties()
+            .property(QgsMapLayerElevationProperties.Property.ZOffset)
+            .asExpression(),
+            "9",
+        )
 
         props_clone = props.clone()
         self.assertEqual(props_clone.zScale(), 2)
@@ -130,30 +156,39 @@ class TestQgsVectorLayerElevationProperties(QgisTestCase):
         self.assertTrue(props_clone.extrusionEnabled())
         self.assertFalse(props_clone.respectLayerSymbology())
         self.assertEqual(props_clone.type(), Qgis.VectorProfileType.ContinuousSurface)
-        self.assertEqual(props_clone.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow)
+        self.assertEqual(
+            props_clone.profileSymbology(), Qgis.ProfileSurfaceSymbology.FillBelow
+        )
         self.assertTrue(props_clone.showMarkerSymbolInSurfacePlots())
         self.assertEqual(props2.elevationLimit(), 909)
 
-        self.assertEqual(props_clone.profileLineSymbol().color().name(), '#ff4433')
-        self.assertEqual(props_clone.profileFillSymbol().color().name(), '#ff4455')
-        self.assertEqual(props_clone.profileMarkerSymbol().color().name(), '#ff1122')
+        self.assertEqual(props_clone.profileLineSymbol().color().name(), "#ff4433")
+        self.assertEqual(props_clone.profileFillSymbol().color().name(), "#ff4455")
+        self.assertEqual(props_clone.profileMarkerSymbol().color().name(), "#ff1122")
 
         self.assertEqual(
-            props_clone.dataDefinedProperties().property(QgsMapLayerElevationProperties.ZOffset).asExpression(),
-            '9')
+            props_clone.dataDefinedProperties()
+            .property(QgsMapLayerElevationProperties.Property.ZOffset)
+            .asExpression(),
+            "9",
+        )
 
     def test_defaults(self):
         # a layer without z values present should default to terrain clamping mode
-        vl = QgsVectorLayer(unitTestDataPath() + '/3d/trees.shp')
+        vl = QgsVectorLayer(unitTestDataPath() + "/3d/trees.shp")
         self.assertTrue(vl.isValid())
 
-        self.assertEqual(vl.elevationProperties().clamping(), Qgis.AltitudeClamping.Terrain)
+        self.assertEqual(
+            vl.elevationProperties().clamping(), Qgis.AltitudeClamping.Terrain
+        )
 
         # a layer WITH z values present should default to relative mode
-        vl = QgsVectorLayer(unitTestDataPath() + '/3d/points_with_z.shp')
+        vl = QgsVectorLayer(unitTestDataPath() + "/3d/points_with_z.shp")
         self.assertTrue(vl.isValid())
 
-        self.assertEqual(vl.elevationProperties().clamping(), Qgis.AltitudeClamping.Relative)
+        self.assertEqual(
+            vl.elevationProperties().clamping(), Qgis.AltitudeClamping.Relative
+        )
 
     def test_show_by_default(self):
         props = QgsVectorLayerElevationProperties(None)
@@ -176,5 +211,5 @@ class TestQgsVectorLayerElevationProperties(QgisTestCase):
         self.assertTrue(props.showByDefaultInElevationProfilePlots())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
